# #!/bin/sh
#############################################
# Test script for testing clish parameters
#
# Robert Unuk   07.05.2015
#############################################
# Testfile #
#_now=$(date +"%m_%d_%Y")
_now=$(date +%Y%m%d_%H%M%S)
TEST_FILE=/etc/clish/tests/testparams.cfg
TESTS_RESULT_DIR=/tmp/tests/clish/$_now
TESTS_BACKUP_DIR=/tmp/tests/clish/bckp
TESTS_BACKUP_DIR_REBOOT=/tmp/tests/clish/bckpreboot
TESTS_RESULT_FILE=${TESTS_RESULT_DIR}/clish_test_all_cmd.log
STARTUP_CONFIG=/etc/startup-config
INTERFACES_FILE=/etc/network/interfaces
FILE_BONDSTATIC=/etc/sysconfig/bonding.static
tipc_file=/etc/opensaf/tipc_config
isSystemd=`/sbin/cfg-isSystemdInit.sh`
#############################################
# functions
#############################################
function cidr2dot()
{
# Grab input - from pipe or from positional parameters
	INPUT=${1:-$(</dev/stdin)};
	MASK=$(echo $INPUT|sed 's_.*/__')
	case $MASK in
		0) M=0.0.0.0;; 1) M=128.0.0.0;; 2) M=192.0.0.0;; 3) M=224.0.0.0;; 4) M=240.0.0.0;;
		5) M=248.0.0.0;; 6) M=252.0.0.0;; 7) M=254.0.0.0;; 8) M=255.0.0.0;;
		9) M=255.128.0.0;; 10) M=255.192.0.0;; 11) M=255.224.0.0;; 12) M=255.240.0.0;;
		13) M=255.248.0.0;; 14) M=255.252.0.0;; 15) M=255.254.0.0;; 16) M=255.255.0.0;;
		17) M=255.255.128.0;; 18) M=255.255.192.0;; 19) M=255.255.224.0;; 20) M=255.255.240.0;;
		21) M=255.255.248.0;; 22) M=255.255.252.0;; 23) M=255.255.254.0;; 24) M=255.255.255.0;;
		25) M=255.255.255.128;; 26) M=255.255.255.192;; 27) M=255.255.255.224;; 28) M=255.255.255.240;;
		29) M=255.255.255.248;; 30) M=255.255.255.252;; 31) M=255.255.255.254;; 32) M=255.255.255.255;;
	esac
	[ $M ] && echo $M
}


function check_startup_config()
{
if [ -f ${STARTUP_CONFIG} ]
then
# Hostname
	hostname=`cat ${STARTUP_CONFIG} |grep hostname | head -1 |awk '{print $2}'`
	if [ "${hostname}" != "" ]
	then
		Hostname=${hostname}
	fi
# System name
	system_name=`cat ${STARTUP_CONFIG} | grep 'system name' |awk '{print $3}'`
	if [ "${system_name}" != "" ]
	then
		System_name=${system_name}
	fi
# Local_mgmt_IP
	locmgmtip=`cat ${STARTUP_CONFIG} |grep 'ip address' |head -1 |awk '{print $3}'`
	if [ "${locmgmtip}" != "" ]
	then
		Local_mgmt_IP=${locmgmtip}
	fi
# Mgmt_IP_route
	route=`cat ${STARTUP_CONFIG} |grep 'ip route mgmt' |cut -d " " -f 4-`
	if [ "${route}" != "" ]
	then
		Mgmt_IP_route=${route}
	fi
# System_unit_nodeID	
	system_unitID=`cat ${STARTUP_CONFIG} |grep 'system unit-id' | awk '{print $3}'`
	system_nodeID=`cat ${STARTUP_CONFIG} |grep 'system unit-id' | awk '{print $5}'`
	if [ "${system_unitID}" != "" ]
	then
		System_unit_nodeID="${system_unitID} ${system_nodeID}"
	fi
# Chassis_type_size	
	chassis_typ=`cat ${STARTUP_CONFIG} |grep 'chassis type' | awk '{print $3}'`
	chassis_size=`cat ${STARTUP_CONFIG} |grep 'chassis type' | awk '{print $5}'`
	if [ "${chassis_type}" != "" ]
	then
		Chassis_type_size="${chassis_typ} ${chassis_size}"
	fi
# Domain_name
	domainname=`cat ${STARTUP_CONFIG} |grep 'domain-name' | head -1 |awk '{print $2}'`
	if [ "${domainname}" != "" ]
	then
		Domain_name=${domainname}
	fi	
    
# InternetConnectivity
	internetionnectivity=`cat ${STARTUP_CONFIG} |grep 'internet-connection' | awk '{print $2}'`
	if [ "${internetionnectivity}" != "" ]
	then
		InternetConnectivity=${internetionnectivity}
	fi	    

# NtpServerLocation
	ntpserverlocation=`cat ${STARTUP_CONFIG} |grep 'ntp-server-location' | awk '{print $2}'`
	if [ "${ntpserverlocation}" != "" ]
	then
		NtpServerLocation=${ntpserverlocation}
	fi	 
    
# Primary_NTP_server
	prNtpSer=`cat ${STARTUP_CONFIG} |grep 'ntp-server primary' | awk '{print $3}'`
	if [ "${prNtpSer}" != "" ]
	then
		Primary_NTP_server=${prNtpSer}
	fi	

# Secondary_NTP_server
	secNtpSer=`cat ${STARTUP_CONFIG} |grep 'ntp-server secondary' | awk '{print $3}'`
	if [ "${secDnsSer}" != "" ]
	then
		Secondary_NTP_server=${secNtpSer}
	fi	

# Tertiary_NTP_server
	terNtpSer=`cat ${STARTUP_CONFIG} |grep 'ntp-server tertiary' | awk '{print $3}'`
	if [ "${terNtpSer}" != "" ]
	then
		Tertiary_NTP_server=${terNtpSer}
	fi

# Primary_DNS_server
	prDnsSer=`cat ${STARTUP_CONFIG} |grep 'dns-server primary' | awk '{print $3}'`
	if [ "${prDnsSer}" != "" ]
	then
		Primary_DNS_server=${prDnsSer}
	fi	

# Secondary_DNS_server
	secDnsSer=`cat ${STARTUP_CONFIG} |grep 'dns-server secondary' | awk '{print $3}'`
	if [ "${secDnsSer}" != "" ]
	then
		Secondary_DNS_server=${secDnsSer}
	fi	

# Tertiary_DNS_server
	terDnsSer=`cat ${STARTUP_CONFIG} |grep 'dns-server tertiary' | awk '{print $3}'`
	if [ "${terDnsSer}" != "" ]
	then
		Tertiary_DNS_server=${terDnsSer}
	fi

# Static_host
	sthost=`cat ${STARTUP_CONFIG} |grep 'host add' | head -1 | awk '{print $3 " " $4}'`
	if [ "${sthost}" != "" ]
	then
		Static_host=${sthost}
	fi
# Timezone
	timezone=`cat ${STARTUP_CONFIG} |grep timezone | head -1 |awk '{print $2}'`
	if [ "${timezone}" != "" ]
	then
		Timezone=${timezone}
	fi
# Filter_name
	fname=`cat ${STARTUP_CONFIG} |grep "filter $Filter_name" | awk '{printf $2}'`
	if [ "${fname}" != "" ]
	then
		Filter_name=${fname}
	fi
	
############################# system is duplicated

	if [ "$System_type" == "duplicated" ]
	then 
		product_name=$(awk '/product/ {print $2}' ${STARTUP_CONFIG})
		# HSB_mgmt_float_IP
		hsb_mgmtfloat=`cat ${STARTUP_CONFIG} |grep 'ip address mgmt float' | awk '{ printf $5}'`	
		if [ "${hsb_mgmtfloat}" != "" ]
		then
			HSB_mgmt_float_IP=${hsb_mgmtfloat}
		fi
		# HSB_local_INT_IP
		if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]
		then
			# first get board node ID
			node=`cat ${STARTUP_CONFIG} | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
			if [ "$node" == "1" ]
			then
			# I am node 1
				hsb_intIpLoc=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 1/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
			else
			# I am node 2
				hsb_intIpLoc=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 2/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
			fi
		elif [ -f ${FILE_BONDSTATIC} ]
		then
			# first get board node ID
			node=`cat ${STARTUP_CONFIG} | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
			if [ "$node" == "1" ]
			then
			# I am node 1
				hsb_intIpLoc=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}' | sed 's/\$S_NODE/1/g'`
			else
			# I am node 2
				hsb_intIpLoc=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}' | sed 's/\$S_NODE/2/g'`
			fi
		else
			hsb_intIpLoc=`cat ${STARTUP_CONFIG} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' ip address internal' |  grep -vw '  ip address internal' |awk '{print $4}'`
		fi
		if [ "${hsb_intIpLoc}" != "" ]
		then
			HSB_local_INT_IP=${hsb_intIpLoc}
		fi
		# HSB_remote_host
		hsb_remhost=`cat ${STARTUP_CONFIG} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' hostname' | awk '{print $2}'`
		if [ "${hsb_remhost}" != "" ]
		then
			HSB_remote_host=${hsb_remhost}
		fi
		
		# HSB_remote_host_mgmt_IP
		remhostmgmIp=`cat ${STARTUP_CONFIG} | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address mgmt' | awk '{print $4}'`
		if [ "${remhostmgmIp}" != "" ]
		then
			HSB_remote_host_mgmt_IP=${remhostmgmIp}
		fi
	    
		# HSB_remote_host_INT_IP
		if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]
		then
		# first get board node ID
			node=`cat ${STARTUP_CONFIG} | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
			if [ "$node" == "1" ]
			then
		    # I am node 1 - need to return internal IP address of node 2
				remhstintIp=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 2/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
			else
		    # I am node 2 - need to return internal IP address of node 1
				remhstintIp=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 1/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
			fi
		elif [ -f ${FILE_BONDSTATIC} ]
		then
			node=`cat ${STARTUP_CONFIG} | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
			if [ "$node" == "1" ]
			then
				# I am node 1 - need to return internal IP address of node 2
				remhstintIp=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}' | sed 's/\$S_NODE/2/g'`
			else
				# I am node 2 - need to return internal IP address of node 1
				remhstintIp=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}' | sed 's/\$S_NODE/1/g'`
			fi
		else
			remhstintIp=`cat ${STARTUP_CONFIG} | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address internal' |awk '{print $4}'`
		fi
		if [ "${remhstintIp}" != "" ]
		then
			HSB_remote_host_INT_IP=${remhstintIp}
		fi	
	    
		# HSB_internal_vlan
		if [ -f ${FILE_BONDSTATIC} ]
		then
			vlanint="2005"
		else
			vlanint=`cat ${STARTUP_CONFIG} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'vlan internal' | awk '{print $3}'`
		fi
		if [ "${vlanint}" != "" ]
		then
			HSB_internal_vlan=${vlanint}
		fi
		# HSB_internal_interface
		if [ -f ${FILE_BONDSTATIC} ]
		then
			intIface=""
		else
			intIface=`cat ${STARTUP_CONFIG} |awk '/hsb/{p=1} /!/{p=0} p' | grep 'internal interface' | awk '{print $3}'`
		fi
		if [ "${intIface}" != "" ]
		then
			HSB_internal_interface=${intIface}
		fi
	fi
############################# system is geo
	if [ "$System_type" == "geo-single" ] || [ "$System_type" == "geo-dual" ]
	then 
	
# GEO_mgmt_float_IP
		geoflt=`cat ${STARTUP_CONFIG} |grep "ip address mgmt geofloat ${GEO_mgmt_float_IP}"`
		if [ "${geoflt}" != "" ]
		then
			GEO_mgmt_float_IP=${geoflt}
		fi	
# GEO_preferred_unit
		geoprun=`cat ${STARTUP_CONFIG} |grep "ip address mgmt geofloat ${GEO_preferred_unit}"`
		if [ "${geoprun}" != "" ]
		then
			GEO_preferred_unit=${geoprun}
		fi	
# GEO_mode
		geomod=`cat ${STARTUP_CONFIG} |grep "geo-mode ${GEO_mode}"`
		if [ "${geomod}" != "" ]
		then
			GEO_mode=${geomod}
		fi
# GEO_switchover_timeout
		geoswto=`cat ${STARTUP_CONFIG} |grep "geo-switchover timeout ${GEO_switchover_timeout}"`
		if [ "${geoswto}" != "" ]
		then
			GEO_switchover_timeout=${geoswto}
		fi
# GEO_remote_unit_internal_vlan
		geoRemIntVlan=`cat ${STARTUP_CONFIG} |grep "remote vlan internal ${GEO_remote_unit_internal_vlan}"`	
		if [ "${geoRemIntVlan}" != "" ]
		then
			GEO_remote_unit_internal_vlan=${geoRemIntVlan}
		fi
# GEO_remote_unit_mgmt_float_IP
		geoRemFlIp=`cat ${STARTUP_CONFIG} |grep "remote ip address mgmt float ${GEO_remote_unit_mgmt_float_IP}"`
		if [ "${geoRemFlIp}" != "" ]
		then
			GEO_remote_unit_mgmt_float_IP=${geoRemFlIp}
		fi
# GEO_remote_hostname_1 
		geoRemHst1=`cat ${STARTUP_CONFIG} |grep "remote node-id 1 hostname ${GEO_remote_hostname_1}"`
		if [ "${geoRemHst1}" != "" ]
		then
			GEO_remote_hostname_1=${geoRemHst1}
		fi
# GEO_remote_host_1_mgmt_IP
		geoRemHst1Ip=`cat ${STARTUP_CONFIG} |grep "ip address mgmt ${GEO_remote_host_1_mgmt_IP}"`
		if [ "${geoRemHst1Ip}" != "" ]
		then
			GEO_remote_host_1_mgmt_IP=${geoRemHst1Ip}
		fi
# GEO_remote_host_1_INT_IP
		geoRemHst1IntIp=`cat ${STARTUP_CONFIG} |grep "ip address internal ${GEO_remote_host_1_INT_IP}"`
		if [ "${geoRemHst1IntIp}" != "" ]
		then
			GEO_remote_host_1_INT_IP=${geoRemHst1IntIp}
		fi
# GEO_remote_hostname_2
		geoRemHst2=`cat ${STARTUP_CONFIG} |grep "remote node-id 2 hostname ${GEO_remote_hostname_2}"`
		if [ "${geoRemHst2}" != "" ]
		then
			GEO_remote_hostname_2=${geoRemHst2}
		fi
# GEO_remote_host_2_mgmt_IP
		geoRemHst2Ip=`konf -- -d |grep "ip address mgmt ${GEO_remote_host_2_mgmt_IP}"`
		if [ "${geoRemHst2Ip}" != "" ]
		then
			GEO_remote_host_2_mgmt_IP=${geoRemHst2Ip}
		fi
# GEO_remote_host_2_INT_IP
		geoRemHst2IntIp=`konf -- -d |grep "ip address internal ${GEO_remote_host_2_INT_IP}"`
		if [ "${geoRemHst2IntIp}" != "" ]
		then
			GEO_remote_host_2_INT_IP=${geoRemHst2IntIp}
		fi	
	fi
fi
}

function backup_files()
{
arrbckpfls[0]='/etc/hosts'
arrbckpfls[1]='/etc/hostname'
if [ "$isSystemd" == "NO" ]
then
	arrbckpfls[2]='/etc/network/interfaces'
else
	arrbckpfls[2]='/etc/systemd/network/\*'
fi
arrbckpfls[3]='/etc/resolv.conf'
arrbckpfls[4]='/etc/bind/named.conf.options'
arrbckpfls[5]='/etc/ntp.conf'
arrbckpfls[6]='/etc/localtime'
arrbckpfls[7]='/etc/snmp/snmpd.conf'
arrbckpfls[8]='/opt/iskratel/bin/niesubag.ini'
arrbckpfls[9]='/etc/ha.d/haresources'
arrbckpfls[10]='/etc/ha.d/ha.cf'
arrbckpfls[11]='/etc/hostname.redundant'
arrbckpfls[12]='/opt/iskratel/etc/ham.d/ham.cf'
arrbckpfls[13]='/opt/iskratel/etc/ham.d/gham.cf.geo'
arrbckpfls[14]='/opt/iskratel/etc/ham.d/gham.cf'
arrbckpfls[15]='/etc/drbd.conf'
arrbckpfls[16]='/etc/opensaf/tipc_config'
arrbckpfls[17]='/etc/startup-config'
arrbckpfls[18]='/root/.ssh/authorized_keys'
arrbckpfls[19]='/opt/si2000/neroot/.ssh/authorized_keys'

if [ "$1" = "backuping" ]
then
#backup files
	for i in "${arrbckpfls[@]}"
	do
	   :
	#   j=$i
		if [ -f $i ]
		then
			cp $i $TESTS_BACKUP_DIR
		fi
	done
fi

if [ "$1" = "copyresultfiles" ]
then
#copy result files
	for i in "${arrbckpfls[@]}"
	do
	   :
	#   j=$i
		if [ -f $i ]
		then
			if [ "${Phase_install}" != "formatted" ]
			then	
				cp $i $TESTS_RESULT_DIR
			else
				if [ "$i" != "/etc/hostname.redundant" ]
				then
					cp $i $TESTS_RESULT_DIR
				fi
			fi
		
			if [ "$i" == "/etc/localtime" ]
			then
				LOCTIMELINK=`ls -l /etc/localtime |awk '{print $(NF-2),"\t",$NF}'`
				cat > $TESTS_RESULT_DIR/localtime.link << EOF
${LOCTIMELINK}
EOF
				cp $TESTS_RESULT_DIR/localtime.link $TESTS_RESULT_DIR/localtime
				rm $TESTS_RESULT_DIR/localtime.link
			fi
		fi
	done
fi
# copyresult for after reboot
if [ "$1" = "copyresultfilesafterreboot" ]
then
#copy result files
	for i in "${arrbckpfls[@]}"
	do
	   :
	#   j=$i
		if [ -f $i ]
		then
			if [ "${Phase_install}" != "formatted" ]
			then	
				cp $i $TESTS_BACKUP_DIR_REBOOT
			else
				if [ "$i" != "/etc/hostname.redundant" ]
				then
					cp $i $TESTS_BACKUP_DIR_REBOOT
				fi
			fi
		
			if [ "$i" == "/etc/localtime" ]
			then
				LOCTIMELINK=`ls -l /etc/localtime |awk '{print $(NF-2),"\t",$NF}'`
				cat > $TESTS_RESULT_DIR/localtime.link << EOF
${LOCTIMELINK}
EOF
				cp $TESTS_RESULT_DIR/localtime.link $TESTS_RESULT_DIR/localtime
				rm $TESTS_RESULT_DIR/localtime.link
			fi
		fi
	done
fi


if [ "$1" = "restoring" ]
then
#restore files
	for i in "${arrbckpfls[@]}"
	do
	   :
	#   j=$i
		if [ -f $i ]
		then
			j=${i##*/}
			cp $TESTS_BACKUP_DIR/$j $i
		fi
	done
fi

}

function checkstdalparams()
{
arrstdal[0]='Hostname'
arrstdal[1]='System_unit_nodeID'
arrstdal[2]='Chassis_type_size'
arrstdal[3]='Domain_name'
arrstdal[4]='Local_mgmt_IP'
arrstdal[5]='Mgmt_IP_route'
arrstdal[6]='Primary_DNS_server'
arrstdal[7]='Secondary_DNS_server'
arrstdal[8]='Tertiary_DNS_server'
arrstdal[9]='Primary_NTP_server'
arrstdal[10]='Secondary_NTP_server'
arrstdal[11]='Tertiary_NTP_server'
arrstdal[12]='Static_host'
arrstdal[13]='Timezone'
arrstdal[14]='Filter_name'
arrstdal[15]='vlanadd1'
arrstdal[16]='Pingserver'

for i in "${arrstdal[@]}"
do
   :
	j=$i
	match=`cat $TEST_FILE | grep $i`
	if [ "$match" == "" ]
	then
		echo "Error parameter $i is not defined in $TEST_FILE !!!"
		exit 1
	fi
	# Check value of value
	eval i=\$$i
	if [ "${i}" == "" ]
	then
		printf "${YELLOW}Warrning no default value of $j exsist in $TEST_FILE !!!${NC}\n"
	fi

done
}

function usage()
{
echo
echo "Usage:"
echo ""
echo "test-clish-parameters.sh <system_type> <system_state> [use-startup-config]"
echo ""
echo "<system_type>:         standalone   (standalone system)"
echo "                       duplicated   (duplicated system)"
echo "                       geo-dual     (geo-dual system)"
echo ""
echo "<system_state>:        formatted    (only basic FS installed - format with ISO image)"
echo "                       runtime      (installed and running ESP or ESP + APP)"
echo ""
echo "use-startup-config:    if this flag is set, value of each tested parameter will be read"
echo "                       and used from /etc/startup-config. If value not present in"
echo "                       /etc/startup-config it will be read from test params file"
echo "                       /etc/clish/tests/testparams.cfg. If this flag not set, all"
echo "                       values will be read from /etc/clish/tests/testparams.cfg"
echo ""
echo "no-console:	     if this flag is set, tests will be executed over ssh "
echo "                       if not set, test is executed with console"
echo ""
echo "Results are saved in /tmp/clish/tests/clish_test_all_cmd.log"
echo "Running test on cmj board can cause temporary network connectivity so test execution via console is preferred"
echo
}

function checkduplparams()
{
arrdupl[0]=HSB_mgmt_float_IP
arrdupl[1]=HSB_local_INT_IP
arrdupl[2]=HSB_remote_host
arrdupl[3]=HSB_remote_host_mgmt_IP
arrdupl[4]=HSB_remote_host_INT_IP
arrdupl[5]=HSB_internal_vlan
arrdupl[6]=HSB_internal_interface
for i in "${arrdupl[@]}"
do
   :
	match=`cat $TEST_FILE | grep $i`
	if [ "$match" == "" ]
	then
		echo "Error parameter $i is not defined in $TEST_FILE !!!"
		exit 1
	fi
done
}

function checkgeoparams()
{
arrgeo[0]=GEO_mgmt_float_IP
arrgeo[1]=GEO_preferred_unit
arrgeo[2]=GEO_mode
arrgeo[3]=GEO_switchover_timeout
arrgeo[4]=GEO_remote_unit_internal_vlan
arrgeo[5]=GEO_remote_unit_mgmt_float_IP
arrgeo[6]=GEO_remote_hostname_1
arrgeo[7]=GEO_remote_host_1_mgmt_IP
arrgeo[8]=GEO_remote_host_1_INT_IP
arrgeo[9]=GEO_remote_hostname_2
arrgeo[10]=GEO_remote_host_2_mgmt_IP
arrgeo[11]=GEO_remote_host_2_INT_IP

for i in "${arrgeo[@]}"
do
   :
	match=`cat $TEST_FILE | grep $i`
	if [ "$match" == "" ]
	then
		echo "Error parameter $i is not defined in $TEST_FILE !!!"
		exit 1
	fi
done
}


function chktestfileparams()
{
if [ "$System_type" == "standalone" ]
then 
	checkstdalparams
fi

if [ "$System_type" == "duplicated" ]
then 
	checkstdalparams
	checkduplparams
fi
}

if [ "$System_type" == "geo-single" ] || [ "$System_type" == "geo-dual" ]
then 
	checkstdalparams
	checkgeoparams
fi

function chkCeProduct()
{
export ceproduct="0"
if [ -f /etc/sysconfig/bonding.static ]
then
	ceproduct="1"
fi
}

function hostname_running()
{
if [ "${Hostname}" != "" ]
then
	echo "hostname $Hostname" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	hostname=`konf -- -d |grep hostname | head -1 | awk '{ printf $2}'`
fi
if [ "$hostname" == "$Hostname" ]
then
	printf "${GREEN}Hostname running OK${NC}\n"
	echo "Hostname running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Hostname running NOK${NC}\n"
	echo "Hostname running NOK" >> $TESTS_RESULT_FILE
fi
}

function hostname_files()
{
hostname_file=`cat /etc/hosts| grep  $Hostname`
if [ "${hostname_file}" != "" ]
then 
	printf "${GREEN}Hostname files OK${NC}\n"
	echo "Hostname files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Hostname files NOK${NC}\n"
	echo "Hostname files NOK" >> $TESTS_RESULT_FILE
fi
}

function hostname_service()
{
hostname_service=`hostname |sed 's/ha-//'`
if [ ${hostname_service} == "$Hostname" ] 
then
	printf "${GREEN}Hostname service OK${NC}\n"
	echo "Hostname service OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Hostname service NOK${NC}\n"
	echo "Hostname service NOK" >> $TESTS_RESULT_FILE
fi
}

function systemname_running()
{
if [ "${System_name}" != "" ]
then
	echo "system name $System_name" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	hostname=`konf -- -d |grep 'system name' | head -1 | awk '{ printf $3}'`
fi
if [ "$system_name" == "$System_name" ]
then
	printf "${GREEN}System name running OK${NC}\n"
	echo "System name running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}System name running NOK${NC}\n"
	echo "System name running NOK" >> $TESTS_RESULT_FILE
fi
}

function systemname_files()
{
printf "${GREEN}System name files N.P.${NC}\n"
echo "System name files N.P." >> $TESTS_RESULT_FILE
}

function systemname_service()
{
printf "${GREEN}System name service N.P.${NC}\n"
echo "System name service N.P." >> $TESTS_RESULT_FILE
}

function mgmtip_running()
{
cat > /tmp/infmgmt <<EOF
interface mgmt
 ip address ${Local_mgmt_IP}
EOF
if [ "${Local_mgmt_IP}" != "" ]
then
	cat /tmp/infmgmt | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep -v filter |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	local_mgmt_ip=`konf -- -d| awk '/interface mgmt/{p=1} /!/{p=0} p' | grep -v filter |grep 'ip address' | awk '{print $3}'`
fi

if [ "$local_mgmt_ip" == "$Local_mgmt_IP" ]
then
	printf "${GREEN}Local mgmt IP running OK${NC}\n"
	echo "Local mgmt IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Local mgmt IP running NOK${NC}\n"
	echo "Local mgmt IP running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/infmgmt
}

function mgmtip_files()
{
if [ "$isSystemd" == "NO" ]
then
	LocMgmIp=`echo "$Local_mgmt_IP" | sed 's/\(.*\).../\1/'`
	ipmgmt_file=`cat /etc/network/interfaces| grep  $LocMgmIp`
else
	ipmgmt_file=`cat /etc/systemd/network/bond0.network| grep  "$Local_mgmt_IP"`
fi

if [ "${ipmgmt_file}" != "" ]
then 
	printf "${GREEN}Local mgmt IP files OK${NC}\n"
	echo "Local mgmt IP files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Local mgmt IP files NOK${NC}\n"
	echo "Local mgmt IP files NOK" >> $TESTS_RESULT_FILE
fi
}

function mgmtip_service()
{
LocMgmIp=`echo "$Local_mgmt_IP" | sed 's/\(.*\).../\1/'`
if ping -c 1 $LocMgmIp &> /dev/null
then
	mgmtip_service="1"
else
	mgmtip_service="0"
fi

if [ ${mgmtip_service} == "1" ] 
then
	printf "${GREEN}Local mgmt IP service OK${NC}\n"
	echo "Local mgmt IP service OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Local mgmt IP service NOK${NC}\n"
	echo "Local mgmt IP service NOK" >> $TESTS_RESULT_FILE
fi
}

function systype_running()
{
if [ "${System_type}" != "" ]
then
	echo "system type ${System_type}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	system_type=`konf -- -d |grep 'system type' | awk '{ printf $3}'`
fi
if [ "${system_type}" == "${System_type}" ]
then
	printf "${GREEN}System type running OK${NC}\n"
	echo "System type running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}System type running NOK${NC}\n"
	echo "System type running NOK" >> $TESTS_RESULT_FILE
fi
}

function systype_files()
{
system_type=`konf -- -d |grep 'system type' | awk '{ printf $3}'`
if [ "${system_type}" == "standalone" ]
then
	printf "${GREEN}System type files N.P.${NC}\n"
	echo "System type files N.P." >> $TESTS_RESULT_FILE
else
	printf "${GREEN}System type files N.P.${NC}\n"
	echo "System type files N.P." >> $TESTS_RESULT_FILE
fi
}

function systype_service()
{
printf "${GREEN}System type service N.P.${NC}\n"
echo "System type service N.P." >> $TESTS_RESULT_FILE
}

function sysUnitNode_running()
{
if [ "${System_unit_nodeID}" != "" ]
then
	UnID=`echo "$System_unit_nodeID" |awk '{printf $1}'`
	NodeID=`echo "$System_unit_nodeID" |awk '{printf $2}'`
	echo "system unit-id ${UnID} node-id ${NodeID}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
fi
unID=`konf -- -d |grep 'system unit-id' | awk '{ printf $3}'`
nodeID=`konf -- -d |grep 'system unit-id' | awk '{ printf $5}'`
if [ "${unID}" == "${UnID}" ] && [ "${nodeID}" == "${NodeID}" ]
then
	printf "${GREEN}System unit/node ID running OK${NC}\n"
	echo "System unit/node ID OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}System unit/node ID running NOK${NC}\n"
	echo "System unit/node ID running NOK" >> $TESTS_RESULT_FILE
fi
}

function sysUnitNode_files()
{
printf "${GREEN}System unit/node ID files N.P.${NC}\n"
echo "System unit/node ID files N.P." >> $TESTS_RESULT_FILE
}

function sysUnitNode_service()
{
printf "${GREEN}System unit/node ID service N.P.${NC}\n"
echo "System unit/node ID service N.P." >> $TESTS_RESULT_FILE
}

function check_dhcpd_files()
{
if [ "${ChType}" == "MED" ]
then 
	if [ -f /etc/dhcpd.conf.med.${ChSize} ]
	then
		DIFF=`diff /etc/dhcpd.conf /etc/dhcpd.conf.med.${ChSize}`
		if [ "$DIFF" != "" ]
		then
			printf "${RED}Eroor in /etc/dhcpd.conf file${NC}\n"
			echo "Eroor in /etc/dhcpd.conf file" >> $TESTS_RESULT_FILE
		fi
		cp /etc/dhcpd.conf.med.${ChSize} ${TESTS_RESULT_DIR}
	fi
fi
}

function Chassis_type_size_running()
{
if [ "${Chassis_type_size}" != "" ]
then
	ChType=`echo "$Chassis_type_size" |awk '{printf $1}'`
	ChSize=`echo "$Chassis_type_size" |awk '{printf $2}'`
	echo "chassis type ${ChType} size ${ChSize}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
fi
chType=`konf -- -d |grep 'chassis type' | awk '{ printf $3}'`
chSize=`konf -- -d |grep 'chassis type' | awk '{ printf $5}'`
if [ "${chType}" == "${ChType}" ] && [ "${chSize}" == "${ChSize}" ]
then
	printf "${GREEN}Chassis type/size OK${NC}\n"
	echo "Chassis type/size OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Chassis type/size NOK${NC}\n"
	echo "Chassis type/size NOK" >> $TESTS_RESULT_FILE
fi
# check dhcpd.conf.med.x files for CE product
chkCeProduct
if [ "${ceproduct}" == "1" ]
then
	check_dhcpd_files
fi
}

function Chassis_type_size_files()
{
printf "${GREEN}Chassis type/size files N.P.${NC}\n"
echo "Chassis type/size files N.P." >> $TESTS_RESULT_FILE
}

function Chassis_type_size_service()
{
printf "${GREEN}Chassis type/size service N.P.${NC}\n"
echo "Chassis type/size service N.P." >> $TESTS_RESULT_FILE
}

function domain_name_running()
{
if [ "${Domain_name}" != "" ]
then
	echo "domain-name $Domain_name" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	domain_name=`konf -- -d |grep 'domain-name' | awk '{ printf $2}'`
fi
if [ "${domain_name}" == "${Domain_name}" ]
then
	printf "${GREEN}Domain name running OK${NC}\n"
	echo "Domain name running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Domain name running NOK${NC}\n"
	echo "Domain name running NOK" >> $TESTS_RESULT_FILE
fi
}
function domain_name_files()
{
domain_name=`cat /etc/resolv.conf| grep  $Domain_name`
if [ "${domain_name}" != "" ]
then
	printf "${GREEN}Domain name files OK${NC}\n"
	echo "Domain name files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Domain name files NOK${NC}\n"
	echo "Domain name files NOK" >> $TESTS_RESULT_FILE
fi
}
function domain_name_service()
{
printf "${GREEN}Domain name service N.P.${NC}\n"
echo "Domain name service N.P." >> $TESTS_RESULT_FILE
}

function mgmtroute_running()
{
if [ "${Mgmt_IP_route}" != "" ]
then
	echo "ip route mgmt $Mgmt_IP_route" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	mgmt_IP_route=`konf -- -d |grep 'ip route mgmt' |awk '{print substr($0, index($0, $4))}'`
fi
if [ "${mgmt_IP_route}" == "${Mgmt_IP_route}" ]
then
	printf "${GREEN}Mgmt IP route running OK${NC}\n"
	echo "Mgmt IP route running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Mgmt IP route running NOK${NC}\n"
	echo "Mgmt IP route running NOK" >> $TESTS_RESULT_FILE
fi

}
function mgmtroute_files()
{
if [ "$isSystemd" == "NO" ]
then
	mgmtroute=`cat /etc/network/interfaces |grep 'route add -net' |awk '{for(z=1;z<=4;z++)$z="";$0=$0;$1=$1}1'  |awk '{z=2;$z="";$0=$0;$1=$1}1' |awk '{z=3;$z="";$0=$0;$1=$1}1'`
else
	gw=`grep Gateway /etc/systemd/network/bond0.network | cut -d'=' -f2`
	subnet=`grep Destination /etc/systemd/network/bond0.network | cut -d'=' -f2`
	network=`echo $subnet | cut -d'/' -f1`
	mask=`echo $subnet | cut -d'/' -f2| cidr2dot `
	mgmtroute="$network $mask $gw"
fi

if [ "${mgmtroute}" == "${Mgmt_IP_route}" ]
then
	printf "${GREEN}Mgmt IP route files OK${NC}\n"
	echo "Mgmt IP route files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Mgmt IP route files NOK${NC}\n"
	echo "Mgmt IP route files NOK" >> $TESTS_RESULT_FILE
fi
}
function mgmtroute_service()
{
Gw=`echo "${Mgmt_IP_route}"  |awk '{for(z=1;z<=2;z++)$z="";$0=$0;$1=$1}1'`
mgmtroute_service=`route -n | grep ${Gw} |awk '{for(z=4;z<=10;z++)$z="";$0=$0;$1=$1}1' | awk ' { t = $2; $2 = $3; $3 = t; print; } '`
if [ "${mgmtroute_service}" == "${Mgmt_IP_route}" ]
then
	printf "${GREEN}Mgmt IP route service OK${NC}\n"
	echo "Mgmt IP route service OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Mgmt IP route service NOK${NC}\n"
	echo "Mgmt IP route service NOK" >> $TESTS_RESULT_FILE
fi
}

function PrDNSer_running()
{
if [ "${Primary_DNS_server}" != "" ]
then
	echo "dns-server primary $Primary_DNS_server" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	prDnsSer=`konf -- -d |grep 'dns-server primary' | awk '{ printf $3}'`
fi
if [ "${prDnsSer}" == "$Primary_DNS_server" ]
then
	printf "${GREEN}Primary DNS server running OK${NC}\n"
	echo "Primary DNS server running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Primary DNS server running NOK${NC}\n"
	echo "Primary DNS server running NOK" >> $TESTS_RESULT_FILE
fi
}
function PrDNSer_files()
{
dnspr=`cat /etc/bind/named.conf.options |grep ${Primary_DNS_server}`
if [ "${dnspr}" != "" ]
then
	printf "${GREEN}Primary DNS server files OK${NC}\n"
	echo "Primary DNS server files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Primary DNS server files NOK${NC}\n"
	echo "Primary DNS server files NOK" >> $TESTS_RESULT_FILE
fi
}
function PrDNSer_service()
{
testping=`ping -c 1 ${Primary_DNS_server}`
if [ "$?" == "0" ]
then
	printf "${GREEN}Primary DNS server service OK${NC}\n"
	echo "Primary DNS server service OK" >> $TESTS_RESULT_FILE
	DnsOK="1"
else
	# printf "${RED}Please check DNS service !${NC}\n"
	# echo "Please check DNS service !" >> $TESTS_RESULT_FILE
	printf "${RED}Primary DNS server not reachable !${NC}\n"
	echo "Primary DNS server not reachable !" >> $TESTS_RESULT_FILE
fi
}

function SecDNSer_running()
{
if [ "${Secondary_DNS_server}" != "" ]
then
	echo "dns-server secondary $Secondary_DNS_server" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	secDnsSer=`konf -- -d |grep 'dns-server secondary' | awk '{ printf $3}'`
fi
if [ "${secDnsSer}" == "$Secondary_DNS_server" ]
then
	printf "${GREEN}Secondary DNS server running OK${NC}\n"
	echo "Secondary DNS server running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Secondary DNS server running NOK${NC}\n"
	echo "Secondary DNS server running NOK" >> $TESTS_RESULT_FILE
fi
}
function SecDNSer_files()
{
dnssec=`cat /etc/bind/named.conf.options |grep ${Secondary_DNS_server}`
if [ "${dnssec}" != "" ]
then
	printf "${GREEN}Secondary DNS server files OK${NC}\n"
	echo "Secondary DNS server files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Secondary DNS server files NOK${NC}\n"
	echo "Secondary DNS server files NOK" >> $TESTS_RESULT_FILE
fi
}
function SecDNSer_service()
{
testping=`ping -c 1 ${Secondary_DNS_server}`
if [ "$?" == "0" ]
then
	printf "${GREEN}Secondary DNS server service OK${NC}\n"
	echo "Secondary DNS server service OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Secondary DNS server not reachable !${NC}\n"
	echo "Secondary DNS server not reachable !" >> $TESTS_RESULT_FILE
fi
}

function TerDNSer_running()
{
if [ "${Tertiary_DNS_server}" != "" ]
then
	echo "dns-server tertiary $Tertiary_DNS_server" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	terDnsSer=`konf -- -d |grep 'dns-server tertiary' | awk '{ printf $3}'`
fi
if [ "${terDnsSer}" == "$Tertiary_DNS_server" ]
then
	printf "${GREEN}Tertiary DNS server running OK${NC}\n"
	echo "Tertiary DNS server running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Tertiary DNS server running NOK${NC}\n"
	echo "Tertiary DNS server running NOK" >> $TESTS_RESULT_FILE
fi
}

function TerDNSer_files()
{
dnster=`cat /etc/bind/named.conf.options |grep ${Tertiary_DNS_server}`
if [ "${dnster}" != "" ]
then
	printf "${GREEN}Tertiary DNS server files OK${NC}\n"
	echo "Tertiary DNS server files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Tertiary DNS server files NOK${NC}\n"
	echo "Tertiary DNS server files NOK" >> $TESTS_RESULT_FILE
fi
}

function TerDNSer_service()
{
testping=`ping -c 1 ${Tertiary_DNS_server}`
if [ "$?" == "0" ]
then
	printf "${GREEN}Tertiary DNS server service OK${NC}\n"
	echo "Tertiary DNS server service OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Tertiary DNS server not reachable !${NC}\n"
	echo "Tertiary DNS server not reachable !" >> $TESTS_RESULT_FILE
fi
}

################################################
function internetConnectivity_running()
{
if [ "${InternetConnectivity}" != "" ]
then
	echo "internet-connection $InternetConnectivity" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
fi
internetConn=`konf -- -d |grep 'internet-connection' | awk '{ printf $2}'`
if [ "${internetConn}" == "$InternetConnectivity" ]
then
	printf "${GREEN}Internet connectivity running OK${NC}\n"
	echo "Internet connectivity running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Internet connectivity running NOK${NC}\n"
	echo "Internet connectivity running NOK" >> $TESTS_RESULT_FILE
fi
}

function internetConnectivity_files()
{
printf "${GREEN}Internet connectivity files N.P.${NC}\n"
echo "Internet connectivity files N.P." >> $TESTS_RESULT_FILE
}

function internetConnectivity_service()
{
printf "${GREEN}Internet connectivity service N.P.${NC}\n"
echo "Internet connectivity service N.P." >> $TESTS_RESULT_FILE
}

function ntpServerLocation_running()
{
if [ "${NtpServerLocation}" != "" ]
then
	echo "ntp-server-location $NtpServerLocation" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
fi
ntpSrvLoc=`konf -- -d |grep 'ntp-server-location' | awk '{ printf $2}'`
if [ "${ntpSrvLoc}" == "$NtpServerLocation" ]
then
	printf "${GREEN}Ntp server location running OK${NC}\n"
	echo "Ntp server location running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Ntp server location running NOK${NC}\n"
	echo "Ntp server location running NOK" >> $TESTS_RESULT_FILE
fi
}

function ntpServerLocation_files()
{
printf "${GREEN}Ntp server location files N.P.${NC}\n"
echo "Ntp server location files N.P." >> $TESTS_RESULT_FILE
}

function ntpServerLocation_service()
{
printf "${GREEN}Internet connectivity service N.P.${NC}\n"
echo "Ntp server location service N.P." >> $TESTS_RESULT_FILE
}

################################################
function PrNTPSer_running()
{
if [ "${Primary_NTP_server}" != "" ]
then
	echo "ntp-server primary $Primary_NTP_server" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
fi
prNTPSer=`konf -- -d |grep 'ntp-server primary' | awk '{ printf $3}'`
if [ "${prNTPSer}" == "$Primary_NTP_server" ]
then
	printf "${GREEN}Primary NTP server running OK${NC}\n"
	echo "Primary NTP server running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Primary NTP server running NOK${NC}\n"
	echo "Primary NTP server running NOK" >> $TESTS_RESULT_FILE
fi
}

function PrNTPSer_files()
{
if [ "${Primary_NTP_server}" != "" ]
then
	ntppr=`cat /etc/ntp.conf |grep ${Primary_NTP_server}`
fi
if [ "${ntppr}" != "" ]
then
	printf "${GREEN}Primary NTP server files OK${NC}\n"
	echo "Primary NTP server files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Primary NTP server files NOK${NC}\n"
	echo "Primary NTP server files NOK" >> $TESTS_RESULT_FILE
fi
}

function PrNTPSer_service()
{
printf "${GREEN}NTP primary service N.P.${NC}\n"
echo "NTP primary service N.P." >> $TESTS_RESULT_FILE
}

function SecNTPSer_running()
{
if [ "${Secondary_NTP_server}" != "" ]
then
	echo "ntp-server secondary $Secondary_NTP_server" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
fi
secNTPSer=`konf -- -d |grep 'ntp-server secondary' | awk '{ printf $3}'`
if [ "${secNTPSer}" == "$Secondary_NTP_server" ]
then
	printf "${GREEN}Secondary NTP server running OK${NC}\n"
	echo "Secondary NTP server running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Secondary NTP server running NOK${NC}\n"
	echo "Secondary NTP server running NOK" >> $TESTS_RESULT_FILE
fi
}
function SecNTPSer_files()
{
if [ "${Secondary_NTP_server}" != "" ]
then
	ntpsec=`cat /etc/ntp.conf |grep ${Secondary_NTP_server}`
fi
if [ "${ntpsec}" != "" ]
then
	printf "${GREEN}Secondary NTP server files OK${NC}\n"
	echo "Secondary NTP server files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Secondary NTP server files NOK${NC}\n"
	echo "Secondary NTP server files NOK" >> $TESTS_RESULT_FILE
fi
}
function SecNTPSer_service()
{
printf "${GREEN}NTP secondary service N.P.${NC}\n"
echo "NTP secondary service N.P." >> $TESTS_RESULT_FILE
}

function TerNTPSer_running()
{
if [ "${Tertiary_NTP_server}" != "" ]
then
	echo "ntp-server tertiary $Tertiary_NTP_server" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
fi
terNTPSer=`konf -- -d |grep 'ntp-server tertiary' | awk '{ printf $3}'`
if [ "${terNTPSer}" == "$Tertiary_NTP_server" ]
then
	printf "${GREEN}Tertiary NTP server running OK${NC}\n"
	echo "Tertiary NTP server running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Tertiary NTP server running NOK${NC}\n"
	echo "Tertiary NTP server running NOK" >> $TESTS_RESULT_FILE
fi
}

function TerNTPSer_files()
{
if [ "${Tertiary_NTP_server}" != "" ]
then
	ntpter=`cat /etc/ntp.conf |grep ${Tertiary_NTP_server}`
fi
if [ "${ntpter}" != "" ]
then
	printf "${GREEN}Tertiary NTP server files OK${NC}\n"
	echo "Tertiary NTP server files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Tertiary NTP server files NOK${NC}\n"
	echo "Tertiary NTP server files NOK" >> $TESTS_RESULT_FILE
fi
}

function TerNTPSer_service()
{
printf "${GREEN}NTP tertiary service N.P.${NC}\n"
echo "NTP tertiary service N.P." >> $TESTS_RESULT_FILE
}

function Sthost_running()
{
if [ "${Static_host}" != "" ]
then
	echo "host add ${Static_host}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	Statichost=`echo "$Static_host" | awk '{ printf $1}'`
	sthost=`konf -- -d |grep 'host add' | awk '{ printf $3}'`
	stip=`konf -- -d |grep 'host add' | awk '{ printf $4}'`
fi
if [ "${sthost}" == "$Statichost" ]
then
	printf "${GREEN}Static host running OK${NC}\n"
	echo "Static host running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Static host running NOK${NC}\n"
	echo "Static host running NOK" >> $TESTS_RESULT_FILE
fi
}

function Sthost_files()
{
Statichost=`echo "$Static_host" | awk '{ printf $1}'`
sthostfile=`cat /etc/hosts |grep ${Statichost}`
if [ "${sthostfile}" != "" ]
then
	printf "${GREEN}Static host files OK${NC}\n"
	echo "Static host files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Static host files NOK${NC}\n"
	echo "Static host files NOK" >> $TESTS_RESULT_FILE
fi
}

function Sthost_service()
{
StHosts=`cat /etc/hosts |grep $Statichost`
if [ "${StHosts}" != "" ]
then
	printf "${GREEN}Static host service OK${NC}\n"
	echo "Static host service OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Static host service NOK${NC}\n"
	echo "Static host service NOK" >> $TESTS_RESULT_FILE
fi
}

function timezone_running()
{
if [ "${Timezone}" != "" ]
then
	echo "timezone ${Timezone}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	timezone=`konf -- -d |grep 'timezone' | awk '{ printf $2}'`
fi
if [ "${timezone}" == "${Timezone}" ]
then
	printf "${GREEN}Timezone running OK${NC}\n"
	echo "Timezone running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Timezone running NOK${NC}\n"
	echo "Timezone running NOK" >> $TESTS_RESULT_FILE
fi
}
function timezone_files()
{
timezone=`ls /etc/localtime | awk '{print $NF}' | sed -r 's/\/usr\/share\/zoneinfo\///'`
if [ "${timezone}" != "" ]
then
	printf "${GREEN}Timezone files OK${NC}\n"
	echo "Timezone files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Timezone files NOK${NC}\n"
	echo "Timezone files NOK" >> $TESTS_RESULT_FILE
fi
}
function timezone_service()
{
printf "${GREEN}Timezone service N.P.${NC}\n"
echo "Timezone service N.P." >> $TESTS_RESULT_FILE
}

function snmpserver_running()
{
snmpsername=`echo $SNMP_server_community | awk '{ printf $1}'`
snmpseracc=`echo $SNMP_server_community | awk '{ printf $2}'`
if [ "${SNMP_server_community}" != "" ]
then
	echo "snmp-server community ${snmpsername} access ${snmpseracc}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	snmpservnamerun=`konf -- -d |grep 'snmp-server community' | awk '{ printf $3}'`
	snmpservaccrun=`konf -- -d |grep 'snmp-server community' | awk '{ printf $5}'`
fi
if [ "${snmpservnamerun}" == "${snmpsername}" ] && [ "${snmpservaccrun}" == "${snmpseracc}" ]
then
	printf "${GREEN}SNMP server community running OK${NC}\n"
	echo "SNMP server community running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}SNMP server community running NOK${NC}\n"
	echo "SNMP server community running NOK" >> $TESTS_RESULT_FILE
fi

}

function snmpserver_files()
{
snmpsername=`echo $SNMP_server_community | awk '{ printf $1}'`
snmpseracc=`echo $SNMP_server_community | awk '{ printf $2}'`
snmpserflname=`cat /etc/snmp/snmpd.conf |grep "community ${snmpsername}" |awk '{printf $2}'`
snmpserflacc=`cat /etc/snmp/snmpd.conf |grep "community ${snmpsername}" |head -c2`
if [ "${snmpsername}" == "${snmpserflname}" ] && [ "${snmpseracc}" == "${snmpserflacc}" ]
then
	printf "${GREEN}SNMP server community files OK${NC}\n" 
	echo "SNMP server community files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}SNMP server community files NOK${NC}\n"
	echo "SNMP server community files NOK" >> $TESTS_RESULT_FILE
fi 
# remove snmp community from file
if [ "${SNMP_server_community}" != "" ]
then
	echo "no snmp-server community ${snmpsername} access ${snmpseracc}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
fi
}

function snmpserver_service()
{
printf "${GREEN}SNMP server community service N.P.${NC}\n"
echo "SNMP server community service N.P." >> $TESTS_RESULT_FILE
}

function snmptrdestIp_running()
{
SNMPTREXIST=`cat /opt/iskratel/bin/niesubag.ini |grep ${SNMP_trap_dest_IP}`
if [ "${SNMPTREXIST}" != "" ]
then
	/sbin/trapdest.sh --delete ${SNMP_trap_dest_IP} >> /dev/null
fi
if [ "${SNMP_trap_dest_IP}" != "" ]
then
	echo "snmptrap ${SNMP_trap_dest_IP}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	snmptrapdstIp=`konf -- -d |grep snmptrap | awk '{ printf $2}'`
	if [ "${snmptrapdstIp}" == "${SNMP_trap_dest_IP}" ]
	then
		printf "${GREEN}SNMP trap dest. IP running OK${NC}\n"
		echo "SNMP trap dest. IP running OK" >> $TESTS_RESULT_FILE
	else
		printf "${RED}SNMP trap dest. IP running NOK${NC}\n"
		echo "SNMP trap dest. IP running NOK" >> $TESTS_RESULT_FILE
	fi
fi
}

function snmptrdestIp_files()
{
trdestIpexsist=`cat /opt/iskratel/bin/niesubag.ini |grep ${SNMP_trap_dest_IP}`
if [ "${trdestIpexsist}" == "" ]
then

	snmptrapdstIp=`konf -- -d |grep snmptarp | awk '{ printf $2}'`
	snmptrdestIpfl=`cat /opt/iskratel/bin/niesubag.ini |grep ${snmptrapdstIp}`
	if [ "${snmptrdestIpfl}" != "" ]
	then
		printf "${GREEN}SNMP trap dest. IP files OK${NC}\n"
		echo "SNMP trap dest. IP files OK" >> $TESTS_RESULT_FILE
	else
		printf "${RED}SNMP trap dest. IP files NOK${NC}\n"
		echo "SNMP trap dest. IP files NOK" >> $TESTS_RESULT_FILE
	fi
		if [ "${SNMP_trap_dest_IP}" != "" ]
		then	
			echo "no snmptrap ${SNMP_trap_dest_IP}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
		fi
else
	printf "${GREEN}SNMP trap dest. IP files OK${NC}\n"
	echo "SNMP trap dest. IP files OK" >> $TESTS_RESULT_FILE
fi
}

function snmptrdestIp_service()
{
printf "${GREEN}SNMP trap dest. IP service N.P.${NC}\n"
echo "SNMP trap dest. IP service N.P." >> $TESTS_RESULT_FILE
}



function snmptrdestPort_running()
{
if [ "${SNMP_trap_dest_port}" != "" ]
then	
	echo "snmptrap port ${SNMP_trap_dest_port}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	snmpdestport=`konf -- -d |grep 'snmptrap port' | awk '{ printf $3}'`
fi
if [ "${snmpdestport}" == "${SNMP_trap_dest_port}" ]
then
	printf "${GREEN}SNMP trap dest. port running OK${NC}\n"
	echo "SNMP trap dest. port running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}SNMP trap dest. port running NOK${NC}\n"
	echo "SNMP trap dest. port running NOK" >> $TESTS_RESULT_FILE
fi
}

function snmptrdestPort_files()
{
snmpport=`konf -- -d |grep 'snmptarp port' | awk '{ printf $3}'`
snmptrport=`cat /opt/iskratel/bin/niesubag.ini |grep "port = ${snmpport}"`
if [ "${snmptrport}" != "" ]
then
	printf "${GREEN}SNMP trap dest. port files OK${NC}\n"
	echo "SNMP trap dest. port files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}SNMP trap dest. port files NOK${NC}\n"
	echo "SNMP trap dest. port files NOK" >> $TESTS_RESULT_FILE
fi
}

function snmptrdestPort_service()
{
printf "${GREEN}SNMP trap dest. port service N.P.${NC}\n"
echo "SNMP trap dest. port service N.P." >> $TESTS_RESULT_FILE
}


function snmptrdestCommu_running()
{
if [ "${SNMP_trap_community}" != "" ]
then	
	echo "snmptrap community ${SNMP_trap_community}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	snmpcommu=`konf -- -d |grep 'snmptrap community' | awk '{ printf $3}'`
fi
if [ "${snmpcommu}" == "${SNMP_trap_community}" ]
then
	printf "${GREEN}SNMP trap dest. community running OK${NC}\n"
	echo "SNMP trap dest. community running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}SNMP trap dest. community running NOK${NC}\n"
	echo "SNMP trap dest. community running NOK" >> $TESTS_RESULT_FILE
fi
}
function snmptrdestCommu_files()
{
snmpCommu=`konf -- -d |grep 'snmptarp community' | awk '{ printf $3}'`
snmpcommu=`cat /opt/iskratel/bin/niesubag.ini |grep "port = ${snmpport}"`
if [ "${snmpcommu}" != "" ]
then
	printf "${GREEN}SNMP trap dest. community files OK${NC}\n"
	echo "SNMP trap dest. community files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}SNMP trap dest. community files NOK${NC}\n"
	echo "SNMP trap dest. community files NOK" >> $TESTS_RESULT_FILE
fi
}
function snmptrdestCommu_service()
{
printf "${GREEN}SNMP trap dest. community service N.P.${NC}\n"
echo "SNMP trap dest. community service N.P." >> $TESTS_RESULT_FILE
}

function vlanswitchports_running()
{
if [ "${vlanadd1}" != "" ]
then	
	echo "vlan add ${vlanadd1}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	Vlanadd1=`konf -- -d |grep 'vlan add' | awk '{ printf $3}'`
fi
if [ "${Vlanadd1}" == "${vlanadd1}" ]
then
	printf "${GREEN}vlan add running OK${NC}\n"
	echo "vlan add running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}vlan add running NOK${NC}\n"
	echo "vlan add running NOK" >> $TESTS_RESULT_FILE
fi
}

function vlanswitchports_files()
{
printf "${GREEN}vlan switchports N.P.${NC}\n"
echo "vlan switchports N.P." >> $TESTS_RESULT_FILE
}

function vlanswitchports_service()
{
printf "${GREEN}vlan switchports service N.P.${NC}\n"
echo "vlan switchports N.P." >> $TESTS_RESULT_FILE
}

function mgmtvlan_running()
{
if [ "${mgmtvlan}" != "" ]
then	
	if [ -f /etc/sysconfig/bonding.static ]
	then
		echo "vlan mgmt ${mgmtvlan}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view | echo "y" >>/dev/null
	else
		echo "vlan mgmt ${mgmtvlan}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	fi
	Mgmtvlan=`konf -- -d |grep 'vlan mgmt' | awk '{ printf $3}'`
fi
if [ "${Mgmtvlan}" == "${mgmtvlan}" ]
then
	printf "${GREEN}mgmt vlan running OK${NC}\n"
	echo "mgmt vlan running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}mgmt vlan running NOK${NC}\n"
	echo "mgmt vlan running NOK" >> $TESTS_RESULT_FILE
fi
}

function mgmtvlan_files()
{
if [ ! -f /etc/sysconfig/bonding.static ]
then
	printf "${GREEN}mgmt vlan files N.P.${NC}\n"
	echo "mgmt vlan files N.P." >> $TESTS_RESULT_FILE
else
	sleep 2
	rcsocMgmtVlan=`cat /rc.soc |grep tagged | awk {'print $2'}`
	if [ "${rcsocMgmtVlan}" == "${mgmtvlan}" ]
	then
		printf "${GREEN}mgmt vlan files OK${NC}\n"
		echo "mgmt vlan files OK" >> $TESTS_RESULT_FILE
	else
		printf "${RED}mgmt vlan files NOK${NC}\n"
		echo "mgmt vlan files NOK" >> $TESTS_RESULT_FILE
	fi
fi
}

function mgmtvlan_service()
{
printf "${GREEN}mgmt vlan service N.P.${NC}\n"
echo "mgmt vlan service N.P." >> $TESTS_RESULT_FILE
}

function ha_interface()
{
cat > /tmp/hsbenable <<EOF
!
hsb
 enable
!
EOF
cat /tmp/hsbenable |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
hainfpr=$(ip l | grep -E "^[0-9]*: " | grep fp_ | sed -n 1p | sed -e 's/^[0-9]*: *fp_//' | sed -e 's/:.*//')
hainfsec=$(ip l | grep -E "^[0-9]*: " | grep fp_ | sed -n 2p | sed -e 's/^[0-9]*: *fp_//' | sed -e 's/:.*//')
if [ "${hainfpr}" != "" ]
then
	if [ "${hainfpr}" != "" ]
	then	
		echo "ha interface primary fp ${hainfpr}" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	fi
fi
infpr=`konf -- -d |grep 'ha interface primary fp' | awk '{print $5}'`
infsec=`konf -- -d |grep 'ha interface secondary fp' | awk '{print $5}'`

if [ "${hainfpr}" != "" ]
then
	if [ "${hainfpr}" == "${infpr}" ]
	then
		printf "${GREEN}ha interface primary fp running OK${NC}\n"
		echo "ha interface primary fp running OK" >> $TESTS_RESULT_FILE
	else
		printf "${RED}ha interface primary fp running NOK${NC}\n"
		echo "ha interface primary fp running NOK" >> $TESTS_RESULT_FILE
	fi
fi	
if [ "${hainfsec}" != "" ]
then
	if [ "${hainfsec}" == "${infsec}" ]
	then
		printf "${GREEN}ha interface secondary fp running OK${NC}\n"
		echo "ha interface secondary fp running OK" >> $TESTS_RESULT_FILE
	else
		printf "${RED}ha interface secondary fp running NOK${NC}\n"
		echo "ha interface secondary fp running NOK" >> $TESTS_RESULT_FILE
	fi
fi

if [ "${hainfpr}" == "" ]
then
	printf "${GREEN}no ha interface configured on system${NC}\n"
fi
rm /tmp/hsbenable
}

function hsbmgmtfltIp_running()
{
cat > /tmp/hsbflt <<EOF
!
hsb
 ip address mgmt float ${HSB_mgmt_float_IP}
!
EOF
cat /tmp/hsbflt | awk '/hsb/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
hsb_mgmtfloat=`konf -- -d |grep 'ip address mgmt float' | awk '{ printf $5}'`
if [ "${hsb_mgmtfloat}" == "${HSB_mgmt_float_IP}" ]
then
	printf "${GREEN}HSB mgmt float IP running OK${NC}\n"
	echo "HSB mgmt float IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB mgmt float IP running NOK${NC}\n"
	echo "HSB mgmt float IP running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/hsbflt 
}

function hsbmgmtfltIp_files()
{
hsbmgmtfltfile=`cat /etc/ha.d/haresources |grep ${HSB_mgmt_float_IP}`
if [ "${hsbmgmtfltfile}" != "" ]
then
	printf "${GREEN}HSB mgmt float IP files OK${NC}\n"
	echo "HSB mgmt float IP files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB mgmt float IP files NOK${NC}\n"
	echo "HSB mgmt float IP files NOK" >> $TESTS_RESULT_FILE
fi
}

function hsbmgmtfltIp_service()
{
printf "${GREEN}HSB mgmt float IP service N.P.${NC}\n"
echo "HSB mgmt float IP service N.P." >> $TESTS_RESULT_FILE
}

function hsblocIntIp_running()
{
cat > /tmp/hsblocint <<EOF
!
hsb
 enable
 ip address internal ${HSB_local_INT_IP}
 vlan internal ${HSB_internal_vlan}
!
EOF
cat /tmp/hsblocint | awk '/hsb/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
hsb_intIpLoc=`konf -- -d |grep "ip address internal ${HSB_local_INT_IP}"`
if [ "${hsb_intIpLoc}" != "" ]
then
	printf "${GREEN}HSB local INT IP running OK${NC}\n"
	echo "HSB local INT IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB local INT IP running NOK${NC}\n"
	echo "HSB local INT IP running NOK" >> $TESTS_RESULT_FILE
fi 
rm /tmp/hsblocint
}

function test_intIP_interfaces()
{
match="0"
cp ${STARTUP_CONFIG} ${STARTUP_CONFIG}.tmp
konf -- -d > ${STARTUP_CONFIG}
i="0"
j="0"
iface_file=/etc/network/interfaces
cp ${iface_file} ${iface_file}.orig
sh /sbin/cfg-int-interfaces.sh
# test
HSB_INT_IP_NoMask=`echo $HSB_local_INT_IP | sed 's/\/.*//'`
MATCH=`cat ${INTERFACES_FILE} | grep "$HSB_INT_IP_NoMask" |grep -v 'broadcast'`
if [ "${MATCH}" != "" ]
then 
	match="1"
fi
}

function hsblocIntIp_files()
{
# test internal IP's in files
# test /etc/network/interfaces
test_intIP_interfaces
if [ "$match" == "1" ]
then
	printf "${GREEN}HSB local INT IP files OK${NC}\n"
	echo "HSB local INT IP files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB local INT IP files NOK${NC}\n"
	echo "HSB local INT IP files NOK" >> $TESTS_RESULT_FILE
fi
}

function hsblocIntIp_service()
{
printf "${GREEN}HSB local INT IP service N.P.${NC}\n"
echo "HSB local INT IP service N.P." >> $TESTS_RESULT_FILE
}

function hsbremhost_running()
{
cat > /tmp/hsbremhost <<EOF
!
hsb
 hostname ${HSB_remote_host}
!
EOF
cat /tmp/hsbremhost | awk '/hsb/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
hsb_remhost=`konf -- -d |grep "hostname ${HSB_remote_host}"`
if [ "${hsb_remhost}" != "" ]
then
	printf "${GREEN}HSB remote host running OK${NC}\n"
	echo "HSB remote host running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB remote host running NOK${NC}\n"
	echo "HSB remote host running NOK" >> $TESTS_RESULT_FILE
fi 
rm /tmp/hsbremhost
}
function hsbremhost_files()
{
remhostfile=`cat /etc/hostname.redundant |grep ${HSB_remote_host}`
if [ "${remhostfile}" != "" ]
then
	printf "${GREEN}HSB remote host files OK${NC}\n"
	echo "HSB remote host files OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB remote host files NOK${NC}\n"
	echo "HSB remote host files NOK" >> $TESTS_RESULT_FILE
fi
}
function hsbremhost_service()
{
printf "${GREEN}HSB remote host service N.P.${NC}\n"
echo "HSB remote host service N.P." >> $TESTS_RESULT_FILE
}

function remhstmgmtIp_running()
{
cat > /tmp/remhsbmgmIp <<EOF
!
hsb
 hostname ${HSB_remote_host}
  ip address mgmt ${HSB_remote_host_mgmt_IP}
!
EOF
cat /tmp/remhsbmgmIp | awk '/hsb/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
remhostmgmIp=`konf -- -d |grep "ip address mgmt ${HSB_remote_host_mgmt_IP}"`
if [ "${remhostmgmIp}" != "" ]
then
	printf "${GREEN}HSB remote host mgmt IP running OK${NC}\n"
	echo "HSB remote host mgmt IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB remote host mgmt IP running NOK${NC}\n"
	echo "HSB remote host mgmt IP running NOK" >> $TESTS_RESULT_FILE
fi 
rm /tmp/remhsbmgmIp
}

function remhstmgmtIp_files()
{
printf "${GREEN}HSB remote host mgmt IP files N.P.${NC}\n"
echo "HSB remote host mgmt IP files N.P." >> $TESTS_RESULT_FILE
}

function remhstmgmtIp_service()
{
printf "${GREEN}HSB remote host mgmt IP service N.P.${NC}\n"
echo "HSB remote host mgmt IP service N.P." >> $TESTS_RESULT_FILE
}

function remhstintIp_running()
{
cat > /tmp/remhstintIp <<EOF
!
hsb
 hostname ${HSB_remote_host}
 ip address internal ${HSB_remote_host_INT_IP}
!
EOF
cat /tmp/remhstintIp | awk '/hsb/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
remhstintIp=`konf -- -d |grep "ip address internal ${HSB_remote_host_INT_IP}"`
if [ "${remhstintIp}" != "" ]
then
	printf "${GREEN}HSB remote host INT IP running OK${NC}\n"
	echo "HSB remote host INT IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB remote host INT IP running NOK${NC}\n"
	echo "HSB remote host INT IP running NOK" >> $TESTS_RESULT_FILE
fi 
rm /tmp/remhstintIp
}

function remhstintIp_files()
{
printf "${GREEN}HSB remote host INT IP files N.P.${NC}\n"
echo "HSB remote host INT IP files N.P." >> $TESTS_RESULT_FILE
}

function remhstintIp_service()
{
printf "${GREEN}HSB remote host INT IP service N.P.${NC}\n"
echo "HSB remote host INT IP service N.P." >> $TESTS_RESULT_FILE
}

function hsbintVlan_running()
{
cat > /tmp/vlanint <<EOF
!
hsb
 vlan internal ${HSB_internal_vlan}
!
EOF

ip addr del ${HSB_local_INT_IP} dev ${HSB_internal_interface}.${HSB_internal_vlan} >>/dev/null
cat /tmp/vlanint | awk '/hsb/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
vlanint=`konf -- -d |grep "vlan internal ${HSB_internal_vlan}"`
if [ "${vlanint}" != "" ]
then
	printf "${GREEN}HSB internal vlan running OK${NC}\n"
	echo "HSB internal vlan running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB internal vlan running NOK${NC}\n"
	echo "HSB internal vlan running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/vlanint
}

function hsbintVlan_files()
{
printf "${GREEN}HSB internal vlan files N.P.${NC}\n"
echo "HSB internal vlan files N.P." >> $TESTS_RESULT_FILE
}

function hsbintVlan_service()
{
printf "${GREEN}HSB internal vlan service N.P.${NC}\n"
echo "HSB internal vlan service N.P." >> $TESTS_RESULT_FILE
}

function hsbintIface_running()
{
cat > /tmp/intIface <<EOF
!
hsb
 internal interface ${HSB_internal_interface}
!
EOF
cat /tmp/intIface | awk '/hsb/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
intIface=`konf -- -d |grep "internal interface ${HSB_internal_interface}"`
if [ "${intIface}" != "" ]
then
	printf "${GREEN}HSB internal interface running OK${NC}\n"
	echo "HSB internal interface running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB internal interface running NOK${NC}\n"
	echo "HSB internal interface running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/intIface
}

function hsbintIface_files()
{
printf "${GREEN}HSB internal interface files service N.P.${NC}\n"
echo "HSB internal interface files service N.P." >> $TESTS_RESULT_FILE
}
function hsbintIface_service()
{
printf "${GREEN}HSB internal interface service N.P.${NC}\n"
echo "HSB internal interface service N.P." >> $TESTS_RESULT_FILE
}
#####

function check_tipc_file()
{
cp ${tipc_file} ${tipc_file}.orig
cp ${STARTUP_CONFIG} ${STARTUP_CONFIG}.tmp
konf -- -d > ${STARTUP_CONFIG}
check_tipc
mv ${STARTUP_CONFIG}.tmp ${STARTUP_CONFIG}
mv ${tipc_file}.orig ${tipc_file}
}
#####

function check_tipcdisable_file()
{
cp ${STARTUP_CONFIG} ${STARTUP_CONFIG}.tmp
konf -- -d > ${STARTUP_CONFIG}
i="0"
# j="0"
tipc_file=/etc/opensaf/tipc_config
cp ${tipc_file} ${tipc_file}.orig
sh /sbin/cfg-tipc-conf.sh reboot

ETH_IFACE=`cat /etc/opensaf/tipc_config |grep 'ETH_INTERFACE=' | sed 's/^.*=//'`
ETH_IFACE_2=`cat /etc/opensaf/tipc_config |grep 'ETH_INTERFACE_2=' | sed 's/^.*=//'`

VLAN=`cat ${STARTUP_CONFIG} |grep 'vlan internal' |awk '{print $3}'`
if [ -f /etc/ha.d/itha.cf ]
then
	HA1=fp_`cat ${STARTUP_CONFIG} |grep 'ha interface primary fp' |awk '{print $5}'`
	HA2=fp_`cat ${STARTUP_CONFIG} |grep 'ha interface secondary fp' |awk '{print $5}'`
else
	VLAN="2005"
fi

if [ "${ETH_IFACE}" == "lo" ]
then 
	i="1"
fi
	
mv ${STARTUP_CONFIG}.tmp ${STARTUP_CONFIG}
mv ${tipc_file}.orig ${tipc_file}
}
#####

function test_etcdrbdconf() {
#	DEVICE=(${DDEV[@]})
#	DEVFS=(${DFS[@]})
#	DRBDDISKNAME=(${DDISK[@]})

index=0
while test $index -lt ${#DEVICE[@]};
do
	DRBD_PORT=`expr ${index} + 7788`
	if [ "x${DEVICE[$index]}" = "x" ]
	then
		echo "Error: missing device name DDEV in ${DRBDCF}"
		return 1
	fi

	if [ "x${DEVFS[$index]}" = "x" ]
	then
		echo "Error: missing mountpoint DFS in ${DRBDCF}"
		return 1
	fi
	if [ "x${DRBDDISKNAME[$index]}" = "x" ]
	then
		echo "Error: missing drbd name DDISK in ${DRBDCF}"
		return 1
	fi

	# Convert UUID to real device file if used inside /etc/fstab
	# Exclude mountpoints that are binded ant not using real device
	physical_devce_fstab=`grep ${DEVFS[$index]} /etc/fstab | grep -v ',*bind' | sed "s%^#* */%/%" | sed "s%^#* *UUID%UUID%" | awk '{print $1}'`
	if [[ ${physical_devce_fstab} == UUID* ]]
	then
		physical_devce=$(blkid | grep $(echo ${physical_devce_fstab} | sed "s|.*=||" | sed 's|"||g') | sed "s|:.*||")
	else
		physical_devce=${physical_devce_fstab}
	fi

	resource=`echo "${DRBDDISKNAME[$index]}"`
	resMatch=`cat $DRBDCONF |grep "$resource"`
	echo "resMatch = $resMatch"

	index=`expr ${index} + 1`
done
}

#####
function check_drbd_file()
{
j="0"
DRBDCF=/etc/sysconfig/drbdp.cf
DRBDCONF=/etc/drbd.conf

cp ${STARTUP_CONFIG} ${STARTUP_CONFIG}.tmp
konf -- -d > ${STARTUP_CONFIG}

drbd_file=$DRBDCONF
cp ${drbd_file} ${drbd_file}.orig
sh /sbin/cfg-drbdconf.sh

#-----------
if [ -e ${DRBDCF} ]
then
	. ${DRBDCF}
fi

if [ ${#DDEV[@]} -gt 0 ] 
then
	# Create an array of 
	DEVICE=(${DDEV[@]})
	DEVFS=(${DFS[@]})
	DRBDDISKNAME=(${DDISK[@]})

	test_etcdrbdconf
else
	echo "Error: no DDEV defined in ${DRBDCF}"
	return 1
fi
#-----------

mv ${STARTUP_CONFIG}.tmp ${STARTUP_CONFIG}
mv ${drbd_file}.orig ${drbd_file}
}
#####


function check_geo_hosts_file()
{
touch ${STARTUP_CONFIG}.tmp1
cp ${STARTUP_CONFIG} ${STARTUP_CONFIG}.tmp1
konf -- -d > ${STARTUP_CONFIG}
INT11_IP=`/sbin/cfg-getparams.sh mmMnInternalIpAddress11`
INT12_IP=`/sbin/cfg-getparams.sh mmMnInternalIpAddress12`
INT21_IP=`/sbin/cfg-getparams.sh mmMnInternalIpAddress21`
INT22_IP=`/sbin/cfg-getparams.sh mmMnInternalIpAddress22`
TARGET_NAME11=`/sbin/cfg-getparams.sh mmMnHostname11`
TARGET_NAME12=`/sbin/cfg-getparams.sh mmMnHostname11`
TARGET_NAME21=`/sbin/cfg-getparams.sh mmMnHostname21`
TARGET_NAME22=`/sbin/cfg-getparams.sh mmMnHostname22`

T1=`cat /etc/hosts |grep "$INT11_IP" |awk '{print $1}'`
T2=`cat /etc/hosts |grep "$INT12_IP" |awk '{print $1}'`
T3=`cat /etc/hosts |grep "$TARGET_NAME11" |awk '{print $1}'`
T4=`cat /etc/hosts |grep "$TARGET_NAME12" |awk '{print $1}'`
T5=`cat /etc/hosts |grep "$INT21_IP" |awk '{print $1}'`
T6=`cat /etc/hosts |grep "$INT22_IP" |awk '{print $1}'`
T7=`cat /etc/hosts |grep "$TARGET_NAME21" |awk '{print $1}'`
T8=`cat /etc/hosts |grep "$TARGET_NAME22" |awk '{print $1}'`

if ([ "${T1}" != "" ] && [ "${T2}" != "" ] && [ "${T3}" != "" ] && [ "${T4}" != "" ] && [ "${T5}" != "" ] && [ "${T6}" != "" ] && [ "${T7}" != "" ] && [ "${T8}" != "" ])
then
	if [ "${Phase_install}" != "formatted" ]
	then
		check_tipc_file
		if [ "${TIPC_OK}" == "1" ]
		then
			printf "${GREEN}HSB enable files OK${NC}\n"
			echo "HSB enable files OK" >> $TESTS_RESULT_FILE
		else
			printf "${RED}HSB enable files NOK${NC}\n"
			echo "HSB enable files NOK" >> $TESTS_RESULT_FILE
		fi
	fi
fi
mv ${STARTUP_CONFIG}.tmp1 ${STARTUP_CONFIG}
}
#####

function check_hosts_file()
{
touch ${STARTUP_CONFIG}.tmp1
cp ${STARTUP_CONFIG} ${STARTUP_CONFIG}.tmp1
konf -- -d > ${STARTUP_CONFIG}
INT1_IP=`/sbin/cfg-getparams.sh mmMnInternalIpAddress11`
INT2_IP=`/sbin/cfg-getparams.sh mmMnInternalIpAddress12`
TARGET_NAME1=`/sbin/cfg-getparams.sh mmMnHostname11`
TARGET_NAME2=`/sbin/cfg-getparams.sh mmMnHostname11`

T1=`cat /etc/hosts |grep "$INT1_IP" |awk '{print $1}'`
T2=`cat /etc/hosts |grep "$INT2_IP" |awk '{print $1}'`
T3=`cat /etc/hosts |grep "$TARGET_NAME1" |awk '{print $1}'`
T4=`cat /etc/hosts |grep "$TARGET_NAME2" |awk '{print $1}'`

if ([ "${T1}" != "" ] && [ "${T2}" != "" ] && [ "${T3}" != "" ] && [ "${T4}" != "" ])
then
	if [ "${Phase_install}" != "formatted" ]
	then
		check_tipc_file
	# check_drbd_file
		if [ "${TIPC_OK}" == "1" ]
		then
			printf "${GREEN}HSB enable files OK${NC}\n"
			echo "HSB enable files OK" >> $TESTS_RESULT_FILE
		else
			printf "${RED}HSB enable files NOK${NC}\n"
			echo "HSB enable files NOK" >> $TESTS_RESULT_FILE
		fi
	fi
fi
cp /etc/hosts $TESTS_RESULT_DIR/hosts.enable
mv ${STARTUP_CONFIG}.tmp1 ${STARTUP_CONFIG}
}
#####
function geo_enable_test()
{
cat > /tmp/geoenable <<EOF
!
georedundancy
 enable
!
EOF
cat /tmp/geoenable |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
# test running
geoEnable=`konf -- -d | awk '/georedundancy/{p=1} /!/{p=0} p' |grep "enable"`
if [ "${geoEnable}" != "" ]
then
	printf "${GREEN}GEO enable running OK${NC}\n"
	echo "GEO enable running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO enable running NOK${NC}\n"
	echo "GEO enable running NOK" >> $TESTS_RESULT_FILE
fi

# test files
check_geo_hosts_file
#check_drbd_file

# test service
printf "${GREEN}HSB enable service N.P.${NC}\n"
echo "HSB enable service N.P." >> $TESTS_RESULT_FILE
}
#####

function hsb_enable_test()
{
cat > /tmp/hsbenable <<EOF
!
hsb
 enable
!
EOF
touch /etc/ha.d/itha.cf
cat /tmp/hsbenable |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view &> /dev/null
# test running
hsbEnable=`konf -- -d | awk '/hsb/{p=1} /!/{p=0} p' |grep "enable"`
if [ "${hsbEnable}" != "" ]
then
	printf "${GREEN}HSB enable running OK${NC}\n"
	echo "HSB enable running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB enable running NOK${NC}\n"
	echo "HSB enable running NOK" >> $TESTS_RESULT_FILE
fi

# test files
check_hosts_file
if [ "${Phase_install}" != "formatted" ]
then
	check_tipc_file
fi
#check_drbd_file

# test service
printf "${GREEN}HSB enable service N.P.${NC}\n"
echo "HSB enable service N.P." >> $TESTS_RESULT_FILE
}

function check_disablehosts_file()
{
touch ${STARTUP_CONFIG}.tmp1
cp ${STARTUP_CONFIG} ${STARTUP_CONFIG}.tmp1
konf -- -d > ${STARTUP_CONFIG}
INT1_IP=`/sbin/cfg-getparams.sh mmMnInternalIpAddress11`
INT2_IP=`/sbin/cfg-getparams.sh mmMnInternalIpAddress12`
TARGET_NAME1=`/sbin/cfg-getparams.sh mmMnHostname11`
TARGET_NAME2=`/sbin/cfg-getparams.sh mmMnHostname11`

T1=`cat /etc/hosts |grep "$INT1_IP" |awk '{print $1}'`
T2=`cat /etc/hosts |grep "$INT2_IP" |awk '{print $1}'`
T3=`cat /etc/hosts |grep "$TARGET_NAME1" |awk '{print $1}'`
T4=`cat /etc/hosts |grep "$TARGET_NAME2" |awk '{print $1}'`

if ([ "${T1}" == "" ] && [ "${T1}" == "" ])
then
	if [ "${Phase_install}" != "formatted" ]
	then
		check_tipcdisable_file
		if [ "${i}" == "1" ]
		then
			printf "${GREEN}HSB disable files OK${NC}\n"
			echo "HSB disable files OK" >> $TESTS_RESULT_FILE
		else
			printf "${RED}HSB disable files NOK${NC}\n"
			echo "HSB disable files NOK" >> $TESTS_RESULT_FILE
		fi
	fi
fi
cp /etc/hosts $TESTS_RESULT_DIR/hosts.disable
mv ${STARTUP_CONFIG}.tmp1 ${STARTUP_CONFIG}
}

function hsb_disable_test()
{
cat > /tmp/disable <<EOF
!
hsb
 disable
!
EOF
cat /tmp/disable |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
# test running
hsbEnable=`konf -- -d | awk '/hsb/{p=1} /!/{p=0} p' |grep "enable"`
if [ "${hsbEnable}" == "" ]
then
	printf "${GREEN}HSB disable running OK${NC}\n"
	echo "HSB disable running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}HSB disable running NOK${NC}\n"
	echo "HSB disable running NOK" >> $TESTS_RESULT_FILE
fi
# test service
printf "${GREEN}HSB disable service N.P.${NC}\n"
echo "HSB disable service N.P." >> $TESTS_RESULT_FILE
# test files
check_disablehosts_file

#check_drbd_file

}

function geoMgmtfltIp_running()
{
cat > /tmp/geomgmtflt <<EOF
!
georedundancy
 ip address mgmt geofloat ${GEO_mgmt_float_IP}
!
EOF
cat /tmp/geomgmtflt | awk '/georedundancy/{p=1} /remote node-id/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoflt=`konf -- -d |grep "ip address mgmt geofloat ${GEO_mgmt_float_IP}"`
if [ "${geoflt}" != "" ]
then
	printf "${GREEN}GEO mgmt float IP running OK${NC}\n"
	echo "GEO mgmt float IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO mgmt float IP running NOK${NC}\n"
	echo "GEO mgmt float IP running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/geomgmtflt
}

function geoMgmtfltIp_files()
{
printf "${GREEN}GEO mgmt float IP files N.P.${NC}\n"
echo "GEO mgmt float IP files N.P." >> $TESTS_RESULT_FILE
}

function geoMgmtfltIp_service()
{
printf "${GREEN}GEO mgmt float IP service N.P.${NC}\n"
echo "GEO mgmt float IP service N.P." >> $TESTS_RESULT_FILE
}

function geoPrUnit_running()
{
cat > /tmp/geoprunit <<EOF
!
georedundancy
 preferred-unit ${GEO_preferred_unit}
!
EOF
cat /tmp/geoprunit | awk '/georedundancy/{p=1} /remote node-id/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoprun=`konf -- -d |grep "ip address mgmt geofloat ${GEO_preferred_unit}"`
if [ "${geoprun}" != "" ]
then
	printf "${GREEN}GEO mgmt float IP running OK${NC}\n"
	echo "GEO mgmt float IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO mgmt float IP running NOK${NC}\n"
	echo "GEO mgmt float IP running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/geoprunit
}

function geoPrUnit_files()
{
printf "${GREEN}GEO preferred unit files N.P.${NC}\n"
echo "GEO preferred unit files N.P." >> $TESTS_RESULT_FILE
}

function geoPrUnit_service()
{
printf "${GREEN}GEO preferred unit service N.P.${NC}\n"
echo "GEO preferred unit service N.P." >> $TESTS_RESULT_FILE
}

function geomode_running()
{
cat > /tmp/geomode <<EOF
!
georedundancy
 geo-mode ${GEO_mode}
!
EOF
cat /tmp/geomode | awk '/georedundancy/{p=1} /remote node-id/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geomod=`konf -- -d |grep "geo-mode ${GEO_mode}"`
if [ "${geomod}" != "" ]
then
	printf "${GREEN}GEO mode running OK${NC}\n"
	echo "GEO mode running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO mode running NOK${NC}\n"
	echo "GEO mode running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/geomode
}

function geomode_files()
{
printf "${GREEN}GEO mode files N.P.${NC}\n"
echo "GEO mode files N.P." >> $TESTS_RESULT_FILE
}

function geomode_service()
{
printf "${GREEN}GEO mode service N.P.${NC}\n"
echo "GEO mode service N.P." >> $TESTS_RESULT_FILE
}

function geoswoverTo_running()
{
cat > /tmp/geoswto <<EOF
!
georedundancy
 geo-switchover timeout ${GEO_switchover_timeout}
!
EOF
cat /tmp/geoswto | awk '/georedundancy/{p=1} /remote node-id/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoswto=`konf -- -d |grep "geo-switchover timeout ${GEO_switchover_timeout}"`
if [ "${geoswto}" != "" ]
then
	printf "${GREEN}GEO switchover timeout running OK${NC}\n"
	echo "GEO switchover timeout running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO switchover timeout running NOK${NC}\n"
	echo "GEO switchover timeout running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/geoswto
}

function geoswoverTo_files()
{
printf "${GREEN}GEO switchover timeout files N.P.${NC}\n"
echo "GEO switchover timeout files N.P." >> $TESTS_RESULT_FILE
}
function geoswoverTo_service()
{
printf "${GREEN}GEO switchover timeout service N.P.${NC}\n"
echo "GEO switchover timeout service N.P." >> $TESTS_RESULT_FILE
}

function geoRemIntVlan_running()
{
cat > /tmp/georemvlan <<EOF
!
georedundancy
 remote vlan internal ${GEO_remote_unit_internal_vlan}
!
EOF
cat /tmp/georemvlan | awk '/georedundancy/{p=1} /remote node-id/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoRemIntVlan=`konf -- -d |grep "remote vlan internal ${GEO_remote_unit_internal_vlan}"`
if [ "${geoRemIntVlan}" != "" ]
then
	printf "${GREEN}GEO remote unit internal vlan running OK${NC}\n"
	echo "GEO remote unit internal vlan running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO remote unit internal vlan NOK${NC}\n"
	echo "GEO remote unit internal vlan NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/georemvlan
}

function geoRemIntVlan_files()
{
printf "${GREEN}GEO remote unit internal vlan files N.P.${NC}\n"
echo "GEO remote unit internal vlan files N.P." >> $TESTS_RESULT_FILE
}
function geoRemIntVlan_service()
{
printf "${GREEN}GEO remote unit internal vlan service N.P.${NC}\n"
echo "GEO remote unit internal vlan service N.P." >> $TESTS_RESULT_FILE
}

function geoRemUnFltIp_running()
{
cat > /tmp/georemFlIp <<EOF
!
georedundancy
 remote ip address mgmt float ${GEO_remote_unit_mgmt_float_IP}
!
EOF
cat /tmp/georemFlIp | awk '/georedundancy/{p=1} /remote node-id/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoRemFlIp=`konf -- -d |grep "remote ip address mgmt float ${GEO_remote_unit_mgmt_float_IP}"`
if [ "${geoRemFlIp}" != "" ]
then
	printf "${GREEN}GEO remote unit mgmt float IP running OK${NC}\n"
	echo "GEO remote unit mgmt float IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO remote unit mgmt float IP NOK${NC}\n"
	echo "GEO remote unit mgmt float IP NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/georemFlIp
}

function geoRemUnFltIp_files()
{
printf "${GREEN}GEO remote unit mgmt float IP files N.P.${NC}\n"
echo "GEO remote unit mgmt float IP files N.P." >> $TESTS_RESULT_FILE
}

function geoRemUnFltIp_service()
{
printf "${GREEN}GEO remote unit mgmt float IP service N.P.${NC}\n"
echo "GEO remote unit mgmt float IP service N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst1_running()
{
cat > /tmp/georemhst1 <<EOF
!
georedundancy
 remote node-id 1 hostname ${GEO_remote_hostname_1}
!
EOF
cat /tmp/georemhst1 | awk '/georedundancy/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoRemHst1=`konf -- -d |grep "remote node-id 1 hostname ${GEO_remote_hostname_1}"`
if [ "${geoRemHst1}" != "" ]
then
	printf "${GREEN}GEO remote hostname 1 running OK${NC}\n"
	echo "GEO remote hostname 1 running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO remote hostname 1 NOK${NC}\n"
	echo "GEO remote hostname 1 NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/georemhst1
}

function geoRemHst1_files()
{
printf "${GREEN}GEO remote hostname 1 files N.P.${NC}\n"
echo "GEO remote hostname 1 files N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst1_service()
{
printf "${GREEN}GEO remote hostname 1 service N.P.${NC}\n"
echo "GEO remote hostname 1 service N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst1Ip_running()
{
cat > /tmp/georemhst1Ip <<EOF
!
georedundancy
 remote node-id 1 hostname ${GEO_remote_hostname_1}
 ip address mgmt ${GEO_remote_host_1_mgmt_IP}
!
EOF
cat /tmp/georemhst1Ip | awk '/georedundancy/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoRemHst1Ip=`konf -- -d |grep "ip address mgmt ${GEO_remote_host_1_mgmt_IP}"`
if [ "${geoRemHst1Ip}" != "" ]
then
	printf "${GREEN}GEO remote host 1 mgmt IP running OK${NC}\n"
	echo "GEO remote host 1 mgmt IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO remote host 1 mgmt IP running NOK${NC}\n"
	echo "GEO remote host 1 mgmt IP running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/georemhst1Ip
}

function geoRemHst1Ip_files()
{
printf "${GREEN}GEO remote host 1 mgmt IP files N.P.${NC}\n"
echo "GEO remote host 1 mgmt IP files N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst1Ip_service()
{
printf "${GREEN}GEO remote host 1 mgmt IP service N.P.${NC}\n"
echo "GEO remote host 1 mgmt IP service N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst1IntIp_running()
{
cat > /tmp/georemhst1IntIp <<EOF
!
georedundancy
 remote node-id 1 hostname ${GEO_remote_hostname_1}
 ip address internal ${GEO_remote_host_1_INT_IP}
!
EOF
cat /tmp/georemhst1IntIp | awk '/georedundancy/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoRemHst1IntIp=`konf -- -d |grep "ip address internal ${GEO_remote_host_1_INT_IP}"`
if [ "${geoRemHst1IntIp}" != "" ]
then
	printf "${GREEN}GEO remote host 1 INT IP running OK${NC}\n"
	echo "GEO remote host 1 INT IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO remote host 1 INT IP running NOK${NC}\n"
	echo "GEO remote host 1 INT IP running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/georemhst1IntIp
}

function geoRemHst1IntIp_files()
{
printf "${GREEN}GEO remote host 1 INT IP files N.P.${NC}\n"
echo "GEO remote host 1 INT IP files N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst1IntIp_service()
{
printf "${GREEN}GEO remote host 1 INT IP service N.P.${NC}\n"
echo "GEO remote host 1 INT IP service N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst2_running()
{
cat > /tmp/georemhst2 <<EOF
!
georedundancy
 remote node-id 2 hostname ${GEO_remote_hostname_2}
!
EOF
cat /tmp/georemhst2 | awk '/georedundancy/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoRemHst2=`konf -- -d |grep "remote node-id 2 hostname ${GEO_remote_hostname_2}"`
if [ "${geoRemHst2}" != "" ]
then
	printf "${GREEN}GEO remote hostname 2 running OK${NC}\n"
	echo "GEO remote hostname 2 running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO remote hostname 2 NOK${NC}\n"
	echo "GEO remote hostname 2 NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/georemhst2
}

function geoRemHst2_files()
{
printf "${GREEN}GEO remote hostname 2 files N.P.${NC}\n"
echo "GEO remote hostname 2 files N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst2_service()
{
printf "${GREEN}GEO remote hostname 2 service N.P.${NC}\n"
echo "GEO remote hostname 2 service N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst2Ip_running()
{
cat > /tmp/georemhst2Ip <<EOF
!
georedundancy
 remote node-id 2 hostname ${GEO_remote_hostname_2}
 ip address mgmt ${GEO_remote_host_2_mgmt_IP}
!
EOF
cat /tmp/georemhst2Ip | awk '/georedundancy/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoRemHst2Ip=`konf -- -d |grep "ip address mgmt ${GEO_remote_host_2_mgmt_IP}"`
if [ "${geoRemHst2Ip}" != "" ]
then
	printf "${GREEN}GEO remote host 2 mgmt IP running OK${NC}\n"
	echo "GEO remote host 2 mgmt IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO remote host 2 mgmt IP running NOK${NC}\n"
	echo "GEO remote host 2 mgmt IP running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/georemhst2Ip
}

function geoRemHst2Ip_files()
{
printf "${GREEN}GEO remote host 2 mgmt IP files N.P.${NC}\n"
echo "GEO remote host 2 mgmt IP files N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst2Ip_service()
{
printf "${GREEN}GEO remote host 2 mgmt IP service N.P.${NC}\n"
echo "GEO remote host 2 mgmt IP service N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst2IntIp_running()
{
cat > /tmp/georemhst2IntIp <<EOF
!
georedundancy
 remote node-id 2 hostname ${GEO_remote_hostname_2}
 ip address internal ${GEO_remote_host_2_INT_IP}
!
EOF
cat /tmp/georemhst2IntIp | awk '/georedundancy/{p=1} /!/{p=0} p' | grep -vw 'enable' |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
geoRemHst2IntIp=`konf -- -d |grep "ip address internal ${GEO_remote_host_2_INT_IP}"`
if [ "${geoRemHst2IntIp}" != "" ]
then
	printf "${GREEN}GEO remote host 2 INT IP running OK${NC}\n"
	echo "GEO remote host 2 INT IP running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}GEO remote host 2 INT IP running NOK${NC}\n"
	echo "GEO remote host 2 INT IP running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/georemhst2IntIp
}

function geoRemHst2IntIp_files()
{
printf "${GREEN}GEO remote host 2 INT IP files N.P.${NC}\n"
echo "GEO remote host 2 INT IP files N.P." >> $TESTS_RESULT_FILE
}

function geoRemHst2IntIp_service()
{
printf "${GREEN}GEO remote host 2 INT IP service N.P.${NC}\n"
echo "GEO remote host 2 INT IP service N.P." >> $TESTS_RESULT_FILE
}

function filtercr_running()
{
echo "filter $Filter_name ACCEPT " |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
fname=`konf -- -d |grep "filter $Filter_name" | awk '{printf $2}'`
if [ "$fname" == "$Filter_name" ]
then
	printf "${GREEN}Filter name running OK${NC}\n"
	echo "Filter name running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Filter name running NOK${NC}\n"
	echo "Filter name running NOK" >> $TESTS_RESULT_FILE
fi
}

function filtercr_files()
{
printf "${GREEN}Filter name files N.P.${NC}\n"
echo "Filter name files N.P." >> $TESTS_RESULT_FILE
}

function filtercr_service()
{
printf "${GREEN}Filter name service N.P.${NC}\n"
echo "Filter name service N.P." >> $TESTS_RESULT_FILE
}

function mgmtIpfilter_running()
{
#echo "filter $Filter_name INPUT 2 " |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
cat > /tmp/ifFilter <<EOF
!
interface mgmt
 filter $Filter_name INPUT 2
!
EOF
cat /tmp/ifFilter |clish -l  -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
mgmtIpfilter=`konf -- -d |grep "filter $Filter_name INPUT"`
if [ "${mgmtIpfilter}" != "" ]
then
	printf "${GREEN}Mgmt IP filter append running OK${NC}\n"
	echo "Mgmt IP filter append running OK" >> $TESTS_RESULT_FILE
else
	printf "${RED}Mgmt IP filter append running NOK${NC}\n"
	echo "Mgmt IP filter append running NOK" >> $TESTS_RESULT_FILE
fi
rm /tmp/ifFilter
}

function mgmtIpfilter_files()
{
printf "${GREEN}Mgmt IP filter append files N.P.${NC}\n"
echo "Mgmt IP filter append files N.P." >> $TESTS_RESULT_FILE
}

function mgmtIpfilter_service()
{
printf "${GREEN}Mgmt IP filter append service N.P.${NC}\n"
echo "Mgmt IP filter append service N.P." >> $TESTS_RESULT_FILE
}

function configure_system_hsb()
{
konf -- -d > /etc/startup-config
/sbin/cfg-modifystartup.sh hsb $HSB_remote_host >> /dev/null
cp /etc/startup-config-$HSB_remote_host $TESTS_RESULT_DIR
}

function configure_system_geo()
{
konf -- -d > /etc/startup-config
/sbin/cfg-modifystartup.sh geo ${GEO_remote_hostname_1} >> /dev/null
/sbin/cfg-modifystartup.sh geo ${GEO_remote_hostname_2} >> /dev/null

cp /etc/startup-config-${GEO_remote_hostname_1} $TESTS_RESULT_DIR
cp /etc/startup-config-${GEO_remote_hostname_2} $TESTS_RESULT_DIR
}

function check_haresources()
{
FILE_CFG=/etc/startup-config
FILE_BONDSTATIC=/etc/sysconfig/bonding.static
INTERFACE="bond0"
TARGET_NAME1=ha-$(/sbin/cfg-getparams.sh mmMnHostname11)
INTVLAN=$(/sbin/cfg-getparams.sh mmInternalVlan)
MN_FLOAT_IP_MASK=$(/sbin/cfg-getparams.sh hsbMnFloatIpMaskAddress)
INT_FLOAT_IP_MASK=$(/sbin/cfg-getparams.sh hsbIntFloatIpMaskAddress)

HSB=`cat ${FILE_CFG} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
if [ "${HSB}" == "" ]
then
	HARE_OK="0"
	# for standalone systems
	if [ -f ${FILE_BONDSTATIC} ]
	then
		MATCH1=`cat /etc/ha.d/haresources |grep $TARGET_NAME1`
		MATCH2=`cat /etc/ha.d/haresources |grep "$INT_FLOAT_IP_MASK/$INTERFACE.2005"`
		if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ]
		then
			HARE_OK="0"
		else
			HARE_OK="1"
		fi
	else
		MATCH1=`cat /etc/ha.d/haresources |grep $TARGET_NAME1`
		if [ "${MATCH1}" == "" ]
		then
			HARE_OK="0"
		else
			HARE_OK="1"
		fi
	fi
else
	# for duplicated systems
	if [ "${MN_FLOAT_IP_MASK}" == "" ]
	then
		if [ -f ${FILE_BONDSTATIC} ]
		then
			MATCH1=`cat /etc/ha.d/haresources |grep $TARGET_NAME1`
			MATCH2=`cat /etc/ha.d/haresources |grep "$INT_FLOAT_IP_MASK/$INTERFACE.2005"`
			if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ]
			then
				HARE_OK="0"
			else
				HARE_OK="1"
			fi
		else
			MATCH1=`cat /etc/ha.d/haresources |grep $TARGET_NAME1`
			if [ "${MATCH1}" == "" ]
			then
				HARE_OK="0"
			else
				HARE_OK="1"
			fi
		fi
	else
		if [ -f ${FILE_BONDSTATIC} ]
		then
			MATCH1=`cat /etc/ha.d/haresources |grep $TARGET_NAME1`
			MATCH2=`cat /etc/ha.d/haresources |grep "$INT_FLOAT_IP_MASK/$INTERFACE.2005"`
			MATCH3=`cat /etc/ha.d/haresources |grep "$MN_FLOAT_IP_MASK/$INTERFACE"`
			if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ] || [ "${MATCH3}" == "" ]
			then
				HARE_OK="0"
			else
				HARE_OK="1"
			fi
		else
			MATCH1=`cat /etc/ha.d/haresources |grep $TARGET_NAME1`
			MATCH2=`cat /etc/ha.d/haresources |grep "$MN_FLOAT_IP_MASK/$INTERFACE"`
			if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ]
			then
				HARE_OK="0"
			else
				HARE_OK="1"
			fi		
		fi
	fi
fi
cp /etc/ha.d/haresources $TESTS_RESULT_DIR
}

function check_hacf()
{
FILE=/etc/startup-config
INTERFACE=bond0
HACF_OK="0"

	function hsb1_etchadhacf() {

	MATCH1=`cat /etc/ha.d/ha.cf |grep "$INTERFACE.$INT_VLAN $INT2_IP"`
	MATCH2=`cat /etc/ha.d/ha.cf |grep "node ha-$TARGET_NAME1"`
	MATCH3=`cat /etc/ha.d/ha.cf |grep "node ha-$TARGET_NAME2"`

	if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ] || [ "${MATCH3}" == "" ]
	then
		HACF_OK="0"
	else
		HACF_OK="1"
	fi
	}

	function nohsb_etchadhacf() {

	MATCH1=`cat /etc/ha.d/ha.cf |grep $TARGET_NAME1`

	if [ "${MATCH1}" == "" ]
	then
		HACF_OK="0"
	else
		HACF_OK="1"
	fi
	}

HSB=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
if [ "${HSB}" == "" ]
then
	TARGET_NAME1=`cat /etc/hostname`
	nohsb_etchadhacf
else
	#TARGET_NAME1=`cat ${FILE} | awk '/hostname/{p=1} /!/{p=0} p' |  grep hostname | grep -vw ' hostname' | grep -v 'hostnameredundant'|  head -n 1 | awk '{print $2}'`
	TARGET_NAME1=$(/sbin/cfg-getparams.sh localHostname)
	#TARGET_NAME2=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'hostname' | awk '{print $2}'`
	TARGET_NAME2=$(/sbin/cfg-getparams.sh hsbRemoteHostname)
	#IP=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address internal' |awk '{print $4}'`
	IP=$(/sbin/cfg-getparams.sh hsbRemIntIpAddress)
	. /sbin/cfg-calculate-network.sh ${IP}
        convert_ip_mask
        INT2_IP=`echo ${IPN}`
	INT_VLAN=$(/sbin/cfg-getparams.sh mmInternalVlan)

	hsb1_etchadhacf
fi
cp /etc/ha.d/ha.cf $TESTS_RESULT_DIR
}

function check_hamcf()
{
#############

. /etc/sysconfig/solid
if [ "x$NESRV_ENABLE" == "xyes" ]
then
	USE_DB="TRUE"
else
	USE_DB="FALSE"
fi

FILE_HAMCF=/opt/iskratel/etc/ham.d/ham.cf
FILE_HAMSYSGENCF=/opt/iskratel/etc/ham.d/hamsysgen.cf
FILE_HAMSYSCOMCF=/opt/iskratel/etc/ham.d/hamsyscom.cf
FILE_HAMCF_STANDARD=/opt/iskratel/etc/ham.d/hamstandard.cf
FILE_BONDSTATIC=/etc/sysconfig/bonding.static
FILE_CFG=/etc/startup-config

sysType=`cat ${FILE_CFG} | grep 'system type' | awk '{print $3}'`
if [ "$sysType" == "standalone" ]
then
	# standalone system
	if [ "x$NESRV_ENABLE" == "xyes" ]
	then
		USE_DB="TRUE"
	else
		USE_DB="FALSE"
	fi

	# get local MN IP address
	IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
	. /sbin/cfg-calculate-network.sh ${IP}
	convert_ip_mask
	MYIP=`echo ${IPN}`
	# echo $MYIP

	MN1_IP=${MYIP}
	# echo $MN1_IP

	mkdir -p $(dirname ${FILE_HAMCF})

	MATCH1=`cat ${FILE_HAMCF} |grep "locip = $MN1_IP"`
	MATCH2=`cat ${FILE_HAMCF} |grep "floatappip = $MN1_IP"`

	if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ]
	then
		HAMCF_OK="0"
	else
		HAMCF_OK="1"
	fi
fi

if [ "$sysType" == "duplicated" ]
then
	# duplicated system - check if hsb enabled
	HSB=`cat ${FILE_CFG} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
	if [ "$HSB" != "" ]
	then

		LOCPORT="9437"
		REMPORT="9537"

		#get local internal IP
		IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT1_IP=`echo ${IPN}`
		#echo $INT1_IP

		#get remote internal IP
		IP=$(/sbin/cfg-getparams.sh hsbRemIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT2_IP=`echo ${IPN}`
		#echo $INT2_IP

		#get local MN IP
		IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN1_IP=`echo ${IPN}`
		#echo $MN1_IP

		#get remote MN IP
		IP=$(/sbin/cfg-getparams.sh hsbRemoteMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN2_IP=`echo ${IPN}`
		#echo $MN2_IP

		#get MN float IP
		IP=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN_FLOAT=`echo ${IPN}`
		#echo $MN_FLOAT

		mkdir -p $(dirname ${FILE_HAMCF})


		MATCH1=`cat ${FILE_HAMCF} |grep "locip = $INT1_IP"`
		MATCH2=`cat ${FILE_HAMCF} |grep "remip = $INT2_IP"`
		MATCH3=`cat ${FILE_HAMCF} |grep "mwdlocport = ${LOCPORT}"`
		MATCH4=`cat ${FILE_HAMCF} |grep "mwdremport = ${REMPORT}"`
		MATCH5=`cat ${FILE_HAMCF} |grep "floatappip = $MN_FLOAT"`
		MATCH6=`cat ${FILE_HAMCF} |grep "locappip = $MN1_IP"`
		MATCH7=`cat ${FILE_HAMCF} |grep "remappip = $MN2_IP"`


		if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ] || [ "${MATCH3}" == "" ] || [ "${MATCH4}" == "" ] || [ "${MATCH5}" == "" ] || [ "${MATCH6}" == "" ] || [ "${MATCH7}" == "" ] 
		then
			HAMCF_OK="0"
		else
			HAMCF_OK="1"
		fi		
				

	fi
fi

if [ "$sysType" == "geo-dual" ]
then
	# geo-dual system - check if geo enabled
	GEO=`cat ${FILE_CFG} | awk '/georedundancy/{p=1} /!/{p=0} p' | grep 'enable'`
	if [ "$GEO" != "" ]
	then

		LOCPORT="9437"
		REMPORT="9537"

		#get local internal IP
		IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT1_IP=`echo ${IPN}`
		#echo $INT1_IP

		#get remote internal IP
		IP=$(/sbin/cfg-getparams.sh hsbRemIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT2_IP=`echo ${IPN}`
		#echo $INT2_IP

		#get local MN IP
		IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN1_IP=`echo ${IPN}`
		#echo $MN1_IP

		#get remote MN IP
		IP=$(/sbin/cfg-getparams.sh hsbRemoteMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN2_IP=`echo ${IPN}`
		#echo $MN2_IP

		#get MN float IP
		IP=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN_FLOAT=`echo ${IPN}`
		#echo $MN_FLOAT

		mkdir -p $(dirname ${FILE_HAMCF})
		mkdir -p $(dirname ${FILE_HAMSYSGENCF})
		mkdir -p $(dirname ${FILE_HAMCF_STANDARD})


		MATCH1=`cat ${FILE_HAMCF} |grep "locip = $INT1_IP"`
		MATCH2=`cat ${FILE_HAMCF} |grep "remip = $INT2_IP"`
		MATCH3=`cat ${FILE_HAMCF} |grep "mwdlocport = ${LOCPORT}"`
		MATCH4=`cat ${FILE_HAMCF} |grep "mwdremport = ${REMPORT}"`
		MATCH5=`cat ${FILE_HAMCF} |grep "floatappip = $MN_FLOAT"`
		MATCH6=`cat ${FILE_HAMCF} |grep "locappip = $MN1_IP"`
		MATCH7=`cat ${FILE_HAMCF} |grep "remappip = $MN2_IP"`
		
		
		if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ] || [ "${MATCH3}" == "" ] || [ "${MATCH4}" == "" ] || [ "${MATCH5}" == "" ] || [ "${MATCH6}" == "" ] || [ "${MATCH7}" == "" ] 
		then
			HAMCF_OK="0"
		else
			HAMCF_OK="1"
		fi				
	fi
fi
cp ${FILE_HAMCF} $TESTS_RESULT_DIR
#############
}

function check_drbdconf()
{
#!/bin/bash

DRBDCF=/etc/sysconfig/drbdp.cf
DRBDCONF=/etc/drbd.conf
FILE_STARTUP=/etc/startup-config

# /etc not mounted yet
# DRBD_ON=`find /etc/rc* -type l -name S[0-9][0-9]drbd | wc -l`

HSB=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
if [ "${HSB}" == "" ]
then
	PRODUCT_TYPE="nohsb"
else
	PRODUCT_TYPE="hsb"
fi

#get remote MN IP
#IP=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address mgmt' |awk '{print $4}'`
IP=$(/sbin/cfg-getparams.sh hsbRemoteMnIpAddress)
. /sbin/cfg-calculate-network.sh ${IP}
convert_ip_mask
REM_IP=`echo ${IPN}`

#get local internal IP
#IP=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' ip address internal' |  grep -vw '  ip address internal' |awk '{print $4}'`
IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
. /sbin/cfg-calculate-network.sh ${IP}
convert_ip_mask
INT1_IP=`echo ${IPN}`

#get remote internal IP
#IP=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address internal' |awk '{print $4}'`
IP=$(/sbin/cfg-getparams.sh hsbRemIntIpAddress)
. /sbin/cfg-calculate-network.sh ${IP}
convert_ip_mask
INT2_IP=`echo ${IPN}`

#get local hostname
#TARGET_NAME1=`cat ${FILE_STARTUP} | awk '/hostname/{p=1} /!/{p=0} p' |  grep hostname |  grep -vw ' hostname' | grep -v 'hostnameredundant'|  head -n 1 | awk '{print $2}'`
TARGET_NAME1=$(/sbin/cfg-getparams.sh localHostname)

#get remote hostname
#TARGET_NAME2=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' hostname' | awk '{print $2}'`
TARGET_NAME2=$(/sbin/cfg-getparams.sh hsbRemoteHostname)

if [ "${GEO}" == "" ]
then
	UNIT_TYPE="noredundant"
else
	UNIT_TYPE="redundant"
fi

function hsb_etcdrbdconf() {
#	DEVICE=(${DDEV[@]})
#	DEVFS=(${DFS[@]})
#	DRBDDISKNAME=(${DDISK[@]})

#	Disable interractive info agreement for usage count
	
index=0
while test $index -lt ${#DEVICE[@]};
do
	DRBD_PORT=`expr ${index} + 7788`
	if [ "x${DEVICE[$index]}" = "x" ]
	then
		echo "Error: missing device name DDEV in ${DRBDCF}"
		return 1
	fi

	if [ "x${DEVFS[$index]}" = "x" ]
	then
		echo "Error: missing mountpoint DFS in ${DRBDCF}"
		return 1
	fi
	if [ "x${DRBDDISKNAME[$index]}" = "x" ]
	then
		echo "Error: missing drbd name DDISK in ${DRBDCF}"
		return 1
	fi

	# Convert UUID to real device file if used inside /etc/fstab
	# Exclude mountpoints that are binded ant not using real device
	physical_devce_fstab=`grep ${DEVFS[$index]} /etc/fstab | grep -v ',*bind' | sed "s%^#* */%/%" | sed "s%^#* *UUID%UUID%" | awk '{print $1}'`
	if [[ ${physical_devce_fstab} == UUID* ]]
	then
		physical_devce=$(blkid | grep $(echo ${physical_devce_fstab} | sed "s|.*=||" | sed 's|"||g') | sed "s|:.*||")
	else
		physical_devce=${physical_devce_fstab}
	fi
############################	
	MATCH1=`cat ${DRBDCONF} |grep "resource ${DRBDDISKNAME[$index]}"`
	MATCH2=`cat ${DRBDCONF} |grep "on $TARGET_NAME1"`
	MATCH3=`cat ${DRBDCONF} |grep "disk       ${physical_devce};"`
	MATCH4=`cat ${DRBDCONF} |grep "address    ${INT1_IP}:${DRBD_PORT}"`
	MATCH5=`cat ${DRBDCONF} |grep "address    ${INT2_IP}:${DRBD_PORT}"`
	
	if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ] || [ "${MATCH3}" == "" ] || [ "${MATCH4}" == "" ] || [ "${MATCH5}" == "" ]
	then
		DRBD_OK="0"
		return 1
	else
		DRBD_OK="1"
	fi				
############################		

	index=`expr ${index} + 1`
done
}


if [ -e ${DRBDCF} ]
then
	. ${DRBDCF}
fi

# cat /etc/fstab | sed "s%^#/%/%" > /etc/fstab.tmp
# cp /etc/fstab.tmp /etc/fstab

if [ ${#DDEV[@]} -gt 0 ] 
then
	# Create an array of 
	DEVICE=(${DDEV[@]})
	DEVFS=(${DFS[@]})
	DRBDDISKNAME=(${DDISK[@]})

	hsb_etcdrbdconf

	# remount uncommented partitions
	mount -a -O sysfs

else
	echo "Error: no DDEV defined in ${DRBDCF}"
	return 1
fi
cp ${DRBDCONF} $TESTS_RESULT_DIR
}

function check_tipc()
{
file=/etc/startup-config
FILE_BONDSTATIC=/etc/sysconfig/bonding.static
INT_INTERFACE=`cat ${file} |grep 'internal interface' |awk '{printf $3}'`
type=$1
TIPC_OK="0"
if [ -f /etc/opensaf/tipc_config ]
then

	# get old interfaces from tipc_config
	old_intf1=`cat /etc/opensaf/tipc_config | grep ETH_INTERFACE | grep -vw ETH_INTERFACE_2 |  awk -F'ETH_INTERFACE=' '{print $2}'`
	old_intf2=`cat /etc/opensaf/tipc_config | grep ETH_INTERFACE_2 |  awk -F'ETH_INTERFACE_2=' '{print $2}'`

        # called after reboot - read startup conf
	sys_type=`cat ${file} | grep "system type" | awk '{print $3}'`
	if [ "$sys_type" != "standalone" ] && [ "$sys_type" != "geo-single" ]
	then
		# check if ha interfaces configured
		ha_intf=`cat ${file} | grep 'ha interface'`
		if [ "$ha_intf" == "" ]
		then
			# ha interface nof configured - set default
	        	# check if hsb enabled
	        	dupl=`cat ${file} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' enable'`
	        	if [ "$dupl" != "" ]
	        	then
	                	# hsb enabled - get internal vlan id
	                	if [ -f ${FILE_BONDSTATIC} ]
	                	then
	                        	# internal vlan predefined
	                        	INT_VLAN=2005
					INTERFACE=bond0.$INT_VLAN
	                	else
	                        	# get internal vlan
	                        	INT_VLAN=`cat ${file} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' vlan internal' |awk '{print $3}'`
					if [ "${INT_VLAN}" != "" ]
					then
						INTERFACE=bond0.$INT_VLAN
					else
						INTERFACE=bond0
					fi
	                	fi

	                	# set tipc interface
				# cp /etc/opensaf/tipc_config.def /etc/opensaf/tipc_config
				if [ "$old_intf2" != "" ]
				then
					MATCH1=`cat /etc/opensaf/tipc_config |grep intf2`
					if [ "${MATCH1}" != "" ]
					then
						TIPC_OK="1"
					fi
					# update itmlinec to stop monitoring old intf
					/sbin/cfg-mlinec.sh chg_link_equip_port $old_intf2 0 >> /dev/null
				fi
				
				if [ "${INT_INTERFACE}" != "" ]
				then 
					if [ "${INT_VLAN}" != "" ]
					then
						INTERFACE=fp_${INT_INTERFACE}.${INT_VLAN}
					else
						INTERFACE=fp_${INT_INTERFACE}
					fi
				fi
							
				MATCH2=`cat /etc/opensaf/tipc_config |grep ${INTERFACE}`
				if [ "${MATCH2}" != "" ]
				then
					TIPC_OK="1"
				fi

				# update itmlinec to stop monitoring old intf
                                /sbin/cfg-mlinec.sh chg_link_equip_port $old_intf1 0 >> /dev/null
	        	else
	                	#  hsb not enabled - still standalone
				# cp /etc/opensaf/tipc_config.def /etc/opensaf/tipc_config
				if [ "$old_intf2" != "" ]
				then
					
					MATCH3=`cat /etc/opensaf/tipc_config |grep intf2`
					if [ "${MATCH3}" != "" ]
					then
						TIPC_OK="1"
					fi
					# update itmlinec to stop monitoring old intf
					/sbin/cfg-mlinec.sh chg_link_equip_port $old_intf2 0 >> /dev/null
				fi
				MATCH4=`cat /etc/opensaf/tipc_config |grep lo`
				if [ "${MATCH4}" != "" ]
				then
					TIPC_OK="1"
				fi
				sed -i -e "s/$old_intf1/lo/g" /etc/opensaf/tipc_config

				# update itmlinec to stop monitoring old intf
                                /sbin/cfg-mlinec.sh chg_link_equip_port $old_intf1 0 >> /dev/null
		        fi
		else
			intf1=`cat ${file} | grep 'ha interface primary' | awk '{print $4}'`
                        intf2=`cat ${file} | grep 'ha interface secondary' | awk '{print $4}'`

			if [ "$intf1" == "bp" ]
			then
				intf1=eth2
			else
				intf1_tmp=`cat ${file} | grep 'ha interface primary' | awk '{print $5}'`
				if [ "$intf1_tmp" != "" ]
				then
					intf1=fp_${intf1_tmp}
				fi
			fi

                        if [ "$intf2" == "bp" ]
                        then
                                intf2=eth2
                        else
                                intf2_tmp=`cat ${file} | grep 'ha interface secondary' | awk '{print $5}'`
				if [ "$intf2_tmp" != "" ]
				then
					intf2=fp_${intf2_tmp}
				fi
                        fi

                        # modify /etc/opensaf/tipc_config
                        # cp /etc/opensaf/tipc_config.def /etc/opensaf/tipc_config

			# set primary intf
			MATCH1=`cat /etc/opensaf/tipc_config |grep $intf1`
			if [ "${MATCH1}" != "" ]
			then
				TIPC_OK="1"
			fi
			
			# update itmlinec to start monitoring intf
			/sbin/cfg-mlinec.sh chg_link_equip_port $intf1 1 >> /dev/null

			if [ "$intf2" != "" ]
			then
				MATCH2=`cat /etc/opensaf/tipc_config |grep $intf2`
				if [ "${MATCH2}" != "" ]
				then
					TIPC_OK="1"
				fi
				# update itmlinec to start monitoring intf
				/sbin/cfg-mlinec.sh chg_link_equip_port $intf2 1 >> /dev/null
			else
				# get internal vlan
                                INT_VLAN=`cat ${file} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' vlan internal' |awk '{print $3}'`
				if [ "${INT_VLAN}" != "" ]
				then
					INTERFACE=bond0.$INT_VLAN
				else
					INTERFACE=bond0
				fi

				if [ "$INT_INTERFACE" != "" ]
				then
					if [ "$INT_VLAN" != "" ]
					then
						INTERFACE=fp_${INT_INTERFACE}.${INT_VLAN}
					else
						INTERFACE=fp_${INT_INTERFACE}
					fi
				fi
				MATCH3=`cat /etc/opensaf/tipc_config |grep ${INTERFACE}`
				if [ "${MATCH3}" != "" ]
				then
					TIPC_OK="1"
				fi

				# update itmlinec to stop monitoring old intf
	                        /sbin/cfg-mlinec.sh chg_link_equip_port $old_intf2 0 >> /dev/null
			fi

			# bring up configured intfs - admin UP
			if [ "$intf1" != "intf1" ]
			then
				ip link set $intf1 up
			fi

			if [ "$intf2" != "" ]
			then
				ip link set $intf2 up
			fi
	        fi
	else
		# i am standalone - set tipc interface to 'lo'
		# cp /etc/opensaf/tipc_config.def /etc/opensaf/tipc_config

		# set second intf
		if [ "$old_intf2" != "" ]
		then
			MATCH4=`cat /etc/opensaf/tipc_config |grep intf2`
			if [ "${MATCH4}" != "" ]
			then
				TIPC_OK="1"
			fi
			sed -i -e "s/$old_intf2/intf2/g" /etc/opensaf/tipc_config
		fi

		# set first intf
		MATCH5=`cat /etc/opensaf/tipc_config |grep lo`
		if [ "${MATCH5}" != "" ]
		then
			TIPC_OK="1"
		fi
		sed -i -e "s/$old_intf1/lo/g" /etc/opensaf/tipc_config
	fi
else

	echo "Info: cfg-tipc-conf.sh -> /etc/opensaf/tipc_config does not exist - nothing to do!"
	return 0

fi
cp /etc/opensaf/tipc_config $TESTS_RESULT_DIR
}

function check_hamsyscomgen()
{
. /etc/sysconfig/solid
if [ "x$NESRV_ENABLE" == "xyes" ]
then
	USE_DB="TRUE"
else
	USE_DB="FALSE"
fi

FILE_HAMSYSGENCF=/opt/iskratel/etc/ham.d/hamsysgen.cf
FILE_HAMSYSCOMCF=/opt/iskratel/etc/ham.d/hamsyscom.cf
FILE_HAMCF_STANDARD=/opt/iskratel/etc/ham.d/hamstandard.cf
FILE_BONDSTATIC=/etc/sysconfig/bonding.static
FILE=${FILE_HAMCF}.apps
FILE_CFG=/etc/startup-config


# HSB=`cat ${FILE_CFG} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
# if [ "${HSB}" == "" ]

sysType=`cat ${FILE_CFG} | grep 'system type' | awk '{print $3}'`
if [ "$sysType" == "standalone" ]
then
	# standalone system

	if [ "x$NESRV_ENABLE" == "xyes" ]
	then
		USE_DB="TRUE"
	else
		USE_DB="FALSE"
	fi

	# get local MN IP address
	IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
	. /sbin/cfg-calculate-network.sh ${IP}
	convert_ip_mask
	MYIP=`echo ${IPN}`
	# echo $MYIP

	MN1_IP=${MYIP}
	# echo $MN1_IP

	mkdir -p $(dirname ${FILE_HAMSYSGENCF})


	MATCH1=`cat ${FILE_HAMSYSCOMCF} |grep "enabled = ${USE_DB}"`

	if [ "${MATCH1}" == "" ]
	then
		HAMSYSCOM_OK="0"
	else
		HAMSYSCOM_OK="1"
	fi	
		
	if [ -f ${FILE_BONDSTATIC} ]
	then
		MATCH1=`cat ${FILE_HAMSYSGENCF} |grep "useDB = ${USE_DB}"`
		
		if [ "${MATCH1}" == "" ]
		then
			HAMSYSGEN_OK="0"
		else
			HAMSYSGEN_OK="1"
		fi			
	else

		MATCH1=`cat ${FILE_HAMSYSGENCF} |grep "useDB = ${USE_DB}"`
		MATCH2=`cat ${FILE_HAMSYSGENCF} |grep "locip = $MN1_IP"`
		MATCH3=`cat ${FILE_HAMSYSGENCF} |grep "floatappip = $MN1_IP"`
		MATCH4=`cat ${FILE_HAMSYSGENCF} |grep "locappip = $MN1_IP"`
	
		if [ "${MATCH1}" == "" ]
		then
			HAMSYSGEN_OK="0"
		else
			HAMSYSGEN_OK="1"
		fi			
	fi
fi

if [ "$sysType" == "duplicated" ]
then
	# duplicated system - check if hsb enabled
	HSB=`cat ${FILE_CFG} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
	if [ "$HSB" != "" ]
	then

		LOCPORT="9437"
		REMPORT="9537"

		#get local internal IP
		IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT1_IP=`echo ${IPN}`
		#echo $INT1_IP

		#get remote internal IP
		IP=$(/sbin/cfg-getparams.sh hsbRemIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT2_IP=`echo ${IPN}`
		#echo $INT2_IP

		#get local MN IP
		IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN1_IP=`echo ${IPN}`
		#echo $MN1_IP

		#get remote MN IP
		IP=$(/sbin/cfg-getparams.sh hsbRemoteMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN2_IP=`echo ${IPN}`
		#echo $MN2_IP

		#get MN float IP
		IP=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN_FLOAT=`echo ${IPN}`
		#echo $MN_FLOAT

		mkdir -p $(dirname ${FILE_HAMCF})
		mkdir -p $(dirname ${FILE_HAMSYSGENCF})
		mkdir -p $(dirname ${FILE_HAMCF_STANDARD})

		MATCH1=`cat ${FILE_HAMSYSCOMCF} |grep "enabled = ${USE_DB}"`
			
		if [ "${MATCH1}" == "" ]
		then
			HAMSYSCOM_OK="0"
		else
			HAMSYSCOM_OK="1"
		fi	


		MATCH1=`cat ${FILE_HAMSYSGENCF} |grep "useDB = ${USE_DB}"`
			
		if [ "${MATCH1}" == "" ]
		then
			HAMSYSGEN_OK="0"
		else
			HAMSYSGEN_OK="1"
		fi			
	

				# Generate hamstandard.cf
		MATCH1=`cat ${FILE_HAMCF_STANDARD} |grep "locip = $INT1_IP"`
		MATCH2=`cat ${FILE_HAMCF_STANDARD} |grep "remip = $INT2_IP"`
		MATCH3=`cat ${FILE_HAMCF_STANDARD} |grep "mwdlocport = ${LOCPORT}"`
		MATCH4=`cat ${FILE_HAMCF_STANDARD} |grep "mwdremport = ${REMPORT}"`
		MATCH5=`cat ${FILE_HAMCF_STANDARD} |grep "floatappip = $MN_FLOAT"`
		MATCH6=`cat ${FILE_HAMCF_STANDARD} |grep "locappip = $MN1_IP"`
		MATCH7=`cat ${FILE_HAMCF_STANDARD} |grep "remappip = $MN2_IP"`
		MATCH8=`cat ${FILE_HAMCF_STANDARD} |grep "useDB = ${USE_DB}"`
								
		if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ] || [ "${MATCH3}" == "" ] || [ "${MATCH4}" == "" ] || [ "${MATCH5}" == "" ] || [ "${MATCH6}" == "" ] || [ "${MATCH7}" == "" ] || [ "${MATCH8}" == "" ]
		then
			HAMSTAND_OK="0"
		else
			HAMSTAND_OK="1"
		fi			
				
	fi
fi

if [ "$sysType" == "geo-dual" ]
then
	# geo-dual system - check if geo enabled
	GEO=`cat ${FILE_CFG} | awk '/georedundancy/{p=1} /!/{p=0} p' | grep 'enable'`
	if [ "$GEO" != "" ]
	then

		LOCPORT="9437"
		REMPORT="9537"

		#get local internal IP
		IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT1_IP=`echo ${IPN}`
		#echo $INT1_IP

		#get remote internal IP
		IP=$(/sbin/cfg-getparams.sh hsbRemIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT2_IP=`echo ${IPN}`
		#echo $INT2_IP

		#get local MN IP
		IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN1_IP=`echo ${IPN}`
		#echo $MN1_IP

		#get remote MN IP
		IP=$(/sbin/cfg-getparams.sh hsbRemoteMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN2_IP=`echo ${IPN}`
		#echo $MN2_IP

		#get MN float IP
		IP=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN_FLOAT=`echo ${IPN}`
		#echo $MN_FLOAT

		mkdir -p $(dirname ${FILE_HAMCF})
		mkdir -p $(dirname ${FILE_HAMSYSGENCF})
		mkdir -p $(dirname ${FILE_HAMCF_STANDARD})

		MATCH1=`cat ${FILE_HAMSYSCOMCF} |grep "enabled = ${USE_DB}"`
	
		if [ "${MATCH1}" == "" ]
		then
			HAMSYSCOM_OK="0"
		else
			HAMSYSCOM_OK="1"
		fi	



		if [ -f ${FILE_BONDSTATIC} ]
		then

			MATCH1=`cat ${FILE_HAMSYSGENCF} |grep "locip = $INT1_IP"`
			MATCH2=`cat ${FILE_HAMSYSGENCF} |grep "remip = $INT2_IP"`
			MATCH3=`cat ${FILE_HAMSYSGENCF} |grep "useDB = ${USE_DB}"`
			if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ] || [ "${MATCH3}" == "" ]
			then
				HAMSYSGEN_OK="0"
			else
				HAMSYSGEN_OK="1"
			fi	

		else
			MATCH1=`cat ${FILE_HAMSYSGENCF} |grep "locip = $INT1_IP"`
			MATCH2=`cat ${FILE_HAMSYSGENCF} |grep "remip = $INT2_IP"`
			MATCH3=`cat ${FILE_HAMSYSGENCF} |grep "mwdlocport = ${LOCPORT}"`
			MATCH4=`cat ${FILE_HAMSYSGENCF} |grep "mwdremport = ${REMPORT}"`
			MATCH5=`cat ${FILE_HAMSYSGENCF} |grep "floatappip = $MN_FLOAT"`
			MATCH6=`cat ${FILE_HAMSYSGENCF} |grep "locappip = $MN1_IP"`
			MATCH7=`cat ${FILE_HAMSYSGENCF} |grep "remappip = $MN2_IP"`
			MATCH8=`cat ${FILE_HAMSYSGENCF} |grep "useDB = ${USE_DB}"`
			
									
			if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ] || [ "${MATCH3}" == "" ] || [ "${MATCH4}" == "" ] || [ "${MATCH5}" == "" ] || [ "${MATCH6}" == "" ] || [ "${MATCH7}" == "" ] || [ "${MATCH8}" == "" ]
			then
				HAMSYSGEN_OK="0"
			else
				HAMSYSGEN_OK="1"
			fi	
							
		fi
		# Generate hamstandard.cf
		MATCH1=`cat ${FILE_HAMCF_STANDARD} |grep "locip = $INT1_IP"`
		MATCH2=`cat ${FILE_HAMCF_STANDARD} |grep "remip = $INT2_IP"`
		MATCH3=`cat ${FILE_HAMCF_STANDARD} |grep "mwdlocport = ${LOCPORT}"`
		MATCH4=`cat ${FILE_HAMCF_STANDARD} |grep "mwdremport = ${REMPORT}"`
		MATCH5=`cat ${FILE_HAMCF_STANDARD} |grep "floatappip = $MN_FLOAT"`
		MATCH6=`cat ${FILE_HAMCF_STANDARD} |grep "locappip = $MN1_IP"`
		MATCH7=`cat ${FILE_HAMCF_STANDARD} |grep "remappip = $MN2_IP"`
		MATCH8=`cat ${FILE_HAMCF_STANDARD} |grep "useDB = ${USE_DB}"`
								
		if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ] || [ "${MATCH3}" == "" ] || [ "${MATCH4}" == "" ] || [ "${MATCH5}" == "" ] || [ "${MATCH6}" == "" ] || [ "${MATCH7}" == "" ] || [ "${MATCH8}" == "" ]
		then
			HAMSTAND_OK="0"
		else
			HAMSTAND_OK="1"
		fi			

	fi
fi

}

function check_interfaces()
{
FILE_STARTUP=/etc/startup-config
if [ "$isSystemd" == "NO" ]
then
	FILE=/etc/network/interfaces
fi
FILEMLINEC=/etc/itmlinec.conf
MYIPFILE=/etc/sysconfig/myip
BONDPORTS=/etc/sysconfig/bondports
FILE_BONDSTATIC=/etc/sysconfig/bonding.static
S_NODE=$(/sbin/cfg-getparams.sh mmNodeNumber)

	function etcnetworkinterfaces() {
	# runu interfaces
	if [ "$isSystemd" == "NO" ]
	then
		MATCH1=`cat ${FILE} | grep "pre-up ifconfig ${ETH_INTERFACES[$index]} 0.0.0.0 up"`
		MATCH01=`cat ${FILE} | grep "up ifconfig \$\IFACE up"`
		MATCH02=`cat ${FILE} | awk '/#start MN vlan/{p=1} /#STATICBOND/{p=0} p' | grep "address ${IPN}"`
		MATCH03=`cat ${FILE} | awk '/#start MN vlan/{p=1} /#STATICBOND/{p=0} p' | grep "netmask ${NMASK}"`
		MATCH04=`cat ${FILE} | awk '/#start MN vlan/{p=1} /#STATICBOND/{p=0} p' | grep "broadcast ${SUBNET_BROADCAST}"`

		if [ "${MATCH01}" != "" ] || [ "${MATCH02}" != "" ] || [ "${MATCH03}" != "" ] || [ "${MATCH04}" != "" ]
		then
			MATCH2="ok"
		fi

	else
		if [ -f /etc/systemd/network/${ETH_INTERFACES[$index]}.network ]
		then
			MATCH1="OK"
		fi
		Mgmtvlan=`konf -- -d |grep 'vlan mgmt' | awk '{ printf $3}'`
		if [ $Mgmtvlan == "" ]
		then
			BOND0_FILE=/etc/systemd/network/bond0.network
		else
			BOND0_FILE=/etc/systemd/network/bond0.$Mgmtvlan.network
			
		fi
		MATCH02=`cat ${BOND0_FILE} | grep "Address=${IP}"`

		if [ "${MATCH01}" != "" ] || [ "${MATCH02}" != "" ] 
		then
			MATCH2="ok"
		fi

	fi

	tLen=${#ETH_INTERFACES[@]}

	if [ "$isSystemd" == "NO" ]
	then
		for (( i=0; i<${tLen}; i++ ));
		do
			MATCH=`cat ${FILE} | grep "up ifenslave \$\IFACE ${ETH_INTERFACES[i]}"`
			if [ "$MATCH" != "" ]
			then
				MATCH3="ok"
			fi
		done
	else
		MATCH3="ok"
	fi

	if [ "$isSystemd" == "NO" ]
	then
		for (( i=0; i<${tLen}; i++ ));
		do
			MATCH=`cat ${FILE} | grep "down ifenslave -d \$\IFACE ${ETH_INTERFACES[i]}"`
			if [ "$MATCH" != "" ]
			then
				MATCH4="ok"
			fi
		done
	else
		MATCH4="ok"
	fi

	if [ "${MATCH1}" == "" ] || [ "${MATCH2}" == "" ] || [ "${MATCH3}" == "" ] || [ "${MATCH4}" == "" ]
	then
		NETWORK_OK="0"
	else
		NETWORK_OK="1"
	fi			


	# mand - add static internal interfaces for DSP
	if [ -f ${FILE_BONDSTATIC} ]
	then
		cat ${FILE_BONDSTATIC} | awk '/STATICBOND/{p=1} /!/{p=0} p' >> ${FILE}
	fi

	echo "#This is temporary autogenerated file for internal configurations usage, do not change or use it !!!" > ${MYIPFILE}
	echo "MYIP=${IPN}${MYMASK}" >> ${MYIPFILE}

	}

# main
IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
#	IP=`cat ${FILE_STARTUP} | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep 'ip address' | awk '{print $3}'`

if [ "$IP" != "" ]
then
	MASK=`echo ${IP} | sed 's/^.*\(...\)$/\1/'`
	MYMASK=${MASK}
	IPN=`echo ${IP} | sed 's/\(.*\).../\1/'`
	if [ "${IPN}" == "" ] || [ "${MASK}" == "" ]
	then
		echo "Error: IP/mask configuration error"
		#exit 1
	fi
else
	echo "Error: No mgmt IP address configured !"
	IPN=""
fi

. /sbin/cfg-calculate-network.sh ${IP}
convert_ip_mask

if [ -e ${BONDPORTS} ]
then
	. ${BONDPORTS}
else
	# mand added - create bondports file in it does not exist
	/sbin/cfg-create-bond-ports.sh ${BONDPORTS}
	. ${BONDPORTS}
fi

if [ ${#PORTS[@]} -gt 0 ]
then
	# Create an array of ports
	ETH_INTERFACES=(${PORTS[@]})
	etcnetworkinterfaces
else
	echo "Error: no bonded ports defined in ${BONDPORTS}"
	return 1
fi
}

# func template
#############################################
#function systype_running()
#{
#}
#function systype_files()
#{
#}
#function systype_service()
#{
#}
#############################################


#############################################
# main                                      #
#############################################
if [ ! -d /tmp/tests/clish/bckp ]
then
	mkdir -p /tmp/tests/clish/bckp
fi


if [ ! -d /tmp/tests/clish/bckpreboot ]
then
	mkdir -p /tmp/tests/clish/bckpreboot
fi

if [ ! -f $TESTS_RESULT_FILE ]
then
	mkdir -p $TESTS_RESULT_DIR
	touch $TESTS_RESULT_FILE
fi

RED='\033[0;31m' # Red Color
GREEN='\e[32m' # Green Color
YELLOW='\e[33m'
NC='\033[0m' # No Color

if [[ ( $1 == "--help") ||  $1 == "-h" ]]
then
        usage
        exit 0
fi

System_type=$1
Phase_install=$2
UseStartupConfig=$3

if ([ "${System_type}" != "standalone" ] && [ "${System_type}" != "duplicated" ] && [ "${System_type}" != "geo-dual" ])
then
        echo "Wrong input parameter - ${System_type} !" | tee  -a $TESTS_RESULT_FILE
        usage
        exit 1
fi

if ([ "${Phase_install}" != "formatted" ] && [ "${Phase_install}" != "runtime" ])
then
        echo "Wrong input parameter - ${Phase_install} !" | tee  -a $TESTS_RESULT_FILE
        usage
        exit 1
fi

if [ "$3" != "" ]
then
	if [ "$3" != "use-startup-config" ]
	then
		if [ "$3" != "no-console" ]
		then
			echo "Wrong input parameter - $3 !"
			echo ""
			usage
			exit 1
		fi
	fi
fi

if [ "$4" != "" ]
then
	if [ "$4" != "no-console" ]
	then
		echo "Wrong input parameter - $3 !"
		echo ""
		usage
		exit 1
	fi
fi

if [ "$4" == "no-console" ] || [ "$3" == "no-console" ]
then
	NoConsole="YES"
else
	NoConsole="NO"
fi

if [ "$3" == "use-startup-config" ]
then
	ValueUseStartupConfig="YES"
else
	ValueUseStartupConfig="NO"
fi

if [ -f $TEST_FILE ]
then
	. $TEST_FILE
else
	echo "Missing test parameters file $TEST_FILE - aborting !"
	exit 1
fi

if [ "$3" == "use-startup-config" ]
then
	check_startup_config
else
	if [ "${NoConsole}" == "YES" ]
	then
	# If optional parameter no-console is used then then skip setting mgmt Ip and route
	# Local_mgmt_IP
		locmgmtip=`cat ${STARTUP_CONFIG} |grep 'ip address' |head -1 |awk '{print $3}'`
		if [ "${locmgmtip}" != "" ]
		then
			Local_mgmt_IP=${locmgmtip}
		else
			# skip test Local_mgmt_IP
			NoTesLocal_mgmt_IP="1"
		fi
	# Mgmt_IP_route
		route=`cat ${STARTUP_CONFIG} |grep 'ip route mgmt' |cut -d " " -f 4-`
		if [ "${route}" != "" ]
		then
			Mgmt_IP_route=${route}
		else
			# skip test Mgmt_IP_route
			NoTestMgmt_IP_route="1"
		fi
	fi
fi

function check_files_after_reboot()
{
# check /etc/network/interfaces

if [ "$isSystemd" == "NO" ]
then
	if [ -f /etc/network/interfaces ]
	then
		check_interfaces
		if [ "${NETWORK_OK}" == "1" ]
		then
			printf "${GREEN}file interfaces is OK${NC}\n"
			echo "file interfaces is OK" >> $TESTS_RESULT_FILE
		else
			printf "${RED}file interfaces is NOK${NC}\n"
			echo "file interfaces is NOK" >> $TESTS_RESULT_FILE
		fi
	fi
else
	if [ -f /etc/systemd/network/eth0.network ] && [ -f /etc/systemd/network/bond0.network ]
	then
		check_interfaces
		if [ "${NETWORK_OK}" == "1" ]
		then
			printf "${GREEN}file interfaces is OK${NC}\n"
			echo "file interfaces is OK" >> $TESTS_RESULT_FILE
		else
			printf "${RED}file interfaces is NOK${NC}\n"
			echo "file interfaces is NOK" >> $TESTS_RESULT_FILE
		fi
	fi
fi

# check /etc/ha.d/haresources
if [ "${Phase_install}" != "formatted" ]
then
	if [ -f /etc/ha.d/haresources ]
	then
		check_haresources
		if [ "${HARE_OK}" == "1" ]
		then
			printf "${GREEN}file haresources is OK${NC}\n"
			echo "file haresources is OK" >> $TESTS_RESULT_FILE
		else
			printf "${RED}file haresources is NOK${NC}\n"
			echo "file haresources is NOK" >> $TESTS_RESULT_FILE
		fi
	fi
fi

# check /etc/ha.d/ha.cf
if [ -f /etc/ha.d/ha.cf ]
then
	check_hacf
	if [ "${HACF_OK}" == "1" ]
	then
		printf "${GREEN}file ha.cf is OK${NC}\n"
		echo "file ha.cf is OK" >> $TESTS_RESULT_FILE
	else
		printf "${RED}file ha.cf is NOK${NC}\n"
		echo "file ha.cf is NOK" >> $TESTS_RESULT_FILE
	fi
fi

# check /opt/iskratel/etc/ham.d/ham.cf
if [ -f /opt/iskratel/etc/ham.d/ham.cf ]
then
	check_hamcf
	if [ "${HAMCF_OK}" == "1" ]
	then
		printf "${GREEN}file ham.cf is OK${NC}\n"
		echo "file ham.cf is OK" >> $TESTS_RESULT_FILE
	else
		printf "${RED}file ham.cf is NOK${NC}\n"
		echo "file hamcf is NOK" >> $TESTS_RESULT_FILE
	fi
fi

# check /etc/drbd.conf
if [ -f /etc/drbd.conf ]
then
	DRBDCF=/etc/sysconfig/drbdp.cf
	if [ -f ${DRBDCF} ]
	then
		check_drbdconf
		if [ "${DRBD_OK}" == "1" ]
		then
			printf "${GREEN}file drbd.conf is OK${NC}\n"
			echo "file drbd.conf is OK" >> $TESTS_RESULT_FILE
		else
			printf "${RED}file drbd.conf is NOK${NC}\n"
			echo "file drbd.conf is NOK" >> $TESTS_RESULT_FILE
		fi
	fi
fi
# check /etc/opensaf/tipc_config
if [ -f /etc/opensaf/tipc_config ]
then
	check_tipc
	if [ "${TIPC_OK}" == "1" ]
	then
		printf "${GREEN}file tipc_config is OK${NC}\n"
		echo "file tipc_config is OK" >> $TESTS_RESULT_FILE
	else
		printf "${RED}file tipc_config is NOK${NC}\n"
		echo "file tipc_config is NOK" >> $TESTS_RESULT_FILE
	fi
fi


#
FILE_HAMSYSGENCF=/opt/iskratel/etc/ham.d/hamsysgen.cf
FILE_HAMSYSCOMCF=/opt/iskratel/etc/ham.d/hamsyscom.cf
FILE_HAMCF_STANDARD=/opt/iskratel/etc/ham.d/hamstandard.cf

if ([ -f ${FILE_HAMSYSGENCF} ] && [ -f ${FILE_HAMSYSCOMCF} ] && [ -f ${FILE_HAMCF_STANDARD} ])
then
	check_hamsyscomgen

	if [ "${HAMSYSCOM_OK}" == "1" ]
	then
		printf "${GREEN}file hamsyscom is OK${NC}\n"
		echo "file hamsyscom is OK" >> $TESTS_RESULT_FILE
	else
		printf "${RED}file hamsyscom is NOK${NC}\n"
		echo "file hamsyscom is NOK" >> $TESTS_RESULT_FILE
	fi

	if [ "${HAMSYSGEN_OK}" == "1" ]
	then
		printf "${GREEN}file hamsysgen is OK${NC}\n"
		echo "file hamsysgen is OK" >> $TESTS_RESULT_FILE
	else
		printf "${RED}file hamsysgen is NOK${NC}\n"
		echo "file hamsysgen is NOK" >> $TESTS_RESULT_FILE
	fi

	sysType=`cat ${FILE_CFG} | grep 'system type' | awk '{print $3}'`
	if [ "$sysType" != "standalone" ]
	then
		if [ "${HAMSTAND_OK}" == "1" ]
		then
			printf "${GREEN}file hamstandard is OK${NC}\n"
			echo "file hamstandard is OK" >> $TESTS_RESULT_FILE
		else
			printf "${RED}file hamstandard is NOK${NC}\n"
			echo "file hamstandard is NOK" >> $TESTS_RESULT_FILE
		fi
	fi
fi
}

function gen_files_for_after_reboot()
{
echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
echo "Generating files for after reboot" | tee -a $TESTS_RESULT_FILE
echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
/sbin/system-config-clish >> /dev/null
/sbin/system-config-clish-late >> /dev/null 2> /dev/null

}

echo
echo "#############################################################################"
echo "### CLISH test (FULL) - testing all parameters                            ###"
echo "#############################################################################"
echo
# Input parameters
# system type (standalone duplicated geo-single geo-dual)
# Phase of installed priduct (formatted or runtime)
# invert logic for no-console display in log file
if [ "${NoConsole}" == "YES" ]
then
	NoConsoleInvert="NO"
else
	NoConsoleInvert="YES"
fi

if [ "${System_type}" == "standalone" ] || [ "${System_type}" == "duplicated" ] || [ "${System_type}" == "geo-single" ] || [ "${System_type}" == "geo-dual" ]
then
	echo "###############################################################################" > $TESTS_RESULT_FILE	
	echo "System type:        ${System_type}" | tee  -a $TESTS_RESULT_FILE
	echo "System state:       ${Phase_install}" | tee  -a $TESTS_RESULT_FILE
	echo "use-startup-config: ${ValueUseStartupConfig}" | tee  -a $TESTS_RESULT_FILE
	echo "console: ${NoConsoleInvert}" | tee  -a $TESTS_RESULT_FILE
fi

# check if all parameters are set in testfile
chktestfileparams

echo
echo "-----------------------------------------"
echo "Backup startup-config ..."
cp ${STARTUP_CONFIG} ${STARTUP_CONFIG}.bkp
echo "Backup files ..."
backup_files backuping

# Restarting konf deamon
if [ "$isSystemd" == "NO" ]
then
	/etc/init.d/konfd stop >>/dev/null
	/etc/init.d/konfd start >>/dev/null
else
	systemctl stop klish-konfd.service >>/dev/null
	systemctl start klish-konfd.service >>/dev/null
fi

echo "-----------------------------------------"
echo

echo
echo "###############################################################################" | tee  -a $TESTS_RESULT_FILE
echo "### Start all clish parameter tests ###" | tee  -a $TESTS_RESULT_FILE
echo "###############################################################################" | tee  -a $TESTS_RESULT_FILE
echo "" | tee  -a $TESTS_RESULT_FILE
echo

# Hostname
if [ "$Hostname" != "" ]
then
	echo "###############################################################################" | tee  -a $TESTS_RESULT_FILE
	echo "Starting test for hostname $Hostname"                             			| tee -a $TESTS_RESULT_FILE 
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	hostname_running
	hostname_files
	hostname_service
else
	printf "${YELLOW}Warrning $Hostname does not exsist in $TEST_FILE !!!${NC}\n"
fi

# System name
if [ "$System_name" != "" ]
then
	echo "###############################################################################" | tee  -a $TESTS_RESULT_FILE
	echo "Starting test for system name $System_name"                                               | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	systemname_running
	systemname_files
	systemname_service
else
	printf "${YELLOW}Warning $System_name does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$NoTesLocal_mgmt_IP" != "1" ]
then
	if [ "$Local_mgmt_IP" != "" ]
	then
		# Local mgmt IP
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for management IP address $Local_mgmt_IP"               | tee -a $TESTS_RESULT_FILE 
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		mgmtip_running
		mgmtip_files
		mgmtip_service
	else
		printf "${YELLOW}Warrning $Local_mgmt_IP does not exsist in $TEST_FILE !!!${NC}\n"
	fi
fi

if [ "${NoTestMgmt_IP_route}" != "1" ]
then
	if [ "$Mgmt_IP_route" != "" ]
	then
		# Mgmt IP route
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for Mgmt IP route $Mgmt_IP_route" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		mgmtroute_running
		mgmtroute_files
		mgmtroute_service
	else
		printf "${YELLOW}Warrning $Mgmt_IP_route does not exsist in $TEST_FILE !!!${NC}\n"
	fi
fi

if [ "${System_type}" != "" ]
then
	# System type
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for System type ${System_type}" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	systype_running
	systype_files
	systype_service
else
	printf "${YELLOW}Warrning ${System_type} does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$System_unit_nodeID" != "" ]
then
	# System unit/node ID
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for System unit/node ID $System_unit_nodeID" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	sysUnitNode_running
	sysUnitNode_files
	sysUnitNode_service
else
	printf "${YELLOW}Warrning $System_unit_nodeID does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$Chassis_type_size" != "" ]
then
	# Chassis type/size
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Chassis type/size $Chassis_type_size" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	Chassis_type_size_running
	Chassis_type_size_files
	Chassis_type_size_service
else
	printf "${YELLOW}Warrning $Chassis_type_size does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$Domain_name" != "" ]
then
	# Domain name
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Domain name $Domain_name" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	domain_name_running
	domain_name_files
	domain_name_service
else
	printf "${YELLOW}Warrning $Domain_name does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$Primary_DNS_server" != "" ]
then
	# Primary DNS server
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Primary DNS server $Primary_DNS_server" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	PrDNSer_running
	PrDNSer_files
	PrDNSer_service
else
	printf "${YELLOW}Warrning $Primary_DNS_server does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$Secondary_DNS_server" != "" ]
then
	# Secondary DNS server
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Secondary DNS server $Secondary_DNS_server" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	SecDNSer_running
	SecDNSer_files
	SecDNSer_service
else
	printf "${YELLOW}Warrning $Secondary_DNS_server does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$Tertiary_DNS_server" != "" ]
then
	# Tertiary DNS server
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Tertiary DNS server $Tertiary_DNS_server" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	TerDNSer_running
	TerDNSer_files
	TerDNSer_service
else
	printf "${YELLOW}Warrning $Tertiary_DNS_server does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "${ceproduct}" == "1" ]
then
	if [ "${InternetConnectivity}" != "" ]
	then
		# Internet connectivity
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for Internet connectivity $InternetConnectivity" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		internetConnectivity_running
		internetConnectivity_files
		internetConnectivity_service
	fi

	if [ "${NtpServerLocation}" != "" ]
	then
		# Ntp server location
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for Ntp server location $NtpServerLocation" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		ntpServerLocation_running
		ntpServerLocation_files
		ntpServerLocation_service
	fi
fi

if [ "$Primary_NTP_server" != "" ]
then
	# Primary NTP server
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Primary NTP server $Primary_NTP_server" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	PrNTPSer_running
	PrNTPSer_files
	PrNTPSer_service
else
	printf "${YELLOW}Warrning $Primary_NTP_server does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$Secondary_NTP_server" != "" ]
then
	# Secondary NTP server
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Secondary NTP server $Secondary_NTP_server" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	SecNTPSer_running
	SecNTPSer_files
	SecNTPSer_service
else
	printf "${YELLOW}Warrning $Secondary_NTP_server does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$Tertiary_NTP_server" != "" ]
then
	# Tertiary NTP server
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Tertiary NTP server $Tertiary_NTP_server" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	TerNTPSer_running
	TerNTPSer_files
	TerNTPSer_service
else
	printf "${YELLOW}Warrning $Tertiary_NTP_server does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$Static_host" != "" ]
then
	# Static host
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Static host $Static_host" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	Sthost_running
	Sthost_files
	Sthost_service
else
	printf "${YELLOW}Warrning $Static_host does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$Timezone" != "" ]
then
	# Timezone
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Timezone $Timezone" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	timezone_running
	timezone_files
	timezone_service
else
	printf "${YELLOW}Warrning $Timezone does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$SNMP_server_community" != "" ]
then
	# SNMP server community
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for SNMP server community $SNMP_server_community" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	snmpserver_running
	snmpserver_files
	snmpserver_service
else
	printf "${YELLOW}Warrning $SNMP_server_community does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "${Phase_install}" != "formatted" ]
then
	if [ "$SNMP_trap_dest_IP" != "" ]
	then
		# SNMP trap dest. IP
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for SNMP trap dest. IP $SNMP_trap_dest_IP" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		snmptrdestIp_running
		snmptrdestIp_files
		snmptrdestIp_service
	else
		printf "${YELLOW}Warrning $SNMP_trap_dest_IP does not exsist in $TEST_FILE !!!${NC}\n"
	fi
fi

if [ "${Phase_install}" != "formatted" ]
then
	if [ "$SNMP_trap_dest_port" != "" ]
	then
		# SNMP trap dest. port
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for SNMP trap dest. port $SNMP_trap_dest_port" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		snmptrdestPort_running
		snmptrdestPort_files
		snmptrdestPort_service
	else
		printf "${YELLOW}Warrning $SNMP_trap_dest_port does not exsist in $TEST_FILE !!!${NC}\n"
	fi
fi


if [ "${Phase_install}" != "formatted" ]
then
	if [ "$SNMP_trap_community" != "" ]
	then
		# SNMP trap community
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for SNMP trap community $SNMP_trap_community" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		snmptrdestCommu_running
		snmptrdestCommu_files
		snmptrdestCommu_service
	else
		printf "${YELLOW}Warrning $SNMP_trap_community does not exsist in $TEST_FILE !!!${NC}\n"
	fi
fi

# chech vlan on switchports (CE products only)
if [ -f /etc/sysconfig/bonding.static ]
then
	if [ "$vlanadd1" != "" ]
	then
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for vlan on switchports $vlanadd1" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		vlanswitchports_running
		vlanswitchports_files
		vlanswitchports_service
	else
		printf "${YELLOW}Warrning $vlanadd1 does not exsist in $TEST_FILE !!!${NC}\n"
	fi
fi


if [ "$mgmtvlan" != "" ]
then
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for mgmt vlan $mgmtvlan" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	mgmtvlan_running
	mgmtvlan_files
	mgmtvlan_service
else
	printf "${YELLOW}Warrning $vlanadd1 does not exsist in $TEST_FILE !!!${NC}\n"
fi


# check if system is hsb
if [ "${System_type}" == "duplicated" ] || [ "${System_type}" == "geo-single" ] || [ "${System_type}" == "geo-dual" ]
then
	if [ "$HSB_mgmt_float_IP" != "" ]
	then
		# HSB mgmt float IP
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for HSB mgmt float IP $HSB_mgmt_float_IP" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		hsbmgmtfltIp_running
		hsbmgmtfltIp_files
		hsbmgmtfltIp_service
	else
		printf "${YELLOW}Warrning $HSB_mgmt_float_IP does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	# HSB local INT IP
	chkCeProduct
	if [ "${ceproduct}" == "0" ]
	then
		if [ "$HSB_local_INT_IP" != "" ]
		then
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			echo "Starting test for HSB local INT IP $HSB_local_INT_IP" | tee -a $TESTS_RESULT_FILE
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			hsblocIntIp_running
			hsblocIntIp_service
		else
			printf "${YELLOW}Warrning $HSB_local_INT_IP does not exsist in $TEST_FILE !!!${NC}\n"
		fi
	fi

	if [ "$HSB_remote_host" != "" ]
	then	
		# HSB remote host
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for HSB remote host $HSB_remote_host" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		hsbremhost_running
		hsbremhost_files
		hsbremhost_service
	else
		printf "${YELLOW}Warrning $HSB_remote_host does not exsist in $TEST_FILE !!!${NC}\n"
	fi

	if [ "$HSB_remote_host_mgmt_IP" != "" ]
	then	
		# HSB remote host mgmt IP	
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for HSB remote host mgmt IP $HSB_remote_host_mgmt_IP" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		remhstmgmtIp_running
		remhstmgmtIp_files
		remhstmgmtIp_service
	else
		printf "${YELLOW}Warrning $HSB_remote_host_mgmt_IP does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	# HSB remote host INT IP
	chkCeProduct
	if [ "${ceproduct}" == "0" ]
	then
		if [ "$HSB_remote_host_INT_IP" != "" ]
		then	
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			echo "Starting test for HSB remote host INT IP $HSB_remote_host_INT_IP" | tee -a $TESTS_RESULT_FILE
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			remhstintIp_running
			remhstintIp_files
			remhstintIp_service
		else
			printf "${YELLOW}Warrning $HSB_remote_host_INT_IP does not exsist in $TEST_FILE !!!${NC}\n"
		fi
	fi
	
	# HSB internal vlan
	chkCeProduct
	if [ "${ceproduct}" == "0" ]
	then
		if [ "$HSB_internal_vlan" != "" ]
		then	
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			echo "Starting test for HSB internal vlan $HSB_internal_vlan" | tee -a $TESTS_RESULT_FILE
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			hsbintVlan_running
			hsbintVlan_files
			hsbintVlan_service
		else
			printf "${YELLOW}Warrning $HSB_internal_vlan does not exsist in $TEST_FILE !!!${NC}\n"
		fi
	fi
	
	# HSB internal interface
	chkCeProduct
	if [ "${ceproduct}" == "0" ]
	then
		if [ "$HSB_internal_interface" != "" ]
		then	
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			echo "Starting test for HSB internal interface $HSB_internal_interface" | tee -a $TESTS_RESULT_FILE
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			hsbintIface_running
			hsbintIface_files
			hsbintIface_service
		else
			printf "${YELLOW}Warrning $HSB_internal_interface does not exsist in $TEST_FILE !!!${NC}\n"
		fi
	fi
	

	
# runu CS itha.cf not exsist 
	ITHA_CFG=/etc/ha.d/itha.cf
	if [ -f ${ITHA_CFG=/etc/ha.d/itha.cf} ]
	then
		# test hsb enable disable
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for enable hsb " | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		hsb_enable_test
		configure_system_hsb
		
		# HSB local INT IP files
		chkCeProduct
		if [ "${ceproduct}" == "0" ]
		then
			if [ "$HSB_local_INT_IP" != "" ]
			then
				echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
				echo "Starting test for HSB local INT IP $HSB_local_INT_IP files test" | tee -a $TESTS_RESULT_FILE
				echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
				hsblocIntIp_files
			else
				printf "${YELLOW}Warrning $HSB_local_INT_IP does not exsist in $TEST_FILE !!!${NC}\n"
			fi
		fi

		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for disable hsb " | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		hsb_disable_test

		# ha interface non CE
		chkCeProduct
		if [ "${ceproduct}" == "0" ]
		then
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			echo "Starting test for ha interfaces ..." | tee -a $TESTS_RESULT_FILE
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			ha_interface
		fi
	fi
fi
# check if geo system
if [ "${System_type}" == "geo-single" ] || [ "${System_type}" == "geo-dual" ]
then
	ITHA_CFG=/etc/ha.d/itha.cf
	if [ -f ${ITHA_CFG=/etc/ha.d/itha.cf} ]
	then
		cat > /tmp/hsbenable <<EOF
!
hsb
enable
!
EOF
		cat /tmp/hsbenable |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view >>/dev/null
	fi
	
	if [ "$GEO_mgmt_float_IP" != "" ]
	then	
		# GEO mgmt float IP
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for GEO mgmt float IP $GEO_mgmt_float_IP" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		geoMgmtfltIp_running
		geoMgmtfltIp_files
		geoMgmtfltIp_service
	else
		printf "${YELLOW}Warrning $GEO_mgmt_float_IP does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	if [ "$GEO_preferred_unit" != "" ]
	then	
		# GEO preferred unit
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for GEO preferred unit $GEO_preferred_unit" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		geoPrUnit_running
		geoPrUnit_files
		geoPrUnit_service
	else
		printf "${YELLOW}Warrning $GEO_preferred_unit does not exsist in $TEST_FILE !!!${NC}\n"
	fi

	if [ "$GEO_mode" != "" ]
	then	
		# GEO mode
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for GEO mode $GEO_mode" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		geomode_running
		geomode_files
		geomode_service
	else
		printf "${YELLOW}Warrning $GEO_mode does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	if [ "$GEO_switchover_timeout" != "" ]
	then	
		# GEO switchover timeout
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for GEO switchover timeout $GEO_switchover_timeout" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		geoswoverTo_running
		geoswoverTo_files
		geoswoverTo_service
	else
		printf "${YELLOW}Warrning $GEO_switchover_timeout does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	if [ "$GEO_remote_unit_internal_vlan" != "" ]
	then	
		# GEO remote unit internal vlan
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for GEO remote unit internal vlan $GEO_remote_unit_internal_vlan" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		geoRemIntVlan_running
		geoRemIntVlan_files
		geoRemIntVlan_service
	else
		printf "${YELLOW}Warrning $GEO_remote_unit_internal_vlan does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	if [ "$GEO_remote_unit_mgmt_float_IP" != "" ]
	then	
		# GEO remote unit mgmt float IP
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for GEO remote unit mgmt float IP $GEO_remote_unit_mgmt_float_IP" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		geoRemUnFltIp_running
		geoRemUnFltIp_files
		geoRemUnFltIp_service
	else
		printf "${YELLOW}Warrning $GEO_remote_unit_mgmt_float_IP does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	if [ "$GEO_remote_hostname_1" != "" ]
	then	
		# GEO remote hostname 1
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for GEO remote hostname 1 $GEO_remote_hostname_1" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		geoRemHst1_running
		geoRemHst1_files
		geoRemHst1_service
	else
		printf "${YELLOW}Warrning $GEO_remote_hostname_1 does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	if [ "$GEO_remote_host_1_mgmt_IP" != "" ]
	then	
		# GEO remote host 1 mgmt IP
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for GEO remote host 1 mgmt IP $GEO_remote_host_1_mgmt_IP" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		geoRemHst1Ip_running
		geoRemHst1Ip_files
		geoRemHst1Ip_service
	else
		printf "${YELLOW}Warrning $GEO_remote_host_1_mgmt_IP does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	# GEO remote host 1 INT IP
	chkCeProduct
	if [ "${ceproduct}" == "0" ]
	then
		if [ "$GEO_remote_host_1_INT_IP" != "" ]
		then	
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			echo "Starting test for GEO remote host 1 INT IP $GEO_remote_host_1_INT_IP" | tee -a $TESTS_RESULT_FILE
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			geoRemHst1IntIp_running
			geoRemHst1IntIp_files
			geoRemHst1IntIp_service
		else
			printf "${YELLOW}Warrning $GEO_remote_host_1_INT_IP does not exsist in $TEST_FILE !!!${NC}\n"
		fi
	fi

	if [ "$GEO_remote_hostname_2" != "" ]
	then	
		# GEO remote hostname 2
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for GEO remote hostname 2 $GEO_remote_hostname_2" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		geoRemHst2_running
		geoRemHst2_files
		geoRemHst2_service
	else
		printf "${YELLOW}Warrning $GEO_remote_hostname_2 does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	if [ "$GEO_remote_host_2_mgmt_IP" != "" ]
	then	
		# GEO remote host 2 mgmt IP
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		echo "Starting test for GEO remote host 2 mgmt IP $GEO_remote_host_2_mgmt_IP" | tee -a $TESTS_RESULT_FILE
		echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
		geoRemHst2Ip_running
		geoRemHst2Ip_files
		geoRemHst2Ip_service
	else
		printf "${YELLOW}Warrning $GEO_remote_host_2_mgmt_IP does not exsist in $TEST_FILE !!!${NC}\n"
	fi
	
	# GEO remote host 2 INT IP
	chkCeProduct
	if [ "${ceproduct}" == "0" ]
	then
		if [ "$GEO_remote_host_2_INT_IP" != "" ]
		then	
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			echo "Starting test for GEO remote host 2 INT IP $GEO_remote_host_2_INT_IP" | tee -a $TESTS_RESULT_FILE
			echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
			geoRemHst2IntIp_running
			geoRemHst2IntIp_files
			geoRemHst2IntIp_service
		else
			printf "${YELLOW}Warrning $GEO_remote_host_2_INT_IP does not exsist in $TEST_FILE !!!${NC}\n"
		fi
	fi
######### runu
	# test geo enable disable
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for enable geo ..." | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	ITHA_CFG=/etc/ha.d/itha.cf
	if [ -f ${ITHA_CFG=/etc/ha.d/itha.cf} ]	
	then
		geo_enable_test
	fi
	configure_system_hsb
	configure_system_geo
		
	if [ "${Phase_install}" != "formatted" ]
	then
		/sbin/cfg-gham.sh reboot
		cp /opt/iskratel/etc/ham.d/gham.cf $TESTS_BACKUP_DIR
	fi

#	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
#	echo "Starting test for disable geo ..." | tee -a $TESTS_RESULT_FILE
#	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE	
#	geo_disable_test
fi

if [ "$Filter_name" != "" ]
then	
	# Filter create
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Filter create $Filter_name" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	filtercr_running
	filtercr_files
	filtercr_service
else
	printf "${YELLOW}Warrning $Filter_name does not exsist in $TEST_FILE !!!${NC}\n"
fi

if [ "$Filter_name" != "" ]
then	
	# Mgmt IP filter append
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	echo "Starting test for Mgmt IP filter $Filter_name" | tee -a $TESTS_RESULT_FILE
	echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
	mgmtIpfilter_running
	mgmtIpfilter_files
	mgmtIpfilter_service
else
	printf "${YELLOW}Warrning $Filter_name does not exsist in $TEST_FILE !!!${NC}\n"
fi

echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
echo "Dump of running-config : " | tee -a $TESTS_RESULT_FILE
echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
konf -- -d
konf -- -d >> $TESTS_RESULT_FILE

##############################################
# copy modified files in TEST RESULT DIR
backup_files copyresultfiles
##############################################
gen_files_for_after_reboot
# copy files for after reboot on new backup dir
backup_files copyresultfilesafterreboot
echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
echo "Checking files for after reboot" | tee -a $TESTS_RESULT_FILE
echo "###############################################################################" | tee -a $TESTS_RESULT_FILE

konf -- -d > /tmp/clishTest-running-conf

cp /tmp/clishTest-running-conf ${STARTUP_CONFIG}
/sbin/system-config-clish-late >> /dev/null

check_files_after_reboot

##############################################
#
##############################################
# Restoring old configuration 
echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
echo "" | tee -a $TESTS_RESULT_FILE
echo "Restoring original configuration" | tee -a $TESTS_RESULT_FILE
echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
echo

cp ${STARTUP_CONFIG}.bkp ${STARTUP_CONFIG}

/sbin/system-config-clish-late >> /dev/null

if [ "$isSystemd" == "NO" ]
then
	/etc/init.d/konfd stop >>/dev/null
	/etc/init.d/konfd start >>/dev/null
else
	systemctl stop klish-konfd.service >>/dev/null
	systemctl start klish-konfd.service >>/dev/null
fi


#restor original files
backup_files restoring
sh /etc/actions/boot-late/reload-konfd | tee -a $TESTS_RESULT_FILE
chkCeProduct
if [ "${ceproduct}" == "1" ]
then
	sh /etc/actions/boot-late/reload-konfd-cmj| tee -a $TESTS_RESULT_FILE
fi
echo "load" |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w enable-view >>/dev/null

if [ "$isSystemd" == "NO" ]
then
	/etc/init.d/networking restart
fi


echo "" | tee -a $TESTS_RESULT_FILE
echo "###############################################################################" | tee -a $TESTS_RESULT_FILE
echo "### End of clish tests ###" | tee -a $TESTS_RESULT_FILE
echo "### Results of clish tests are stored in file $TESTS_RESULT_FILE ###" | tee -a $TESTS_RESULT_FILE
echo
cp $TESTS_RESULT_FILE /tmp/clish_test_cmd.log
