#!/bin/bash
# Script for checking if ssh keys are exchanged with remote host
# Returns:
#	0 for OK
#	1 NOK (SSH keys not exchanged)
#	2 NOK (remote host not reachable on port 22 - ssh port)

if [ "$1" == "--help" ]
then
	echo
	echo "Usage: $0 <remote_host_ip_or_url>"
	echo 

	echo "Returns:"
	echo "	0 - SSH keys exchanged"
	echo "	1 - SSH keys not exchanged"
	echo "	2 - Remote host not reachable on port 22 - ssh"
	echo

	exit 0
fi

if [ "$1" == "" ]
then
        echo
	echo "Please enter remote host IP or URL address"
	echo
        echo "Usage: $0 <remote_host_ip_or_url>"
        echo

        exit 0
fi

remHost=$1

if [ -f /usr/bin/nc ]
then
	nc --wait=1 --zero $remHost 22 &>/dev/null
	if [ "$?" == "0" ]
	then
		rv=1
	else
		rv=0
	fi
else
	if [ -f /usr/bin/nmap ]
	then
		# check if host reachable on port 22 - ssh
		rv=`nmap -p 22 $remHost 2>/dev/null | grep 'open' | wc -l`
	else
		#can not check connectivity to 22 port
		rv=1
	fi
fi


if [ "$rv" == "0" ]
then
	echo 2
else
	# check if ssh key are exchanged
	ssh -o BatchMode=yes -o StrictHostKeyChecking=yes root@$remHost -C 'ls / > /dev/null' 2> /dev/null

	if [ "$?" != "0" ]
	then
		echo 1
	else
		echo 0
	fi
fi

