#!/bin/bash

DRBDCF=/etc/sysconfig/drbdp.cf
DRBDCONF_DIR=/etc/drbd.d/
FILE_STARTUP=/etc/startup-config

# /etc not mounted yet
# DRBD_ON=`find /etc/rc* -type l -name S[0-9][0-9]drbd | wc -l`

HSB=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
if [ "${HSB}" == "" ]
then
PRODUCT_TYPE="nohsb"
else
PRODUCT_TYPE="hsb"
fi

#get remote MN IP
#IP=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address mgmt' |awk '{print $4}'`
IP=$(/sbin/cfg-getparams.sh hsbRemoteMnIpAddress)
. /sbin/cfg-calculate-network.sh ${IP}
convert_ip_mask
REM_IP=`echo ${IPN}`
echo $REM_IP

#get local internal IP
#IP=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' ip address internal' |  grep -vw '  ip address internal' |awk '{print $4}'`
IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
. /sbin/cfg-calculate-network.sh ${IP}
convert_ip_mask
INT1_IP=`echo ${IPN}`
echo $INT1_IP

#get remote internal IP
#IP=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address internal' |awk '{print $4}'`
IP=$(/sbin/cfg-getparams.sh hsbRemIntIpAddress)
. /sbin/cfg-calculate-network.sh ${IP}
convert_ip_mask
INT2_IP=`echo ${IPN}`
echo $INT2_IP

#get local hostname
#TARGET_NAME1=`cat ${FILE_STARTUP} | awk '/hostname/{p=1} /!/{p=0} p' |  grep hostname |  grep -vw ' hostname' | grep -v 'hostnameredundant'|  head -n 1 | awk '{print $2}'`
TARGET_NAME1=$(/sbin/cfg-getparams.sh localHostname)
echo $TARGET_NAME1

#get remote hostname
#TARGET_NAME2=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' hostname' | awk '{print $2}'`
TARGET_NAME2=$(/sbin/cfg-getparams.sh hsbRemoteHostname)
echo $TARGET_NAME2

if [ "$PRODUCT_TYPE" == "nohsb" ]
then
	INT1_IP="0"
	INT2_IP="0"
fi

if [ "${GEO}" == "" ]
then
	UNIT_TYPE="noredundant"
else
	UNIT_TYPE="redundant"
fi

function hsb_etcdrbdconf() {
#	DEVICE=(${DDEV[@]})
#	DEVFS=(${DFS[@]})
#	DRBDDISKNAME=(${DDISK[@]})

#	Disable interractive info agreement for usage count
	mkdir -p ${DRBDCONF_DIR}
	rm -f ${DRBDCONF_DIR}/*.res
	index=0
	while test $index -lt ${#DEVICE[@]};
	do
		DRBD_PORT=`expr ${index} + 7788`
		if [ "x${DEVICE[$index]}" = "x" ]
		then
			echo "Error: missing device name DDEV in ${DRBDCF}"
			exit 1
		fi

		if [ "x${DEVFS[$index]}" = "x" ]
		then
			echo "Error: missing mountpoint DFS in ${DRBDCF}"
			exit 1
		fi
		if [ "x${DRBDDISKNAME[$index]}" = "x" ]
		then
			echo "Error: missing drbd name DDISK in ${DRBDCF}"
			exit 1
		fi

		# Convert UUID to real device file if used inside /etc/fstab
		# Exclude mountpoints that are binded ant not using real device
		physical_devce_fstab=`grep ${DEVFS[$index]} /etc/fstab | grep -v ',*bind' | sed "s%^#* */%/%" | sed "s%^#* *UUID%UUID%" | awk '{print $1}'`
		if [[ ${physical_devce_fstab} == UUID* ]]
		then
			physical_devce=$(blkid | grep $(echo ${physical_devce_fstab} | sed "s|.*=||" | sed 's|"||g') | sed "s|:.*||")
		else
			physical_devce=${physical_devce_fstab}
		fi
		
cat >> ${DRBDCONF_DIR}/$(basename ${DEVFS[$index]}).res <<EOF
resource ${DRBDDISKNAME[$index]} {
  on ha-$TARGET_NAME1 {
    device     ${DEVICE[index]};
    disk       ${physical_devce};
    address    ${INT1_IP}:${DRBD_PORT};
    meta-disk  internal;
  }

  on ha-$TARGET_NAME2 {
    device     ${DEVICE[index]};
    disk       ${physical_devce};
    address    ${INT2_IP}:${DRBD_PORT};
    meta-disk  internal;
  }
}
EOF
	index=`expr ${index} + 1`
	done
}

function hsb_etcfstab()
{
	index=0
	while test ${index} -lt ${#DEVICE[@]};
	do
		sed -i \
			-e "/${DRBDDISKNAME[$index]}/s|#*||" \
			-e "/${DRBDDISKNAME[$index]}/s|^ ||" \
		/etc/fstab

		sed -i \
			-e "/${DRBDDISKNAME[$index]}/s|^/|# /|" \
		/etc/fstab

		sed -i \
			-e "/${DRBDDISKNAME[$index]}/s|^UUID|# UUID|" \
		/etc/fstab

		# Unmount possible previously mounted partition
		umount ${DEVFS[$index]} 2>/dev/null
		index=`expr ${index} + 1`
	done
}

function nohsb_etcfstab()
{
	index=0
	while test ${index} -lt ${#DEVICE[@]};
	do
		sed -i \
			-e "/${DRBDDISKNAME[$index]}/s|#*||" \
			-e "/${DRBDDISKNAME[$index]}/s|^ ||" \
		/etc/fstab

		sed -i \
			-e "/${DRBDDISKNAME[$index]}/s|^#/|/|" \
		/etc/fstab

		sed -i \
			-e "/${DRBDDISKNAME[$index]}/s|^#UUID|UUID|" \
		/etc/fstab
		index=`expr ${index} + 1`
	done
}

#function logt_cfg() {
#if [ ${PRODUCT_TYPE} == "hsb" ]
#then
#	IP_HSB_NODE=${REM_IP}
#		echo "IP_HSB_NODE is " ${IP_HSB_NODE} | $LOGGER
#else
#	IP_HSB_NODE=
#	echo "IP_HSB_NODE is empty due to NOHSB configuration !!!" ${IP_HSB_NODE} | $LOGGER
#fi
#
#mkdir -p /opt/iskratel/etc
#cat > /opt/iskratel/etc/logt.cfg << EOF
###################################################################
## This file is generated from itRwc.sh script                    #
###################################################################
## Main configuration data
###################################################################
#BACKUP_OPTION=RUN               #make backup(RUN) or not(NORUN)
#BACKUP_TIMEOUT=200              #time after system initialization when backup is made
#TRANSFER_OPTION=RUN             #make transfer to MN(RUN) or not(NORUN)
#TRANSFER_TIMEOUT=10             #time after backup when transfer to MN is made
#
###################################################################
## tar.gz backup files setup                                      #
###################################################################
#pot_tar=/var/backup/logt                        # pot do mape za shranjevanje tar.gz datotek - backupov
#max_tar_MNtransfer=5                            # maksimalno stevilo tar.gz datotek - backupov na sistemu
#redial_period_MNtransfer=600                    # perioda ponavljanja v sekundah ob prekinitvi z MN
#write_history=yes                               # pise zgodovino kreiranih tar.gz v /var/lib/misc/logtTar.history
#IP_HSB_node=${IP_HSB_NODE}                       # IP ali hostname podvojene - nasprotne strani
#
###################################################################
## kaj se backupira - v arhiv vkljuci naslednje datoteke ali mape #
###################################################################
##[include] # vkljuci brez brisanja:
#####################################
#/var/log/                               # vsi logi na /var/log
#/opt/solid/work1318/*out                # solid baza
#/opt/solid/work1318/*ini                # solid baza
#/opt/solid/work1318/*cfg                # solid baza
#/etc/*conf                              # etc konfiguracijske datoteke
#/etc/hostname                           # ime sistema
#/etc/hosts                              # mrezna konfiguracija
#/etc/fstab                              # particiniranje fs
#/etc/default/ntpdate                    # sistemska ura
#/etc/sysconfig                          # sistemska konfiguracija
#/etc/network/interfaces                 # mrezna konfiguracija
#/etc/ha.d/ha.cf                         # ha konfiguracija
#/etc/ha.d/haresources                   # ha konfiguracija
#/opt/iskratel/etc/ham.d/ham.cf          # ham konfiguracija
###################################
#[rminclude] # vkljuci in izbrise:
###################################
#/core*                                  # core datoteke na /
#/root/core*                             # core datoteke na /root
#/opt/iskratel/bin/core*                 # core datoteke na /opt/iskratel/bin
#/opt/si2000/neroot/active/bin/core*     # core datoteke na /opt/si2000/neroot/active/bin
#EOF
#}

# main #

#logt_cfg

if [ -e ${DRBDCF} ]
then
	. ${DRBDCF}
else
	exit 0
fi

# cat /etc/fstab | sed "s%^#/%/%" > /etc/fstab.tmp
# cp /etc/fstab.tmp /etc/fstab

if [ ${#DDEV[@]} -gt 0 ] 
then
	# Create an array of 
	DEVICE=(${DDEV[@]})
	DEVFS=(${DFS[@]})
	DRBDDISKNAME=(${DDISK[@]})

	hsb_etcdrbdconf

	drbd_mode_enabled=$(LANG=C systemctl is-enabled drbd.service 2>/dev/null | grep enabled | wc -l)
	# Execute this if DRBD is enabled
	if [ ${drbd_mode_enabled} -gt 0 ]
	then
		systemctl try-restart drbd.service
	fi

	if [ ${PRODUCT_TYPE} == "nohsb" ]
	then
		nohsb_etcfstab
	else
		hsb_etcfstab
	fi

	# remount uncommented partitions
	mount -a -O sysfs

else
	echo "Error: no DDEV defined in ${DRBDCF}"
	exit 1
fi
