#!/bin/bash
#This script returns system parameter value based on input parameter

MYIPFILE=/etc/sysconfig/myip
FILE=/etc/startup-config
RUNTIME_FILE=/etc/sysconfig/running-config
FILE_BONDSTATIC=/etc/sysconfig/bonding.static
TAB=$(printf '\t')

#used for "help" & for "all"
#insert new param here: ${TAB}newParam - description
function print_help()
{
help_text="
${TAB}mmMnNodeName  -			returns system node name
${TAB}mmMnSubnetMask  -		returns MN IP address mask in form x.y.z.w
${TAB}mmMnFloatSubnetMask  -		returns MN float IP address mask in form x.y.z.w
${TAB}mmMnGateway  -			returns GW IP address in form a.b.c.d (default GW or GW to MN node network)
${TAB}mmMnGatewayNet  -		returns MN node network address or 0.0.0.0 if def. GW is configured
${TAB}mmMnGatewaySubnetMask  -	returns MN node network mask or 0.0.0.0 if def. GW is configured
${TAB}mmMnVlan  -			returns vlan id of MN IP interface
${TAB}mmMnIpAddress11  -		returns MN IP address for node 1 in unit 1 in form a.b.c.d
${TAB}mmMnIpAddress12  -		returns MN IP address for node 2 in unit 1 in form a.b.c.d
${TAB}mmMnIpAddress21  -		returns MN IP address for node 1 in unit 2 in form a.b.c.d
${TAB}mmMnIpAddress22  -		returns MN IP address for node 2 in unit 2 in form a.b.c.d
${TAB}mmMnHostname11  -		returns hostname for node 1 in unit 1
${TAB}mmMnHostname12  -		returns hostname for node 2 in unit 1
${TAB}mmMnHostname21  -		returns hostname for node 1 in unit 2
${TAB}mmMnHostname22  -		returns hostname for node 2 in unit 2
${TAB}mmMnInternalIpAddress11  -	returns internal IP address for node 1 in unit 1 in form a.b.c.d
${TAB}mmMnInternalIpAddress12  -	returns internal IP address for node 1 in unit 2 in form a.b.c.d
${TAB}mmMnInternalIpAddress21  -	returns internal IP address for node 2 in unit 1 in form a.b.c.d
${TAB}mmMnInternalIpAddress22  -	returns internal IP address for node 2 in unit 2 in form a.b.c.d
${TAB}mmMnFloatIpAddress1  -		returns unit 1 MN float IP address in form a.b.c.d
${TAB}mmMnFloatIpAddress2  -		returns unit 2 MN float IP address in form a.b.c.d
${TAB}mmSystemConfigDomainName  - 	returns system domain name
${TAB}mmSystemConfigTimezone  -	returns system timezone in form 'Europe/Ljubljana'
${TAB}mmNameServer1  -		returns primary DNS server
${TAB}mmNameServer2  -		returns secondary DNS server
${TAB}mmNameServer3  -		returns tertiary DNS server
${TAB}mmNtpServer1  -			returns primary NTP server
${TAB}mmNtpServer2  -			returns secindary NTP server
${TAB}mmNtpServer3  -			returns tertiary NTP server
${TAB}mmInternalFloatIpAddr  -	returns internal float IP address in form a.b.c.d (valid only on CE)
${TAB}mmInternalSubnetMask  -		returns local unit internal subnet mask
${TAB}mmInternalVlan  -		returns local unit internal vlan id
${TAB}mmInternalRemoteVlan  -         returns remote unit internal vlan id
${TAB}mmMnVlanInternal1  -		returns unit 1 internal vlan id
${TAB}mmMnVlanInternal2  -            returns unit 2 internal vlan id
${TAB}mmSystemConfigProductName -     returns product name
${TAB}mmInternalIntf  -		returns local unit internal interface name
${TAB}mmRemoteInternalIntf  -         returns remote unit internal interface name
${TAB}mmNodeNumber  -			returns local node id
${TAB}mmUnitNumber  -			returns local unit id
${TAB}mmPreferedUnitNumber  -		returns preferred unit id (valid for GEO system type)
${TAB}mmRedundancyType  -		returns HSB enable status (if HSB mode is enabled):
						hsb - HSB mode enabled
						nohsb - HSB mode disabled

${TAB}mmGeoMnFloatIpAddr  -		returns MN GEO float IP address in form a.b.c.d
${TAB}mmGeoMnFloatSubnetMask -	returns MN GEO float IP netmask in form a.b.c.d
${TAB}mmGeoRedundancyType  -		returns GEO enable status (if GEO mode is enabled):
						redundant - GEO mode enabled
						noredundant - GEO mode disabled

${TAB}mmGeoRedundancyMode  -		returns GEO switchover mode:
						0 - NON-GEO unit configuration (same efect as GEO = FALSE)
						1 - GEO takeover not allowed
						2 - only manual GEO takeover allowed
						3 - automatic and manual GEO takeover allowed

${TAB}mmGeoRedundancySOTimeout  -	returns GEO switchover timeout in minutes
${TAB}mmGeoL2L3Type  -		returns GEO type:
						L2 - L2 georedundancy type
						L3 - L3 georedundancy type
${TAB}mmGeoL3FloatIp  -		returns L3 GEO float IP exists:
                                                L3-FLOAT-IP
                                                L3-NO-FLOAT-IP
${TAB}mmGeoMnTrackingFloatIpAddr -	returns GEO tracking float IP address
${TAB}mmMnChassisType  -		returns system chassis type (MEA,MED,ATCA,ATCA_D)
${TAB}mmMnChassisSize  -		returns system chassis size
${TAB}mmMnSnmptrap  -			returns SNMP trap destination IP address in form a.b.c.d
${TAB}mmMnSnmptrapv3  -			returns SNMPv3 trap destination IP address in form a.b.c.d
${TAB}mmMnSnmptrapCommunity  -	returns SNMP trap community
${TAB}mmMnSnmptrapPort  -		returns SNMP trap port
${TAB}mmMnSnmptrapType  -		returns SNMP notification type
${TAB}localMnIpAddress  -		returns local MN IP address in form a.b.c.d
${TAB}hsbRemoteMnIpAddress  -		returns HSB remote MN IP address in form a.b.c.d
${TAB}localHostname  -		returns local node hostname
${TAB}hsbRemoteHostname  -		returns HSB remote node hostname
${TAB}localIntIpAddress  -		returns local internal IP address in form a.b.c.d
${TAB}hsbRemIntIpAddress  -		returns HSB remote internal IP address in form a.b.c.d
${TAB}hsbMnFloatIpAddress  -		returns HSB MN float IP address in form a.b.c.d
${TAB}hsbMnFloatIpMaskAddress  -	returns HSB MN float IP address netmask
${TAB}hsbIntFloatIpAddress  -		returns HSN internal float IP address in form a.b.c.d (valid only for CE)
${TAB}hsbIntFloatIpMaskAddress  -	returns HSN internal float IP address netmask
${TAB}boardPos  -			retruns configured (not IPMI) board position
${TAB}ClusterPublicHostnames  -	returns public hostnames of all nodes in cluster (remote host are marked with 'remote' at the begining of line)
${TAB}ClusterPublicIPs  -		returns MN IP address of all nodes in cluster (remote are marked with 'remote' at the begining of line)
${TAB}ClusterPrivateHostnames  -	returns private hostnames of all nodes in cluster (remote host are marked with 'remote' at the begining of line)
${TAB}ClusterPrivateIPs  -		returns internal IP address of all nodes in cluster (remote are marked with 'remote' at the begining of line)
${TAB}systemType  -			returns system type:
						standalone - standalone system (one unit with one node)
						duplicated - HSB system (one unit with two nodes)
						geo-dual - GEO redundant system (two units each with two nodes)

${TAB}mmMnMtuSize  -			returns MTU size for mgmt IP interface
${TAB}mlncActPort  -			returns MLINEC active ports:
						copper - Front Panel copper ports
						optics - Front Panel optics ports
						bp - Back Panel ports

						NOT SUPPORTED YET

${TAB}haIntfPrimary  -			returns HA primary interface name 
${TAB}haIntfSecondary  -		returns HA secondary interface name 
${TAB}mmMnUsedFpInterfacesAll  -	returns list of already used front panel interfaces 
${TAB}mmRemoteMnGateway  - 		returns remote gateway IP address 
${TAB}mmRemoteMnGatewayNet  -		returns remote gateway network 
${TAB}mmRemoteMnGatewaySubnetMask - 	returns remote gateway's netmask  
${TAB}product  -			returns product type
${TAB}mn-type  -			returns MN type: EM or NEM
${TAB}configServerUrl  - 		returns configuration Server URL
${TAB}configServerUser  - 		returns configuration Server user
${TAB}configServerPass  - 		returns configuration Server password
${TAB}haFaultTolerance  - 		returns HA fault tolerance timeout
${TAB}internetConnection  - 		returns if internet connection is available (valid only for CE)
${TAB}ntpServerLocation  - 		returns location of ntp servers (valid only for CE)
${TAB}vlanList  -			returns list of created vlans
${TAB}intfListAll  -			returns FP and BP interface list
${TAB}intfListFp  -			returns FP interface list
${TAB}intfListBp  -			returns BP interface list
"
echo -n "$help_text" 
echo
}

# function show_help
function show_help()
{
cat << EOF

Usage:
	cfg-getparams.sh <param> [--runtime]

	cfg-getparams.sh prints value of requested parameter and returns value 0 on success or value 1 on error.
	Printed value is valid only if scripts returns 0. By default it returns saved value. To get runtime value use
	'--runtime' flag as a second parameter.

Exmaple:

	# get chassis size
	SIZE=\`/sbin/cfg-getparams.sh mmMnChassisSize\`
	if [ "\$?" == "0" ]
	then
		echo "Chassis size is \$SIZE"
	else
		echo "Error reading chassis size"
	fi


	# get chassis size - runtime value
	SIZE=\`/sbin/cfg-getparams.sh mmMnChassisSize --runtime\`
	if [ "\$?" == "0" ]
	then
		echo "Chassis size is \$SIZE"
	else
		echo "Error reading chassis size"
	fi

Available value for <param>:

	help  -				show this help
	all  -				show values of all parameters
EOF
print_help
}

function get_product_name()
{
   echo "$(awk '/product/ {print $2}' $FILE)"
}

function node_and_unit()
{
   N_AND_U=$(awk '/system unit-id/{p=1} /!/{p=0} p' $FILE)
   #system unit-id 1 node-id 1
   S_NODE=$(echo $N_AND_U|awk '{print $5}')
   UNIT_ID=$(echo $N_AND_U|awk '{print $3}')   
}

function strip_mask()
{
   sed 's_/.*$__'
}

# convert mask from [IP]/xy to x.y.z.w
function cidr2dot()
{
   # Grab input - from pipe or from positional parameters
   INPUT=${1:-$(</dev/stdin)};
   MASK=$(echo $INPUT|sed 's_.*/__')   
   case $MASK in 
      1) M=128.0.0.0;; 2) M=192.0.0.0;; 3) M=224.0.0.0;; 4) M=240.0.0.0;;
      5) M=248.0.0.0;; 6) M=252.0.0.0;; 7) M=254.0.0.0;; 8) M=255.0.0.0;;
      9) M=255.128.0.0;; 10) M=255.192.0.0;; 11) M=255.224.0.0;; 12) M=255.240.0.0;;
      13) M=255.248.0.0;; 14) M=255.252.0.0;; 15) M=255.254.0.0;; 16) M=255.255.0.0;;
      17) M=255.255.128.0;; 18) M=255.255.192.0;; 19) M=255.255.224.0;; 20) M=255.255.240.0;;
      21) M=255.255.248.0;; 22) M=255.255.252.0;; 23) M=255.255.254.0;; 24) M=255.255.255.0;;
      25) M=255.255.255.128;; 26) M=255.255.255.192;; 27) M=255.255.255.224;; 28) M=255.255.255.240;;
      29) M=255.255.255.248;; 30) M=255.255.255.252;; 31) M=255.255.255.254;; 32) M=255.255.255.255;;
   esac
   [ $M ] && echo $M
}

runtime_arg=""
rest_arg=""

#loop through input args
for in_arg in "$@"
do
	if [ "$in_arg" == "--runtime" ]
	then
		runtime_var=$in_arg
	fi

	if [ "$in_arg" == "--rest" ]
        then
                rest_var=$in_arg
        fi
done

if [ "$runtime_var" == "--runtime" ]
then
	# reset FILE var
	FILE=$RUNTIME_FILE

	#load running conf into temp file
	konf -- -d > $FILE
fi

if [ ! -e "$FILE" ]
then
	echo "Error: $FILE does not exists!"
	exit 1
fi

if [ "$1" = "all" ]
then
  TAB='@'
  allParams=`print_help|awk '/^@/ {print $1}'|tr -d @`

  for i in $allParams; do
     res=`$0 $i $2`
     echo -ne "$i:\t$res\n"
  done

  exit 0
fi

case $1 in
   help) # help message
	show_help

        exit 1	
   ;;

   product) # product type - cCS,bgw,...
	get_product_name
   ;;

    mn-type) # product MN type
	if [ -f /tmp/web-install-job.data-mntype ]
	then
        	mnType=`cat /tmp/web-install-job.data-mntype`
	else
		if [ -f /etc/sysconfig/install-mn_type ]
		then
			mnType=`cat /etc/sysconfig/install-mn_type`
		else
			mnType="NEM"
		fi
	fi

	echo $mnType
   ;;

   mmMnNodeName) #
   awk '/system name/ {print $3}' $FILE
   ;;

   mmMnSubnetMask) #MN_MASK
   awk '/interface mgmt/{p=1} /!/{p=0} p' $FILE | awk '/ip address/ {print $3}' | cidr2dot
   ;;

   mmMnFloatSubnetMask) #MN_FLOAT_MASK
   awk '/ip address mgmt float/ {if ($1 !~ /remote/) print $5}' $FILE | cidr2dot
   ;;

   mmMnGateway) #MN_NODE_GW
   awk '/ip route mgmt/ {print $6}' $FILE
   ;;
   
   mmMnGatewayNet) #MN_NODE_GW_NETWORK
   awk '/ip route mgmt/ {print $4}' $FILE
   ;;
   
   mmMnGatewaySubnetMask) #MN_NODE_NET_MASK
   awk '/ip route mgmt/ {print $5}' $FILE
   ;;

   mmMnVlan) #MN_VLAN
   awk '/vlan mgmt/ {print $3}' $FILE
   ;;

   mmMnIpAddress11) #MN11_IP
   node_and_unit
   if [ "${UNIT_ID}" == "1" ]; then
      if [ "${S_NODE}" == "1" ]; then
         awk '/interface mgmt/{p=1} /!/{p=0} p' $FILE|awk '/ip address/ {print $3}'|strip_mask
      else
         awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/  ip address mgmt/ {print $4}'|strip_mask
      fi
   else
      awk '/remote node-id 1/{p=1} /remote node-id 2/{p=0} p' $FILE |awk '/ip address mgmt [0-9]/ {print $4}'|strip_mask
   fi
   ;;

   mmMnIpAddress12) #MN12_IP
   node_and_unit
   if [ "${UNIT_ID}" == "1" ]; then
      if [ "${S_NODE}" == "2" ]; then
         awk '/interface mgmt/{p=1} /!/{p=0} p' $FILE|awk '/ip address/ {print $3}'|strip_mask
      else
         awk '/hsb/{p=1} /!/{p=0} p' $FILE|awk '/  ip address mgmt/ {print $4}'|strip_mask
      fi
   else
      awk '/remote node-id 2/{p=1} /!/{p=0} p' $FILE|awk '/ip address mgmt [0-9]/ {print $4}'|strip_mask
   fi
   ;;

   mmMnIpAddress21) #MN21_IP
   node_and_unit
   if [ "${UNIT_ID}" == "2" ]; then
      if [ "${S_NODE}" == "1" ]; then
         awk '/interface mgmt/{p=1} /!/{p=0} p' $FILE|awk '/ip address/ {print $3}'|strip_mask
      else
         awk '/hsb/{p=1} /!/{p=0} p' $FILE|awk '/  ip address mgmt/ {print $4}'|strip_mask
      fi
   else
      awk '/remote node-id 1/{p=1} /remote node-id 2/{p=0} p' $FILE|awk '/ip address mgmt [0-9]/ {print $4}'|strip_mask
   fi
   ;;

   mmMnIpAddress22) #MN22_IP
   node_and_unit
   if [ "${UNIT_ID}" == "2" ]; then
      if [ "${S_NODE}" == "2" ]; then
         awk '/interface mgmt/{p=1} /!/{p=0} p' $FILE | awk '/ip address/ {print $3}' | strip_mask
      else
         awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/  ip address mgmt/ {print $4}' | strip_mask
      fi
   else
      awk '/remote node-id 2/{p=1} /!/{p=0} p' $FILE | awk '/ip address mgmt [0-9]/ {print $4}'|strip_mask
   fi
  ;;

   mmMnHostname11) #TARGET_NAME11
   node_and_unit
   if [ "${UNIT_ID}" == "1" ]; then
      if [ "${S_NODE}" == "1" ]; then
         awk '/hostname/{p=1} /!/{p=0} p' $FILE | awk '/^hostname / {print $2}'
      else
         awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/ hostname/ {print $2}'
      fi
   else
      awk '/remote node-id 1 hostname/ {print $5}' $FILE
   fi
   ;;

   mmMnHostname12) #TARGET_NAME12
   node_and_unit
   if [ "${UNIT_ID}" == "1" ]; then
      if [ "${S_NODE}" == "2" ]; then
         awk '/hostname/{p=1} /!/{p=0} p' $FILE | awk '/^hostname / {print $2}'
      else
         awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/ hostname/ {print $2}'
      fi
   else
      awk '/remote node-id 2 hostname/ {print $5}' $FILE
   fi
   ;;

   mmMnHostname21) #TARGET_NAME21
   node_and_unit
   if [ "${UNIT_ID}" == "2" ]; then
      if [ "${S_NODE}" == "1" ]; then
         awk '/hostname/{p=1} /!/{p=0} p' $FILE |  awk '/^hostname / {print $2}'
      else
         awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/ hostname/ {print $2}'
      fi
   else
      awk '/remote node-id 1 hostname/ {print $5}' $FILE
   fi
   ;;

   mmMnHostname22) #TARGET_NAME22
   node_and_unit
   if [ "${UNIT_ID}" == "2" ]; then
      if [ "${S_NODE}" == "2" ]; then
         awk '/hostname/{p=1} /!/{p=0} p' $FILE |  awk '/^hostname / {print $2}'
      else
         awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/ hostname/ {print $2}'
      fi
   else
      awk '/remote node-id 2 hostname/ {print $5}' $FILE
   fi
   ;;
   
   mmMnInternalIpAddress11Mask) #INT11_IP/Mask
   product_name=$(get_product_name)
   if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]; then
      awk '/CMJ NODE 1/{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}'
   elif [ -f ${FILE_BONDSTATIC} ]; then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         IPN=""
         echo ${IPN}
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         node_and_unit
         if [ -n "${UNIT_ID}" ]; then
            if [ -n "${S_NODE}" ]; then
               awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/1/g'
            fi
         fi
      fi
   else
      node_and_unit
      if [ "${UNIT_ID}" == "1" ]; then
         if [ "${S_NODE}" == "1" ]; then
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^ ip address internal/ {print $4}'
         else
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'
         fi
      else
         awk '/remote node-id 1/{p=1} /remote node-id 2/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'
      fi
   fi
   ;;

   mmMnInternalIpAddress12Mask) #INT12_IP/Mask
   product_name=$(get_product_name)
   if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]; then
      awk '/CMJ NODE 2/{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}'
   elif [ -f ${FILE_BONDSTATIC} ]; then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         IPN=""
         echo ${IPN}
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         node_and_unit
         if [ -n "${UNIT_ID}" ]; then
            if [ -n "${S_NODE}" ]; then
               awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/2/g'
            fi
         fi
      fi
   else
      node_and_unit
      if [ "${UNIT_ID}" == "1" ]; then
         if [ "${S_NODE}" == "2" ]; then
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^ ip address internal/ {print $4}'
         else
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'
         fi
      else
         awk '/remote node-id 2/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'
      fi
   fi
   ;;

   mmMnInternalIpAddress21Mask) #INT21_IP/Mask
   product_name=$(get_product_name)
   if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]; then
      awk '/CMJ NODE 1/{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}'
   elif [ -f ${FILE_BONDSTATIC} ]; then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         IPN=""
         echo ${IPN}
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         node_and_unit
         if [ -n "${UNIT_ID}" ]; then
            if [ -n "${S_NODE}" ]; then
               awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/1/g'
            fi
         fi
      fi
   else
      node_and_unit
      if [ "${UNIT_ID}" == "2" ]; then
         if [ "${S_NODE}" == "1" ]; then
             awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^ ip address internal/ {print $4}'
         else
             awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'
         fi
      else
         awk '/remote node-id 1/{p=1} /remote node-id 2/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'
      fi
   fi
   ;;

   mmMnInternalIpAddress22Mask) #INT22_IP/Mask
   product_name=$(get_product_name)
   if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]; then
      awk '/CMJ NODE 2/{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}'
   elif [ -f ${FILE_BONDSTATIC} ]; then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         IPN=""
         echo ${IPN}
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         node_and_unit
         if [ -n "${UNIT_ID}" ]; then
            if [ -n "${S_NODE}" ]; then
               awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/2/g'
            fi
         fi
      fi
   else
      node_and_unit
      if [ "${UNIT_ID}" == "2" ]; then
         if [ "${S_NODE}" == "2" ]; then
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^ ip address internal/ {print $4}'
         else
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'
         fi
      else
         awk '/remote node-id 2/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'
      fi
   fi
   ;;

   mmMnInternalIpAddress11) #INT11_IP
   product_name=$(get_product_name)
   if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]; then
      awk '/CMJ NODE 1/{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}'
   elif [ -f ${FILE_BONDSTATIC} ]; then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         IPN=""
         echo ${IPN}
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         node_and_unit
         if [ -n "${UNIT_ID}" ]; then
            if [ -n "${S_NODE}" ]; then
               awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/1/g'
            fi
         fi
      fi
   else
      node_and_unit
      if [ "${UNIT_ID}" == "1" ]; then
         if [ "${S_NODE}" == "1" ]; then
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^ ip address internal/ {print $4}'|strip_mask
         else
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'|strip_mask
         fi
      else
         awk '/remote node-id 1/{p=1} /remote node-id 2/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'|strip_mask
      fi
   fi  
   ;;

   mmMnInternalIpAddress12) #INT12_IP 
   product_name=$(get_product_name)
   if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]; then
      awk '/CMJ NODE 2/{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}'
   elif [ -f ${FILE_BONDSTATIC} ]; then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         IPN=""
         echo ${IPN}
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         node_and_unit
         if [ -n "${UNIT_ID}" ]; then
            if [ -n "${S_NODE}" ]; then
               awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/2/g'
            fi
         fi
      fi
   else
      node_and_unit
      if [ "${UNIT_ID}" == "1" ]; then
         if [ "${S_NODE}" == "2" ]; then
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^ ip address internal/ {print $4}'|strip_mask
         else
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'|strip_mask
         fi
      else
         awk '/remote node-id 2/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'|strip_mask
      fi
   fi
   ;;

   mmMnInternalIpAddress21) #INT21_IP
   product_name=$(get_product_name)
   if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]; then
      awk '/CMJ NODE 1/{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}'
   elif [ -f ${FILE_BONDSTATIC} ]; then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         IPN=""
         echo ${IPN}
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         node_and_unit
         if [ -n "${UNIT_ID}" ]; then
            if [ -n "${S_NODE}" ]; then
               awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/1/g'
            fi
         fi
      fi
   else
      node_and_unit
      if [ "${UNIT_ID}" == "2" ]; then
         if [ "${S_NODE}" == "1" ]; then
             awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^ ip address internal/ {print $4}'|strip_mask
         else
             awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'|strip_mask
         fi
      else
         awk '/remote node-id 1/{p=1} /remote node-id 2/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'|strip_mask
      fi
   fi
   ;;

   mmMnInternalIpAddress22) #INT22_IP
   product_name=$(get_product_name)
   if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]; then
      awk '/CMJ NODE 2/{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}'
   elif [ -f ${FILE_BONDSTATIC} ]; then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         IPN=""
         echo ${IPN}
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         node_and_unit
         if [ -n "${UNIT_ID}" ]; then
            if [ -n "${S_NODE}" ]; then
               awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/2/g'
            fi
         fi
      fi
   else
      node_and_unit
      if [ "${UNIT_ID}" == "2" ]; then
         if [ "${S_NODE}" == "2" ]; then
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^ ip address internal/ {print $4}'|strip_mask
         else
            awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'|strip_mask
         fi
      else
         awk '/remote node-id 2/{p=1} /!/{p=0} p' $FILE | awk '/^  ip address internal/ {print $4}'|strip_mask
      fi
   fi
   ;;

   mmMnFloatIpAddress1) #MN1_FLOAT - unit 1
   S_UNIT=`awk '/system unit-id/ {print $3}' $FILE`
   if [ "${S_UNIT}" == "1" ]; then
      awk '/^ ip address mgmt float / {print $5}' $FILE | strip_mask
   else
      awk '/remote ip address mgmt float/ {print $6}' $FILE | strip_mask
   fi
   ;;
   
   mmMnFloatIpAddress2) #MN2_FLOAT - unit 2
   S_UNIT=`awk '/system unit-id/ {print $3}' $FILE`
   if [ "${S_UNIT}" == "2" ]; then
      awk '/^ ip address mgmt float / {print $5}' $FILE | strip_mask
   else
      awk '/remote ip address mgmt float/ {print $6}' $FILE | strip_mask
   fi
   ;;

   mmMnVlanInternal1) #internal vlan for unit 1
   S_UNIT=`awk '/system unit-id/ {print $3}' $FILE`
   if [ "${S_UNIT}" == "1" ]; then
      awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/ vlan internal/ {print $3}'
   else
      awk '/georedundancy/{p=1} /!/{p=0} p' $FILE | awk '/ remote vlan internal/ {print $4}'
   fi
   ;;

   mmMnVlanInternal2) #internal vlan for unit 2
   S_UNIT=`awk '/system unit-id/ {print $3}' $FILE`
   if [ "${S_UNIT}" == "2" ]; then
      awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/ vlan internal/ {print $3}'
   else
      awk '/georedundancy/{p=1} /!/{p=0} p' $FILE | awk '/ remote vlan internal/ {print $4}'
   fi
   ;;

   mmSystemConfigProductName)
   #try to read name dirctly from file
   prodName=$(awk -F= '/package name/ {print $2}' /etc/sysconfig/product-install-cfg.xml |tr -d '"/>')
   if [ "$prodName" = "" ]; then 
      #slow... 
      prodName=`/sbin/ha-sw-tool --show --os=working --current-only | cut -d' ' -f2`
   fi 
   echo ${prodName}
   ;;

   mmSystemConfigDomainName) #DOMAIN
   awk '/domain-name/ {print $2}' $FILE
   ;;

   mmSystemConfigTimezone) #TIME_ZONE
   awk '/timezone/ {print $2}' $FILE
   ;;

   mmNameServer1) #NAMESERVER1
   awk '/dns-server primary/ {print $3}' $FILE
   ;;

   mmNameServer2) #NAMESERVER2
   awk '/dns-server secondary/ {print $3}' $FILE
   ;;

   mmNameServer3) #NAMESERVER3
   awk '/dns-server tertiary/ {print $3}' $FILE
   ;;

   mmNtpServer1) #NTP_SRV1X
   awk '/ntp-server primary/ {print $3}' $FILE
   ;;

   mmNtpServer2) #NTP_SRV2
   awk '/ntp-server secondary/ {print $3}' $FILE
   ;;

   mmNtpServer3) #NTP_SRV3
   awk '/ntp-server tertiary/ {print $3}' $FILE
   ;;

   mmInternalFloatIpAddr) #INT_FLOAT_IP
   PRODUCT=`awk '/product/ {print $2}' $FILE`
   if [ -f ${FILE_BONDSTATIC} ]; then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         IPN=""
         echo ${IPN}
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         IP="192.0.2.30"
         echo ${IP}
      fi
   else
      ENABLE=`awk '/hsb/{p=1} /!/{p=0} p' $FILE | grep 'enable'`
      if [ "${ENABLE}" != "" ]; then
         awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/ip address intfloat/ {print $4}' | cidr2dot
      fi
   fi	
   ;;
  
   mmInternalSubnetMask) #INT_MASK
   PRODUCT=`awk '/product/ {print $2}' $FILE`
   if [ -f ${FILE_BONDSTATIC} -a ${PRODUCT} == "Compact_Call_Server" ]; then
      cidr2dot 24
   else
      awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/^ ip address int/ {print $4}'| cidr2dot
   fi
   ;;

   mmInternalVlan) #INT_VLAN
   PRODUCT=`awk '/product/ {print $2}' $FILE`
   if [ -f ${FILE_BONDSTATIC} -a ${PRODUCT} == "Compact_Call_Server" ]; then
      echo 2005
   else
      REDTYPE=`awk '/system type/ {print $3}' $FILE`
      if [ "${REDTYPE}" != "standalone" ]; then
         awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/vlan internal/ {print $3}'
      fi     
   fi     
   ;;
   
   mmInternalRemoteVlan) #INT_VLAN ???
   PRODUCT=`awk '/product/ {print $2}' $FILE`
   if [ -f ${FILE_BONDSTATIC} -a ${PRODUCT} == "Compact_Call_Server" ]; then
      echo 2005
   else
      REDTYPE=`awk '/system type/ {print $3}' $FILE`
      if [ "${REDTYPE}" != "standalone" ]; then
         awk '/georedundancy/{p=1} /!/{p=0} p' $FILE |  awk '/remote vlan internal/ {print $4}'
      fi     
   fi     
   ;;   

   mmInternalIntf) #INT_INTF ???
   if [ -f ${FILE_BONDSTATIC} ]; then
  	:
   else
   	awk '/hsb/{p=1} /!/{p=0} p' $FILE | awk '/internal interface/ {print $3}'
   fi
   ;;

   mmRemoteInternalIntf) #REM_INT_INTF ???
   if [ -f ${FILE_BONDSTATIC} ]; then
        :
   else
        awk '/georedundancy/{p=1} /!/{p=0} p' $FILE | awk '/remote internal interface/ {print $4}'
   fi
   ;;


   mmNodeNumber) #S_NODE
   awk '/system unit-id/ {print $5}' $FILE
   ;;

   mmUnitNumber) #UNIT_ID
   awk '/system unit-id/ {print $3}' $FILE
   ;;

   mmPreferedUnitNumber) #PREFERED_UNIT
   awk '/preferred-unit/ {print $2}' $FILE
   ;;

   mmRedundancyType) #HSB
   REDTYPE=`awk '/hsb/{p=1} /!/{p=0} p' $FILE | grep 'enable'`
   if [ "${REDTYPE}" == "" ]; then
      echo "nohsb"
   fi
   if [ "${REDTYPE}" == " enable" ]; then
      echo "hsb" 
   fi  
   ;;

   mmGeoMnFloatIpAddr) #MN_GEO_FLOAT
   awk '/ip address mgmt geofloat/ {print $5}' $FILE | strip_mask
   ;;

   mmGeoMnFloatSubnetMask) #MN_GEO_MASK
   awk '/ip address/{p=1} /!/{p=0} p' $FILE | awk '/geofloat/ {print $5}' | cidr2dot
   ;;

   mmGeoRedundancyType) #UNIT_TYPE
   GEO=`awk '/georedundancy/{p=1} /!/{p=0} p' $FILE | grep 'enable'`
   if [ "${GEO}" == "" ]; then
      echo "noredundant"
   else
      echo "redundant" 
   fi  
   ;;
   
   mmGeoRedundancyMode) #GEO_MODE
   awk '/geo-mode/ {print $2}' $FILE
   ;;

   mmGeoL2L3Type) #GEO_TYPE
   type=`awk '/georedundancy/{p=1} /!/{p=0} p' $FILE | awk '/geo-type/ {print $2}'`
   if [ "$type" == "L3" ]; then
      echo "L3"
   else
      echo "L2"
   fi
   ;;

   mmGeoL3FloatIp) #is L3 geo float ip
   isL3FloatIp=`awk '/ip address mgmt geofloat/ {print $5}' $FILE | strip_mask`
   if [ "$isL3FloatIp" == "" ]; then
      echo "L3-NO-FLOAT-IP"
   else
      echo "L3-FLOAT-IP"
   fi
   ;;

   mmGeoMnTrackingFloatIpAddr) #geo tracking float ip
   awk '/georedundancy/{p=1} /!/{p=0} p' $FILE |awk '/ ip address mgmt tracking-geofloat/ {print $5}'
   ;;

   mmGeoRedundancySOTimeout) #GEO_SWITCHOVER_TIMEOUT
   awk '/geo-switchover/ {print $3}' $FILE
   ;;

   mmMnChassisType) #CHASSIS TYPE
   CHASSIS=`cat ${FILE} | grep 'chassis type'`
   if [ "${CHASSIS}" != "" ]
   then
   CHTYPE=`cat ${FILE} | awk '/chassis/{p=1} /!/{p=0} p' |  grep type | awk '{print $3}'`
   else
   CHTYPE=`cat ${FILE} | awk '/chassis/{p=1} /!/{p=0} p' | awk '{print $3}'`
   fi
   echo ${CHTYPE}
   ;;

   mmMnChassisSize) #CHASSIS SIZE
   CHASSIS=`cat ${FILE} | grep 'chassis size'`
   if [ "${CHASSIS}" != "" ]
   then  
   CHSIZE=`cat ${FILE} | awk '/chassis/{p=1} /!/{p=0} p' |  grep size | awk '{print $3}'`
   else
   CHSIZE=`cat ${FILE} | awk '/chassis/{p=1} /!/{p=0} p' | awk '{print $5}'`
   fi   
   echo ${CHSIZE}
   ;;

   mmMnSnmptrap) #SNMP TRAP IP
   SNMPTRAP=`cat ${FILE} | awk '/snmptrap/{p=1} /!/{p=0} p' |grep -vw 'snmptrap port\|community\|type\|v3' | awk '{print $2}'`
   echo ${SNMPTRAP}
   ;;

   mmMnSnmptrapv3) #SNMPv3 TRAP IP
   SNMPTRAPV3=$(awk '/^snmptrap v3/ {print $3}' $FILE)
   echo $SNMPTRAPV3
   ;;

   mmMnSnmptrapCommunity) #SNMP COMMUNITY
   awk '/snmptrap community/ {print $3}' $FILE
   ;;

   mmMnSnmptrapPort) #SNMP PORT
   awk '/snmptrap port/ {print $3}' $FILE
   ;;
            
   mmMnSnmptrapType) #SNMP notification type 
   awk '/snmptrap type/ {print $3}' $FILE
   ;;

   mnWhoAmI) #WHOAMI
   WHOAMI=`ip add | grep 'inet ' |grep -vw 'lo' |grep -vw 'bond0.....' |grep -vw 'bond0....' |grep -vw 'bond0...' |grep -vw 'bond0..' |awk '{print $2}' |sed q `
   
   test -f ${MYIPFILE} && . ${MYIPFILE}
   if [ "${WHOAMI}" == "" ]
   then
	if [ "${MYIP}" == "" ]
	then
	echo "error in WhoAmI , can not define IP of board !"
	exit 1
   	else 
	echo ${MYIP}
	fi
   else
	   echo ${WHOAMI}
   fi
   ;;
   
   localMnIpAddress) # local host mgmt IP address

	IP=`cat ${FILE} | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep 'ip address' | awk '{print $3}'`
#	. /sbin/cfg-calculate-network.sh ${IP}
#	convert_ip_mask
#	echo ${IPN}
	echo ${IP}
   ;;

   hsbRemoteMnIpAddress) # remote HSB host  mgmt IP address

	IP=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address mgmt' | awk '{print $4}'`
#	. /sbin/cfg-calculate-network.sh ${IP}
#	convert_ip_mask
#	echo ${IPN}
	echo ${IP}
   ;;

   localHostname) # local hostname

	NAME=`cat ${FILE} | awk '/hostname/{p=1} /!/{p=0} p' | grep 'hostname' | grep -vw ' hostname'| grep -vw ' remote hostname'| head -n 1 | awk '{print $2}'`
	echo $NAME

   ;;

   hsbRemoteHostname) # remote HSB hostname

        NAME=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' hostname' | awk '{print $2}'`
        echo $NAME

   ;;

   localIntIpAddress) # local host internal IP address
   product_name=$(get_product_name)
   if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]; then
		# first get board node ID
   		node=`cat ${FILE} | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
   		if [ "$node" == "1" ]
   		then
			# I am node 1
   			INT_IP=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 1/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
   			echo ${INT_IP}
   		else
			# I am node 2
   			INT_IP=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 2/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
   			echo ${INT_IP}
   		fi		
   elif [ -f ${FILE_BONDSTATIC} ]; then
                REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
                if [ "${REDTYPE}" == "standalone" ]
                then
                        IPN=""
                        echo ${IPN}
		fi
		if [ "${REDTYPE}" == "duplicated" ]
		then
   			node=`cat ${FILE} | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
         		if [ -n "${node}" ]; then
            			awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/'${node}'/g'
         		fi
		fi
   else
	   	REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
   		if [ "${REDTYPE}" == "standalone" ]
   		then
   			IPN=""
   			echo ${IPN}
   		else
   			IP=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' ip address internal' |  grep -vw '  ip address internal' |awk '{print $4}'`
#   			. /sbin/cfg-calculate-network.sh ${IP}
#   			convert_ip_mask
#   			echo ${IPN}
			echo ${IP}
   		fi
   fi
   ;;

   hsbRemIntIpAddress) # remote host internal IP address
   product_name=$(get_product_name)
   if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]; then
		# first get board node ID
   		node=`cat ${FILE} | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
   		if [ "$node" == "1" ]
   		then
			# I am node 1 - need to return internal IP address of node 2
   			INT_IP=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 2/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
   			echo ${INT_IP}
   		else
			# I am node 2 - need to return internal IP address of node 1
   			INT_IP=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 1/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
   			echo ${INT_IP}
   		fi		
   elif [ -f ${FILE_BONDSTATIC} ]; then
                REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
                if [ "${REDTYPE}" == "standalone" ]
                then
                        IPN=""
                        echo ${IPN}
		fi
		if [ "${REDTYPE}" == "duplicated" ]
		then
   			node=`cat ${FILE} | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
   		      	if [ -n "${node}" ]; then
        	 		if [ "${node}" == "1" ]; then
					rem_node=2
        	    			awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/'${rem_node}'/g'
        	 		elif [ "${node}" == "2" ]; then
					rem_node=1
        	    			awk '/ S_NODE /{p=1} /!/{p=0} p' ${FILE_BONDSTATIC}  | awk '/address/ {print $2}' | sed 's/\$S_NODE/'${rem_node}'/g'
				fi
			fi
         	fi
   else
   
	   	REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
   		if [ "${REDTYPE}" == "standalone" ]
   		then
   			IPN=""
   			echo ${IPN}
   		else
   			IP=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address internal' |awk '{print $4}'`
#   			. /sbin/cfg-calculate-network.sh ${IP}
#   			convert_ip_mask
#   			echo ${IPN}
			echo ${IP}
   		fi
   fi
   ;;

   hsbMnFloatIpAddress) # HSB float MN IP address
   IP=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' ip address mgmt float' |awk '{print $5}'`
#   . /sbin/cfg-calculate-network.sh ${IP}
#   convert_ip_mask
#   echo ${IPN}
   echo ${IP}
   ;;

    hsbMnFloatIpMaskAddress) # HSB float MN IP address and mask
    IP=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' ip address mgmt float' |awk '{print $5}'`
    echo ${IP}
   ;;

   hsbIntFloatIpAddress) #HSB float internal IP address
   PRODUCT=`awk '/product/ {print $2}' $FILE`
   if [ -f ${FILE_BONDSTATIC} ]
   then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         if [ -f ${FILE_BONDSTATIC} ] && [ "$PRODUCT" == "Compact_Call_Server" ]
         then
             IP="192.0.2.30"
             echo ${IP}
         else
             IPN=""
             echo ${IPN}
         fi
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         IP="192.0.2.30"
#    . /sbin/cfg-calculate-network.sh ${IP}
#    convert_ip_mask
         echo ${IP}
      fi
   else
	ENABLE=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
   	if [ "${ENABLE}" != "" ]
   	then
   		IP=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'ip address internal float' | awk '{print $5}'`
		if [ "$IP" != "" ]
		then
#   			. /sbin/cfg-calculate-network.sh ${IP}
#   			convert_ip_mask
   			echo ${IP}
		else
			echo "0"
		fi
   	fi
   fi	
   ;;
 
   hsbIntFloatIpMaskAddress) #HSB float internal IP address and mask
   PRODUCT=`awk '/product/ {print $2}' $FILE`
   if [ -f ${FILE_BONDSTATIC} ]
   then
      REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
      if [ "${REDTYPE}" == "standalone" ]
      then
         if [ -f ${FILE_BONDSTATIC} ] && [ "$PRODUCT" == "Compact_Call_Server" ]
	 then
             IP="192.0.2.30/24"
             echo ${IP}
         else
             IPN=""
             echo ${IPN}
         fi
      fi
      if [ "${REDTYPE}" == "duplicated" ]
      then
         IP="192.0.2.30/24"
         echo ${IP}
      fi
   else
	ENABLE=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
   	if [ "${ENABLE}" != "" ]
   	then
   		IP=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'ip address internal float' | awk '{print $5}'`
		if [ "$IP" != "" ]
		then
                	echo ${IP}
		else
			echo "0"
		fi
   	fi
   fi	
   ;;
  
   boardPos) #  board position
	chass_type=`cat ${FILE} | grep 'chassis type' |awk '{print $3}'`
	if [ "$chass_type" != "VIRTUAL" ] && [ "$chass_type" != "OPENSTACK" ]
	then
		pos=`cat ${FILE} | grep 'system board position' |awk '{print $4}'`
		if [ "${pos}" != "" ]
		then
			echo ${pos}
		else
			echo "0"
		fi
	else
		# VIRT MACHINE - return node-id
		nodeId=`cat ${FILE} | grep 'system unit-id' |awk '{print $5}'`
		if [ "${nodeId}" != "" ]
		then
			echo ${nodeId}
		else
			echo "0"
		fi
	fi
   ;;

   ClusterPublicHostnames) # 
	hostnamesPublic_loc=`cat ${FILE} | grep 'hostname' | grep -v ' hostname'`
	hostnamesPublic_rem=`cat ${FILE} | grep ' hostname'`
	echo -e "${hostnamesPublic_loc}\nremote ${hostnamesPublic_rem}"
   ;;
   
   ClusterPublicIPs) # 
        IPsPublic_loc=`cat ${FILE} | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep 'ip address' | sed 's/\/.*//'`
        IPsPublic_rem=`cat ${FILE} | grep 'ip address mgmt' | grep -v 'float' | sed 's/\/.*//' | sed 's/./&remote/1'`

	echo -e "${IPsPublic_loc}\n${IPsPublic_rem}"
   ;;

      ClusterPrivateHostnames) # 
	# hostnamePublic_loc=`cat /etc/hostname | cut -c 4-`
        hostnamesPrivate_loc=`cat ${FILE} | grep 'hostname' | grep -v ' hostname' | awk '{print $2}'`
	hostnamesPrivate_rem=`cat ${FILE} |  awk '/hsb/{p=1} /!/{p=0} p' | grep ' hostname' | awk '{print $2}'`
	hostnamesPrivate_rem3=`cat ${FILE} | grep 'remote node-id 1' | awk '{print $5}'`
	hostnamesPrivate_rem4=`cat ${FILE} | grep 'remote node-id 2' | awk '{print $5}'`

	if [ "$hostnamesPrivate_rem3" == "" ] && [ "$hostnamesPrivate_rem4" == "" ]
	then
		echo -e "ha-${hostnamesPrivate_loc}\nremote ha-${hostnamesPrivate_rem}"
		exit 0
	fi

	if [ "$hostnamesPrivate_rem3" != "" ] && [ "$hostnamesPrivate_rem4" != "" ]
	then
        	echo -e "ha-${hostnamesPrivate_loc}\nremote ha-${hostnamesPrivate_rem}\nremote ha-${hostnamesPrivate_rem3}\nremote ha-${hostnamesPrivate_rem4}"
		exit 0
	fi

	if [ "$hostnamesPrivate_rem3" != "" ]
	then
		echo -e "ha-${hostnamesPrivate_loc}\nremote ha-${hostnamesPrivate_rem}\nremote ha-${hostnamesPrivate_rem3}"
		exit 0
	fi

	if [ "$hostnamesPrivate_rem4" != "" ]
	then
		echo -e "ha-${hostnamesPrivate_loc}\nremote ha-${hostnamesPrivate_rem}\nremote ha-${hostnamesPrivate_rem4}"
		exit 0
	fi
   ;;

      ClusterPrivateIPs) # 
   	product_name=$(get_product_name)
   	if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]
	then
                # first get board node ID
                node=`cat ${FILE} | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
                if [ "$node" == "1" ]
                then
                        ipLoc=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 1/{p=1} /!/{p=0} p' | grep 'address'`
			ipRem=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 2/{p=1} /!/{p=0} p' | grep 'address'`
                else
                        ipLoc=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 2/{p=1} /!/{p=0} p' | grep 'address'`
                        ipRem=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 1/{p=1} /!/{p=0} p' | grep 'address'`
                fi
	elif [ -f ${FILE_BONDSTATIC} ]
	then
                # first get board node ID
                node=`cat ${FILE} | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
                if [ "$node" == "1" ]
                then
                        ipLoc=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | sed 's/\$S_NODE/1/g'`
			ipRem=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | sed 's/\$S_NODE/2/g'`
                else
                        ipLoc=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | sed 's/\$S_NODE/2/g'`
                        ipRem=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | sed 's/\$S_NODE/1/g'`
                fi
	else

                REDTYPE=`cat ${FILE} | grep 'system type' | awk '{print $3}'`
                if [ "${REDTYPE}" == "standalone" ]
                then
                        ipLoc="127.0.0.1"
			ipRem=""
                else
                        ipLoc=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' ip address internal' | grep -v '  ip address internal' | awk '{print $4}' | sed 's/\/.*//'`
			ipRem=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address internal' | awk '{print $4}' | sed 's/\/.*//'`
			ipRem3=`cat ${FILE} | awk '/remote node-id 1/{p=1} /remote node-id 2/{p=0} p' | grep '  ip address internal' | awk '{print $4}' | sed 's/\/.*//'`
			ipRem4=`cat ${FILE} | awk '/remote node-id 2/{p=1} /!/{p=0} p' | grep '  ip address internal' | awk '{print $4}' | sed 's/\/.*//'`
                fi
	fi

        if [ "$ipRem3" == "" ] && [ "$ipRem4" == "" ]
        then
		echo -e "${ipLoc}\nremote ${ipRem}"
                exit 0
        fi

        if [ "$ipRem3" != "" ] && [ "$ipRem4" != "" ]
        then
		echo -e "${ipLoc}\nremote ${ipRem}\nremote ${ipRem3}\nremote ${ipRem4}"
                exit 0
        fi

        if [ "$ipRem3" != "" ]
        then
		echo -e "${ipLoc}\nremote ${ipRem}\nremote ${ipRem3}"
                exit 0
        fi

        if [ "$ipRem4" != "" ]
        then
		echo -e "${ipLoc}\nremote ${ipRem}\nremote ${ipRem4}"
                exit 0
        fi
   ;;

   systemType) #  get system type - standalone, dupl or geo
   type=`awk '/system type/ {print $3}' $FILE`
   if [ "${type}" != "" ]; then
      echo ${type}
   else
      echo "unknown"
   fi
   ;;

   mmMnMtuSize) #  get mgmt IP MTU
   mtu=`awk '/interface mgmt/{p=1} /!/{p=0} p' $FILE |awk '/mtu/ {print $2}'`
   if [ "${mtu}" != "" ]; then
      echo ${mtu}
   else
      echo 1500
   fi
   ;;

   mlncActPort) # mlinec act ports
	mlnc=`cat ${FILE} | grep 'mlinec bp' | awk '{print $2}'`
	if [ "${mlnc}" != "" ]
	then
		echo ${mlnc}
		exit 0
	else
		mlnc=`cat ${FILE} | grep 'mlinec fp' | awk '{print $3}'`
		if [ "${mlnc}" != "" ]
        	then
               		echo ${mlnc}
               		exit 0
        	else
			exit 1
		fi
	fi	
   ;;

   haIntfPrimary) # HA primary intf
	pri_intf=`awk '/ha interface primary/ {print $4}' $FILE`
	if [ "$pri_intf" != "" ]
	then
		if [ "$pri_intf" == "bp" ]
		then
			# it is BP intf - only in ATCA_D shelf
			echo "eth2"
		else
			# it is FP intf
			awk '/ha interface primary/ {print $5}' $FILE
		fi
	else
		echo ""
	fi
   ;;

   haIntfSecondary) # HA secondary intf
	 sec_intf=`awk '/ha interface secondary/ {print $4}' $FILE`
         if [ "$sec_intf" != "" ]
         then
                 if [ "$sec_intf" == "bp" ]
                 then
                         # it is BP intf - only in ATCA_D shelf
                         echo "eth2"
                 else
	                 # it is FP intf
	                 awk '/ha interface secondary/ {print $5}' $FILE
                 fi
         else
                 echo ""
         fi
   ;;

   mmMnUsedFpInterfacesAll) # all already used front panel ports 
	   for i in haIntfPrimary haIntfSecondary mmInternalIntf; do 
		   $0 $i
	   done
   ;;
   
   mmRemoteMnGateway) #MN_NODE_GW
   awk '/remote ip mgmt route/ {print $7}' $FILE
   ;;
   
   mmRemoteMnGatewayNet) #MN_NODE_GW_NETWORK
   awk '/remote ip mgmt route/ {print $5}' $FILE
   ;;
   
   mmRemoteMnGatewaySubnetMask) #MN_NODE_NET_MASK
   awk '/remote ip mgmt route/ {print $6}' $FILE
   ;;

   configServerUrl) #CONFIGURATION SERVER URL
   awk '/config-server/ {print $2}' $FILE
   ;;

   configServerUser) #CONFIGURATION SERVER USER
   awk '/config-server/ {print $3}' $FILE
   ;;

   configServerPass) #CONFIGURATION SERVER PASSWORD
   awk '/config-server/ {print $4}' $FILE
   ;;

   haFaultTolerance) # HA FAULT TOLERANCE
   timeout=`cat ${FILE} | grep 'ha fault-tolerance timeout' | awk '{print $4}'`
   if [ "${timeout}" != "" ]
   then
	echo ${timeout}
   else
	echo ""
   fi
   ;;

   internetConnection) # INTERNET CONNECTION
   awk '/internet-connection/ {print $2}' $FILE
   ;;

   ntpServerLocation) # NTP SERVER LOCATION
   awk '/ntp-server-location/ {print $2}' $FILE
   ;;

   vlanList) # list of created vlans
   vlans=`cat ${FILE} | grep 'vlan add' | cut -d ' ' -f3 | grep -v '2005'`
   echo ${vlans}
   ;;

   intfListAll) # all intf list
   intfs_fp=`cat ${FILE} | grep 'interface switchport fp' | cut -d ' ' -f4 | sort -n -t/ -k2,2`
   intfs_bp=`cat ${FILE} | grep 'interface switchport bp 2' | cut -d ' ' -f4 | sort -n -t/ -k2,2`
   echo -n ${intfs_fp}
   echo -n " "
   echo ${intfs_bp}
   ;;

   intfListFp) # fp intf list
   intfs_fp=`cat ${FILE} | grep 'interface switchport fp' | cut -d ' ' -f4 | sort -n -t/ -k2,2`
   echo ${intfs_fp}
   ;;

   intfListBp) # bp intf list
   intfs_bp=`cat ${FILE} | grep 'interface switchport bp 2' | cut -d ' ' -f4 | sort -n -t/ -k2,2`
   echo ${intfs_bp}
   ;;

   *) # unknown input param
	if [ "$1" == "" ]
	then
		if [ "$rest_var" == "" ]
		then
			echo
		fi
		echo "Error: no input param!"
	else
		if [ "$rest_var" == "" ]
		then
			echo
		fi
		echo "Error: unknown argument - $1!"
	fi

	if [ "$rest_var" == "" ]
	then
		show_help
	fi
	
	exit 1
   ;;

esac  

# if runtime conf exists, delete it
# if [ -f $RUNTIME_FILE ]
# then
#         # delete runtime file
#        rm $RUNTIME_FILE
# fi

