#!/bin/sh

. /etc/sysconfig/solid
if [ "x$NESRV_ENABLE" == "xyes" ]
then
	USE_DB="TRUE"
else
	USE_DB="FALSE"
fi

drbd_mode_enabled=0
if type systemctl >/dev/null 2>/dev/null
then
	# systemd environment
	drbd_mode_enabled=$(LANG=C systemctl is-enabled drbd.service 2>/dev/null | grep enabled | wc -l)
else
	# sysinit environment
	drbd_mode_enabled=$(find /etc/rc* -type l -name S[0-9][0-9]drbd | wc -l)
fi

if [ ${drbd_mode_enabled} -gt 0 ]
then
	USE_DRBD="TRUE"
else
	USE_DRBD="FALSE"
fi

FILE_HAMCF=/opt/iskratel/etc/ham.d/ham.cf
FILE_HAMSYSGENCF=/opt/iskratel/etc/ham.d/hamsysgen.cf
FILE_HAMSYSCOMCF=/opt/iskratel/etc/ham.d/hamsyscom.cf
FILE_HAMCF_STANDARD=/opt/iskratel/etc/ham.d/hamstandard.cf
FILE_BONDSTATIC=/etc/sysconfig/bonding.static
FILE=${FILE_HAMCF}.apps
FILE_CFG=/etc/startup-config
FILE_ITHA_CFG=/opt/iskratel/defaults/templates/itha.cf.hsb
PRODUCT=$(/sbin/cfg-getparams.sh product)

if [ -f ${FILE_HAMCF} ]
then 
HAMAPPS=`cat  ${FILE_HAMCF} | grep Apps`
else
HAMAPPS=""
fi

if [ "${HAMAPPS}" != "" ]
then
cp ${FILE_HAMCF} ${FILE_HAMCF}.apps
APP_PART="TRUE"
else
APP_PART="FALSE"
fi

# HSB=`cat ${FILE_CFG} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
# if [ "${HSB}" == "" ]

new_ft=`cat ${FILE_CFG} | grep 'faulttolerance' | awk '{print $2}'`
chassis=`cat ${FILE_CFG} | grep 'chassis type' | awk '{print $3}'`

if [ "${new_ft}" != "" ]
then
	FT=$((new_ft+=500))
elif [ "${chassis}" == "OPENSTACK" ]
then
	FT=5500
elif [ "${chassis}" == "VIRTUAL" ]
then
  FT=1500
else
        if [ -f $FILE_ITHA_CFG ]
        then
		new_ft=`cat $FILE_ITHA_CFG | grep FaultTolerance |cut -d ' ' -f3`
		FT=$((new_ft+=300))
        else
	        FT=800
        fi
fi

sysType=`cat ${FILE_CFG} | grep 'system type' | awk '{print $3}'`
if [ "$sysType" == "standalone" ]
then
	# standalone system

	if [ "x$NESRV_ENABLE" == "xyes" ]
	then
		USE_DB="TRUE"
	else
		USE_DB="FALSE"
	fi

	# get local MN IP address
	IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
	. /sbin/cfg-calculate-network.sh ${IP}
	convert_ip_mask
	MYIP=`echo ${IPN}`
	# echo $MYIP

	MN1_IP=${MYIP}
	# echo $MN1_IP

	mkdir -p $(dirname ${FILE_HAMCF})
	mkdir -p $(dirname ${FILE_HAMSYSGENCF})

	if [ -f ${FILE_BONDSTATIC} -a  "x$PRODUCT" == "xCompact_Call_Server" ]
	then

cat > ${FILE_HAMSYSCOMCF} <<EOF
[Apps]
numSect = 7 

[Apps/app0]
name = DRH
enabled = TRUE
level = 0
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app1]
name = SYSUP
enabled = TRUE
level = 10
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app2]
name = DGM
enabled = TRUE
level = 6
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app3]
name = DBWD
EOF
echo "enabled = ${USE_DB}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 1
hsberr = reboot
nohsberr = reboot
maxrestart = 5
acttime = 6

[Apps/app4]
name = SHMCP
enabled = TRUE
level = 3
hsberr = restart
nohsberr = restart
maxrestart = 5
acttime = 6
maxnoreboot = 0
cntrtime = 60

[Apps/app5]
name = DRBDP
EOF
echo "enabled = ${USE_DRBD}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 10
acttime = 6
maxnoreboot = 1
cntrtime = 60

[Apps/app6]
name = LOGT
enabled = TRUE
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 0
acttime = 6
EOF

else

cat > ${FILE_HAMSYSCOMCF} <<EOF
[Apps]
numSect = 7

[Apps/app0]
name = DRH
enabled = TRUE
level = 0
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app1]
name = SYSUP
enabled = TRUE
level = 10
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app2]
name = DGM
enabled = TRUE
level = 6
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app3]
name = DBWD
EOF
echo "enabled = ${USE_DB}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 1
hsberr = reboot
nohsberr = reboot
maxrestart = 5
acttime = 6

[Apps/app4]
name = SHMCP
enabled = FALSE
level = 3
hsberr = restart
nohsberr = restart
maxrestart = 5
acttime = 6
maxnoreboot = 0
cntrtime = 60

[Apps/app5]
name = DRBDP
EOF
echo "enabled = ${USE_DRBD}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 10
acttime = 6
maxnoreboot = 1
cntrtime = 60

[Apps/app6]
name = LOGT
enabled = TRUE
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 0
acttime = 6
EOF

fi

cat > ${FILE_HAMCF} <<EOF
[General/unit]
GEO = FALSE

[General/socket]
locip = $MN1_IP

mwdlocport = 9437

[General/ipaddr]
floatappip = $MN1_IP
locappip = $MN1_IP

[General/HSB]
HSB = FALSE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMCF}
cat >> ${FILE_HAMCF} <<EOF
locport = 1318
remport = 1318

EOF

# REQ01096055 
	if [ -f ${FILE_BONDSTATIC} -a  "x$PRODUCT" == "xCompact_Call_Server" ]
	then

cat > ${FILE_HAMSYSGENCF} <<EOF
[General/unit]
GEO = FALSE

[General/cluster]
MULTI = FALSE

[General/HSB]
HSB = FALSE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMSYSGENCF}
cat >> ${FILE_HAMSYSGENCF} <<EOF
locport = 1318
remport = 1318

[General/socket]
locip = $MN1_IP

[General/FT]
FaultTolerance = 1000
EOF

	else

cat > ${FILE_HAMSYSGENCF} <<EOF
[General/unit]
GEO = FALSE

[General/socket]
locip = $MN1_IP

mwdlocport = 9437

[General/ipaddr]
floatappip = $MN1_IP
locappip = $MN1_IP

[General/HSB]
HSB = FALSE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMSYSGENCF}
cat >> ${FILE_HAMSYSGENCF} <<EOF
locport = 1318
remport = 1318

[Debug]
keepal_log = 0               ;Log every keepal_log-th keep alive message. 0 disables keepalive almost forever.

[General/FT]
FaultTolerance = $FT
EOF

	fi
fi

if [ "$sysType" == "duplicated" ]
then
	# duplicated system - check if hsb enabled
	HSB=`cat ${FILE_CFG} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
	if [ "$HSB" != "" ]
	then

		LOCPORT="9437"
		REMPORT="9537"

		#get local internal IP
		IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT1_IP=`echo ${IPN}`
		#echo $INT1_IP

		#get remote internal IP
		IP=$(/sbin/cfg-getparams.sh hsbRemIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT2_IP=`echo ${IPN}`
		#echo $INT2_IP

		#get local MN IP
		IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN1_IP=`echo ${IPN}`
		#echo $MN1_IP

		#get remote MN IP
		IP=$(/sbin/cfg-getparams.sh hsbRemoteMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN2_IP=`echo ${IPN}`
		#echo $MN2_IP

		#get MN float IP
		IP=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN_FLOAT=`echo ${IPN}`
		#echo $MN_FLOAT

		mkdir -p $(dirname ${FILE_HAMCF})
		mkdir -p $(dirname ${FILE_HAMSYSGENCF})
		mkdir -p $(dirname ${FILE_HAMCF_STANDARD})

if [ -f ${FILE_BONDSTATIC} -a  "x$PRODUCT" == "xCompact_Call_Server" ]
then

cat > ${FILE_HAMSYSCOMCF} <<EOF
[Apps]
numSect = 7 

[Apps/app0]
name = DRH
enabled = TRUE
level = 0
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app1]
name = SYSUP
enabled = TRUE
level = 10
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app2]
name = DGM
enabled = TRUE
level = 6
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app3]
name = DBWD
EOF
echo "enabled = ${USE_DB}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 1
hsberr = reboot
nohsberr = reboot
maxrestart = 5
acttime = 6

[Apps/app4]
name = SHMCP
enabled = TRUE
level = 3
hsberr = restart
nohsberr = restart
maxrestart = 5
acttime = 6
maxnoreboot = 0
cntrtime = 60

[Apps/app5]
name = DRBDP
EOF
echo "enabled = ${USE_DRBD}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 10
acttime = 6
maxnoreboot = 1
cntrtime = 60

[Apps/app6]
name = LOGT
enabled = TRUE
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 0
acttime = 6
EOF

else

cat > ${FILE_HAMSYSCOMCF} <<EOF
[Apps]
numSect = 7

[Apps/app0]
name = DRH
enabled = TRUE
level = 0
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app1]
name = SYSUP
enabled = TRUE
level = 10
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app2]
name = DGM
enabled = TRUE
level = 6
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app3]
name = DBWD
EOF
echo "enabled = ${USE_DB}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 1
hsberr = reboot
nohsberr = reboot
maxrestart = 5
acttime = 6

[Apps/app4]
name = SHMCP
enabled = FALSE
level = 3
hsberr = restart
nohsberr = restart
maxrestart = 5
acttime = 6
maxnoreboot = 0
cntrtime = 60

[Apps/app5]
name = DRBDP
EOF
echo "enabled = ${USE_DRBD}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 10
acttime = 6
maxnoreboot = 1
cntrtime = 60

[Apps/app6]
name = LOGT
enabled = TRUE
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 0
acttime = 6
EOF

fi

cat > ${FILE_HAMCF} <<EOF
[General/unit]
GEO = FALSE

[General/socket]
locip = $INT1_IP
remip = $INT2_IP

mwdlocport = ${LOCPORT}
mwdremport = ${REMPORT}

[General/ipaddr]
floatappip = $MN_FLOAT
locappip = $MN1_IP
remappip = $MN2_IP

[General/HSB]
HSB = TRUE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMCF}
cat >> ${FILE_HAMCF} <<EOF
locport = 1318
remport = 1318

EOF

# REQ01096055 
	if [ -f ${FILE_BONDSTATIC} -a  "x$PRODUCT" == "xCompact_Call_Server" ]
	then

cat > ${FILE_HAMSYSGENCF} <<EOF	
[General/unit]
GEO = FALSE

[General/cluster]
MULTI = FALSE

[General/HSB]
HSB = TRUE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMSYSGENCF}
cat >> ${FILE_HAMSYSGENCF} <<EOF
locport = 1318
remport = 1318

[General/socket]
locip = $INT1_IP
remip = $INT2_IP

[General/FT]
FaultTolerance = 1000
EOF
	else
cat > ${FILE_HAMSYSGENCF} <<EOF
[General/unit]
GEO = FALSE

[General/socket]
locip = $INT1_IP
remip = $INT2_IP

mwdlocport = ${LOCPORT}
mwdremport = ${REMPORT}

[General/ipaddr]
floatappip = $MN_FLOAT
locappip = $MN1_IP
remappip = $MN2_IP

[General/HSB]
HSB = TRUE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMSYSGENCF}
cat >> ${FILE_HAMSYSGENCF} <<EOF
locport = 1318
remport = 1318

[Debug]
keepal_log = 0               ;Log every keepal_log-th keep alive message. 0 disables keepalive almost forever.

[General/FT]
FaultTolerance = $FT
EOF

	fi

# Generate hamstandard.cf
cat > ${FILE_HAMCF_STANDARD} <<EOF
[General/unit]
GEO = FALSE

[General/socket]
locip = $INT1_IP
remip = $INT2_IP

mwdlocport = ${LOCPORT}
mwdremport = ${REMPORT}

[General/ipaddr]
floatappip = $MN_FLOAT
locappip = $MN1_IP
remappip = $MN2_IP

[General/HSB]
HSB = TRUE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMCF_STANDARD}
cat >> ${FILE_HAMCF_STANDARD} <<EOF
locport = 1318
remport = 1318

EOF
	fi
fi

if [ "$sysType" == "geo-dual" ]
then
	# geo-dual system - check if geo enabled
	GEO=`cat ${FILE_CFG} | awk '/georedundancy/{p=1} /!/{p=0} p' | grep 'enable'`
	if [ "$GEO" != "" ]
	then

		LOCPORT="9437"
		REMPORT="9537"

		#get local internal IP
		IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT1_IP=`echo ${IPN}`
		#echo $INT1_IP

		#get remote internal IP
		IP=$(/sbin/cfg-getparams.sh hsbRemIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT2_IP=`echo ${IPN}`
		#echo $INT2_IP

		#get local MN IP
		IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN1_IP=`echo ${IPN}`
		#echo $MN1_IP

		#get remote MN IP
		IP=$(/sbin/cfg-getparams.sh hsbRemoteMnIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN2_IP=`echo ${IPN}`
		#echo $MN2_IP

		#get MN float IP
		IP=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		MN_FLOAT=`echo ${IPN}`
		#echo $MN_FLOAT

		mkdir -p $(dirname ${FILE_HAMCF})
		mkdir -p $(dirname ${FILE_HAMSYSGENCF})
		mkdir -p $(dirname ${FILE_HAMCF_STANDARD})

		if [ -f ${FILE_BONDSTATIC} -a  "x$PRODUCT" == "xCompact_Call_Server" ]
		then

cat > ${FILE_HAMSYSCOMCF} <<EOF
[Apps]
numSect = 9 

[Apps/app0]
name = DRH
enabled = TRUE
level = 0
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app1]
name = SYSUP
enabled = TRUE
level = 10
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app2]
name = DGM
enabled = TRUE
level = 6
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app3]
name = DBWD
EOF
echo "enabled = ${USE_DB}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 1
hsberr = reboot
nohsberr = reboot
maxrestart = 5
acttime = 6

[Apps/app4]
name = SHMCP
enabled = TRUE
level = 3
hsberr = restart
nohsberr = restart
maxrestart = 5
acttime = 6
maxnoreboot = 0
cntrtime = 60

[Apps/app5]
name = DRBDP
EOF
echo "enabled = ${USE_DRBD}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 10
acttime = 6
maxnoreboot = 1
cntrtime = 60

[Apps/app6]
name = LOGT
enabled = TRUE
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 0
acttime = 6

[Apps/app7]
name = GHAMP
enabled = TRUE
level = 1
hsberr = restart
nohsberr = restart
maxrestart = 5
acttime = 6

[Apps/app8]
name = UHAMP
enabled = TRUE
level = 1
hsberr = restart
nohsberr = restart
maxrestart = 5
acttime = 6
EOF

		else

cat > ${FILE_HAMSYSCOMCF} <<EOF
[Apps]
numSect = 9

[Apps/app0]
name = DRH
enabled = TRUE
level = 0
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app1]
name = SYSUP
enabled = TRUE
level = 10
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app2]
name = DGM
enabled = TRUE
level = 6
hsberr = reboot
nohsberr = restart
maxrestart = 3
acttime = 6

[Apps/app3]
name = DBWD
EOF
echo "enabled = ${USE_DB}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 1
hsberr = reboot
nohsberr = reboot
maxrestart = 5
acttime = 6

[Apps/app4]
name = SHMCP
enabled = FALSE
level = 3
hsberr = restart
nohsberr = restart
maxrestart = 5
acttime = 6
maxnoreboot = 0
cntrtime = 60

[Apps/app5]
name = DRBDP
EOF
echo "enabled = ${USE_DRBD}" >> ${FILE_HAMSYSCOMCF}
cat >> ${FILE_HAMSYSCOMCF} <<EOF
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 10
acttime = 6
maxnoreboot = 1
cntrtime = 60

[Apps/app6]
name = LOGT
enabled = TRUE
level = 2
hsberr = restart
nohsberr = restart
maxrestart = 0
acttime = 6

[Apps/app7]
name = GHAMP
enabled = TRUE
level = 1
hsberr = restart
nohsberr = restart
maxrestart = 5
acttime = 6

[Apps/app8]
name = UHAMP
enabled = TRUE
level = 1
hsberr = restart
nohsberr = restart
maxrestart = 5
acttime = 6
EOF

fi

cat > ${FILE_HAMCF} <<EOF
[General/unit]
GEO = TRUE

[General/socket]
locip = $INT1_IP
remip = $INT2_IP

mwdlocport = ${LOCPORT}
mwdremport = ${REMPORT}

[General/ipaddr]
floatappip = $MN_FLOAT
locappip = $MN1_IP
remappip = $MN2_IP

[General/HSB]
HSB = TRUE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMCF}
cat >> ${FILE_HAMCF} <<EOF
locport = 1318
remport = 1318

EOF

		# REQ01096055 
		if [ -f ${FILE_BONDSTATIC} -a  "x$PRODUCT" == "xCompact_Call_Server" ]
		then

cat > ${FILE_HAMSYSGENCF} <<EOF	
[General/unit]
GEO = TRUE

[General/cluster]
MULTI = FALSE

[General/HSB]
HSB = TRUE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMSYSGENCF}
cat >> ${FILE_HAMSYSGENCF} <<EOF
locport = 1318
remport = 1318

[General/socket]
locip = $INT1_IP
remip = $INT2_IP

[General/FT]
FaultTolerance = 1000
EOF
		else
cat > ${FILE_HAMSYSGENCF} <<EOF
[General/unit]
GEO = TRUE

[General/socket]
locip = $INT1_IP
remip = $INT2_IP

mwdlocport = ${LOCPORT}
mwdremport = ${REMPORT}

[General/ipaddr]
floatappip = $MN_FLOAT
locappip = $MN1_IP
remappip = $MN2_IP

[General/HSB]
HSB = TRUE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMSYSGENCF}
cat >> ${FILE_HAMSYSGENCF} <<EOF
locport = 1318
remport = 1318

[Debug]
keepal_log = 0               ;Log every keepal_log-th keep alive message. 0 disables keepalive almost forever.

[General/FT]
FaultTolerance = $FT
EOF

		fi

# Generate hamstandard.cf
cat > ${FILE_HAMCF_STANDARD} <<EOF
[General/unit]
GEO = TRUE

[General/socket]
locip = $INT1_IP
remip = $INT2_IP

mwdlocport = ${LOCPORT}
mwdremport = ${REMPORT}

[General/ipaddr]
floatappip = $MN_FLOAT
locappip = $MN1_IP
remappip = $MN2_IP

[General/HSB]
HSB = TRUE

[DB]
EOF
echo "useDB = ${USE_DB}" >> ${FILE_HAMCF_STANDARD}
cat >> ${FILE_HAMCF_STANDARD} <<EOF
locport = 1318
remport = 1318

EOF
	fi
fi

[ ! -e "$FILE" ] && exit 1
APPS=`cat ${FILE}  | awk '/\[Apps\]/{p=1} /application_data/{p=0} p'`
cat >> ${FILE_HAMCF} <<EOF
${APPS}
EOF
