#!/bin/sh
FILE_CFG=/etc/startup-config
FILE_BONDSTATIC=/etc/sysconfig/bonding.static

if [ "$1" == "" ]
then
	# get local hostname
	TARGET_NAME1=$(/sbin/cfg-getparams.sh localHostname)

	# create /etc/hostname file
	echo ${TARGET_NAME1} > /etc/hostname

	isSystemd=`/sbin/cfg-isSystemdInit.sh`
	if [ "$isSystemd" == "NO" ]
	then
		/etc/init.d/hostname.sh restart
	else
		hostnamectl set-hostname ${TARGET_NAME1}
	fi

	# read local mgmt IP address
	LOC_IP_MGMT=$(/sbin/cfg-getparams.sh localMnIpAddress)
	echo $LOC_IP_MGMT
	L_IP=`echo ${LOC_IP_MGMT} | sed 's/\/.*//'`
	echo $L_IP

	sysType=$(/sbin/cfg-getparams.sh systemType)
	isHsbEnable=$(/sbin/cfg-getparams.sh mmRedundancyType)
	isGeoEnable=$(/sbin/cfg-getparams.sh mmGeoRedundancyType)

	if [[ ( "$sysType" == "duplicated" && "$isHsbEnable" == "hsb" ) || ( "$sysType" == "geo-dual" && "$isGeoEnable" == "redundant" ) ]]
	then
		# get hsb remote hostname
		TARGET_NAME2=$(/sbin/cfg-getparams.sh hsbRemoteHostname)

		# get local internal IP address
		IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT1_IP=`echo ${IPN}`
		echo $INT1_IP

		# get hsb remote internal IP address
		IP=$(/sbin/cfg-getparams.sh hsbRemIntIpAddress)
		. /sbin/cfg-calculate-network.sh ${IP}
		convert_ip_mask
		INT2_IP=`echo ${IPN}`
		echo $INT2_IP

		MASK=`echo ${INT1_IP} | sed 's/^.*\(...\)$/\1/'`
		IP=`echo ${INT1_IP} | sed 's/\(.*\).../\1/'`
		if [ "${IP}" == "" ] || [ "${MASK}" == "" ]
		then
			echo "error in IP/mask configuration file INT1_IP /etc/hosts is not generated !"
			exit 1
		fi

		MASK=`echo ${INT2_IP} | sed 's/^.*\(...\)$/\1/'`
		IP=`echo ${INT2_IP} | sed 's/\(.*\).../\1/'`
		if [ "${IP}" == "" ] || [ "${MASK}" == "" ]
		then
			echo "error in IP/mask configuration file INT2_IP /etc/hosts is not generated !"
			exit 1
		fi

		# read redundant hostname mgmt IP
		REM_IP_MGMT=$(/sbin/cfg-getparams.sh hsbRemoteMnIpAddress)
		echo $REM_IP_MGMT
		R_IP=`echo ${REM_IP_MGMT} | sed 's/\/.*//'`
		echo $R_IP

		MASK=`echo ${R_IP} | sed 's/^.*\(...\)$/\1/'`
		IPN=`echo ${R_IP} | sed 's/\(.*\).../\1/'`
		if [ "${IPN}" == "" ] || [ "${MASK}" == "" ]
		then
			echo "error in IP/mask configuration file REM MGMT IP /etc/hosts is not generated !"
			exit 1
		fi
	fi

	# check if georedundant and add MN ip into file hosts
	IP=`cat $FILE_CFG | awk '/remote node-id 1/{p=1} /!/{p=0} p' | grep 'ip address mgmt' |grep -vw 'ip address mgmt float' | head -n 1 | awk '{print $4}'`
	MN21_IP=`echo ${IP} | sed 's/\/.*//'`

	IP=`cat $FILE_CFG | awk '/remote node-id 2/{p=1} /!/{p=0} p' | grep 'ip address mgmt' |grep -vw 'ip address mgmt float' | head -n 1 | awk '{print $4}'`
	MN22_IP=`echo ${IP} | sed 's/\/.*//'`

	TARGET_NAME21=`cat $FILE_CFG | grep  'remote node-id 1 hostname' | awk '{print $5}'`
	TARGET_NAME22=`cat $FILE_CFG | grep  'remote node-id 2 hostname' | awk '{print $5}'`

	#MN21_IP=$(/sbin/cfg-getparams.sh mmMnIpAddress21)
	#MN22_IP=$(/sbin/cfg-getparams.sh mmMnIpAddress22)	
	#TARGET_NAME21=$(/sbin/cfg-getparams.sh mmMnHostname21)
	#TARGET_NAME22=$(/sbin/cfg-getparams.sh mmMnHostname22)
		
	echo $MN21_IP	
	echo $MN22_IP
	
	#check if cCS250 
	ccs250Variante=$(/sbin/cfg-getparams.sh mn-type)
	MM_NODE_NAME=$(/sbin/cfg-getparams.sh mmMnNodeName)
	MN_FLOAT=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress)
	MN_FLOAT_IP=`echo ${MN_FLOAT} | sed 's/\/.*//'`
	
	if [ "$sysType" == "standalone" ]
	then
		# standalone system

		if [ -z $L_IP ] 
		then
			cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
127.0.0.1	ha-${TARGET_NAME1}
EOF
			# Append entries if IPv6 is supported
			if [ -f /proc/net/if_inet6 ]
			then
				cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
			fi
		else
			if [ "$MM_NODE_NAME" != "" ] && [ "$ccs250Variante" == "EM" ]
			then
				cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
127.0.0.1	ha-${TARGET_NAME1}
${L_IP}	${TARGET_NAME1}
${L_IP}	${MM_NODE_NAME}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			else
				cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
127.0.0.1	ha-${TARGET_NAME1}
${L_IP}	${TARGET_NAME1}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			fi
		fi
	fi

	if [ "$sysType" == "duplicated" ] && [ "$isHsbEnable" == "hsb" ]
	then
		# duplicated system

		if [ -z $L_IP ]
		then
			cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${INT1_IP}	ha-${TARGET_NAME1}
${INT2_IP}	ha-${TARGET_NAME2}
${R_IP}	${TARGET_NAME2}
EOF
			# Append entries if IPv6 is supported
			if [ -f /proc/net/if_inet6 ]
			then
				cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
			fi
		else
			if [ "$MM_NODE_NAME" != "" ] && [ "$ccs250Variante" == "EM" ] && [ "$MN_FLOAT_IP" != "" ]
			then
				cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${INT1_IP}	ha-${TARGET_NAME1}
${INT2_IP}	ha-${TARGET_NAME2}
${L_IP}	${TARGET_NAME1}
${R_IP}	${TARGET_NAME2}
${MN_FLOAT_IP}	${MM_NODE_NAME}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			else
cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${INT1_IP}	ha-${TARGET_NAME1}
${INT2_IP}	ha-${TARGET_NAME2}
${L_IP}	${TARGET_NAME1}
${R_IP}	${TARGET_NAME2}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			fi
 		fi
	fi

	if [ "$sysType" == "geo-single" ] && [ "$isGeoEnable" == "redundant" ]
	then
		# geo-redundant system with one NE in each unit

		if [ -z $L_IP ]
		then
			cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${MN21_IP}	${TARGET_NAME21}	
EOF
			# Append entries if IPv6 is supported
			if [ -f /proc/net/if_inet6 ]
			then
				cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
			fi
		else
			cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${L_IP}	${TARGET_NAME1}
${MN21_IP}	${TARGET_NAME21}	
EOF
			# Append entries if IPv6 is supported
			if [ -f /proc/net/if_inet6 ]
			then
				cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
			fi
		fi
	fi

	if [ "$sysType" == "geo-dual" ] && [ "$isGeoEnable" == "redundant" ]
	then
		# geo-redundant system with 2 NE in each unit

		if [ -z $L_IP ]
		then
			cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${INT1_IP}	ha-${TARGET_NAME1}
${INT2_IP}	ha-${TARGET_NAME2}
${R_IP}	${TARGET_NAME2}
${MN21_IP}	${TARGET_NAME21}	
${MN22_IP}	${TARGET_NAME22}	
EOF
			# Append entries if IPv6 is supported
			if [ -f /proc/net/if_inet6 ]
			then
				cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
			fi
		else  
			cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${INT1_IP}	ha-${TARGET_NAME1}
${INT2_IP}	ha-${TARGET_NAME2}
${L_IP}	${TARGET_NAME1}
${R_IP}	${TARGET_NAME2}
${MN21_IP}	${TARGET_NAME21}	
${MN22_IP}	${TARGET_NAME22}	
EOF
			# Append entries if IPv6 is supported
			if [ -f /proc/net/if_inet6 ]
			then
				cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
			fi
		fi
	fi
fi

if [ "$1" != "" ]
then
	if [ "$2" != "" ]
	then
		sysType=`konf -- -d | grep 'system type' | awk '{print $3}'`

		if [ "$2" == "hsb_enable" ]
		then
			HSB="hsb_enable"
		else
			HSB=""
		fi

		if [ "$2" == "geo_enable" ]
		then
			GEO="geo_enable"
		else
			GEO=""
		fi
	else
		HSB=`konf -- -d | awk '/hsb/{p=1} /!/{p=0} p' | grep enable`
		GEO=`konf -- -d | awk '/georedundancy/{p=1} /!/{p=0} p' | grep enable`
	fi
	
	# #check if cCS250
	MM_NODE_NAME=`konf -- -d | grep "system name" | awk '{print $3}'`
	MN_FLOAT=`konf -- -d | grep 'ip address mgmt float' | awk '{print $5}'`
	MN_FLOAT_IP=`echo ${MN_FLOAT} | sed 's/\/.*//'`
	ccs250Variante=$(/sbin/cfg-getparams.sh mn-type)
	product_name=$(/sbin/cfg-getparams.sh product)

	if [ "$HSB" != "" ] || [ "$GEO" != "" ]
	then
		TARGET_NAME1="$1"
		TARGET_NAME2=`konf -- -d | awk '/hsb/{p=1} /!/{p=0} p' | grep 'hostname' | awk '{print $2}'`

		if [ -f ${FILE_BONDSTATIC} ] && [ "$product_name" == "Compact_Call_Server" ]
		then
			# cCS
			S_NODE=`konf -- -d | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
			if [ "${S_NODE}" == "1" ]
	    		then
					INT1_IP=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 1/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
					INT2_IP=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 2/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
			else
					INT1_IP=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 2/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
					INT2_IP=`cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 1/{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}'`
			fi      
		elif [ -f ${FILE_BONDSTATIC} ]
		then
			S_NODE=`konf -- -d | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
			if [ "${S_NODE}" == "1" ]
	    		then
					INT1_IP=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}' | sed 's/\$S_NODE/1/g'`
					INT2_IP=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}' | sed 's/\$S_NODE/2/g'`
			else
					INT1_IP=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}' | sed 's/\$S_NODE/2/g'`
					INT2_IP=`cat ${FILE_BONDSTATIC} | awk '/ S_NODE /{p=1} /!/{p=0} p' | grep 'address' | awk '{print $2}' | sed 's/\$S_NODE/1/g'`
			fi      
		else
			INT1_IPx=`konf -- -d | awk '/hsb/{p=1} /!/{p=0} p' | grep ' ip address internal' | grep -vw '  ip address internal' | awk '{print $4}'`
			INT2_IPx=`konf -- -d | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address internal' | awk '{print $4}'`

			INT1_IP=`echo ${INT1_IPx} | sed 's/\/.*//'`
			INT2_IP=`echo ${INT2_IPx} | sed 's/\/.*//'`
		fi

		# read redundant hostname mgmt IP
		REM_IP_MGMT=`konf -- -d | awk '/hsb/{p=1} /!/{p=0} p' | grep '  ip address mgmt' | awk '{print $4}'`
		R_IP=`echo ${REM_IP_MGMT} | sed 's/\/.*//'`
 
		# read local mgmt IP addres - first from runnig-conf; if running-conf empty, then read from myip file
		LOC_IP_MGMT=`konf -- -d | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep ' ip address' | awk '{print $3}'`
		if [ -z $LOC_IP_MGMT ]
		then
			cat /etc/sysconfig/myip 2> /dev/null | grep MYIP > /tmp/myip
			LOC_IP_MGMT=`cut -d "=" -f 2 /tmp/myip`
		fi

		L_IP=`echo ${LOC_IP_MGMT} | sed 's/\/.*//'`

		# chech if georedundant and add MN ip into file hosts
		IP=`konf -- -d | awk '/remote node-id 1/{p=1} /!/{p=0} p' | grep 'ip address mgmt' |grep -vw 'ip address mgmt float' | head -n 1 | awk '{print $4}'`
		MN21_IP=`echo ${IP} | sed 's/\/.*//'`

		IP=`konf -- -d | awk '/remote node-id 2/{p=1} /!/{p=0} p' | grep 'ip address mgmt' |grep -vw 'ip address mgmt float' | head -n 1 | awk '{print $4}'`
		MN22_IP=`echo ${IP} | sed 's/\/.*//'`

		TARGET_NAME21=`konf -- -d | grep  'remote node-id 1 hostname' | awk '{print $5}'`
		TARGET_NAME22=`konf -- -d | grep  'remote node-id 2 hostname' | awk '{print $5}'`
				
		if [ "$sysType" == "duplicated" ] && [ "$HSB" != "" ]
		then
			# duplicated system
			if [ -z $L_IP ]
			then
				cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${INT1_IP}	ha-${TARGET_NAME1}
${INT2_IP}	ha-${TARGET_NAME2}
${R_IP}	${TARGET_NAME2}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			else
				if [ "$MM_NODE_NAME" != "" ] && [ "$ccs250Variante" == "EM" ] && [ "$MN_FLOAT_IP" != "" ]
				then
					cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${INT1_IP}	ha-${TARGET_NAME1}
${INT2_IP}	ha-${TARGET_NAME2}
${L_IP}	${TARGET_NAME1}
${R_IP}	${TARGET_NAME2}
${MN_FLOAT_IP}	${MM_NODE_NAME}
EOF
					# Append entries if IPv6 is supported
					if [ -f /proc/net/if_inet6 ]
					then
						cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
					fi
				else
					cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${INT1_IP}	ha-${TARGET_NAME1}
${INT2_IP}	ha-${TARGET_NAME2}
${L_IP} ${TARGET_NAME1}
${R_IP}	${TARGET_NAME2}
EOF
					# Append entries if IPv6 is supported
					if [ -f /proc/net/if_inet6 ]
					then
						cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
					fi

				fi
			fi
		fi

		if [ "$sysType" == "geo-single" ] && [ "$GEO" != "" ]
		then
			# geo-redundant system with one NE in each unit

			if [ -z $L_IP ]
			then
				cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${MN21_IP}	${TARGET_NAME21}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			else
				cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${L_IP}	${TARGET_NAME1}
${MN21_IP}	${TARGET_NAME21}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			fi
		fi

		if [ "$sysType" == "geo-dual" ] && [ "$GEO" != "" ]
		then
			# geo-redundant system with 2 NE in each unit

			if [ -z $L_IP ]
			then
				cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${INT1_IP}	ha-${TARGET_NAME1}
${INT2_IP}	ha-${TARGET_NAME2}
${R_IP}	${TARGET_NAME2}
${MN21_IP}	${TARGET_NAME21}
${MN22_IP}	${TARGET_NAME22}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			else
				cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
${INT1_IP}	ha-${TARGET_NAME1}
${INT2_IP}	ha-${TARGET_NAME2}
${L_IP}	${TARGET_NAME1}
${R_IP}	${TARGET_NAME2}
${MN21_IP}	${TARGET_NAME21}
${MN22_IP}	${TARGET_NAME22}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			fi
		fi
	else
		# standalone system
		TARGET_NAME1="$1"

		# read local mgmt IP addres - first from runnig-conf; if running-conf empty, then read from myip file
		LOC_IP_MGMT=`konf -- -d | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep ' ip address' | awk '{print $3}'`
		if [ -z $LOC_IP_MGMT ]
		then
			cat /etc/sysconfig/myip 2> /dev/null | grep MYIP > /tmp/myip
			LOC_IP_MGMT=`cut -d "=" -f 2 /tmp/myip`
		fi

		L_IP=`echo ${LOC_IP_MGMT} | sed 's/\/.*//'`

		if [ -z $L_IP ]
		then
			cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
127.0.0.1	ha-${TARGET_NAME1}
EOF
			# Append entries if IPv6 is supported
			if [ -f /proc/net/if_inet6 ]
			then
				cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
			fi
		else
			if [ "$MM_NODE_NAME" != "" ] && [ "$ccs250Variante" == "EM" ]
			then
				cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
127.0.0.1	ha-${TARGET_NAME1}
${L_IP}	${TARGET_NAME1}
${L_IP}	${MM_NODE_NAME}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			else
				cat > /etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
127.0.0.1	ha-${TARGET_NAME1}
${L_IP}	${TARGET_NAME1}
EOF
				# Append entries if IPv6 is supported
				if [ -f /proc/net/if_inet6 ]
				then
					cat >> /etc/hosts <<EOF

# The following lines are desirable for IPv6 capable hosts
::1	localhost ip6-localhost ip6-loopback
fe00::0	ip6-localnet
ff00::0	ip6-mcastprefix
ff02::1	ip6-allnodes
ff02::2	ip6-allrouters
EOF
				fi
			fi
		fi
	fi

	# check if MN-server configured - if so, add it in /etc/hosts
	mnSrv=`konf -- -d | grep 'MN-server'`
	if [ "$mnSrv" != "" ]
	then
		mn_srv_ip=`echo $mnSrv | awk '{print $3}'`
		mn_srv_name=`echo $mnSrv | awk '{print $2}'`
		
		short_name=`echo $mn_srv_name | cut -d '.' -f1`
		if [ "$short_name" == "$mn_srv_name" ]
		then
			echo "$mn_srv_ip   $mn_srv_name" >> /etc/hosts
		else
			echo "$mn_srv_ip   $short_name $mn_srv_name" >> /etc/hosts
		fi
	fi

	# check if static hosts are configured - if so, add them in /etc/hosts
	hosts=`konf -- -d | grep 'host add'`
	if [ "$hosts" != "" ]
	then
		konf -- -d | grep 'host add' >> /tmp/hosts

		while read line
		do
			host_ip=`echo $line | awk '{print $4}'`
			host_name=`echo $line | awk '{print $3}'`

			short_host=`echo $host_name | cut -d '.' -f1`
			if [ "$short_host" == "$host_name" ]
			then
				echo "$host_ip   $host_name" >> /etc/hosts
			else
				echo "$host_ip   $short_host $host_name" >> /etc/hosts
			fi
		done < /tmp/hosts

		# delete tmp file
		rm -rf /tmp/hosts
	fi
fi

