#!/bin/sh

FILE_INTERFACES=/etc/network/interfaces
FILE_STARTUP=/etc/startup-config
FILE_BONDSTATIC=/etc/sysconfig/bonding.static
FILE_NETW_DIR=/etc/systemd/network/
FILE_TMPIFACE=/etc/sysconfig/tmpiface
isSystemd=`/sbin/cfg-isSystemdInit.sh`

DEFAULT_INTERFACE_NAME=bond0
DEFAULT_VLAN_ID=2005
NETW_ID=2000

INT_VLAN=$(/sbin/cfg-getparams.sh mmInternalVlan)
S_NODE=$(/sbin/cfg-getparams.sh mmNodeNumber)
INT_INTERFACE=`cat ${FILE_STARTUP} | grep 'internal interface' | grep -v 'remote' | awk '{printf $3}'`
product=`cat ${FILE_STARTUP} | grep product | awk '{print $2}'`

function chkbond0()
{
	if [ "${INTERFACE}" == "${DEFAULT_INTERFACE_NAME}" ]
	then
		if [ "$isSystemd" == "NO" ]
		then
			cat >> ${FILE_INTERFACES} <<EOF
pre-up /usr/sbin/vconfig add ${INTERFACE} $INT_VLAN
post-down /usr/sbin/vconfig rem ${INTERFACE}.${INT_VLAN}
# BOND Internal communication interface
#
#start internal intf vlan
auto ${INTERFACE}.${INT_VLAN}
#end internal intf vlan
iface ${INTERFACE}.${INT_VLAN} inet static
address ${IPN}
network ${SUBNET_BASE}
netmask ${NMASK}
broadcast ${SUBNET_BROADCAST}
EOF

		else
			cat >> ${FILE_INTERFACES} <<EOF
# BOND Internal communication interface
#
#start internal intf vlan
auto ${INTERFACE}.${INT_VLAN}
#end internal intf vlan
iface ${INTERFACE}.${INT_VLAN} inet static
pre-up ifconfig ${INTERFACE} up
pre-up /usr/sbin/vconfig add ${INTERFACE} $INT_VLAN
post-down /usr/sbin/vconfig rem ${INTERFACE}.${INT_VLAN}
post-down ifconfig ${INTERFACE} down
address ${IPN}
network ${SUBNET_BASE}
netmask ${NMASK}
broadcast ${SUBNET_BROADCAST}
EOF
		fi
	fi
}

function mtu_get()
{
	# relevant for OPENSTACK only
	[ "$(/sbin/cfg-getparams.sh mmMnChassisType)" != "OPENSTACK" ] && return 
	#get mtu from network.json
	mtu=$(/sbin/eth_from_ip.py $1 --mtu)
	[ "$mtu" != "" ] && echo "mtu $mtu"
}

function set_etc_network_iface()
{
	INTERFACE=`cat ${FILE_TMPIFACE}`
	# get local internal IP address
	IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
	. /sbin/cfg-calculate-network.sh ${IP}
	convert_ip_mask
	CHK_INT_IP=`cat ${FILE_INTERFACES} | grep "address ${IP}"`
	if [ "${CHK_INT_IP}" == "" ]
	then
		sed '/BOND Internal/,/broadcast/d' ${FILE_INTERFACES} >${FILE_INTERFACES}.tmp
		mv ${FILE_INTERFACES}.tmp ${FILE_INTERFACES}
		if [ ! -f ${FILE_BONDSTATIC} ]
		then
			HSB=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
			if [ "${HSB}" != "" ] && [ "${INT_VLAN}" == "" ]
			then
				MTU=$(mtu_get $IPN)
				cat >> ${FILE_INTERFACES} <<EOF
# Internal interface
#
auto ${INTERFACE}
iface ${INTERFACE} inet static
address ${IPN}
network ${SUBNET_BASE}
netmask ${NMASK}
broadcast ${SUBNET_BROADCAST}
$MTU
EOF
			else
				if [ "${HSB}" != "" ]
				then
					chkbond0
				fi
			fi
		fi

		if [ -f ${FILE_BONDSTATIC} ] && [ "$product" == "Compact_Call_Server" ]
		then
			if [ "${S_NODE}" == "2" ]
			then
				cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 2 BOND/{p=1} /!/{p=0} p' >> ${FILE_INTERFACES}
			elif [ "${S_NODE}" == "1" ]
			then
				cat ${FILE_BONDSTATIC} | awk '/CMJ NODE 1 BOND/{p=1} /!/{p=0} p' >> ${FILE_INTERFACES}
			fi
		elif [ -f ${FILE_BONDSTATIC} ] && [ "${HSB}" != "" ] && [ "${S_NODE}" != "" ] && [ "${INT_VLAN}" != "" ]
		then
			cat ${FILE_BONDSTATIC} | awk '/# S_NODE BOND INT_VLAN/{p=1} /!/{p=0} p' >> ${FILE_INTERFACES}
			sed -i 's/# S_NODE BOND INT_VLAN/\n#\n# S_NODE BOND INT_VLAN/' ${FILE_INTERFACES}
			sed -i 's/\$INT_VLAN/'${INT_VLAN}'/g' ${FILE_INTERFACES}
			sed -i 's/\$S_NODE/'${S_NODE}'/g' ${FILE_INTERFACES}

			#mzva added
	                # Add Seville ports to INT VLAN
	                if [ -f /opt/iskratel/bin/l2menu ] && [ "$product" == "Media_Gateway" ]
	                then
				#Get internal VLAN
				vlan_num=$(cfg-getparams.sh mmInternalVlan)

	                        #Add INT VLAN to processor ports
	                        /opt/iskratel/bin/l2menu add_port_vlan 8 ${vlan_num} no
	                        /opt/iskratel/bin/l2menu add_port_vlan 9 ${vlan_num} no

	                        #Check chassis type
	                        chassis=$(cfg-getparams.sh mmMnChassisType)

	                        #MEA and MED have uplink on ports 1 and 3
	                        if [ "${chassis}" == "MEA" -o "${chassis}" == "MED" ]
	                        then
	                                /opt/iskratel/bin/l2menu add_port_vlan 1 ${vlan_num} no
	                                /opt/iskratel/bin/l2menu add_port_vlan 3 ${vlan_num} no
	                        fi

	                        #MEC have uplink on ports 0 and 2
	                        if [ "${chassis}" == "MEC" ]
	                        then
	                                /opt/iskratel/bin/l2menu add_port_vlan 0 ${vlan_num} no
	                                /opt/iskratel/bin/l2menu add_port_vlan 2 ${vlan_num} no
	                        fi
	                fi
			#end mzva
		fi
	fi
}

function systemd_intnetworkinterface()
{
	# get local internal IP address
	IP=$(/sbin/cfg-getparams.sh localIntIpAddress)
	. /sbin/cfg-calculate-network.sh ${IP}
	convert_ip_mask
	VLAN_MGMT=$(/sbin/cfg-getparams.sh mmMnVlan)
	if [ "${VLAN_MGMT}" != "" ]
	then
		interfaceNetworkFile=${FILE_NETW_DIR}${INTERFACE}.${VLAN_MGMT}.network
	else
		interfaceNetworkFile=${FILE_NETW_DIR}${INTERFACE}.network
	fi
	CHK_INT_IP=`cat $interfaceNetworkFile | grep "address=${IP}"`

	if [ "${CHK_INT_IP}" == "" ]
	then
		# insert vlan interface name in ${INTERFACE}. network file
		if [ -e ${FILE_NETW_DIR}${INTERFACE}.network ]
		then
			HSB=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
			if [ "${HSB}" != "" ] && [ "${INT_VLAN}" != "" ]
			then
				#delete if previously inserted
				sed -i '/#start internal intf vlan/,/#end internal intf vlan/d' ${FILE_NETW_DIR}${INTERFACE}.network
				#insert new
				sed -i "/\[Network\]/a #end internal intf vlan" ${FILE_NETW_DIR}${INTERFACE}.network
				sed -i "/\[Network\]/a VLAN=${INTERFACE}.${INT_VLAN}" ${FILE_NETW_DIR}${INTERFACE}.network
				sed -i "/\[Network\]/a #start internal intf vlan" ${FILE_NETW_DIR}${INTERFACE}.network

				# create vlan intf files - netdev & network
				cat > ${FILE_NETW_DIR}/${INTERFACE}.${INT_VLAN}.netdev <<EOF
[NetDev]
Name=${INTERFACE}.${INT_VLAN}
Kind=vlan

[VLAN]
Id=${INT_VLAN}
EOF

				cat > ${FILE_NETW_DIR}/${INTERFACE}.${INT_VLAN}.network <<EOF
[Match]
Name=${INTERFACE}.${INT_VLAN}

[Network]
Address=${IP}
Broadcast=${SUBNET_BROADCAST}
EOF
			fi
		else
			echo "Warning: ${INTERFACE} have no network configuration file ${INTERFACE}.network in systemd. VLAN [${INT_VLAN}] is not configured."
		fi
	fi
}


function setintvlanonly()
{
	INTERFACE="${DEFAULT_INTERFACE_NAME}"
	echo "${INTERFACE}" > ${FILE_TMPIFACE}
	
	if [ "$isSystemd" == "NO" ]
	then
		set_etc_network_iface
	else
		systemd_intnetworkinterface
	fi
}


function internal_intf_prefix()
{
	#get internal interface's prefix
	#OPENSTACK - no prefix
	[ "$(/sbin/cfg-getparams.sh mmMnChassisType)" == "OPENSTACK" ] && return 
	#check if either of fp_$INT_INTERFACE or $INT_INTERFACE exist on system
	/sbin/cfg-fpinternal.sh $1
	case $? in 
		0) echo "fp_";; #fp_$INT_INTERFACE exist
		3) return;; #$INT_INTERFACE exist, but fp_$INT_INTERFACE not - no prefix
		2) return;; #should not happen - neither exist
	esac
}

function setintiface()
{
	INT_INTF_PREFIX=$(internal_intf_prefix $INT_INTERFACE)
	INTERFACE=${INT_INTF_PREFIX}${INT_INTERFACE}
	echo "${INTERFACE}" > ${FILE_TMPIFACE}

	if [ "$isSystemd" == "NO" ]
	then
		set_etc_network_iface
	else
		systemd_intnetworkinterface
	fi
}

if [ -f ${FILE_BONDSTATIC} ] && [ "$product" == "Compact_Call_Server" ]
then
	#only cCS
	INT_VLAN=${DEFAULT_VLAN_ID}
else
	#CG standalone tipc and default VLAN configuration in order to satisfy MDS
	HSB=`cat ${FILE_STARTUP} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'enable'`
	if [ "${HSB}" != "" ]
	then
		INT_VLAN=$(/sbin/cfg-getparams.sh mmInternalVlan)
	fi
fi

if [ "${INT_VLAN}" != "" ] && [ "${INT_INTERFACE}" == "" ]  
then
	setintvlanonly
fi

if [ "${INT_VLAN}" != "" ] && [ "${INT_INTERFACE}" != "" ]  
then
	setintiface
fi

if [ "${INT_VLAN}" == "" ] && [ "${INT_INTERFACE}" != "" ]
then
        setintiface
fi

if [ "$isSystemd" == "NO" ]
then
	rm ${FILE_TMPIFACE}
fi
