#!/bin/bash

FILE_STARTUP=/etc/startup-config
FILE_INTERFACES=/etc/network/interfaces
FILE_MYIP=/etc/sysconfig/myip
FILE_BONDPORTS=/etc/sysconfig/bondports
FILE_BONDSTATIC=/etc/sysconfig/bonding.static

SYSTEMD_DIR=/etc/systemd
SYSTEMD_NETWORK_DIR=${SYSTEMD_DIR}/network

BOND_INTERFACE_NAME=bond0

S_NODE=$(/sbin/cfg-getparams.sh mmNodeNumber)

function patch_bond_static()
{
	#check if eth3 interface exist on system and comment/uncomment eth3 section in bonding.static
	if ip link show dev eth3 >/dev/null 2>&1; then 
		#eth3 exist, uncomment eth3 section
		if grep -q '^#auto eth3' $FILE_BONDSTATIC; then 
			#commented section - uncomment it
			sed -i '/^#auto eth3/,/^!/ s/^#//' $FILE_BONDSTATIC
		fi
	else
		#eth3 not exist, comment eth3 section
		if grep -q '^auto eth3' $FILE_BONDSTATIC; then 
			#uncommented section - comment it
			sed -i '/^auto eth3/,/^!/ s/^/#/; s/^#!/!/' $FILE_BONDSTATIC
		fi	
	fi
}

function etcnetworkinterfaces()
{
	cat > ${FILE_INTERFACES} <<EOF
auto lo
iface lo inet loopback

EOF

	if [ "${IPN}" != "" ]
	then

		cat >> ${FILE_INTERFACES} <<EOF
# BOND MN interface (bonding, untagged)
#
auto ${BOND_INTERFACE_NAME}
iface ${BOND_INTERFACE_NAME} inet manual
EOF
		index=0
		while test $index -lt ${#ETH_INTERFACES[@]};
		do
			cat >> ${FILE_INTERFACES} <<EOF
   pre-up ifconfig ${ETH_INTERFACES[$index]} 0.0.0.0 up
EOF
			index=`expr ${index} + 1`
		done

		if [ "${VLAN_MGMT}" == "" ]
		then

			mtu=`cat ${FILE_STARTUP} | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep mtu | awk '{print $2}'`
			if [ "${mtu}" != "" ]
			then
				cat >> ${FILE_INTERFACES} <<EOF
   up ifconfig \$IFACE ${IPN} netmask ${NMASK} broadcast ${SUBNET_BROADCAST} mtu ${mtu}

EOF
			else
				cat >> ${FILE_INTERFACES} <<EOF
   up ifconfig \$IFACE ${IPN} netmask ${NMASK} broadcast ${SUBNET_BROADCAST}

EOF
			fi
		else
			cat >> ${FILE_INTERFACES} <<EOF
   up ifconfig \$IFACE up

EOF
		fi

		which ifenslave 2> /dev/null
		if [ $? -eq 0 ]; then
			# 'ifenslave' binary present:
			cat >> ${FILE_INTERFACES} <<EOF
   up ifenslave \$IFACE ${ETH_INTERFACES[@]}
   down ifenslave -d \$IFACE ${ETH_INTERFACES[@]}
   down ifconfig \$IFACE down

EOF
		else
			# 'ifenslave' binary not available:
			cat >> ${FILE_INTERFACES} <<EOF
   bond-slaves ${ETH_INTERFACES[@]}
   bond-mode active-backup
   bond-primary ${ETH_INTERFACES[@]}
   down ifconfig \$IFACE down

EOF
		fi

		if [ "${VLAN_MGMT}" != "" ]
		then
			cat >> ${FILE_INTERFACES} <<EOF
#start MN vlan
auto ${BOND_INTERFACE_NAME}.${VLAN_MGMT}
#end MN vlan
iface ${BOND_INTERFACE_NAME}.${VLAN_MGMT} inet static
   pre-up /usr/sbin/vconfig add ${BOND_INTERFACE_NAME} ${VLAN_MGMT}
   post-down /usr/sbin/vconfig rem ${BOND_INTERFACE_NAME}.${VLAN_MGMT}
   address ${IPN}
   netmask ${NMASK}
   broadcast ${SUBNET_BROADCAST}
EOF
			mtu=`cat ${FILE_STARTUP} | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep mtu | awk '{print $2}'`
			if [ "${mtu}" != "" ]
			then
				cat >> ${FILE_INTERFACES} <<EOF
   mtu ${mtu}

EOF
			fi
		fi
	fi

	# mand - add static internal interfaces for DSP
	if [ -f ${FILE_BONDSTATIC} ]
	then
		patch_bond_static
		cat ${FILE_BONDSTATIC} | awk '/STATICBOND/{p=1} /!/{p=0} p' >> ${FILE_INTERFACES}
	fi

	echo "#This is temporary autogenerated file for internal configurations usage, do not change or use it !!!" > ${FILE_MYIP}
	echo "MYIP=${IPN}/${MYMASK}" >> ${FILE_MYIP}

}

function etcnetworkinterfaces_ops()
{

if [ -x /sbin/dhclient ]
then
#old system with dhclient
        cat > ${FILE_INTERFACES} <<EOF
# loopback interface
#
auto lo
iface lo inet loopback

# ORCH interface
#
auto eth0
iface eth0 inet dhcp

EOF
fi

if [ -x /sbin/udhcpc ]
then
#New system with udhcpc
        cat > ${FILE_INTERFACES} <<EOF
# loopback interface
#
auto lo
iface lo inet loopback

# ORCH interface
#
auto eth0
iface eth0 inet manual
   up /sbin/udhcpc -n -O 121 -p /run/udhcpc.eth0.pid -i eth0
   down killall udhcp

EOF
fi

	if grep -q " mode dhcp" $FILE_STARTUP; then  #mgmt interface managed by dhcp, we're done 
		echo "# MGMT interface = ORCH interface (dhcp mode) " >> $FILE_INTERFACES
		return
	fi

	if [ "${IPN}" != "" ]
	then
		# get mgmt interface name based on mgmt IP address
		MGMT_INTF=`/sbin/eth_from_ip.py ${IPN}`
		#MGMT_INTF="eth1"
		#get mtu from network.json
		mtu=$(/sbin/eth_from_ip.py ${IPN} --mtu)
		[ "$mtu" != "" ] && MTU_OPT="mtu $mtu"

		cat >> ${FILE_INTERFACES} <<EOF
# MGMT interface
#
auto ${MGMT_INTF}
iface ${MGMT_INTF} inet manual
   up ifconfig \$IFACE ${IPN} netmask ${NMASK} broadcast ${SUBNET_BROADCAST} $MTU_OPT
   down ifconfig \$IFACE down

EOF

	fi
}

function systemd_ntp_config()
{
	clish_ntp1=$(/sbin/cfg-getparams.sh mmNtpServer1)
	clish_ntp2=$(/sbin/cfg-getparams.sh mmNtpServer2)
	clish_ntp3=$(/sbin/cfg-getparams.sh mmNtpServer3)
	clish_ntp=$(echo ${clish_ntp1} ${clish_ntp2} ${clish_ntp3})
	if [ "x${clish_ntp}" != "x" ]
	then
		cat > ${SYSTEMD_DIR}/timesyncd.conf <<EOF
[Time]
NTP=${clish_ntp}
FallbackNTP=${clish_ntp}
EOF
	else
		cat > ${SYSTEMD_DIR}/timesyncd.conf <<EOF
[Time]
#NTP=
#FallbackNTP=
EOF
	fi
}

function systemd_dns_config()
{
	network_interface_file=$1
	for i in 1 2 3
	do
		clish_nameserver=$(/sbin/cfg-getparams.sh mmNameServer${i})
		if [ "x${clish_nameserver}" != "x" ]
		then
			cat >> ${network_interface_file} <<EOF
DNS=${clish_nameserver}
EOF
		fi
	done

	clish_domain=$(/sbin/cfg-getparams.sh mmSystemConfigDomainName)
	if [ "x${clish_nameserver}" != "x" ]
	then
		cat >> ${network_interface_file} <<EOF
Domains=${clish_domain}
EOF
	fi
}

function systemd_networkinterfaces_ops()
{
	rm -rf ${SYSTEMD_NETWORK_DIR}
	mkdir -p ${SYSTEMD_NETWORK_DIR}

#	interface_unit_name=${SYSTEMD_NETWORK_DIR}/${ETH_INTERFACES[0]}
#	cat > ${SYSTEMD_NETWORK_DIR}/eth0.network <<EOF
#[Match]
#Name=eth0
#
#[Network]
#DHCP=yes
#
#[DHCP]
#UseDomains=true
#EOF

	if [ "${IPN}" != "" ]
	then
		# get mgmt interface name based on mgmt IP address
		MGMT_INTF=`/sbin/eth_from_ip.py ${IPN}`
		#MGMT_INTF=eth1
		if [ "x${MGMT_INTF}" != "x" ]
		then
			if [ "x${VLAN_MGMT}" != "x" ]
			then
				interface_unit_name=${SYSTEMD_NETWORK_DIR}/${MGMT_INTF}.${VLAN_MGMT}
				cat > ${interface_unit_name}.netdev <<EOF
[NetDev]
Name=${MGMT_INTF}.${VLAN_MGMT}
Kind=vlan

[VLAN]
Id=${VLAN_MGMT}
EOF
				cat > ${interface_unit_name}.network <<EOF
[Match]
Name=${MGMT_INTF}.${VLAN_MGMT}

EOF
			else
				# bring up interface
				mgmt_ip=$(/sbin/cfg-getparams.sh localMnIpAddress)
                                ip addr add $mgmt_ip dev ${MGMT_INTF}
                                ip link set ${MGMT_INTF} up

				interface_unit_name=${SYSTEMD_NETWORK_DIR}/${MGMT_INTF}
				cat > ${interface_unit_name}.network <<EOF
[Match]
Name=${MGMT_INTF}

EOF
			fi
			cat >> ${interface_unit_name}.network <<EOF
[Network]
Address=$(/sbin/cfg-getparams.sh localMnIpAddress)
DHCP=no
EOF
			clish_mtu=$(cat ${FILE_STARTUP} | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep mtu | awk '{print $2}')
			#if mtu not defined in clish, try to get it from network.json
			[ "$clish_mtu" = "" ] && clish_mtu=$(/sbin/eth_from_ip.py ${IPN} --mtu)
			if [ "x${clish_mtu}" != "x" ]
			then
				cat >> ${interface_unit_name}.network <<EOF
MTUBytes=${clish_mtu}
EOF
			fi
		fi
	fi

	systemd_dns_config ${interface_unit_name}.network
	systemd_ntp_config
}

function systemd_networkinterfaces()
{
	rm -rf ${SYSTEMD_NETWORK_DIR}
	mkdir -p ${SYSTEMD_NETWORK_DIR}

	if [ "x${IPN}" != "x" ]
	then

		index=0
		while test $index -lt ${#ETH_INTERFACES[@]};
		do
			interface_unit_name=${SYSTEMD_NETWORK_DIR}/${ETH_INTERFACES[$index]}


			cat > ${interface_unit_name}.network <<EOF
[Match]
Name=${ETH_INTERFACES[$index]}

[Network]
Bond=${BOND_INTERFACE_NAME}
DHCP=no
EOF
			index=$(expr ${index} + 1)
		done
	fi

	if [ "${VLAN_MGMT}" != "" ]
	then
		cat > ${SYSTEMD_NETWORK_DIR}/${BOND_INTERFACE_NAME}.${VLAN_MGMT}.netdev <<EOF
[NetDev]
Name=${BOND_INTERFACE_NAME}.${VLAN_MGMT}
Kind=vlan

[VLAN]
Id=${VLAN_MGMT}
EOF

		cat > ${SYSTEMD_NETWORK_DIR}/${BOND_INTERFACE_NAME}.${VLAN_MGMT}.network <<EOF
[Match]
Name=${BOND_INTERFACE_NAME}.${VLAN_MGMT}

EOF
	fi

	cat > ${SYSTEMD_NETWORK_DIR}/${BOND_INTERFACE_NAME}.netdev <<EOF
[NetDev]
Name=${BOND_INTERFACE_NAME}
Kind=bond
EOF
	clish_mtu=$(cat ${FILE_STARTUP} | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep mtu | awk '{print $2}')
	if [ "x${clish_mtu}" != "x" ]
	then
		cat >> ${SYSTEMD_NETWORK_DIR}/${BOND_INTERFACE_NAME}.netdev <<EOF
MTUBytes=${clish_mtu}
EOF
	fi

cat >> ${SYSTEMD_NETWORK_DIR}/${BOND_INTERFACE_NAME}.network <<EOF
[Match]
Name=${BOND_INTERFACE_NAME}

EOF
	if [ "${VLAN_MGMT}" != "" ]
	then
		network_interface_file=${SYSTEMD_NETWORK_DIR}/${BOND_INTERFACE_NAME}.${VLAN_MGMT}.network

		cat >> ${SYSTEMD_NETWORK_DIR}/${BOND_INTERFACE_NAME}.network <<EOF
[Network]
#start MN vlan
VLAN=${BOND_INTERFACE_NAME}.${VLAN_MGMT}
#end MN vlan
EOF

	else
		network_interface_file=${SYSTEMD_NETWORK_DIR}/${BOND_INTERFACE_NAME}.network
	fi

	cat >> ${network_interface_file} <<EOF
[Network]
Address=$(/sbin/cfg-getparams.sh localMnIpAddress)
EOF

	systemd_dns_config ${network_interface_file}
	systemd_ntp_config

	echo "#This is temporary autogenerated file for internal configurations usage, do not change or use it !!!" > ${FILE_MYIP}
	echo "MYIP=${IPN}/${MYMASK}" >> ${FILE_MYIP}
}

# main
if [ "$1" != "" ]
then
	# called from cli command with ip address
	IP=$1

	IPN=$(echo ${IP} | awk -F '/' '{print $1}')
	MASK=$(echo ${IP} | awk -F '/' '{print $2}')
	MYMASK=${MASK}

	if [ "${IPN}" == "" ] || [ "${MASK}" == "" ]
	then
		if [ "${IP}" == "" ]
		then
			echo "Error: IP/mask configuration error - aborting !"
			exit 1
		fi
	fi
	if [ "$2" != "" ]
	then
		VLAN_MGMT=$2
	else
		MGMT_VLAN=`/usr/bin/konf -- -d | grep "^vlan mgmt" | awk '{print $3}'`
		if [ "${MGMT_VLAN}" != "" ]
		then
			VLAN_MGMT=${MGMT_VLAN}
		else
			VLAN_MGMT=""
		fi
	fi
else
	IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
	MGMT_VLAN=$(/sbin/cfg-getparams.sh mmMnVlan)
	if [ "${MGMT_VLAN}" != "" ]
	then
		VLAN_MGMT=${MGMT_VLAN}
	else
		VLAN_MGMT=""
	fi

  if [ "${IP}" != "" ]
  then
		IPN=$(echo ${IP} | awk -F '/' '{print $1}')
		MASK=$(echo ${IP} | awk -F '/' '{print $2}')
		MYMASK=${MASK}
		if [ "${IPN}" == "" ] || [ "${MASK}" == "" ]
		then
				echo "Error: IP/mask configuration error"
		fi
  else
		echo "Error: No mgmt IP address configured !"
		IPN=""
  fi
fi

. /sbin/cfg-calculate-network.sh ${IP}
convert_ip_mask

if [ -e ${FILE_BONDPORTS} ]
then
	. ${FILE_BONDPORTS}
else
	# mand added - create bondports file in it does not exist
	/sbin/cfg-create-bond-ports.sh ${FILE_BONDPORTS}
	. ${FILE_BONDPORTS}
fi

if [ ${#PORTS[@]} -gt 0 ]
then
	# Create an array of ports
	ETH_INTERFACES=(${PORTS[@]})
	CHASSIS=$(/sbin/cfg-getparams.sh mmMnChassisType)

	isSystemd=`/sbin/cfg-isSystemdInit.sh`
	if [ "$isSystemd" == "NO" ]
	then
		if [ "${CHASSIS}" == "OPENSTACK" ]
		then
			etcnetworkinterfaces_ops
		else
			etcnetworkinterfaces
		fi
	else
		rm -f ${FILE_INTERFACES}
		if [ "${CHASSIS}" == "OPENSTACK" ]
		then
			systemd_networkinterfaces_ops
		else
			systemd_networkinterfaces
		fi
	fi
else
	echo "Error: no bonded ports defined in ${FILE_BONDPORTS}"
	exit 1
fi
