#!/bin/sh

CFGP=/sbin/cfg-getparams.sh 
get_intf_name ()
{
	if [ "$($CFGP mmMnChassisType)" != "OPENSTACK" ]; then 
		MGMT_INTF=bond0 
	else
		MGMT_INTF=$(/sbin/eth_from_ip.py $($CFGP localMnIpAddress --runtime | sed 's/\/.*$//'))
	fi
	echo $MGMT_INTF
}

filter_params ()
{
	# call from interface setting filter
	if [ "$1" = "INTF-IN" -o "$1" = "INTF-OUT" ]
	then
		FILTER=`konf -- -d | grep "^filter $NAME " | grep "ACCEPT\|DROP"`
	fi

	COUNT=`echo $FILTER | awk '{print NF}'`
	I=3
	while [ "$I" -le "$COUNT" ]
	do
		PARAM=`echo $FILTER | awk '{c=split($0, s); print s['$I'] }'`

		# action parameter
		if [ "$I" -eq "3" ]
		then
			if [ -n "`iptables -nL | grep 'Chain DEFAULT-IN'`" -a "$PARAM" = "ACCEPT" -a "$1" = "INTF-IN" ]
			then
				ACTION="DEFAULT-IN"
			else
				ACTION=$PARAM
			fi

		# protocol parameter
		elif [ "$PARAM" = "protocol" ]
		then
			I=$[$I + 1]
			PROTOCOL=`echo $FILTER | awk '{c=split($0, s); print s['$I'] }'`
			if [ "$PROTOCOL" != "all" ]
			then
				if [ "$PROTOCOL" = "IP" ]
				then
					PROTOCOL="-p 0"
				elif [ "$PROTOCOL" = "ICMP" ]
				then
					PROTOCOL="-p 1"
				elif [ "$PROTOCOL" = "TCP" ]
				then
					PROTOCOL="-p 6"
				elif [ "$PROTOCOL" = "UDP" ]
				then
					PROTOCOL="-p 17"
				elif [ "$PROTOCOL" = "ESP" ]
				then
					PROTOCOL="-p 50"
				elif [ "$PROTOCOL" = "AH" ]
				then
					PROTOCOL="-p 51"
				fi
			else
				PROTOCOL=
			fi

		# source port parameter
		elif [ "$PARAM" = "src-port" ]
		then
			I=$[$I + 1]
			SRCPORT=`echo $FILTER | awk '{c=split($0, s); print s['$I'] }'`

		# source IP address parameter
		elif [ "$PARAM" = "src-ip" ]
		then
			I=$[$I + 1]
			SRCIP=`echo $FILTER | awk '{c=split($0, s); print s['$I'] }'`

		# source IP mask parameter
		elif [ "$PARAM" = "src-mask" ]
		then
			I=$[$I + 1]
			SRCMASK=`echo $FILTER | awk '{c=split($0, s); print s['$I'] }'`

		# destination port parameter
		elif [ "$PARAM" = "dst-port" ]
		then
			I=$[$I + 1]
			DSTPORT=`echo $FILTER | awk '{c=split($0, s); print s['$I'] }'`

		# destination IP address parameter
		elif [ "$PARAM" = "dst-ip" ]
		then
			I=$[$I + 1]
			DSTIP=`echo $FILTER | awk '{c=split($0, s); print s['$I'] }'`

		# destination IP mask parameter
		elif [ "$PARAM" = "dst-mask" ]
		then
			I=$[$I + 1]
			DSTMASK=`echo $FILTER | awk '{c=split($0, s); print s['$I'] }'`

		# destination MAC address parameter
		elif [ "$PARAM" = "src-mac" ]
		then
			I=$[$I + 1]
			SRCMAC=`echo $FILTER | awk '{c=split($0, s); print s['$I'] }'`
			SRCMAC="-m mac --mac-source $SRCMAC"
		fi

		I=$[$I + 1]
	done

	# define port parameter
	if [ -n "$SRCPORT" -a -n "$DSTPORT" ]
	then
		PORT="--sport $SRCPORT:$SRCPORT --dport $DSTPORT:$DSTPORT"
	elif [ -n "$SRCPORT" -a -z "$DSTPORT" ]
	then
		PORT="--sport $SRCPORT:$SRCPORT"
	elif [ -z "$SRCPORT" -a -n "$DSTPORT" ]
	then
		PORT="--dport $DSTPORT:$DSTPORT"
	fi

	# check empty masks
	if [ -n "$SRCIP" -a -z "$SRCMASK" ]
	then
		SRCMASK="255.255.255.255"
	fi
	if [ -n "$DSTIP" -a -z "$DSTMASK" ]
	then
		DSTMASK="255.255.255.255"
	fi
	# define IP and mask parameter
	if [ -n "$SRCIP" -a -n "$DSTIP" ]
	then
		IPMASK="-s $SRCIP/$SRCMASK -d $DSTIP/$DSTMASK"
	elif [ -n "$SRCIP" -a -z "$DSTIP" ]
	then
		IPMASK="-s $SRCIP/$SRCMASK"
	elif [ -z "$SRCIP" -a -n "$DSTIP" ]
	then
		IPMASK="-d $DSTIP/$DSTMASK"
	fi
};

# insert interface-mgmt filter
if [ "$1" = "interface-mgmt" -a "$2" = "filter" ]
then
	# input parameters
	NAME=$3
	DIRECTION=$4
	ORDER=$5

	if [ "$DIRECTION" = "INPUT" ]
	then
		# if chain does not exist, create it
		if [  -z "`iptables -nL | grep "Chain C-IN-$NAME "`" ]
		then
			# create chain
			iptables -N C-IN-$NAME

			# find filter with rules
			filter_params INTF-IN

			# add rules to chain
			iptables -A C-IN-$NAME -i $(get_intf_name) $SRCMAC $PROTOCOL $IPMASK $PORT -j $ACTION
		fi

		# if parent chain does not exist, create it
		if [  -z "`iptables -nL | grep "Chain C-IN-MGMT "`" ]
		then
			iptables -N C-IN-MGMT

			# find number of chain and include chain into INPUT chain
			CHAINS=`iptables -nL INPUT | grep -v "Chain INPUT" | grep INPUT | awk '{print $1}'`
			NO_CHAIN=`echo $CHAINS | awk '{print NF}'`
			NO_CHAIN=$[$NO_CHAIN + 1]
			iptables -I INPUT $NO_CHAIN -j C-IN-MGMT
		fi

		# find order in mgmt chain
		ORDERS=`konf -- -d | grep " filter " | grep " INPUT " | awk '{print $4}'`
		COUNT=`echo $ORDERS | awk '{print NF}'`
		J=1
		ACC_ORDER=1
		while [ "$J" -le "$COUNT" ]
		do
			F_ORDER=`echo $ORDERS | awk '{c=split($0, s); print s['$J'] }'`
			if [ "$F_ORDER" -lt "$ORDER" ]
			then
				ACC_ORDER=$[$ACC_ORDER + 1]
			fi
			J=$[$J + 1]
		done

		# add chain into mgmt chain
		iptables -I C-IN-MGMT $ACC_ORDER -j C-IN-$NAME

	elif [ "$DIRECTION" = "OUTPUT" ]
	then
		# if chain does not exist, create it
		if [  -z "`iptables -nL | grep "Chain C-OUT-$NAME "`" ]
		then
			# create chain
			iptables -N C-OUT-$NAME

			# find filter with rules
			filter_params INTF-OUT

			# add rules to chain
			iptables -A C-OUT-$NAME -o $(get_intf_name) $SRCMAC $PROTOCOL $IPMASK $PORT -j $ACTION
		fi

		# if parent chain does not exist, create it
		if [  -z "`iptables -nL | grep "Chain C-OUT-MGMT "`" ]
		then
			iptables -N C-OUT-MGMT

			# find number of chain and include chain into OUTPUT chain
			CHAINS=`iptables -nL OUTPUT | grep -v "Chain OUTPUT" | grep OUTPUT | awk '{print $1}'`
			NO_CHAIN=`echo $CHAINS | awk '{print NF}'`
			NO_CHAIN=$[$NO_CHAIN + 1]
			iptables -I OUTPUT $NO_CHAIN -j C-OUT-MGMT
		fi

		# find order in mgmt chain
		ORDERS=`konf -- -d | grep " filter " | grep " OUTPUT " | awk '{print $4}'`
		COUNT=`echo $ORDERS | awk '{print NF}'`
		J=1
		ACC_ORDER=1
		while [ "$J" -le "$COUNT" ]
		do
			F_ORDER=`echo $ORDERS | awk '{c=split($0, s); print s['$J'] }'`
			if [ "$F_ORDER" -lt "$ORDER" ]
			then
				ACC_ORDER=$[$ACC_ORDER + 1]
			fi
			J=$[$J + 1]
		done

		# add chain into mgmt chain
		iptables -I C-OUT-MGMT $ACC_ORDER -j C-OUT-$NAME
	fi

# end insert interface-mgmt filter

# delete interface-mgmt filter
elif [ "$1" = "interface-mgmt" -a "$2" = "no" -a "$3" = "filter" ]
then
	# input parameters
	NAME=$4
	DIRECTION=$5

	if [ "$DIRECTION" = "INPUT" ]
	then
		# remove chain from mgmt chain
		iptables -D C-IN-MGMT -j C-IN-$NAME

		# remove chain
		iptables -F C-IN-$NAME
		iptables -X C-IN-$NAME

		# if C-IN-MGMT is empty
		if [ -z "`iptables -nL C-IN-MGMT | grep -v "Chain C-IN-MGMT " | grep "C-IN-"`" ]
		then
			# remove mgmt chain from INPUT chain
			iptables -D INPUT -j C-IN-MGMT

			# remove chain C-IN-MGMT
			iptables -F C-IN-MGMT
			iptables -X C-IN-MGMT
		fi

	elif [ "$DIRECTION" = "OUTPUT" ]
	then
		# remove chain from mgmt chain
		iptables -D C-OUT-MGMT -j C-OUT-$NAME

		# remove chain
		iptables -F C-OUT-$NAME
		iptables -X C-OUT-$NAME

		# if C-OUT-MGMT is empty
		if [ -z "`iptables -nL C-OUT-MGMT | grep -v "Chain C-OUT-MGMT " | grep "C-OUT-"`" ]
		then
			# remove mgmt chain from OUTPUT chain
			iptables -D OUTPUT -j C-OUT-MGMT

			# remove chain C-OUT-MGMT
			iptables -F C-OUT-MGMT
			iptables -X C-OUT-MGMT
		fi

	fi

# end delete interface-mgmt filter

# replace filter
elif [ "$1" = "replace" -a "$2" = "filter" ]
then
	# input parameters
	NAME=$3

	# input chain
	if [ -n "`iptables -nL | grep "Chain C-IN-$NAME "`" ]
	then
		FILTER=`echo $2 $3 $4 $5 $6 $7 $8 $9 ${10} ${11} ${12} ${13} ${14} ${15} ${16} ${17} ${18} ${19} ${20}`
		filter_params REPLACE
		iptables -F C-IN-$NAME
		iptables -A C-IN-$NAME -i $(get_intf_name) $SRCMAC $PROTOCOL $IPMASK $PORT -j $ACTION
	fi

	# output chain
	if [ -n "`iptables -nL | grep "Chain C-OUT-$NAME "`" ]
	then
		FILTER=`echo $2 $3 $4 $5 $6 $7 $8 $9 ${10} ${11} ${12} ${13} ${14} ${15} ${16} ${17} ${18} ${19} ${20}`
		filter_params REPLACE
		iptables -F C-OUT-$NAME
		iptables -A C-OUT-$NAME -o $(get_intf_name) $SRCMAC $PROTOCOL $IPMASK $PORT -j $ACTION
	fi

# end replace filter

fi

exit 0

