#!/bin/sh

FILE=/etc/network/interfaces

SYSTEMD_DIR=/etc/systemd
FILE_NETWORK_DIR=${SYSTEMD_DIR}/network

INTERFACE_NAME=bond0
FILE_INTERFACE_NAME=${INTERFACE_NAME}.network

CHASSIS=$(/sbin/cfg-getparams.sh mmMnChassisType)

dot2cidr ()
{
	case $1 in
			128.0.0.0) echo 1;; 192.0.0.0) echo 2;; 224.0.0.0) echo 3;; 240.0.0.0) echo 4;;
			248.0.0.0) echo 5;; 252.0.0.0) echo 6;; 254.0.0.0) echo 7;; 255.0.0.0) echo 8;;
			255.128.0.0) echo 9;; 255.192.0.0) echo 10;; 255.224.0.0) echo 11;; 255.240.0.0) echo 12;;
			255.248.0.0) echo 13;; 255.252.0.0) echo 14;; 255.254.0.0) echo 15;; 255.255.0.0) echo 16;;
			255.255.128.0) echo 17;; 255.255.192.0) echo 18;; 255.255.224.0) echo 19;; 255.255.240.0) echo 20;;
			255.255.248.0) echo 21;; 255.255.252.0) echo 22;; 255.255.254.0) echo 23;; 255.255.255.0) echo 24;;
			255.255.255.128) echo 25;; 255.255.255.192) echo 26;; 255.255.255.224) echo 27;; 255.255.255.240) echo 28;;
			255.255.255.248) echo 29;; 255.255.255.252) echo 30;; 255.255.255.254) echo 31;; 255.255.255.255) echo 32;;
		*) echo 24;;
	esac
}

if [ "$1" != "" ] && [ "$2" != "" ] && [ "$3" != "" ]
then
	GATEWAY_NETWORK=$1
	GATEWAY_MASK=$2
	GATEWAY=$3
else
	GATEWAY_NETWORK=$(/sbin/cfg-getparams.sh mmMnGatewayNet)
	GATEWAY_MASK=$(/sbin/cfg-getparams.sh mmMnGatewaySubnetMask)
	GATEWAY=$(/sbin/cfg-getparams.sh mmMnGateway)
fi

#debug print
#echo ${GATEWAY_NETWORK}
#echo ${GATEWAY_MASK}
#echo ${GATEWAY}

# check if ip route present in file
isSystemd=`/sbin/cfg-isSystemdInit.sh`
if [ "${isSystemd}" == "NO" ]
then
	OLD_IP_ROUTE=`cat ${FILE} | grep "up route add -net"`
else
	MGMT_VLAN=$(/sbin/cfg-getparams.sh mmMnVlan)
	if [ "${CHASSIS}" == "OPENSTACK" ]
	then
		# get mgmt interface name based on mgmt IP address
		IP=$(/sbin/cfg-getparams.sh localMnIpAddress)
		IPN=$(echo ${IP} | awk -F '/' '{print $1}')
		MGMT_INTF=`/sbin/eth_from_ip.py ${IPN}`
		#MGMT_INTF=eth1
		if [ "x${MGMT_VLAN}" != "x" ]
		then
			systemd_interface_file=${FILE_NETWORK_DIR}/${MGMT_INTF}.${MGMT_VLAN}.network
		else
			systemd_interface_file=${FILE_NETWORK_DIR}/${MGMT_INTF}.network
		fi
	else
		if [ "x${MGMT_VLAN}" != "x" ]
		then
			systemd_interface_file=${FILE_NETWORK_DIR}/${INTERFACE_NAME}.${MGMT_VLAN}.network
		else
			systemd_interface_file=${FILE_NETWORK_DIR}/${FILE_INTERFACE_NAME}
		fi
	fi

	OLD_IP_ROUTE=`grep 'Gateway' ${systemd_interface_file} | cut -d "=" -f2`
fi

if [ "${OLD_IP_ROUTE}" != "" ]
then
	# check if route already written
	if [ "${isSystemd}" == "NO" ]
	then
		CHK_DEFAULT_GW=`cat ${FILE} | grep "up route add -net ${GATEWAY_NETWORK} netmask ${GATEWAY_MASK} gw ${GATEWAY}"`
	else
		sed -i -e "s/Gateway=$OLD_IP_ROUTE/Gateway=$GATEWAY/g" ${systemd_interface_file}
		if [ "x${GATEWAY_NETWORK}" == "x0.0.0.0" ]
		then
			mask=0
		else
			mask=`dot2cidr ${GATEWAY_MASK}`
		fi
		sed -i "/Destination/d" ${systemd_interface_file}
		cat >> ${systemd_interface_file} <<EOF
Destination=${GATEWAY_NETWORK}/${mask}
EOF
			
	fi

	if [ "${CHK_DEFAULT_GW}" == "" ]
	then
		# first read old route
		#old_route=`cat ${FILE} |grep "up route add -net"`
		#echo "old route "${OLD_IP_ROUTE}

		# Create temporary file with new line in place
		if [ "${isSystemd}" == "NO" ]
		then
			cat ${FILE} | sed -e "s/${OLD_IP_ROUTE}/up route add -net ${GATEWAY_NETWORK} netmask ${GATEWAY_MASK} gw ${GATEWAY}/" > /tmp/intf

			#Copy the new file over the original file
			cp /tmp/intf ${FILE}

			# delete tmp file
			rm /tmp/intf
		fi
	fi
else
	# add route
	if [ "${GATEWAY_NETWORK}" != "" ] && [ "${GATEWAY_MASK}" != "" ] && [ "${GATEWAY}" != "" ]
	then 
		if [ "${isSystemd}" == "NO" ]
		then
			cat >> ${FILE} <<EOF

up route add -net ${GATEWAY_NETWORK} netmask ${GATEWAY_MASK} gw ${GATEWAY}

EOF
		else
			if [ "x${GATEWAY}" != "x" ]
			then
				if [ "x${GATEWAY_NETWORK}" == "x0.0.0.0" ]
				then
					cat >> ${systemd_interface_file} <<EOF

[Route]
Destination=${GATEWAY_NETWORK}/0
Gateway=${GATEWAY}

EOF
				else
					mask=`dot2cidr ${GATEWAY_MASK}`
					cat >> ${systemd_interface_file} <<EOF

[Route]
Destination=${GATEWAY_NETWORK}/${mask}
Gateway=${GATEWAY}

EOF
				fi
			fi
		fi
			
	fi
fi

if [ "$1" == "" ]
then
	# called after reboot - if openstack chassis add host route to openstack 169.254.169.254 ip address
	if [ "${CHASSIS}" == "OPENSTACK" ]
	then
		# check if route to meta srv exists
		meta_srv_addr=169.254.169.254
		route_to_meta_srv=`ip route | grep ${meta_srv_addr}`
		if [ "${route_to_meta_srv}" == "" ]
		then
			# route to meta srv does not exist
			# get current def gw and set route to meta srv - should point to orch gw ip address
			orch_gw=`ip route | grep default | cut -d ' ' -f3 | sort -u`
			isSystemd=`/sbin/cfg-isSystemdInit.sh`
			if [ "x${orch_gw}" != "x" ]
			then
				if [ "${isSystemd}" == "NO" ]
				then
					cat >> ${FILE} <<EOF

up route add -host ${meta_srv_addr} gw ${orch_gw}

EOF
				else
					# add route to meta srv directly on system - problems with networkd service"
					route add -host $meta_srv_addr gw $orch_gw

#					cat >> ${FILE_NETWORK_DIR}/eth0.network <<EOF
#
#[Route]
#Destination=${meta_srv_addr}/32
#Gateway=${orch_gw}
#
#EOF
				fi
			fi
		fi
	fi
	#
	# add additional routes to network/interfaces file
	#
	while read line; do 
		[ "$line" = "" ] && continue
		if [ "$(/sbin/cfg-isSystemdInit.sh)" == "NO" ]; then 
			#use command ip to distiguish between mgmt and additional routes 
			#otherwise del/add mgmt route could delete or change additional routes
			#which is not ok...
			PREFIX=$(dot2cidr $(echo $line|awk '{print $5}'))
			NET=$(echo $line|awk '{print $4}')
			GW=$(echo $line|awk '{print $6}')
			echo "up ip route add $NET/$PREFIX via $GW" >> $FILE
		else
			echo "systemd not supported yet"
		fi
	done <<< "$(grep "ip route add" /etc/startup-config 2>/dev/null)"
fi
