#!/bin/bash
# BEGIN Modify startup-config in case of migration from old clish to itKlish

FILE=/etc/startup-config
INTF_XML_FILE=/etc/clish/enable/interface.xml
CONFIG_XML_FILE=/etc/clish/enable/configure-mode*.xml

if [ -f ${FILE} ]
then

# delete S_NODE in startup-config
sed -e '/S_NODE/d' ${FILE} > ${FILE}.tmp
mv ${FILE}.tmp ${FILE}

MYIPFILE=/etc/sysconfig/myip
test -f ${MYIPFILE} && . ${MYIPFILE}
IP=`cat ${FILE} | awk '/interface /{p=1} /!/{p=0} p' | grep 'ip address' |  grep -vw 'ip address internal' |  grep -vw 'ip address float' | awk '{print $3}'`

# if IP is empty, check if we have old command in start-up conf
if [ "${IP}" == "" ]
then
        IP=`cat ${FILE} | awk '/interface /{p=1} /!/{p=0} p' | grep ' network params' |awk '{print $3}'`
fi

INT1_IP=`cat ${FILE} | awk '/hsb yes/{p=1} /!/{p=0} p' | grep ' network params int' |  grep -vw '  network params int' |  grep -vw 'network params intfloat' |awk '{print $4}'`
INT2_IP=`cat ${FILE} | awk '/hsb yes/{p=1} /!/{p=0} p' | grep '  network params int' |awk '{print $4}'`

if [ "${MYIP}" == "${IP}" ]
then
NODEID="1"
else
NODEID="2"
fi

# Modify startup config if command interface bond has changed to interface mgmt
INTF=`cat ${INTF_XML_FILE} |grep 'interface mgmt'`
INTFNEW=`cat ${CONFIG_XML_FILE} |grep 'interface mgmt'`
if [ "${INTF}" != "" ] || [ "${INTFNEW}" != "" ] 
then
BOND0=`cat ${FILE} |grep -n 'interface bond' |cut -f1 -d":"`
	if [ "${BOND0}" != "" ]
	then
	sed -i -e "`expr ${BOND0}`s/.*/interface mgmt/g" /${FILE}
	sed -i -e "`expr ${BOND0} + 1 `s/network params/ip address/g" /${FILE}
	ROUTEIP=`cat ${FILE} |grep ' route' | awk '{print $2}'`
	ROUTENET=`cat ${FILE} |grep ' route' | awk '{print $3}'`
	ROUTEMASK=`cat ${FILE} |grep ' route' | awk '{print $4}'`
	sed -i -e "/ route/d" /${FILE}
cat >> ${FILE} <<EOF
!
ip route mgmt ${ROUTENET} ${ROUTEMASK} ${ROUTEIP}
EOF
	fi
fi

# Insert new parameter system unit-id and node-id in startup config if does not exsist already
SYSUNIT=`cat ${FILE} |grep 'system unit-id'`
if [ "${SYSUNIT}" == "" ]
then
sed -i "1i system unit-id 1 node-id ${NODEID}" ${FILE}
sed -i '1i !' ${FILE}
fi

# Chech if system is HSB
REDTYPE=`cat ${FILE} | grep 'hsb yes'`
if [ "${REDTYPE}" == "" ]
then
HSB="no"
else
HSB="yes"
fi

# add system type if it does not exists in conf file
system_type_exists=`cat ${FILE} |grep 'system type'`
if [ "${system_type_exists}" == "" ]
then
	if [ "${HSB}" == "yes" ]
	then
		# Insert new parameter system type
		sed -i "1i system type duplicated" ${FILE}
		sed -i '1i !' ${FILE}
	else
		# Insert new parameter system type
		sed -i "1i system type standalone" ${FILE}
		sed -i '1i !' ${FILE}
	fi
fi

# Replace hsb yes with hsb and insert line enable after hsb
if [ "${HSB}" == "yes" ]
then
sed -i -e "s/hsb yes/hsb/g" /${FILE}
sed -i '/hsb/a \
 enable' ${FILE}
fi

if [ "${NODEID}" == "1" ] && [ "${HSB}" == "yes" ]
then

# Replace old network params with new ip address if NODEID=1
# ????? sed -i -e "s/ip address mgmt/ip address/g" /${FILE}

sed -i -e "s/ network params float/ ip address mgmt float/g" /${FILE}

sed -i -e "s/ network params int/ ip address internal/g" /${FILE}
sed -i -e "s/  network params int/  ip address internal/g" /${FILE}

sed -i -e "s/  network params/  ip address mgmt/g" /${FILE}
fi

if [ "${NODEID}" == "2" ] && [ "${HSB}" == "yes" ]
then

# Replace old network params with new ip address if NODEID=2

IPOLDHSB_TMP=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'network params' |  grep -vw 'network params int' |  grep -vw 'network params float' | grep -vw 'network params intfloat' | awk '{print $3}'`
IPOLDHSB=`echo ${IPOLDHSB_TMP} | sed 's/\/.*//'`
IP_TMP=`cat ${FILE} | awk '/interface /{p=1} /!/{p=0} p' | grep 'ip address' |  grep -vw 'ip address internal' |  grep -vw 'ip address float' | awk '{print $3}'`
IP=`echo ${IP_TMP} | sed 's/\/.*//'`
sed -i -e "s/ network params float/ ip address mgmt float/g" ${FILE}

# Replace MN1IP with MN2IP and vice versa and add mgmt in new startup-config if NODEID=2

sed -i -e "s/  network params ${IPOLDHSB}/  ip address mgmt ${IP}/g" ${FILE}
sed -i -e "s/ ip address ${IP}/ ip address ${IPOLDHSB}/g" ${FILE}

# Replace hostnames 1 into 2 and 2 into 1 if NODEID=2
HOSTNAME1=`cat ${FILE} | awk '/hostname/{p=1} /!/{p=0} p' |  grep hostname |grep -v 'hostnameredundant'|  head -n 1 | awk '{print $2}'`
HOSTNAME2=`cat ${FILE} | awk '/hsb/{p=1} /!/{p=0} p' | grep 'hostname' | awk '{print $2}'`

sed -i -e "s/hostname ${HOSTNAME1}/hostname ${HOSTNAME2}/g" ${FILE}
sed -i -e "s/ hostname ${HOSTNAME2}/ hostname ${HOSTNAME1}/g" ${FILE}

fi

# Modify chassis type and size from two commands into one
CHTYPE=`cat ${FILE} |grep -n 'chassis type' | awk '{print $3}'|tr '[:lower:]' '[:upper:]'`
CHSIZE=`cat ${FILE} |grep -n 'chassis size' | awk '{print $3}'`

if [ "${CHTYPE}" != "" ] && [ "${CHSIZE}" != "" ]
then
sed -i -e "s/chassis.*/chassis type ${CHTYPE} size ${CHSIZE}/g" /${FILE}
sed -i -e '$!N; /^\(.*\)\n\1$/!P; D' /${FILE}
NRLNS=`cat ${FILE}|grep -n chassis| wc -l`
	if [ "${NRLNS}" -gt "1" ]
	then
	LNBR=`cat ${FILE} |grep -n chassis |tail -1 |cut -f1 -d":"`
	sed -i -e "${LNBR}d" ${FILE}
	sed -i -e "${LNBR}d" ${FILE}
	fi
fi

# Change INT IP's if exsist in startup-config forom 1 to 2 and vice versa
INT1_IP_NOMASK=`echo ${INT1_IP} | sed 's/\/.*//'`
INT2_IP_NOMASK=`echo ${INT2_IP} | sed 's/\/.*//'`

sed -i -e "s/ network params int ${INT1_IP_NOMASK}/ ip address internal ${INT2_IP_NOMASK}/g" ${FILE}
sed -i -e "s/  network params int ${INT2_IP_NOMASK}/  ip address internal ${INT1_IP_NOMASK}/g" ${FILE}

if [ ! -f /etc/sysconfig/bonding.static ]
then
# Change Internal vlan from vlan to vlan internal
  INTERNAL=`cat ${FILE} | grep ' vlan internal'`
  if [ "${INTERNAL}" == "" ]
  then
	sed -i -e "s/ vlan/ vlan internal/g" ${FILE} 
  fi
fi

# Modify startup config if command vlan changed to vlan mgmt
VLANM=`cat ${CONFIG_XML_FILE} |grep 'vlan mgmt'` 
if [ "${VLANM}" != "" ]
then
VLANOLD=`cat ${FILE} |grep -w 'vlan .* tagged' | awk '{print $2}'`
	if [ "${VLANOLD}" != "" ]
	then
	sed -i -e "/^ vlan /! s/vlan .* tagged/vlan mgmt ${VLANOLD}/g" /${FILE}
	fi
fi

# system name - if missing, create it(use hostname)
SYSNAME=`cat ${FILE} |grep 'system name'`
if [ "${SYSNAME}" == "" ]
then
        hostName=`cat ${FILE} | grep hostname |grep -v ' hostname'| awk '{print $2}'`
	type=`cat ${FILE} |grep 'system type' | awk '{print $3}'`
	if [ "$hostName" != "" ] && [ "$type" != "" ]
	then
        	sed -i "3i system name ${hostName}-${type}" ${FILE}
 	        sed -i '3i !' ${FILE}
	fi
fi

# product type - if missing, create it(use /etc/sysconfig/info-product)
product_type=`cat ${FILE} |grep 'product'`
if [ "${product_type}" == "" ]
then
	prod=`cat /etc/sysconfig/info-product |grep 'PRODUCT_FAMILY' | cut -d '=' -f2`
	if [ "${prod}" == "CG" ]
	then
		sed -i "5i product Border_Gateway" ${FILE}
	        sed -i '5i !' ${FILE}
	elif [ "${prod}" == "CS" ]
	then
		sed -i "5i product Call_Server" ${FILE}
	        sed -i '5i !' ${FILE}
	elif [ "${prod}" == "CE" ]
	then
 	       sed -i "5i product Compact_Call_Server" ${FILE}
 	       sed -i '5i !' ${FILE}
	elif [ "${prod}" == "LI" ]
	then
	        sed -i "5i product Lawfull_Interception" ${FILE}
	        sed -i '5i !' ${FILE}
	elif [ "${prod}" == "MS" ]
	then
	        sed -i "5i product Media_Server" ${FILE}
	        sed -i '5i !' ${FILE}
	fi
fi

# Modify config server from three commands into one
CONFURL=`cat ${FILE} |grep -n 'config server url' | awk '{print $4}'`
CONFUSER=`cat ${FILE} |grep -n 'config server user' | awk '{print $4}'`
CONFPASS=`cat ${FILE} |grep -n 'config server pass' | awk '{print $4}'`

if [ "${CONFURL}" != "" ] && [ "${CONFUSER}" != "" ] && [ "${CONFPASS}" != "" ]
then
	sed -i "/config server user ${CONFUSER}/,+1 d" ${FILE}
	sed -i "/config server pass ${CONFPASS}/,+1 d" ${FILE}
	D=$'\e' #The sed delimiter will be the ascii escape character
	sed -i -e "s${D}config server url ${CONFURL}${D}config-server ${CONFURL} ${CONFUSER} ${CONFPASS}${D}g" ${FILE}
fi

# on cmj board add vlan 2005 if not added
cmjCheck=/etc/clish/enable/configure-mode-cmj.xml
if [ -f "$cmjCheck" ]
then
	VLAN2005CHECK=`cat ${FILE} |grep 'vlan add 2005'`
	if [ "${VLAN2005CHECK}" == "" ]
	then
		sed -i '1i vlan add 2005' ${FILE}
		sed -i '1i !' ${FILE}
	fi
fi

# on cmj board add internet connectivity and ntp server location command
if [ -f "$cmjCheck" ]
then
	IC=`cat ${FILE} |grep 'internet-connection'`
	if [ "${IC}" == "" ]
	then
		sed -i -e '$a !' ${FILE}
		sed -i -e '$a internet-connection available' ${FILE}
	fi
	NTL=`cat ${FILE} |grep 'ntp-server-location'`
	if [ "${IC}" == "" ]
	then
		sed -i -e '$a !' ${FILE}
		sed -i -e '$a ntp-server-location remote' ${FILE}
	fi
fi
# END Modify startup-config in case of migration from old clish to itKlish

fi

