#!/bin/sh
NTPCONF=/etc/ntp.conf
NTPCONF_SRV=${NTPCONF}.srv
NTPCONF_CLNT=${NTPCONF}.clnt
NTP_SRV=$(which ntpd 2>/dev/null)
NTPDATE=/etc/default/ntpdate

CHRONYCONF=/etc/chrony.conf
CHRONY_SRV=$(which chronyd 2>/dev/null)

SERVICE_HARDENING_SCRIPT=/opt/iskratel/sbin/service-hardening

# check if new ntp server is used
if [ "x${NTP_SRV}" != "x" ]
then
	test -f ${NTPCONF} && cp -f ${NTPCONF} ${NTPCONF}.orig
fi

if [ "x${CHRONY_SRV}" != "x" ]
then
	test -f ${CHRONYCONF} && cp -f ${CHRONYCONF} ${CHRONYCONF}.orig
fi

if [ -f /etc/sysconfig/bonding.static ] && [ -f /etc/sysconfig/node.cfg ]
then
	if [ "$1" == "" ]
	then
		# after reboot
		net_avail=$(/sbin/cfg-getparams.sh internetConnection)
		ntp_loc=$(/sbin/cfg-getparams.sh ntpServerLocation)
	else
		# runtime change
		net_avail=$(/sbin/cfg-getparams.sh internetConnection --runtime)
		ntp_loc=$(/sbin/cfg-getparams.sh ntpServerLocation --runtime)
	fi
else
	net_avail="available"
	ntp_loc="remote"
fi

if [ "${net_avail}" == "available" ] && [ "${ntp_loc}" == "remote" ]
then

	if [ "$2" != "delete" ]
	then
		if [ "$1" != "" ]
		then
			NTPSERVER1=`konf -- -d | grep 'ntp-server primary' | awk '{print $3}'` 
			NTPSERVER2=`konf -- -d | grep 'ntp-server secondary' | awk '{print $3}'` 
			NTPSERVER3=`konf -- -d | grep 'ntp-server tertiary' | awk '{print $3}'` 
		fi
		
		if [ "$1" == "primary" ] 
		then
			NTPSERVER1=$2
		fi
		if [ "$1" == "secondary" ] 
		then
			NTPSERVER2=$2
		fi
		if [ "$1" == "tertiary" ] 
		then
			NTPSERVER3=$2
		fi
		
		if [ "x${NTP_SRV}" != "x" ]
		then
			test -f ${NTPCONF} || touch ${NTPCONF}
		fi

		if [ "x${CHRONY_SRV}" != "x" ]
		then
			test -f ${CHRONYCONF} || touch ${CHRONYCONF}
		fi

		# script is calles within configure-system-clish
		if [ "$1" == "" ]
		then
			NTPSERVER1=$(/sbin/cfg-getparams.sh mmNtpServer1)
			NTPSERVER2=$(/sbin/cfg-getparams.sh mmNtpServer2)
			NTPSERVER3=$(/sbin/cfg-getparams.sh mmNtpServer3)
		fi
		PRODUCT=$(cfg-getparams.sh product)
		if [ "$PRODUCT" == "Media_Server" ]
		then
			NTPSERVER1S="server ${NTPSERVER1} iburst"
			NTPSERVER2S="server ${NTPSERVER2} iburst"
			NTPSERVER3S="server ${NTPSERVER3} iburst"
		else
			NTPSERVER1S="server ${NTPSERVER1}"
			NTPSERVER2S="server ${NTPSERVER2}"
			NTPSERVER3S="server ${NTPSERVER3}"
		fi
		
		if [ "${NTPSERVER1}" == "" ]
		then
			NTPSERVER1S=""
		fi 
		if [ "${NTPSERVER2}" == "" ]
		then
			NTPSERVER2S=""
		fi
		if [ "${NTPSERVER3}" == "" ]
		then
			NTPSERVER3S=""
		fi
		
		NTPSERVER1T="TIMESERVER=${NTPSERVER1}"
		NTPSERVER2T="TIMESERVER=${NTPSERVER2}"
		NTPSERVER3T="TIMESERVER=${NTPSERVER3}"
		
		if [ "${NTPSERVER1}" == "" ]
		then
			NTPSERVER1T=""
		fi 
		if [ "${NTPSERVER2}" == "" ]
		then
			NTPSERVER2T=""
		fi
		if [ "${NTPSERVER3}" == "" ]
		then
			NTPSERVER3T=""
		fi
		
		mkdir -p /etc/ntp
		if [ "x${NTP_SRV}" != "x" ]
		then
			cat > ${NTPCONF} << EOF
driftfile /etc/ntp/ntp.drift
${NTPSERVER1S}
${NTPSERVER2S}
${NTPSERVER3S}
EOF
		#patch ntp.conf file so ntp will not listen on VOIP, RTP, LI, ... interfaces
		[ -x $SERVICE_HARDENING_SCRIPT ] && $SERVICE_HARDENING_SCRIPT patch-ntp $NTPCONF 
		fi

		if [ "x${CHRONY_SRV}" != "x" ]
		then
			if [ "${NTPSERVER1S}" != "" ]
			then
				NTPSERVER1S="${NTPSERVER1S} iburst"
			fi
			if [ "${NTPSERVER2S}" != "" ]
			then
				NTPSERVER2S="${NTPSERVER2S} iburst"
			fi
			if [ "${NTPSERVER3S}" != "" ]
			then
				NTPSERVER3S="${NTPSERVER3S} iburst"
			fi

			CHASSIS=$(/sbin/cfg-getparams.sh mmMnChassisType)
			if [ "$CHASSIS" == "VIRTUAL" ] || [ "$CHASSIS" == "OPENSTACK" ]
			then
				USN=-1
			else
				USN=3
			fi

			cat > ${CHRONYCONF} << EOF
# This file was automatically generated from $0
# some usefull commands for chrony are:
# chronyc tracking		:The tracking command displays parameters about the system.s clock performance
# chronyc sources [-v]		:This command displays information about the current time sources
# chronyc sourcestats [-v]	:Command displays information about the drift rate and offset  for each of the sources
# chronyc activity		:Check how many NTP sources are online/offline
# chronyc makestep		:Correct clock by stepping immediately
# timedatectl			:Usefull tool for tracking time


${NTPSERVER1S}
${NTPSERVER2S}
${NTPSERVER3S}

# In first three updates step the system clock instead of slew
# if the adjustment is larger than 1 second.
# makestep 1 3  :for computer with RTC
# makestep 1 -1 :for computer without an RTC or virtual machine
makestep 1 ${USN}


# Record the rate at which the system clock gains/loses time,
# improving accuracy after reboot
driftfile /var/lib/chrony/drift

# Enable kernel synchronization of the hardware real-time clock (RTC).
rtcsync

# Specify directory for log files.
logdir /var/log/chrony

#IskraTEL added
# store a measurement history
dumpdir /var/run/chrony_meas

EOF
		#chrony does not listen on port 123 by default, so patching is not neccessery 
		#[ -x $SERVICE_HARDENING_SCRIPT ] && $SERVICE_HARDENING_SCRIPT patch-ntp $CHRONYCONF
		fi

		cat > ${NTPDATE} << EOF
${NTPSERVER1T}
${NTPSERVER2T}
${NTPSERVER3T}
EOF
	else
	# if delete argument 
		if [ "$1" == "primary" ]
		then
			if [ "x${NTP_SRV}" != "x" ]
			then
				sed -i '2s/.*/ /' ${NTPCONF}
			fi

			if [ "x${CHRONY_SRV}" != "x" ]
			then
				sed -i '2s/.*/ /' ${CHRONYCONF}
				NTPSERVER1S=""
			fi
			sed -i '1s/.*/ /' ${NTPDATE}
		fi
		if [ "$1" == "secondary" ]
		then
			if [ "x${NTP_SRV}" != "x" ]
			then
				sed -i '3s/.*/ /' ${NTPCONF}
			fi

			if [ "x${CHRONY_SRV}" != "x" ]
			then
				sed -i '3s/.*/ /' ${CHRONYCONF}
				NTPSERVER2S=""
			fi
			sed -i '2s/.*/ /' ${NTPDATE}
		fi
		if [ "$1" == "tertiary" ]
		then
			if [ "x${NTP_SRV}" != "x" ]
			then
				sed -i '4s/.*/ /' ${NTPCONF}
			fi

			if [ "x${CHRONY_SRV}" != "x" ]
			then
				sed -i '4s/.*/ /' ${CHRONYCONF}
				NTPSERVER3S=""
			fi
			sed -i '3s/.*/ /' ${NTPDATE}
		fi

		NTPSERVER1=$(sed -n '1p' ${NTPDATE} | cut -c 12-)
		NTPSERVER2=$(sed -n '2p' ${NTPDATE} | cut -c 12-)
		NTPSERVER3=$(sed -n '3p' ${NTPDATE} | cut -c 12-)

		if [ "$NTPSERVER1" != "" ]
		then
			NTPSERVER1S="server ${NTPSERVER1} iburst"
		else
			NTPSERVER1S=""
		fi
		if [ "$NTPSERVER2" != "" ]
		then
			NTPSERVER2S="server ${NTPSERVER2} iburst"
		else
			NTPSERVER2S=""
		fi
		if [ "$NTPSERVER3" != "" ]
		then
			NTPSERVER3S="server ${NTPSERVER3} iburst"
		else
			NTPSERVER3S=""
		fi

                CHASSIS=$(/sbin/cfg-getparams.sh mmMnChassisType)
                if [ "$CHASSIS" == "VIRTUAL" ] || [ "$CHASSIS" == "OPENSTACK" ]
                then
                        USN=-1
                else
                        USN=3
                fi

                cat > ${CHRONYCONF} << EOF
# This file was automatically generated from $0
# some usefull commands for chrony are:
# chronyc tracking              :The tracking command displays parameters about the system.s clock performance
# chronyc sources [-v]          :This command displays information about the current time sources
# chronyc sourcestats [-v]      :Command displays information about the drift rate and offset  for each of the sources
# chronyc activity              :Check how many NTP sources are online/offline
# chronyc makestep              :Correct clock by stepping immediately
# timedatectl                   :Usefull tool for tracking time


${NTPSERVER1S}
${NTPSERVER2S}
${NTPSERVER3S} 

# In first three updates step the system clock instead of slew
# if the adjustment is larger than 1 second.
# makestep 1 3  :for computer with RTC
# makestep 1 -1 :for computer without an RTC or virtual machine
makestep 1 ${USN}


# Record the rate at which the system clock gains/loses time,
# improving accuracy after reboot
driftfile /var/lib/chrony/drift

# Enable kernel synchronization of the hardware real-time clock (RTC).
rtcsync

# Specify directory for log files.
logdir /var/log/chrony

#IskraTEL added
# store a measurement history
dumpdir /var/run/chrony_meas

EOF

	fi
else
	# read mgmt hsb float IP
	if [ "$1" == "" ]
	then
		# after reboot
		IP=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress)
	else
		# runtime
		IP=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress --runtime)
	fi

	if [ "$IP" != "" ]
	then
		float_ip=`echo "$IP" | cut -d '/' -f1`
	else
		float_ip=""
	fi

	hsb_act=`/opt/iskratel/bin/it_heartbeatmenu --state | grep LOCAL | grep ACTIVE`
	if [ "$hsb_act" != "" ]
	then
		# state ACT
		cp ${NTPCONF_SRV} ${NTPCONF}
  else
		# state STB
		# add local hsb float IP address for ntp server
		cp ${NTPCONF_CLNT} ${NTPCONF}

		if [ "$float_ip" != "" ]
		then
			cat >> ${NTPCONF} << EOF
server ${float_ip}
EOF

		fi
	fi

	cat > ${NTPDATE} << EOF

EOF

fi

# restart ntpd only if runtime change
if [ "$1" != "" ]
then
	if ! cmp ${NTPCONF} ${NTPCONF}.orig >/dev/null 2>&1
	then
		if [ -f /etc/init.d/it_ntp ]
		then
			echo "restarting ntp"
			/etc/init.d/it_ntp restart
		fi
	fi

	if ! cmp ${CHRONYCONF} ${CHRONYCONF}.orig >/dev/null 2>&1
	then
		if type systemctl >/dev/null 2>/dev/null
		then
			systemctl restart chronyd.service
		else
			if [ -f /etc/init.d/chronyd ]
			then
				/etc/init.d/chronyd restart
			fi
		fi
	fi
fi

# set timezone only after reboot
if [ "$1" == "" ]
then
	# generate link for ZONE
	TIME_ZONE=$(/sbin/cfg-getparams.sh mmSystemConfigTimezone)
	if [ "${TIME_ZONE}" != "" ]
	then
		rm -f /etc/localtime
		ln -sf /usr/share/zoneinfo/$TIME_ZONE /etc/localtime
	fi
fi
