#!/bin/bash
# Change file rc.soc, make changes on BCM, make changes in itmlinec.conf.
# Usage: sbin/cfg-port-enable.sh 
#                   <port_number | interface_number> [enable|noshutdown|disable|shutdown|showPort|showPortAll|autoNeg|speedDuplex]
# Example: /sbin/cfg-port-enable.sh 0/1 disable
# Example 1: /sbin/cfg-port-enable.sh 1 disable
# Example 2: /sbin/cfg-port-enable.sh 0/1 showPort
# Example 3: /sbin/cfg-port-enable.sh 0/1 showPortAll
# Example 4: /sbin/cfg-port-enable.sh 0/1 autoNeg 1 [0-off,1-on]
# Example 5: /sbin/cfg-port-enable.sh 0/1 speedDuplex 100 1 [10,100,1000] [0-half,1-full]

#version 2.1

#variables and defines
#temp files locations
tempFile="/tmp/rcsoc_tmp";

#rc.soc file location
rcFile="/rc.soc";

#flags
stateFlag=2; #not set
anStr=""; #not set
duplexStr=""; #not set
speedStr=""; #not set

#main function
function mainFunction() {
#check current "port Enable" state for port $1 (first input parameter)
sed -n '/port ge'$1' Enable=/p' "${rcFile}" > "${tempFile}";
while read line    
do  	
	if [[ $line == *"Enable=false"* ]]
	then
		stateFlag=0; #current state is disable
   elif [[ $line == *"Enable=true"* ]]
   then
      stateFlag=1; #current state is enable
	fi
done < "${tempFile}"

#change rc.soc for port $1 (first input parameter) in case if $2 (second input parameter) and current state are not equal
if [ $2 == "enable" ] || [ $2 == "noshutdown" ]
then
   if [ $stateFlag == 0 ]
then
   sed 's/port ge'$1' Enable=false/port ge'$1' Enable=true/g' "${rcFile}" > "${tempFile}"; #change state from disable to enable
   if [ -f ${tempFile} ]
   then 
      mv ${tempFile} ${rcFile};
   fi
   fi
elif [ $2 == "disable" ] || [ $2 == "shutdown" ]
then
   if [ $stateFlag == 1 ]
then
   sed 's/port ge'$1' Enable=true/port ge'$1' Enable=false/g' "${rcFile}"> "${tempFile}"; #change state from enable to disable
   if [ -f ${tempFile} ]
   then 
      mv ${tempFile} ${rcFile};
   fi
fi
fi
return;
}

#GSTR - example for rc.soc: an=off sp=1000 fd=true
#parse file for current settings
function parseFile() {

sed -n '/port ge'$1' Enable=/p' "${rcFile}" > "${tempFile}";
while read line
do
    if [[ $line == *"Enable=false"* ]]
    then
        stateFlag=0; #current state is disable
    elif [[ $line == *"Enable=true"* ]]
    then
        stateFlag=1; #current state is enable
    fi
    if [[ $line == *"an=off"* ]]
    then
        anStr="an=off"; #auto-negotiation is disabled
    elif [[ $line == *"an=on"* ]]
    then
        anStr="an=on"; #auto-negotiation is enabled
    fi
    if [[ $line == *"fd=false"* ]]
    then
        duplexStr="fd=false"; #half duplex
    elif [[ $line == *"fd=true"* ]]
    then
        duplexStr="fd=true"; #full duplex
    fi
    if [[ $line == *"sp=10"* ]]
    then
        speedStr="sp=10"; #speed
    elif [[ $line == *"sp=100"* ]]
    then
        speedStr="sp=100"; #speed
    elif [[ $line == *"sp=1000"* ]]
    then
        speedStr="sp=1000"; #speed
    fi
done < "${tempFile}"

return;
}


function changeFile() {

#change rc.soc for port $1 (first input parameter) depends of $2 (second input parameter)
if [ $2 == 0 ];
then
    sed 's/.*port ge'$1' Enable=false.*/port ge'$1' Enable=false '$anStr' '$speedStr' '$duplexStr'/g' "${rcFile}" > "${tempFile}";
    if [ -f ${tempFile} ]
    then
        mv ${tempFile} ${rcFile};
    fi
elif [ $2 == 1 ];
then
    sed 's/.*port ge'$1' Enable=true.*/port ge'$1' Enable=true '$anStr' '$speedStr' '$duplexStr'/g' "${rcFile}"> "${tempFile}";
    if [ -f ${tempFile} ]
    then
        mv ${tempFile} ${rcFile};
    fi
fi

sed -i -e 's/^[ \t]*//' -e 's/[ \t]*$//' "${rcFile}" #remove white spaces
return;
}

#PROGRAM START POINT
#make change on BCM via BCMconfigurator
portFlag=0; #not set: 1-for equip control; 2-for peripheral ports; 3-for show all ports status
if [ $1 == "0/1" ]
then
    ifacenbr="4";
    portFlag=1;
elif [ $1 == "0/2" ]
then
    ifacenbr="5";
    portFlag=1;
elif [ $1 == "0/3" ]
then
    ifacenbr="6";
    portFlag=1;
elif [ $1 == "0/4" ]
then
    ifacenbr="7";
    portFlag=1;
elif [ $1 == "1/1" ]
then
    ifacenbr="0";
    portFlag=1;
elif [ $1 == "1/2" ]
then
    ifacenbr="1";
    portFlag=1;
elif [ $1 == "2/1" ]
then
    ifacenbr="201";
    portFlag=2;
elif [ $1 == "2/2" ]
then
    ifacenbr="202";
    portFlag=2;
elif [ $1 == "2/3" ]
then
    ifacenbr="203";
    portFlag=2;
elif [ $1 == "2/4" ]
then
    ifacenbr="204";
    portFlag=2;
elif [ $1 == "2/5" ]
then
    ifacenbr="205";
    portFlag=2;
elif [ $1 == "2/6" ]
then
    ifacenbr="206";
    portFlag=2;
elif [ $1 == "2/7" ]
then
    ifacenbr="207";
    portFlag=2;
elif [ $1 == "2/8" ]
then
    ifacenbr="208";
    portFlag=2;
elif [ $1 == "2/9" ]
then
    ifacenbr="209";
    portFlag=2;
elif [ $1 == "2/10" ]
then
    ifacenbr="210";
    portFlag=2;
elif [ $1 == "2/11" ]
then
    ifacenbr="211";
    portFlag=2;
elif [ $1 == "2/12" ]
then
    ifacenbr="212";
    portFlag=2;
elif [ $1 == "2/13" ]
then
    ifacenbr="213";
    portFlag=2;
elif [ $1 == "2/14" ]
then
    ifacenbr="214";
    portFlag=2;
elif [ $1 == "2/15" ]
then
    ifacenbr="215";
    portFlag=2;
elif [ $1 == "2/16" ]
then
    ifacenbr="216";
    portFlag=2;
elif [ $1 == "2/17" ]
then
    ifacenbr="217";
    portFlag=2;
elif [ $1 == "2/18" ]
then
    ifacenbr="218";
    portFlag=2;
elif [ $1 == "2/19" ]
then
    ifacenbr="219";
    portFlag=2;
elif [ $1 == "2/20" ]
then
    ifacenbr="220";
    portFlag=2;
else
    echo Error: Currently not allowed to configure selected interface - $1
    exit
fi


if [ $2 == "disable" ] || [ $2 == "shutdown" ]
then
    shdwn="0"
elif [ $2 == "enable" ] || [ $2 == "noshutdown" ]
then
    shdwn="1"
elif [ $2 == "showPort" ]  || [ $2 == "-showPort" ]
then
    portFlag=3;
elif [ $2 == "showPortAll" ] || [ $2 == "-showPortAll" ]
then
    portFlag=3;
    ifacenbr="50";
elif [ $2 == "autoNeg" ] || [ $2 == "-autoNeg" ]
then
    portFlag=4;
elif [ $2 == "speedDuplex" ] || [ $2 == "-speedDuplex" ]
then
    portFlag=5;
fi

if [ $portFlag == "1" ]
then
	if  [ "$3" != "" ]
        then
        	if [ "$3" != "reboot" ]
                then
                    /opt/iskratel/sbin/BCMconfigurator -port_enable $ifacenbr $shdwn
                fi
        else
        	/opt/iskratel/sbin/BCMconfigurator -port_enable $ifacenbr $shdwn
        fi

	# mand - NOT USED
	#/sbin/cfg-mlinec.sh chg_link_equip $ifacenbr $shdwn

	mainFunction $ifacenbr $2; #change rc.soc
elif [ $portFlag == "2" ]
then
	/opt/iskratel/sbin/BCMconfigurator -port_enable $ifacenbr $shdwn
elif [ $portFlag == "3" ]
then
	/opt/iskratel/sbin/BCMconfigurator -show_port $ifacenbr
elif [ $portFlag == "4" ] #auto-negotiation
then
    /opt/iskratel/sbin/BCMconfigurator -port_auto_neg_set $ifacenbr $3
    parseFile $ifacenbr;
    
    #set auto-negotiation
    if [ $3 == "0" ]
    then
        anStr="an=off"; #auto-negotiation is disabled
    elif [ $3 == "1" ]
    then
        anStr="an=on"; #auto-negotiation is enabled
        if [ $ifacenbr != "4" ] && [ $ifacenbr != "5" ] #an is on, so set to defaults
        then
            speedStr="sp=1000"; #speed to 1G
            duplexStr="fd=true"; #full duplex
        else
            speedStr=""; #speed
            duplexStr=""; #duplex
        fi
    fi
    
    changeFile  $ifacenbr $stateFlag;
elif [ $portFlag == "5" ] #speed&duplex
then
    /opt/iskratel/sbin/BCMconfigurator -port_speed_duplex_set $ifacenbr $3 $4
    parseFile $ifacenbr;
    
    #set speed
    if [ $3 == "10" ]
    then
        speedStr="sp=10"; #speed
    elif [ $3 == "100" ]
    then
        speedStr="sp=100"; #speed
    elif [ $3 == "1000" ]
    then
        speedStr="sp=1000"; #speed            
    fi
    
    #set duplex
    if [ $4 == "0" ]
    then
        duplexStr="fd=false"; #half duplex
    elif [ $4 == "1" ]
    then
        duplexStr="fd=true"; #full duplex
    fi
    
    changeFile  $ifacenbr $stateFlag;
else
	/opt/iskratel/sbin/BCMconfigurator -port_enable $1 $shdwn
	mainFunction $1 $2; #change rc.soc
fi

#echo debug: calling bcm configurator with $1 $shdwn

exit;
