#!/bin/bash

REPLICA_FILE=/etc/cron.d/repl_on_demand

#Check if smart-flow replica file exists
if [ ! -f $REPLICA_FILE ]
then
	echo "Error: this is system without Solid DB or without smart-flow replication. This command is irregular!"
	exit
fi

TIME=$1

#Get hour and minute
HOUR=$(echo $TIME | awk -F":" '{ print $1}')
MIN=$(echo $TIME | awk -F":" '{ print $2}') 


# if replica-time command was executed
if [ "$1" != "default" ]
then
	#check input parameters - must be number
	if [ "${HOUR//[0-9]}" != "" ] || [ "${MIN//[0-9]}" != "" ]
	then
		echo "Error: please insert correct time and date (format = HH:MM), or revert this command with 'no replica-time'" 
		exit
	fi

	#Check input parameter for hour (0-23)
	if [ $HOUR -lt 0 ] || [ $HOUR -gt 23 ]
	then
	        echo "Wrong hour. Please insert value between 00 and 23, or revert this command with 'no replica-time'"
	        exit
	fi

	#Check input parameter for minute (0-59)
	if [ $MIN -lt 0 ] || [ $MIN -gt 59 ]
	then
	        echo "Wrong minute. Please insert value between 00 and 59, or revert this command with 'no replica-time'"
	        exit
	fi

#Correct replica file with new time
cat > ${REPLICA_FILE} << EOF
#
# cron job for daily propagate refresh cycle


# Run OLD smartflow replication cycle at $HOUR:$MIN
$MIN $HOUR * * * root /opt/iskratel/sbin/repl_on_demand_script
EOF
else
#Into replica file put default time
	TIME=03:00
	cat > ${REPLICA_FILE} << EOF
#
# cron job for daily propagate refresh cycle


# Run OLD smartflow replication cycle at 03:00
00 03 * * * root /opt/iskratel/sbin/repl_on_demand_script
EOF
fi

echo "DB replication time set at $TIME (default time is 03:00)"
