#!/bin/bash

CLISH_CFG_FILE=/etc/startup-config

# init var
if [ "$1" != "" ]
then
	mtu_size=$1
	mtu_size_curr=`konf -- -d | grep mtu |awk '{printf $2}'`
	if [ "$mtu_size_curr" == "" ]
	then
		mtu_size_curr=1500
	fi

#	echo "current mtu: $mtu_size_curr"
#	echo "new mtu: $mtu_size"

	# check if phys listed in bondports
	phys=`cat /etc/sysconfig/bondports | cut -d "(" -f2 | cut -d ")" -f1`
	if [ "$phys" == "" ]
	then
		echo
		echo "Error: no phy interfaces in bondports!"
		echo

		exit 1
	fi

	phy_num=`cat /etc/sysconfig/bondports | cut -d "(" -f2 | cut -d ")" -f1 | wc -w`
	if [ "$phy_num" != "2" ]
	then
		# we are either in instalation mode (more then 2 phys in bond) or HW with only one phy on cpu (CMJ)
		# so no need to make nice reconfiguration - just reconfigure bond0	      

		echo "Info: Reconfigure bond0 ..."
		/sbin/ip link set bond0 mtu $mtu_size
	else
		#check sys type
		sysType=`konf -- -d | grep 'system type' | awk '{printf $3}'`
		if [ "$sysType" == "standalone" ] || [ "$sysType" == "geo-single" ]
		then
			# no need to make nice reconfiguration - just reconfigure bond0	      

			echo "Info: Reconfigure bond0 ..."
			/sbin/ip link set bond0 mtu $mtu_size
		else
			#dupl or geo system - let us reconfigure intfs nice and slow

			phy1=`cat /etc/sysconfig/bondports | cut -d "(" -f2 | cut -d ")" -f1 |awk '{printf $1}'`
			phy2=`cat /etc/sysconfig/bondports | cut -d "(" -f2 | cut -d ")" -f1 |awk '{printf $2}'`

			# check which phy is active in bond
			act_phy=`cat /proc/net/bonding/bond0 | grep 'Currently Active Slave:' | cut -d ' ' -f 4`
			if [ "$act_phy" == "$phy1" ]
			then
				# first reconfigure phy2
				echo "Info: Reconfigure $phy2 ..."
				/sbin/ip link set $phy2 mtu $mtu_size

				sleep 3

				# reconfigure phy1
				echo "Info: Reconfigure $phy1 ..."
				/sbin/ip link set $phy1 mtu $mtu_size

				sleep 2

				# reconfigre bond0 intf
				echo "Info: Reconfigure bond0 ..."
				/sbin/ip link set bond0 mtu $mtu_size
			else
				# first reconfigure phy1
				echo "Info: Reconfigure $phy1 ..."
				/sbin/ip link set $phy1 mtu $mtu_size

				sleep 3

				# reconfigure phy2
				echo "Info: Reconfigure $phy2 ..."
				/sbin/ip link set $phy2 mtu $mtu_size

				sleep 2

				# reconfigre bond0 intf
				echo "Info: Reconfigure bond0 ..."
				/sbin/ip link set bond0 mtu $mtu_size
			fi
		fi
	fi

	# reconfigure all bond vlan intfs if new mtu grater than current
	if [ $mtu_size -gt $mtu_size_curr ]
	then
		intfs=`ip a | grep 'bond0:' | grep '@' | cut -d ' ' -f2 | cut -d '@' -f1`
		for intf in $intfs
		do
			echo "Info: Reconfigure $intf ..."
			/sbin/ip link set $intf mtu $mtu_size
		done
	fi
else
	echo
	echo "Error: no MTU size specified!"
	echo

	exit 1
fi



