#!/bin/bash

IPSNMP=$(cfg-getparams.sh mmMnSnmptrap)
COMMUNITY=$(cfg-getparams.sh mmMnSnmptrapCommunity)
SNMPPORT=$(cfg-getparams.sh mmMnSnmptrapPort)
SNMPTYPE=$(cfg-getparams.sh mmMnSnmptrapType)

#set notif type 
[ "$SNMPTYPE" = "" ] && SNMPTYPE="none"
trapdest.sh --type $SNMPTYPE

if [ "${IPSNMP}" != "" ]
then
for i in `cfg-getparams.sh mmMnSnmptrap`
do trapdest.sh --insert $i
done
fi
test ! -z ${COMMUNITY} && trapdest.sh --community ${COMMUNITY}
[ "$SNMPPORT" = "" ] && SNMPPORT=162 #set default port
trapdest.sh --port ${SNMPPORT}

#print next argument or "none" if not found
get_next_arg()
{
   #$1 = pattern to search for
   #$2..$N = where to search for pattern
   PAT=$1
   shift
   echo $@|awk -v P=$PAT '{
      for (i=1; i<NF; i++) {
         if ($i == P) {
            #pattern founded, print next argument and quit
            print $(i+1)
            next      
         }
      }
      print "none"  #pattern not found - "none" is default 
   }'
}

#add v3 trap destinations
while read line; do
   [ "$line" = "" ] && continue
   IPSNMP=$(get_next_arg "v3" $line)
   [ "$(/sbin/trapdest.sh --exist $IPSNMP)" != "" ] && continue #trapdest already exist  

   #read username, auth-proto, priv-proto & notif type
   USERNAME=$(get_next_arg "user" $line)
   AUTH_PROT=$(get_next_arg "auth-protocol" $line)
   PRIV_PROT=$(get_next_arg "priv-protocol" $line)
   NOTIF_TYPE=$(get_next_arg "type" $line)
   #read passwords from .trapdest file
   AUTH_PASWD=$(/sbin/mesh -d $(grep "^${IPSNMP} " /opt/si2000/mnroot/.trapdest | awk '{print $2}'| tail -n1))
   PRIV_PASWD=$(/sbin/mesh -d $(grep "^${IPSNMP} " /opt/si2000/mnroot/.trapdest | awk '{print $3}'| tail -n1))

   #add trap destination
   /sbin/trapdest.sh --v3 --insert $IPSNMP $USERNAME -a $AUTH_PROT $AUTH_PASWD -p $PRIV_PROT $PRIV_PASWD -t $NOTIF_TYPE
done <<< "$(grep '^snmptrap v3 ' /etc/startup-config)"

#snmp-server community
grep "^snmp-server community" /etc/startup-config |\
awk '{printf "/sbin/cfg-snmpcomm.sh --insert %s %s\n", $5, $3}' > /tmp/snmp-server-comm
bash /tmp/snmp-server-comm
rm -f /tmp/snmp-server-comm

#snmp-server v3 user 
while read line; do
   [ "$line" = "" ] && continue
   USERNAME=$(get_next_arg "user" $line)
   [ "$(/sbin/cfg-snmpcomm.sh --v3 --show|grep -w $USERNAME)" != "" ] && continue #username already exist  

   #read auth-proto, priv-proto & access mode
   AUTH_PROT=$(get_next_arg "auth-protocol" $line)
   PRIV_PROT=$(get_next_arg "priv-protocol" $line)
   ACCESS_MODE=$(get_next_arg "access" $line)
   [ "$ACCESS_MODE" = "none" ] && ACCESS_MODE="rw" #default access mode is read-write 
   #read passwords from .trapdest file
   AUTH_PASWD=$(/sbin/mesh -d $(grep "^${USERNAME} " /opt/si2000/mnroot/.snmpusers | awk '{print $2}'| tail -n1))
   PRIV_PASWD=$(/sbin/mesh -d $(grep "^${USERNAME} " /opt/si2000/mnroot/.snmpusers | awk '{print $3}'| tail -n1))

   #add snmpv3 user
   /sbin/cfg-snmpcomm.sh --v3 --insert $USERNAME -a $AUTH_PROT $AUTH_PASWD -p $PRIV_PROT $PRIV_PASWD -m $ACCESS_MODE
done <<< "$(grep '^snmp-server v3 ' /etc/startup-config)"

#delete entries not present in /etc/startup-config
for u in $(cfg-snmpcomm.sh -3 -s|awk '{print $1}'); do 
   [ "$(grep -w $u /etc/startup-config)" = "" ] && cfg-snmpcomm.sh -3 -d $u
done
