#!/bin/sh

# dump config to tmp file
konf -- -d > /tmp/running-config

# get basic system params
hostname=`cat /tmp/running-config | awk '/hostname/{p=1} /!/{p=0} p' | grep 'hostname' | grep -v ' hostname' | awk '{print $2}'`
domain_name=`cat /tmp/running-config | grep 'domain-name' | cut -d ' ' -f 2`
node_id=`cat /tmp/running-config | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'node-id' | sed "s|.*node-id ||" | cut -c 1`
unit_id=`cat /tmp/running-config | awk '/system unit-id/{p=1} /!/{p=0} p' | grep 'unit-id' | sed "s|.*unit-id ||" | cut -c 1`
sys_type=`cat /tmp/running-config | awk '/system type/{p=1} /!/{p=0} p' | sed "s|.*type ||"`
chass_type=`cat /tmp/running-config | awk '/chassis type/{p=1} /!/{p=0} p' | awk '{printf $3}'`
chass_size=`cat /tmp/running-config | awk '/chassis type/{p=1} /!/{p=0} p' | sed "s|.*size ||"`
cfg_board_pos=`cat /tmp/running-config | grep 'system board position' | awk '{printf $4}'`

# get impi board pos
IPMITOOL_CMD=`which ipmitool 2>/dev/null`
if [ ! -z ${IPMITOOL_CMD} ]
then
	ipmi_pos_hex=`${IPMITOOL_CMD} picmg addrinfo | grep 'Site ID' | sed "s%.*:%%g" | awk '{print $1}'`

	if [ "$ipmi_pos_hex" != "" ]
	then
		# Convert position in hex to decimal
		ipmi_board_pos=`awk "BEGIN {x=$ipmi_pos_hex; print strtonum(x)}"`
	fi
fi

os=`uname -a | grep -i mvl`
if [ "$os" != "" ]
then
	os=MVL
else
	os=`uname -a | grep -i wr`
	if [ "$os" != "" ]
	then
		os=WRL
	fi
fi

arch=`cat /etc/sysconfig/arch`
case $arch in
	*64)
		architecture="$arch (64 bit)"
		;;
	ppc64*)
		architecture="$arch (64 bit)"
		;;
	*)
		architecture="$arch (32 bit)"
		;;
esac

echo
echo "#-------------------#"
echo "# Basic System Info # "
echo "#-------------------#"
echo

echo "Hostname:			$hostname"
echo "Domain:				$domain_name"
echo
echo "OS type:			$os"
echo "System arch:			$architecture"
echo
echo "Configured board position:	$cfg_board_pos"
echo "IPMI board position:	$ipmi_board_pos"
echo
echo "System Type:			$sys_type"
echo "Chassis:			$chass_type (size $chass_size)"
echo
echo "Local unit (Unit ID: $unit_id)"

if [ "$unit_id" == "1" ]
then
	if [ "$node_id" == "1" ]
	then
echo "------------------------------"
		echo "Loc. hostname (node id 1): 	$hostname (config primary)"
else
echo "------------------------------"
		echo "Loc. hostname (node id 2):	$hostname"
	fi
else
	if [ "$node_id" == "1" ]
	then
		echo "------------------------------"
		echo "Loc. hostname (node id 1): 	$hostname"
	else
		echo "------------------------------"
		echo "Loc. hostname (node id 2):	$hostname"
	fi
fi

if [ "$sys_type" == "duplicated" ]
then
	red_hostname=`cat /tmp/running-config | awk '/hsb/{p=1} /!/{p=0} p' | grep ' hostname' | awk '{print $2}'`

	# if this unit id is 1 and node id is 2 then hsb remote node is primary
	if [ "$unit_id" == "1" ]
	then
		if [ "$node_id" == "2" ]
		then
			echo "HSB Red. hostname (node id 1): 		$red_hostname (config primary)"
		else
			echo "HSB Red. hostname (node id 2):		$red_hostname"
		fi
	else
		if [ "$node_id" == "2" ]
	then
			echo "HSB Red. hostname (node id 1): 		$red_hostname"
	else
			echo "HSB Red. hostname (node id 2):		$red_hostname"
fi

fi

echo
fi

# geo=`cat /tmp/running-config | awk '/georedundancy/{p=1} /!/{p=0} p' | grep 'enable'`

if [ "$sys_type" == "geo-dual" ] || [ "$sys_type" == "geo-single" ]
then
	red_hostname=`cat /tmp/running-config | awk '/hsb/{p=1} /!/{p=0} p' | grep ' hostname' | awk '{print $2}'`

	# if this unit id is 1 and node id is 2 then hsb remote node is primary
	if [ "$unit_id" == "1" ]
	then
		if [ "$node_id" == "2" ]
		then
			echo "HSB Red. hostname (node id 1): 	$red_hostname (config primary)"
		else
			echo "HSB Red. hostname (node id 2):	$red_hostname"
		fi
	else
		if [ "$node_id" == "2" ]
		then
			echo "HSB Red. hostname (node id 1): 	$red_hostname"
		else
			echo "HSB Red. hostname (node id 2):	$red_hostname"
		fi

	fi

	echo

	geo_red_hosts_1=`cat /tmp/running-config | awk '/georedundancy/{p=1} /!/{p=0} p' | grep 'remote node-id 1' | awk '{print $5}'`
	geo_red_hosts_2=`cat /tmp/running-config | awk '/georedundancy/{p=1} /!/{p=0} p' | grep 'remote node-id 2' | awk '{print $5}'`

	if [ "$unit_id" == "1" ]
	then
		geo_red_unit_id=2
	else
		geo_red_unit_id=1
	fi

	echo "GEO redundant unit (Unit ID: $geo_red_unit_id)"

	if [ "$geo_red_unit_id" == "1" ]
       	then
		echo "------------------------------"
		echo "Remote node 1:			$geo_red_hosts_1 (config primary)"
        else
		echo "------------------------------"
		echo "Remote node 1:			$geo_red_hosts_1"
        fi

	if [ "$sys_type" == "geo-dual" ]
	then
		echo "Remote node 2:			$geo_red_hosts_2"
        fi
	echo

fi


# delete config tmp file
rm /tmp/running-config

