#!/bin/bash

file=/etc/startup-config
FILE_BONDSTATIC=/etc/sysconfig/bonding.static
TIPC_NET_ID_CALC=/opt/iskratel/etc/tipc_net_id_calc

# INT_INTERFACE=`cat ${file} |grep 'internal interface' | grep -v 'remote' | awk '{printf $3}'`

function internal_intf_prefix()
{
	#get internal interface's prefix
	#OPENSTACK - no prefix
	[ "$(/sbin/cfg-getparams.sh mmMnChassisType)" == "OPENSTACK" ] && return 
	#check if either of fp_$INT_INTERFACE or $INT_INTERFACE exist on system
	/sbin/cfg-fpinternal.sh $1
	case $? in 
		0) echo "fp_";; #fp_$INT_INTERFACE exist
		3) return;; #$INT_INTERFACE exist, but fp_$INT_INTERFACE not - no prefix
		2) return;; #should not happen - neither exist
	esac
}

type=$1

if [ -f /etc/opensaf/tipc_config ]
then

if [ "$type" == "reboot" ]
then
	INT_INTERFACE=$(/sbin/cfg-getparams.sh mmInternalIntf)
	CHASSIS=$(/sbin/cfg-getparams.sh mmMnChassisType)
	product=$(/sbin/cfg-getparams.sh product)

	# get old interfaces from tipc_config
	old_intf1=`cat /etc/opensaf/tipc_config | grep ETH_INTERFACE | grep -vw ETH_INTERFACE_2 |  awk -F'ETH_INTERFACE=' '{print $2}'`
	old_intf2=`cat /etc/opensaf/tipc_config | grep ETH_INTERFACE_2 |  awk -F'ETH_INTERFACE_2=' '{print $2}'`

        # called after reboot - read startup conf
	sys_type=`cat ${file} | grep "system type" | awk '{print $3}'`
	if [ "$sys_type" != "standalone" ] && [ "$sys_type" != "geo-single" ]
	then
		# check if ha interfaces configured
		ha_intf=`cat ${file} | grep 'ha interface'`
		if [ "$ha_intf" == "" ]
		then
			# ha interface nof configured - set default
	        	# check if hsb enabled
	        	dupl=`cat ${file} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' enable'`
	        	if [ "$dupl" != "" ]
	        	then
	                	# hsb enabled - get internal vlan id
	                	if [ -f ${FILE_BONDSTATIC} ] && [ "$product" == "Compact_Call_Server" ]
	                	then
	                        	# internal vlan predefined
	                        	INT_VLAN=2005
					INTERFACE=bond0.$INT_VLAN
	                	else
	                        	# get internal vlan
	                        	INT_VLAN=`cat ${file} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' vlan internal' |awk '{print $3}'`
					if [ "${INT_VLAN}" != "" ]
					then
						INTERFACE=bond0.$INT_VLAN
					else
						INTERFACE=bond0
					fi
	                	fi

	                	# set tipc interface
				# cp /etc/opensaf/tipc_config.def /etc/opensaf/tipc_config
				if [ "$old_intf2" != "" ]
				then
		                	sed -i -e "s/$old_intf2/intf2/g" /etc/opensaf/tipc_config

					if [ ! -f ${FILE_BONDSTATIC} ]
                                	then
						# update itmlinec to stop monitoring old intf
	                                	/sbin/cfg-mlinec.sh chg_link_equip_port $old_intf2 0
					fi
				fi
				
				if [ "${INT_INTERFACE}" != "" ]
				then 
					INT_INTF_PREFIX=$(internal_intf_prefix $INT_INTERFACE)
					INT_INTERFACE=${INT_INTF_PREFIX}${INT_INTERFACE}
					if [ "${INT_VLAN}" != "" ]
					then
						INTERFACE=${INT_INTERFACE}.${INT_VLAN}
					else
						INTERFACE=${INT_INTERFACE}
					fi
				fi
							
				sed -i -e "s/$old_intf1/${INTERFACE}/g" /etc/opensaf/tipc_config

				if [ ! -f ${FILE_BONDSTATIC} ]
                                then
					# update itmlinec to stop monitoring old intf
                                	/sbin/cfg-mlinec.sh chg_link_equip_port $old_intf1 0
				fi
	        	else
	                	#  hsb not enabled - still standalone
				# cp /etc/opensaf/tipc_config.def /etc/opensaf/tipc_config
				if [ "$old_intf2" != "" ]
				then
					sed -i -e "s/$old_intf2/intf2/g" /etc/opensaf/tipc_config

					if [ ! -f ${FILE_BONDSTATIC} ]
                                	then
						# update itmlinec to stop monitoring old intf
                                        	/sbin/cfg-mlinec.sh chg_link_equip_port $old_intf2 0
					fi
				fi

				sed -i -e "s/$old_intf1/lo/g" /etc/opensaf/tipc_config

				if [ ! -f ${FILE_BONDSTATIC} ]
                                then
					# update itmlinec to stop monitoring old intf
                                	/sbin/cfg-mlinec.sh chg_link_equip_port $old_intf1 0
		        	fi
		        fi
		else
			intf1=`cat ${file} | grep 'ha interface primary' | awk '{print $4}'`
                        intf2=`cat ${file} | grep 'ha interface secondary' | awk '{print $4}'`

			if [ "$intf1" == "bp" ]
			then
				intf1=eth2
			else
				intf1_tmp=`cat ${file} | grep 'ha interface primary' | awk '{print $5}'`
				if [ "$intf1_tmp" != "" ]
				then
					intf1=fp_${intf1_tmp}
				fi
			fi

                        if [ "$intf2" == "bp" ]
                        then
                                intf2=eth2
                        else
                                intf2_tmp=`cat ${file} | grep 'ha interface secondary' | awk '{print $5}'`
				if [ "$intf2_tmp" != "" ]
				then
					intf2=fp_${intf2_tmp}
				fi
                        fi

                        # modify /etc/opensaf/tipc_config
                        # cp /etc/opensaf/tipc_config.def /etc/opensaf/tipc_config

			# set primary intf
                        sed -i -e "s/$old_intf1/$intf1/g" /etc/opensaf/tipc_config

			if [ ! -f ${FILE_BONDSTATIC} ]
                        then
				# update itmlinec to start monitoring intf
				/sbin/cfg-mlinec.sh chg_link_equip_port $intf1 1
			fi

			if [ "$intf2" != "" ]
			then
				sed -i -e "s/$old_intf2/$intf2/g" /etc/opensaf/tipc_config

				if [ ! -f ${FILE_BONDSTATIC} ]
                                then
					# update itmlinec to start monitoring intf
	                        	/sbin/cfg-mlinec.sh chg_link_equip_port $intf2 1
				fi
			else
				# get internal vlan
                                INT_VLAN=`cat ${file} | awk '/hsb/{p=1} /!/{p=0} p' | grep ' vlan internal' |awk '{print $3}'`
				if [ "${INT_VLAN}" != "" ]
				then
					INTERFACE=bond0.$INT_VLAN
				else
					INTERFACE=bond0
				fi

				if [ "$INT_INTERFACE" != "" ]
				then
					INT_INTF_PREFIX=$(internal_intf_prefix $INT_INTERFACE)
					INT_INTERFACE=${INT_INTF_PREFIX}${INT_INTERFACE}
					if [ "$INT_VLAN" != "" ]
					then
						INTERFACE=${INT_INTERFACE}.${INT_VLAN}
					else
						INTERFACE=${INT_INTERFACE}
					fi
				fi

                        	sed -i -e "s/$old_intf2/${INTERFACE}/g" /etc/opensaf/tipc_config

				if [ ! -f ${FILE_BONDSTATIC} ]
                                then
					# update itmlinec to stop monitoring old intf
	                        	/sbin/cfg-mlinec.sh chg_link_equip_port $old_intf2 0
				fi
			fi

			# bring up configured intfs - admin UP
			if [ "$intf1" != "intf1" ]
			then
				ip link set $intf1 up
			fi

			if [ "$intf2" != "" ]
			then
				ip link set $intf2 up
			fi
	        fi

		# read float ip addres and get last bype for tipc node id
#		fourthByte=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress | cut -d '/' -f1 | cut -d '.' -f4)
#		thirdByte=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress | cut -d '/' -f1 | cut -d '.' -f3)
#		first=`echo "${thirdByte: -1:1}"`
#		if [ "${first}" == "0" ]
#		then
#			first=`echo "${thirdByte: -2:1}"`
#			if [ "${first}" == "0" ]
#	                then
#				first=`echo "${thirdByte: -3:1}"`
#			fi
#		fi
#
#		tipc_net_id=`cat /etc/opensaf/tipc_config | grep NETWORK_ID`
#		sed -i -e "s/${tipc_net_id}/NETWORK_ID=${first}${fourthByte}/g" /etc/opensaf/tipc_config


		# if /etc/sysconfig/no_calc_tipc_net_id exist, do not calc tipc net id
		if [ ! -f /etc/sysconfig/no_calc_tipc_net_id ]
		then
                  if [ -f /etc/sysconfig/old_tipc_net_id ]
                  then
                        # read float ip addres and get last bype for tipc node id
		  	fourthByte=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress | cut -d '/' -f1 | cut -d '.' -f4)
			thirdByte=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress | cut -d '/' -f1 | cut -d '.' -f3)
			first=`echo "${thirdByte: -1:1}"`
			if [ "${first}" == "0" ]
			then
				first=`echo "${thirdByte: -2:1}"`
				if [ "${first}" == "0" ]
		                then
					first=`echo "${thirdByte: -3:1}"`
				fi
			fi

			tipc_net_id=`cat /etc/opensaf/tipc_config | grep NETWORK_ID`
			sed -i -e "s/${tipc_net_id}/NETWORK_ID=${first}${fourthByte}/g" /etc/opensaf/tipc_config
                  else
                        # new tipc net id calc
			if [ -f $TIPC_NET_ID_CALC ]
			then
				calc_type=`cat $TIPC_NET_ID_CALC | cut -d '=' -f2`

				if [ "$calc_type" == "ip_internal" ]
				then
					unit_id=`/sbin/cfg-getparams.sh mmUnitNumber`
					if [ "$unit_id" == "1" ]
					then
						int_ip=`/sbin/cfg-getparams.sh mmMnInternalIpAddress11Mask`
					else
						int_ip=`/sbin/cfg-getparams.sh mmMnInternalIpAddress21Mask`
					fi

					new_tipc_net_id=`/sbin/cfg-calc-tipc-net-id.sh $int_ip`
				else
                        		hsb_float_ip=`/sbin/cfg-getparams.sh hsbMnFloatIpAddress`
                        		new_tipc_net_id=`/sbin/cfg-calc-tipc-net-id.sh $hsb_float_ip`
				fi
			else
				hsb_float_ip=`/sbin/cfg-getparams.sh hsbMnFloatIpAddress`
				new_tipc_net_id=`/sbin/cfg-calc-tipc-net-id.sh $hsb_float_ip`
			fi

#			hsb_float_ip=`/sbin/cfg-getparams.sh hsbMnFloatIpAddress`
#			new_tipc_net_id=`/sbin/cfg-calc-tipc-net-id.sh $hsb_float_ip`

                        tipc_net_id=`cat /etc/opensaf/tipc_config | grep NETWORK_ID`
                        sed -i -e "s/${tipc_net_id}/NETWORK_ID=${new_tipc_net_id}/g" /etc/opensaf/tipc_config

                  fi
		fi
	else
		# i am standalone - set tipc interface to 'lo'
		# cp /etc/opensaf/tipc_config.def /etc/opensaf/tipc_config

		# set second intf
		if [ "$old_intf2" != "" ]
		then
			sed -i -e "s/$old_intf2/intf2/g" /etc/opensaf/tipc_config
		fi

		# set first intf
		sed -i -e "s/$old_intf1/lo/g" /etc/opensaf/tipc_config
	fi
else
        # called from runtime - read running conf
	sys_type=$1

	INT_INTERFACE=$(/sbin/cfg-getparams.sh mmInternalIntf --runtime)
        CHASSIS=$(/sbin/cfg-getparams.sh mmMnChassisType --runtime)
	product=$(/sbin/cfg-getparams.sh product --runtime)

	# get old interfaces from tipc_config
        old_intf1=`cat /etc/opensaf/tipc_config | grep ETH_INTERFACE | grep -vw ETH_INTERFACE_2 |  awk -F'ETH_INTERFACE=' '{print $2}'`
        old_intf2=`cat /etc/opensaf/tipc_config | grep ETH_INTERFACE_2 |  awk -F'ETH_INTERFACE_2=' '{print $2}'`

	if [ "$sys_type" != "standalone" ] && [ "$sys_type" == "hsb_enable" ]
        then
                # hsb enabled - get internal vlan id
                if [ -f ${FILE_BONDSTATIC} ] && [ "$product" == "Compact_Call_Server" ]
                then
                        # internal vlan predefined
                        INT_VLAN=2005
			INTERFACE=bond0.$INT_VLAN
                else
                        # get internal vlan
                        INT_VLAN=`konf -- -d | awk '/hsb/{p=1} /!/{p=0} p' | grep ' vlan internal' |awk '{print $3}'`
			if [ "$INT_INTERFACE" != "" ]
			then
				INT_INTF_PREFIX=$(internal_intf_prefix $INT_INTERFACE)
				INT_INTERFACE=${INT_INTF_PREFIX}${INT_INTERFACE}
				if [ "${INT_VLAN}" != "" ]
				then
					INTERFACE=$INT_INTERFACE.$INT_VLAN
				else
					INTERFACE=$INT_INTERFACE
				fi
			else
				if [ "${INT_VLAN}" != "" ]
				then
					INTERFACE=bond0.$INT_VLAN
				else
					INTERFACE=bond0
				fi
                	fi
                fi

                # set tipc interface
		# cp /etc/opensaf/tipc_config.def /etc/opensaf/tipc_config
		if [ "$old_intf2" != "" ]
		then
			sed -i -e "s/$old_intf2/intf2/g" /etc/opensaf/tipc_config
		fi
		
		sed -i -e "s/$old_intf1/${INTERFACE}/g" /etc/opensaf/tipc_config


		# if /etc/sysconfig/no_calc_tipc_net_id exist, do not calc tipc net id
		if [ ! -f /etc/sysconfig/no_calc_tipc_net_id ]
                then
		  if [ -f /etc/sysconfig/old_tipc_net_id ]
		  then
		  	# read float ip addres and get last bype for tipc node id
                	fourthByte=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress --runtime | cut -d '/' -f1 | cut -d '.' -f4)
			thirdByte=$(/sbin/cfg-getparams.sh hsbMnFloatIpAddress --runtime | cut -d '/' -f1 | cut -d '.' -f3)
                	first=`echo "${thirdByte: -1:1}"`
	                if [ "${first}" == "0" ]
	                then
	                        first=`echo "${thirdByte: -2:1}"`
	                        if [ "${first}" == "0" ]
	                        then
	                                first=`echo "${thirdByte: -3:1}"`
	                        fi
	                fi

			tipc_net_id=`cat /etc/opensaf/tipc_config | grep NETWORK_ID`
	                sed -i -e "s/${tipc_net_id}/NETWORK_ID=${first}${fourthByte}/g" /etc/opensaf/tipc_config
        	  else
			# new tipc net id calc
                        if [ -f $TIPC_NET_ID_CALC ]
                        then
                                calc_type=`cat $TIPC_NET_ID_CALC | cut -d '=' -f2`

                                if [ "$calc_type" == "ip_internal" ]
                                then
                                        unit_id=`/sbin/cfg-getparams.sh mmUnitNumber --runtime`
                                        if [ "$unit_id" == "1" ]
                                        then
                                                int_ip=`/sbin/cfg-getparams.sh mmMnInternalIpAddress11Mask --runtime`
                                        else
                                                int_ip=`/sbin/cfg-getparams.sh mmMnInternalIpAddress21Mask --runtime`
                                        fi

                                        new_tipc_net_id=`/sbin/cfg-calc-tipc-net-id.sh $int_ip`
                                else
					hsb_float_ip=`/sbin/cfg-getparams.sh hsbMnFloatIpAddress --runtime`
					new_tipc_net_id=`/sbin/cfg-calc-tipc-net-id.sh $hsb_float_ip`
                                fi
                        else
                                hsb_float_ip=`/sbin/cfg-getparams.sh hsbMnFloatIpAddress`
                                new_tipc_net_id=`/sbin/cfg-calc-tipc-net-id.sh $hsb_float_ip`
                        fi

#			hsb_float_ip=`/sbin/cfg-getparams.sh hsbMnFloatIpAddress --runtime`
#			new_tipc_net_id=`/sbin/cfg-calc-tipc-net-id.sh $hsb_float_ip`

			tipc_net_id=`cat /etc/opensaf/tipc_config | grep NETWORK_ID`
                        sed -i -e "s/${tipc_net_id}/NETWORK_ID=${new_tipc_net_id}/g" /etc/opensaf/tipc_config

		  fi
		fi
        else
                # i am standalone - set tipc interface to 'lo'
		# cp /etc/opensaf/tipc_config.def /etc/opensaf/tipc_config
		if [ "$old_intf2" != "" ]
		then
			sed -i -e "s/$old_intf2/intf2/g" /etc/opensaf/tipc_config
		fi
		sed -i -e "s/$old_intf1/lo/g" /etc/opensaf/tipc_config
        fi
fi

else

echo "Info: cfg-tipc-conf.sh -> /etc/opensaf/tipc_config does not exist - nothing to do!"
exit 0

fi

