#!/bin/sh
# Script for check if startup-config exsist
# If no startup-config is available
# Prompt for basic system parameters input

export SHELL=/bin/bash

STFILE=/etc/startup-config
FILEHOSTNAME=/etc/sysconfig/starthostname
	FILECHASSIS=/etc/sysconfig/startChassis
FILEIPADDR=/etc/sysconfig/startIpMask
FILEROUTE=/etc/sysconfig/startDefRoute
FILEMASK=/etc/sysconfig/startRouteMask
FILEGW=/etc/sysconfig/startGw
FILEMGMTVLAN=/etc/sysconfig/startMgmtVlan
CLISH_WIZARD_ON=/etc/sysconfig/clish_wizard_on

function enterGw()
{
	b="1"
	while [ $b -gt 0 ]
	do
		echo
		echo  Please enter gateway IP address:
		read GW
		if [ "${GW}" != "" ]
		then
			validate_ip ${GW}
			res=$?
			if [ "$res" != "0" ]
			then
				echo "Error in IP syntax, please try again!"
				i="1"
				j="1"
			else
				cat >${FILEGW} << EOF
${GW}
EOF
				i="0"
				j="0"
				h="0"
				b="0"
			fi
				
		fi
	done
}


function enterhostname()
{
	echo
	echo  Please enter hostname:
	read HOSTNAME
	if [ "${HOSTNAME}" != "" ]
	then
		cat >${FILEHOSTNAME} << EOF
${HOSTNAME}
EOF
		i="0"
	fi
}

	function enterchassis()
	{
		echo
		read -p "Is deployment chassis 'OPENSTACK' ? (y/n):" -n 1 -r

		if [[ $REPLY =~ ^[Yy]$ ]]
		then
cat >${FILECHASSIS} << EOF
OPENSTACK
EOF
		else
cat >${FILECHASSIS} << EOF
EOF
		fi

		i="0"
	}

function enterIpAddrMask()
{
	u="1"
	while [ $u -gt 0 ]
	do

		echo
		echo  "Please enter management IP address in form 'a.b.c.d/mask':"
		read IPADDR

		if [[ ${IPADDR} == */* ]]
		then
			IP=`echo "$IPADDR" | sed 's/\/.*//'`
			MASK=`echo "$IPADDR" | awk 'match($0,"/"){print substr($0,RSTART+1,4)}'`

	
			if [ "${IP}" != "" ]
			then
				# validate IP
				validate_ip ${IP}
				res=$?
				if [ "$res" != "0" ]
				then
					echo "Error in IP syntax, please try again!"
					i="1"
					j="0"
					z="1"
				else
					cat >${FILEIPADDR} << EOF
$IPADDR
EOF
					i="0"
					j="1"
					z="0"
					u="0"
				fi
			fi
	
			if [ "$i" != "1" ] && [ "$j" != "0" ]
			then 
				# validate mask
				if  [[ $MASK =~ ^-?[0-9]+$ ]]
				then

					if [ "$MASK" -gt "3" ] && [ "$MASK" -lt "33" ]
					then
						i="0"
					else
						echo "Please enter mask from 4 to 32"
						i="1"
						j="0"
						u="1"
					fi
				else
					echo "Not an integer "
					i="1"
					j="0"
				fi
			fi

		else
			echo "Error in IP syntax, please try again!"
			i="1"
			j="0"
		fi
	done
}

function enterRoute()
{
	loop="1"

	while [ $loop -gt 0 ]
	do
		loop="0"
		echo
		echo  "Please enter IP route network address or type 'default' for def. route:"
		read ROUTE
		if [ "${ROUTE}" != "default" ] && [ "${ROUTE}" != "0.0.0.0" ]
		then
			validate_ip ${ROUTE}
			res=$?
			if [ "$res" != "0" ]
			then
				echo "Error in IP syntax, please try again!"
				loop="1"
			else
				cat >${FILEROUTE} << EOF
${ROUTE}
EOF
				i="0"
				err="0"
			fi
		else
			ROUTE="0.0.0.0"
			RT="default"
			err="0"
			cat >${FILEROUTE} << EOF
0.0.0.0
EOF
		fi

	done

	if [ "$err" != "1" ]
	then
		if [ "${RT}" != "default" ]
		then
			if [ -f ${FILEMASK} ]
			then
				# Input already done but changes should me made		
				MASK=`cat ${FILEMASK}`
				read -p "Last entered IP route network mask: '${MASK}' Keep this value ? (y/n):" -n 1 -r
				
				z="1"
				while [ $z -gt 0 ]
				do
					echo " "
					if [[ $REPLY =~ ^[Nn]$ ]]
					then
						entermask
						Z="0"
						break
					else
						if [[ $REPLY =~ ^[Yy]$ ]]
						then
							echo
							# echo "OK mask IP address is the same"							
							z="0"
							break
						else
							z="1"
						fi
						i="0"
					fi
					done
			else
				entermask
			fi			
		else 
			cat >${FILEMASK} << EOF
0.0.0.0
EOF
			i="0"
		fi
	else
		i="1"
	fi
}


entermask()
{
	echo
	echo  Please enter IP route network mask:
	read MASK
	if [ "${MASK}" != "" ]
	then
		validate_ip ${MASK}
		res=$?
		if [ "$res" != "0" ]
		then
			echo "Error in IP syntax, please try again!"
			i="1"
		else
			cat >${FILEMASK} << EOF
${MASK}
EOF
			i="0"
		fi
	else
		i="0"
	fi
}
	
function enterMgmtVlan()
{
	loop="1"

	while [ $loop -gt 0 ]

	do
		loop="0"
		echo
		echo  "Please enter management VLAN:"
		read MGMTVLAN

		validate_vlan ${MGMTVLAN}
		res=$?
		if [ "$res" != "0" ]
		then
			echo "Invalid management VLAN, please try again!"
			loop="1"
		else
cat >${FILEMGMTVLAN} << EOF
${MGMTVLAN}
EOF
		fi
	done
}

function validate_vlan()
{
	local  vlan=$1
	local  stat=1
	if [[ $vlan =~ ^[0-9]+$ ]] && [[ "$vlan" -gt 0 ]] && [[ "$vlan" -lt 4096 ]]; then
		stat=$?
	fi
	if [ -f /etc/sysconfig/bonding.static ]
	then
		if [[ "$vlan" == 2005 ]] || [[ "$vlan" == 1006 ]] || [[ "$vlan" == 1007 ]] || [[ "$vlan" == 1008 ]]; then
			stat=1
		fi
	fi

	return $stat
}

function validate_ip()
{
	local  ip=$1
	local  stat=1
	nrdot=`echo "$ip" | grep -o "\." | wc -l`
	if [ "$nrdot" == "3" ]
	then
		if [[ $ip =~ ^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}$ ]]
		then
			OIFS=$IFS
			IFS='.'
			ip=($ip)
			IFS=$OIFS
			if [[ ${ip[0]} -le 255 && ${ip[1]} -le 255 \
			&& ${ip[2]} -le 255 && ${ip[3]} -le 255 ]]
			then
				stat=$?
			fi
		fi
		return $stat
	else
		return 1
	fi
}

# main part

if [ -f ${STFILE} ] && [ ! -f ${CLISH_WIZARD_ON} ]
then
	echo
	echo "Skipping wizard and going to CLI ..."

	pidof -s clish > /dev/null
	if [ "$?" == "0" ]
	then
		#clish already running
		echo "User 'admin' already logged in!"
		echo
	else
		echo "############################################"
		echo "*               ISKRATEL CLI               *"
		echo "*                                          *"
		echo "*          Authorised Access Only          *"
		echo "############################################"
		echo
		echo "Welcome admin (`date`)"
		echo
		echo "CLI Version: "`/sbin/cfg-itKlish-ver.sh`
		echo
		clish -o -x /etc/clish/enable
	fi

	exit 0

else
	echo "############################################"
	echo "#          ISKRATEL CLI WIZARD             #"
	echo "#                                          #"
	echo "#         Authorised Access Only           #"
	echo "############################################"

	echo "Welcome admin ($(date))"
fi


i="1"
        while [ $i -gt 0 ]
        do
		if [  -f ${FILECHASSIS} ]
		then
			CHASSIS=`cat ${FILECHASSIS}`
			# Input already done but changes should me made
			echo

			z="1"
			while [ $z -gt 0 ]
			do
				read -p "Last entered deployment CHASSIS: '${CHASSIS}' Keep this value? (y/n):" -n 1 -r
				if [[ $REPLY =~ ^[Yy]$ ]]
				then
					echo
					z="0"
					i="0"
					break
				else
					if [[ $REPLY =~ ^[Nn]$ ]]
					then
cat >${FILECHASSIS} << EOF
EOF
						z="0"
						break
					else
						echo " "
					fi
				fi
			done
		else
			enterchassis
		fi
        done

	i="1"

while [ $i -gt 0 ]

do
	if [  -f ${FILEHOSTNAME} ]
	then
		HOSTNAME=`cat ${FILEHOSTNAME}`
		# Input already done but changes should me made
		echo
		z="1"
		while [ $z -gt 0 ]
		do
			read -p "Last entered hostname: '${HOSTNAME}' Keep this value? (y/n):" -n 1 -r
			if [[ $REPLY =~ ^[Yy]$ ]]
			then
				echo
				z="0"
				i="0"
				break
			else
			
				if [[ $REPLY =~ ^[Nn]$ ]]
				then
					enterhostname
					z="0"
					break
				else
					echo " "
				fi
			fi
		done
	else
		enterhostname
	fi
done

i="1"
j="1"
while [ $i -gt 0 ]

do
	if [ "$j" == "1" ]
	then
		if [  -f ${FILEIPADDR} ]
		then
			# Input already done but changes should me made
			IPADDR=`cat ${FILEIPADDR}`
			z="1"
			while [ $z -gt 0 ]
			do
				echo
				read -p "Last entered IP address/mask: '${IPADDR}' Keep this value ? (y/n):" -n 1 -r
				if [[ $REPLY =~ ^[Yy]$ ]]
				then
					echo
					z="0"
					i="0"
					j="0"
					break
				else
					if [[ $REPLY =~ ^[Nn]$ ]]
					then
						enterIpAddrMask
						if [ "$z" == "0" ]
						then
							break
						fi
					else
						echo " "
					fi
				fi
			done
		else
			enterIpAddrMask
		fi
	else
		enterIpAddrMask
	fi
done

i="1"
routechose="1"

while [ $i -gt 0 ]
do
echo
	read -p "Do you wish to add route to MN network or default route? (y/n):" -n 1 -r
	if [[ $REPLY =~ ^[Yy]$ ]]
	then
		if [  -f ${FILEROUTE} ]
		then
			# Input already done but changes should me made		
			ROUTE=`cat ${FILEROUTE}`
			echo
			z="1"
			while [ $z -gt 0 ]
			do
				echo " "
				read -p "Last entered network address for IP route: '${ROUTE}' Keep this value ? (y/n):" -n 1 -r
				if [[ $REPLY =~ ^[Nn]$ ]]
				then
					enterRoute
					z="0"
					i="0"
					break
				else
					if [[ $REPLY =~ ^[Yy]$ ]]
					then
						z="0"
						i="0"
						break
					else
						z="1"
					fi
				fi
			done
		else
			enterRoute
			z="0"
			i="0"
			break
		fi
		routechose="1"
	else
		if [[ $REPLY =~ ^[Nn]$ ]]
		then
			routechose="0"
			i="0"
		else
			i="1"
		fi
	fi
done

i="1"
j="1"

if [ "${routechose}" != "0" ]
then

	while [ $i -gt 0 ]
	do
		if [ "$j" == "1" ]
		then
			if [  -f ${FILEGW} ]
			then
				# Input already done but changes should me made		
				GW=`cat ${FILEGW}`
				echo
				h="1"
				while [ $h -gt "0" ]
				do
					read -p "Last entered gateway IP address: '${GW}' Keep this value ? (y/n):" -n 1 -r
					if [[ $REPLY =~ ^[Yy]$ ]]
					then
						echo " "
						h="0"
						j="0"
						break
					else
						if [[ $REPLY =~ ^[Nn]$ ]]
						then
						enterGw
							if [ "$h" == "0" ]
							then
								break
							fi
						else
							h="1"
						fi
					fi
				done
			else
				enterGw
			fi
		else
			break
		fi
	done
fi

i="1"
mgmtvlanchose="1"

while [ $i -gt 0 ]
do
	echo
	read -p "Do you wish to add management VLAN? (y/n):" -n 1 -r
	if [[ $REPLY =~ ^[Yy]$ ]]
	then
		if [  -f ${FILEMGMTVLAN} ]
		then
			# Input already done but changes should me made
			MGMTVLAN=`cat ${FILEMGMTVLAN}`
			echo
			z="1"
			while [ $z -gt 0 ]
			do
				echo " "
				read -p "Last entered management VLAN: '${MGMTVLAN}' Keep this value ? (y/n):" -n 1 -r
				if [[ $REPLY =~ ^[Nn]$ ]]
				then
					enterMgmtVlan
					z="0"
					i="0"
					break
				else
					if [[ $REPLY =~ ^[Yy]$ ]]
					then
						z="0"
						i="0"
						break
					else
						z="1"
						echo " "
						echo "Wrong selection"
					fi
				fi
			done
		else
			enterMgmtVlan
			z="0"
			i="0"
			break
		fi
		mgmtvlanchose="1"
	else
		if [[ $REPLY =~ ^[Nn]$ ]]
		then
			mgmtvlanchose="0"
			i="0"
		else
			i="1"
			echo " "
			echo "Wrong selection"
		fi
	fi
done

# Confirmation

echo
echo "Check configured values and confirm"
echo "-----------------------------------"

# Saved data
HOSTNAME=`cat ${FILEHOSTNAME}`
IPADDR=`cat ${FILEIPADDR}`
CHASSIS=`cat ${FILECHASSIS}`

if [ "${routechose}" == "1" ]
then
	ROUTE=`cat ${FILEROUTE}`
	MASK=`cat ${FILEMASK}`
	GW=`cat ${FILEGW}`
fi

if [ "${mgmtvlanchose}" == "1" ]
then
	MGMTVLAN=`cat ${FILEMGMTVLAN}`
fi

echo "Hostname: ${HOSTNAME}"
if [ "$CHASSIS" == "OPENSTACK" ]
then
echo "Chassis: ${CHASSIS}"
fi
echo "IP address: ${IPADDR}"
if [ "${routechose}" == "1" ]
then
	echo "IP route: net ${ROUTE} mask ${MASK} gw ${GW}"
	echo
else
	echo "IP route: not configured"
fi

if [ "${mgmtvlanchose}" == "1" ]
then
	echo "Management VLAN: ${MGMTVLAN}"
	echo
else
	echo "Management VLAN: not configured"
fi

i="1"
while [ $i -gt 0 ]
do
	echo
	read -p "Please confirm values (y/n): " -n 1 -r
	echo    # (optional) move to a new line

	if [[ $REPLY =~ ^[Yy]$ ]]
	then
		# save input params in file
		echo "Applying and saving values ..."
		i="0"
			if [ "${routechose}" == "1" ]
			then
cat >${STFILE} << EOF
!
hostname ${HOSTNAME}
EOF

		if [ "$CHASSIS" == "OPENSTACK" ]
		then

cat >>${STFILE} << EOF
!
chassis type OPENSTACK size 1
EOF

		fi

cat >>${STFILE} << EOF
!
interface mgmt
 ip address ${IPADDR}
!
ip route mgmt ${ROUTE} ${MASK} ${GW}
EOF

			else
				cat >${STFILE} << EOF
!
hostname ${HOSTNAME}
EOF

		if [ "$CHASSIS" == "OPENSTACK" ]
		then

cat >>${STFILE} << EOF
!
chassis type OPENSTACK size 1
EOF

		fi

cat >>${STFILE} << EOF
!
interface mgmt
 ip address ${IPADDR}
EOF

			fi

			if [ "${mgmtvlanchose}" == "1" ]
			then
				cat >>${STFILE} << EOF
!
vlan mgmt ${MGMTVLAN}
EOF

			fi
			# Apply values
			cat ${STFILE} | grep '^hostname' | clish -l -x /etc/clish/enable -i /etc/clish/enable -w configure-view
			cat ${STFILE} | awk '/chassis type/{p=1} /!/{p=0} p' |clish -l -x /etc/clish/enable/ -i /etc/clish/enable -w configure-view
			cat ${STFILE} | grep '^vlan mgmt' | clish -l -x /etc/clish/enable -i /etc/clish/enable -w configure-view
			cat ${STFILE} | awk '/interface mgmt/{p=1} /!/{p=0} p' | grep -v filter | clish -l -x /etc/clish/enable -i /etc/clish/enable -w configure-view
			cat ${STFILE} | awk '/ip route mgmt/{p=1} /!/{p=0} p' | clish -l -x /etc/clish/enable -i /etc/clish/enable -w configure-view
			rm ${FILEHOSTNAME} ${FILEIPADDR} ${FILECHASSIS}
			if [ "${routechose}" == "1" ]
			then
				rm ${FILEROUTE} ${FILEMASK} ${FILEGW}
			fi

			if [ "${mgmtvlanchose}" == "1" ]
			then
				rm ${FILEMGMTVLAN}
			fi

			# change neroot permissions to neadmin
			sudo chown neadmin:users /opt/si2000/neroot

			# exit or continue to clish
			echo
			echo
			echo "Type exit to exit from CLI WIZARD or <enter> to continue to CLI:" 
			read user_input
			echo # (optional) move to a new line

			if [ -f $CLISH_WIZARD_ON ]
			then
				rm $CLISH_WIZARD_ON
			fi

			if [ "$user_input" == "exit" ]
			then
				echo "Exiting from CLI WIZARD ..."
				exit 1
			else
				echo "Continue to CLI ..."
				echo
				echo "############################################"
				echo "*               ISKRATEL CLI               *"
				echo "*                                          *"
				echo "*          Authorised Access Only          *"
				echo "############################################"
				echo
				echo "Welcome admin (`date`)"
				echo
				echo "CLI Version: "`/sbin/cfg-itKlish-ver.sh`
				echo
				clish -o -x /etc/clish/enable

				exit 0
			fi
		else
		# echo "Restarting for input new values..."
		if [[ $REPLY =~ ^[Nn]$ ]]
		then
			i="0"
			bash /sbin/clish_wizard.sh
		else
			i="1"
		fi
	fi
done
