#!/usr/bin/env python
import requests
import os,sys,json
import struct, socket 
from requests.exceptions import ConnectionError, Timeout
import syslog

METADATA_URL = 'http://169.254.169.254/openstack/latest/network_data.json'
METADATA_URL_AWS = 'http://169.254.169.254/latest/meta-data/network/interfaces/macs'
RESPONSE_OK = 200
NO_CAHCE_FLAG = '--no-cache'
MTU_FLAG = '--mtu'
debug_flag = 0
force_refresh = 0
get_mtu = 0

#MAND add
config_drive_use = 0
config_drive_dev = '/dev/sr0'
config_drive_mount_point = '/mnt'
config_drive_mount_network_data = '/mnt/openstack/latest/network_data.json'

cache_file_path = '/tmp/network_data.json'

#sample data.json: 
#{
#  "services":[
#     {
#        "type":"dns",
#        "address":"10.1.2.1"
#     },
#     {
#        "type":"dns",
#        "address":"10.1.2.3"
#     }
#  ],
#  "networks":[
#     {
#        "network_id":"2f71b69f-b5d3-4346-8dcf-ae521a099bef",
#        "link":"tap1a15b36e-23",
#        "type":"ipv4_dhcp",
#        "id":"network0"
#     },
#     {
#        "network_id":"84d6578c-1a08-44d9-a256-969e8314b118",
#        "type":"ipv4",
#        "netmask":"255.255.255.0",
#        "link":"tap12b49ece-b6",
#        "routes":[
#           {
#              "netmask":"0.0.0.0",
#              "network":"0.0.0.0",
#              "gateway":"192.168.205.1"
#           }
#        ],
#        "ip_address":"192.168.205.114",
#        "id":"network1"
#     }
#  ],
#  "links":[
#     {
#        "ethernet_mac_address":"fa:16:3e:04:b1:3b",
#        "mtu":1500,
#        "type":"ovs",
#        "id":"tap1a15b36e-23",
#        "vif_id":"1a15b36e-239a-485a-b455-43ade1e1fee0"
#     },
#     {
#        "ethernet_mac_address":"fa:16:3e:d6:04:d8",
#        "mtu":1500,
#        "type":"ovs",
#        "id":"tap12b49ece-b6",
#        "vif_id":"12b49ece-b6c1-4feb-accb-97966038ca4e"
#     }
#  ]
#}


def get_ethernet_addr():
    path = "/sys/class/net/"
    eths = {}
    for file in os.listdir(path): 
        if not file.startswith('eth'): continue
        with open(path+file+"/address") as f: 
            mac = f.readline().strip('\n')
            eths[mac] = file
    return eths

##
##u'networks': {[
#{
#   u'network_id': u'2f71b69f-b5d3-4346-8dcf-ae521a099bef', 
#   u'type': u'ipv4_dhcp', 
#   u'link': u'tap1a15b36e-23', 
#   u'id': u'network0'
# }, 
# {
#   u'network_id': u'84d6578c-1a08-44d9-a256-969e8314b118', 
#   u'type': u'ipv4', 
#   u'netmask': u'255.255.255.0', 
#   u'link': u'tap12b49ece-b6', 
#   u'routes': 
#   [
#      {
#         u'netmask': u'0.0.0.0', 
#         u'network': u'0.0.0.0', 
#         u'gateway': u'192.168.205.1'}
#   ], 
#   u'ip_address': u'1.1.1.1', 
#   u'id': u'network1'
#}]
#u'links': [
#{
#  u'type': u'ovs', 
#  u'vif_id': u'1a15b36e-239a-485a-b455-43ade1e1fee0', 
#  u'ethernet_mac_address': u'fa:16:3e:04:b1:3b', 
#  u'id': u'tap1a15b36e-23', 
#  u'mtu': 1500
#}, 
#{
#  u'type': u'ovs', 
#  u'vif_id': u'12b49ece-b6c1-4feb-accb-97966038ca4e', 
#  u'ethernet_mac_address': u'52:54:00:74:c4:5b', 
#  u'id': u'tap12b49ece-b6', 
#  u'mtu': 1500
#}]}
#
def get_network_data_aws(): 
    debug_print("Get data from %s (Amazon cloud)" % METADATA_URL_AWS)
    # Get data from OpenStack metadata server
    try: 
        response = requests.get(METADATA_URL_AWS, timeout=3)
    except ConnectionError: 
        print >> sys.stderr, "Could not get %s" % METADATA_URL_AWS
        return ''

    data = response.text
    networks = []
    links = []
    for m in data.split('\n'): 
        mac = m.rstrip('/')
        url = '/'.join((METADATA_URL_AWS, mac, 'subnet-ipv4-cidr-block'))
        try: 
            response = requests.get(url, timeout=3)
        except ConnectionError: 
            print >> sys.stderr, "Could not get %s" % url
            return ''
        if response.status_code != RESPONSE_OK: 
            continue  
        cidr = response.text.strip('\n')
        net, mask = cidr_to_netmask(cidr)
        #add network and link entites to local structures 
        netw = { 
            'ip_address' : net,
            'netmask' : mask, 
            'link' : 'link'+mac
        }
        link = {
            'ethernet_mac_address' : mac, 
            'mtu' : 1500, 
            'id' : 'link'+mac
        }
        networks.append(netw)
        links.append(link)

    # add to main dictionary for json.dump
    json_dict = { 'networks' : networks, 'links' : links }
    return json.dumps(json_dict, indent = 3)
    
def get_network_data():
    if force_refresh or not os.path.isfile(cache_file_path): 
        debug_print("Get data from %s" % METADATA_URL)
        # Get data from OpenStack metadata server
        try: 
            response = requests.get(METADATA_URL, timeout=30)
        except Timeout: 
            msg = "Timeout for IP "+sys.argv[1]
            print >> sys.stderr, msg
            syslog.syslog(syslog.LOG_ERR, msg) 
            sys.exit(1)
        except ConnectionError: 
            print >> sys.stderr, "Could not get %s" % METADATA_URL
            sys.exit(1)

        if response.status_code == RESPONSE_OK: 
            #write to cache 
            data = response.text
        else: 
            #maybe not openstack, try AWS 
            data = get_network_data_aws()

        if not data: 
            return None
        # write cache file 
        with open(cache_file_path, 'w') as cache_file:
            cache_file.write(data)
    else: 
        #read from cache
        debug_print("Get data from cache file %s" % cache_file_path)
        try: 
            with open(cache_file_path, 'r') as cache_file: 
                data = cache_file.read()
        except IOError: 
            print >> sys.stderr, "Could not read %s" % cache_file_path
            sys.exit(1)

    try: 
        raw_data = json.loads(data)
    except ValueError as e:
        debug_print("Warnning: %s not in JSON format!" % cache_file_path)
        return zip([],[],[],[])
        
    # Find needed information
    ip_addresses = []
    netmasks = []
    mac_addresses = []
    mtus = []

    #count num. of dhcp networks 
    dhcp_networks = 0
    for n in raw_data['networks']:
        dhcp_networks += 1 if n.get('type') == 'ipv4_dhcp' else 0
    if dhcp_networks > 1: 
        debug_print("There are %d networks with DHCP server enabled, check if this is OK!" % dhcp_networks)

    for i in range (0,len(raw_data['networks'])):
        network = raw_data['networks'][i]
        ip_addr = network.get('ip_address')
        if not ip_addr: 
            debug_print("NIC with MAC %s is on DHCP network, subnet unknown!" % \
                        raw_data['links'][i].get('ethernet_mac_address'))
            if dhcp_networks > 1:
                continue  #get_dhcp_network_data is not adopted to multiple dhcp entries
            dhcp_data = get_dhcp_network_data()
            if dhcp_data:
                ip_addresses.append(dhcp_data[0])
                netmasks.append('255.255.255.255')
                mac_addresses.append(dhcp_data[1])
                mtus.append(dhcp_data[2])
                debug_print("Added dhcp data from leases file: %s, %s, %s" % dhcp_data)
            continue
        #fill IP, netmask & mac_addr
        ip_addresses.append(ip_addr)
        netmasks.append(network.get('netmask'))
        mac_addresses.append(raw_data['links'][i].get('ethernet_mac_address'))
        mtus.append(raw_data['links'][i].get('mtu'))
        
    return zip(mac_addresses, ip_addresses, netmasks, mtus)
    
def get_dhcp_network_data():
    '''reads dhcp parameters (ip, mac, mtu) from leases file'''
    leases_file = "/var/lib/dhcp/dhclient.leases"
    if not os.path.isfile(leases_file): 
        return None
    with open(leases_file, 'r') as leases_data:
        data = leases_data.read()
    #get last 'lease {' line
    idx = data.rfind("lease {")
    if idx < 0: 
        return None # pattern not found
    lease = data[idx:]
    #
    #lease {
    #  interface "eth0";
    #  fixed-address 192.168.224.89;
    #  option subnet-mask 255.255.254.0;
    #  ...
    #  option interface-mtu 1450;
    #  ...
    #}
    #
    fixed_address = ''
    mtu = ''
    mac = ''
    for l in lease.split("\n"): 
        l = l.split()
        if len(l) < 2: continue 
        if "interface" in l:
            interface = l[1].strip('";"')
            mac_file = '/sys/class/net/'+interface+'/address'
            if not os.path.isfile(mac_file): 
                return None
            with open(mac_file, 'r') as d: 
                mac = d.read().strip('\n')
        if "fixed-address" in l: 
            fixed_address = l[1].strip(';')
        if "interface-mtu" in l: # option interface-mtu 1450;
            try:
                mtu = int(l[2].strip(';'))
            except: 
                mtu = 1500
    if fixed_address and mac:
        return (fixed_address, mac, mtu)
    else:
        return None

def ip_to_int(ip):
    try: 
        o = map(int, ip.split('.'))
    except ValueError: 
        o = []
    #check individual bytes
    for b in o: 
        if b<0 or b>255: 
            o = []
            break
    if len(o) != 4: 
        print >> sys.stderr, "%s is not a valid IP" % ip
        sys.exit(3)
    #calculate result 
    res = ((2**24) * o[0]) + ((2**16) * o[1]) + ((2**8) * o[2]) + o[3]
    return res

def get_first_and_last_ip(ip, netmask, mtu): 
    ip_int = ip_to_int(ip)
    netmask_int = ip_to_int(netmask)
    if netmask == '255.255.255.255': 
        first_ip = last_ip = ip_int
    else: 
        first_ip = (ip_int & netmask_int) + 1
        last_ip = (ip_int | (~netmask_int & (2**32 - 1))) - 1  
    return first_ip, last_ip, mtu

def int_to_ip(n):  #convert long int to dotted quad string - debug only
    return socket.inet_ntoa(struct.pack('>L', n))

def cidr_to_netmask(cidr):
    network, net_bits = cidr.split('/')
    host_bits = 32 - int(net_bits)
    netmask = socket.inet_ntoa(struct.pack('!I', (1 << 32) - (1 << host_bits)))
    return network, netmask

def debug_print(s):
    if debug_flag: print >> sys.stderr, s

def usage(name): 
    print >> sys.stderr, "Usage: %s ip_to_check [%s] [%s] [-d]" % (name, NO_CAHCE_FLAG, MTU_FLAG)
    print >> sys.stderr, "          %s - skip reading from cache (fetch data from meta-data server) and refresh cache" % NO_CAHCE_FLAG
    print >> sys.stderr, "          %s - get MTU set on interface" % MTU_FLAG
    print >> sys.stderr, "Example: %s 10.1.1.1" % name
    sys.exit(2)

def main_fun(wanted_ip):
    wanted_ip_int = ip_to_int(wanted_ip) #convert & check input parameter
    network_data = get_network_data() #mac, ip, netmask tuple
    eths = get_ethernet_addr()  #'mac':'eth_name' dictionary (read from system)
    eth_ips = {} # 'eth_name':(first_ip, last_ip) dictionary 
    debug_print("MACs on system: %s" % eths)
    debug_print("Cloud network data: %s" % network_data)
    #convert mac->eth_name and ip,mask -> (first_ip,last_ip)
    for mac, ip, netmask, mtu in network_data:
        if mac in eths: 
            #convert mac->eth
            eth = eths[mac]
            #convert ip,mask -> (first_ip,last_ip)
            eth_ips[eth] = get_first_and_last_ip(ip, netmask, mtu)
            debug_print("%s(%s) IP range: %s - %s (%d-%d), mtu = %s" % \
                        (eth, mac, int_to_ip(eth_ips[eth][0]), int_to_ip(eth_ips[eth][1]), \
                         eth_ips[eth][0], eth_ips[eth][1], mtu)) 

    #now search for matching eth_name 
    for eth in eth_ips: 
        first_ip, last_ip, mtu = eth_ips[eth]
        if wanted_ip_int >= first_ip and wanted_ip_int <= last_ip: 
            if not get_mtu: 
                print eth
            else:
                if mtu: print mtu
            return 0 # OK, found!
    return 1  #NOK, not found!

def main(wanted_ip):
    global force_refresh
    retCode = main_fun(wanted_ip)
    if retCode == 1 and force_refresh == 0: #IP not found, update cache and try again...  
        if config_drive_use == 0:    #MAND add
            force_refresh = 1
            debug_print("%s not found in cached data, updating cache now" % wanted_ip)
            return main_fun(wanted_ip)

if __name__ == '__main__':
    rc = 2
    if (len(sys.argv) == 2):   # $1 IP
        pass   #all done - no force refresh and no debug 
    elif (len(sys.argv) == 3): 
        if (sys.argv[2] == NO_CAHCE_FLAG):  # $1 IP --no-cache
            force_refresh = 1
        elif (sys.argv[2] == MTU_FLAG):  # $1 IP --mtu
            get_mtu = 1
        elif (sys.argv[2] == '-d'):   # $1 IP -d 
            debug_flag = 1
        else: 
            usage(sys.argv[0])
    elif (len(sys.argv) == 4): 
        if (sys.argv[2] == NO_CAHCE_FLAG and sys.argv[3] == '-d'): # $1 IP --no-cache -d 
            debug_flag = 1
            force_refresh = 1
        elif (sys.argv[2] == MTU_FLAG and sys.argv[3] == '-d'): # $1 IP --mtu -d 
            debug_flag = 1
            get_mtu = 1
        elif ((sys.argv[2] == NO_CAHCE_FLAG and sys.argv[3] == MTU_FLAG) or  # $1 IP --no-cache --mtu 
              (sys.argv[2] == MTU_FLAG and sys.argv[3] == NO_CAHCE_FLAG)):   # $1 IP --mtu --no-cache 
            get_mtu = 1
            force_refresh = 1
        else: 
            usage(sys.argv[0])
    elif (len(sys.argv) == 5): 
        if ((sys.argv[2] == NO_CAHCE_FLAG and sys.argv[3] == MTU_FLAG and sys.argv[4] == '-d') or 
            (sys.argv[2] == MTU_FLAG and sys.argv[3] == NO_CAHCE_FLAG and sys.argv[4] == '-d')): 
            get_mtu = 1
            force_refresh = 1
            debug_flag = 1
        else: 
            usege(sys.argv[0])
    else:
        usage(sys.argv[0])

    # MAND add
    # check if config drive exists, if so, mount config drive, copy network json to /tmp/ and clear force_refresh flag
    tmp_file_exists = os.path.isfile(cache_file_path)
    config_drive_dev_exists =  os.path.exists(config_drive_dev)
    if not tmp_file_exists and config_drive_dev_exists:
        os.system("mount "+config_drive_dev+" "+config_drive_mount_point+" > /tmp/mount_out.log 2>/tmp/mount_err.log")
        os.system("cp "+config_drive_mount_network_data+" "+cache_file_path+" 2>/dev/null")
        os.system("umount "+config_drive_dev+" > /tmp/mount_out.log 2>/tmp/mount_err.log")
        force_refresh = 0
        config_drive_use = 1

    rc = main(sys.argv[1])
    sys.exit(rc)

