#!/bin/bash
#
# Example:
#!
#hostname cs2
#!
#system name cs2
#!
#product Call_Server
#!
#system type duplicated
#!
#system unit-id 1 node-id 2
#!
#chassis type OPENSTACK size 1
#!
#domain-name iskratel.si
#!
#interface mgmt
# ip address 192.168.122.29/24
#!
#hsb
# enable
# internal interface ens9
# ip address internal 192.168.200.2/24
# ip address mgmt float 192.168.122.140/24
# hostname cs1
#  ip address internal 192.168.200.1/24
#  ip address mgmt 192.168.122.135/24
#!
#ntp-server primary ntp.iskratel.si
#!
#timezone Europe/Ljubljana
#!
#dns-server primary 192.168.122.1


# Parameters:
CONFTYPE=$1
PRODUCT=$2
HOSTNAME=$3
IPMGMT=$4
DGW=$5
DOMAIN=$6
DNS1=$7
NTP1=$8
TMZN=$9
NODEID=${10}
INTIF=${11}
IPINT=${12}
IPMGMTF=${13}
REM_HOSTNAME=${14}
REM_IPINT=${15}
REM_IPMGMT=${16}

NUM_STDAL_PARAMS=9
NUM_HSB_PARAMS=16

function show_help ()
{
	local rv=${1:-0}
	echo
	if [ ${rv} -ne 0 ]; then
		echo "Check 'help'!"
		exit $rv
	fi
	echo "Create minimal klish configuration - Help:"
	echo "Usage:"
	echo "${0} {stdal|hsb|help} [{PRODUCT} {HOSTNAME} {IPMGMT} {DOMAIN} {DNS1} {NTP1} {TMZN} [{NODEID} {INTIF} {IPINT} {IPMGMTF} {REM_HOSTNAME} {REM_IPINT} {REM_IPMGMT}]]"
	echo
	echo "The first mandatory parameter:"
	echo "{stdal|hsb|help}"
	echo
	echo "If 'stdal' or 'hsb', then additional parameters in exact order are mandatory:"
	echo "{PRODUCT}"
	echo "     i.e. Call_Server"
	echo "{HOSTNMAME}"
	echo "     i.e. cs1"
	echo "{IPMGMT}"
	echo "     i.e. 192.168.122.135/24"
	echo "{DGW}"
	echo "     i.e. 192.168.122.1"
	echo "{DOMAIN}"
	echo "     i.e. iskratel.si"
	echo "{DNS1}"
	echo "     i.e. 192.168.122.1"
	echo "{NTP1}"
	echo "     i.e. ntp.iskratel.si"
	echo "{TMZN}"
	echo "     i.e. Europe/Ljubljana"
	echo
	echo "If 'hsb', then the following additional parameters in exact order are mandatory:"
	echo "{NODEID}"
	echo "     1 | 2"
	echo "{INTIF}"
	echo "     i.e. ens9"
	echo "{IPINT}"
	echo "     i.e. 192.168.200.1/24"
	echo "{IPMGMTF}"
	echo "     i.e. 192.168.122.140/24"
	echo "{REM_HOSTNMAME}"
	echo "     i.e. cs2"
	echo "{REM_IPINT}"
	echo "     i.e. 192.168.200.2/24"
	echo "{REM_IPMGMT}"
	echo "     i.e. 192.168.122.29/24"
	echo
	exit $rv
}

case "${CONFTYPE}" in
help)
	show_help 0
	;;
stdal)
	if [ $# -lt "${NUM_STDAL_PARAMS}" ]; then
		echo "Missing parameters (${#} provided, exactly ${NUM_STDAL_PARAMS} params required)!"
		show_help 1
	fi
	if [ $# -gt "${NUM_STDAL_PARAMS}" ]; then
		echo "Too many parameters (${#} provided, exactly ${NUM_STDAL_PARAMS} params required)!"
		show_help 1
	fi
	echo "Creating minimal 'stdal' klish configuration!"
	;;
hsb)
	if [ $# -lt "${NUM_HSB_PARAMS}" ]; then
		echo "Missing parameters (${#} provided, exactly ${NUM_HSB_PARAMS} params required)!"
		show_help 1
	fi
	if [ $# -gt "${NUM_HSB_PARAMS}" ]; then
		echo "Too many parameters (${#} provided, exactly ${NUM_HSB_PARAMS} params required)!"
		show_help 1
	fi
	echo "Creating minimal 'hsb' klish configuration!"
	;;
*)
	echo "Wrong first parameter!"
	show_help 1
	;;
esac

CLISHCMD="clish -l -x /etc/clish/enable/ -i /etc/clish/enable"

echo -e "hostname ${HOSTNAME}"    | ${CLISHCMD} -w configure-view
echo -e "system name ${HOSTNAME}" | ${CLISHCMD} -w configure-view
echo -e "product ${PRODUCT}"      | ${CLISHCMD} -w configure-view
case "${CONFTYPE}" in
stdal)
	echo -e "system type standalone"     | ${CLISHCMD} -w configure-view
	echo -e "system unit-id 1 node-id 1" | ${CLISHCMD} -w configure-view
	;;
hsb)
	echo -e "system type duplicated"             | ${CLISHCMD} -w configure-view
	echo -e "system unit-id 1 node-id ${NODEID}" | ${CLISHCMD} -w configure-view
	;;
*)
	echo "Wrong first parameter!"
	show_help 1
	;;
esac
#echo -e "chassis type OPENSTACK size 1"        | ${CLISHCMD} -w configure-view
echo -e "chassis type VIRTUAL size 1"          | ${CLISHCMD} -w configure-view
echo -e "domain-name ${DOMAIN}"                | ${CLISHCMD} -w configure-view
echo -e "interface mgmt\nip address ${IPMGMT}" | ${CLISHCMD} -w configure-view
echo -e "ip route mgmt 0.0.0.0 0.0.0.0 ${DGW}" | ${CLISHCMD} -w configure-view
echo -e "ntp-server primary ${NTP1}"           | ${CLISHCMD} -w configure-view
echo -e "timezone ${TMZN}"                     | ${CLISHCMD} -w configure-view
echo -e "dns-server primary ${DNS1}"           | ${CLISHCMD} -w configure-view
case "${CONFTYPE}" in
stdal)
	;;
hsb)
	echo -e "hsb\ninternal interface ${INTIF}"                                | ${CLISHCMD} -w configure-view
	echo -e "hsb\nip address internal ${IPINT}"                               | ${CLISHCMD} -w configure-view
	echo -e "hsb\nip address mgmt float ${IPMGMTF}"                           | ${CLISHCMD} -w configure-view
	echo -e "hsb\nhostname ${REM_HOSTNAME}\nip address internal ${REM_IPINT}" | ${CLISHCMD} -w configure-view
	echo -e "hsb\nhostname ${REM_HOSTNAME}\nip address mgmt ${REM_IPMGMT}"    | ${CLISHCMD} -w configure-view
	echo -e "copy running-config startup-config"                              | ${CLISHCMD} -w enable-view
	echo -e "hsb\nenable"                                                     | ${CLISHCMD} -w configure-view
	;;
*)
	echo "Wrong first parameter!"
	show_help 1
	;;
esac
echo -e "copy running-config startup-config" | ${CLISHCMD} -w enable-view

