#!/bin/bash

echo "`date` [$PPID:$$] $0 $@" >> /var/log/deployment.log

echo "SW package installation and activation ... START" >> /var/log/deployment.log

CONFIG=/opt/si2000/neroot/config.cfg
STARTUP_CONF=/etc/startup-config
SW_INSTALL_COMPLETE=/tmp/sw-install-complete
DB_SYNC_COMPLETE=/tmp/db-sync-complete
FIRST_DEPLOY=/upgrade_root/etc/sysconfig/first_deploy
my_rebuild=""
my_hsb_pair_rebuild="no"

# check if cofnig file exists
if [ -f ${CONFIG} ]
then
	# load file with config data
	source ${CONFIG}

	# check if rebuild is present
        if [ ! -z "$rebuild" ]; then
                my_rebuild="no"
                # split csv
                IFS=',' read -ra HOSTNAME_ARRAY <<< "$rebuild"
                for ONE_HOSTNAME in "${HOSTNAME_ARRAY[@]}"; do
                        if [ "x$ONE_HOSTNAME" = "x${my_hostname}" ]; then
                                my_rebuild="yes"
                                break
                        fi
                done
        fi

	# if rebuil is yes or not set (first deploy), then install sw
	if [ "$my_rebuild" != "no" ]
	then
		# Start SW package installation
		#
		# NOTE: This script has large output so we need to fitler it otherwise
		# ems can crash due to RabbitMQ errror.
		echo "Started NE package installation..." >> /var/log/deployment.log
		echo "Please check /var/log/upgrade-system.log for progress and details." >> /var/log/deployment.log

		# currently only ftp supported
		MN_NAME=`echo ${MN_FQDN_NAME} | cut -d '.' -f1`
		SW_REPO_URL_ADDR="ftp://${MN_NAME}/${NE_RELEASE}"

		#if [ "${USE_HTTPS}" == "no" ]
		#then
		#	SW_REPO_URL_ADDR="ftp://${MN_NAME}/${NE_RELEASE}"
		#else
		#	SW_REPO_URL_ADDR="https://${MN_FQDN_NAME}/mns/ne/${NE_RELEASE}"
		#fi

		#INSTALL_ARGS="--repo-sw-url='${SW_REPO_URL_ADDR}' --nodeid='${NODE_ID}' --datarelease='${DATA_RELEASE}' --housing='${HOUSING}'"
	
		echo "" >> /var/log/deployment.log
		echo "/sbin/element-admin.sh --install --use-api-version=1 --repo-sw-url=${SW_REPO_URL_ADDR} --nodeid=${NODE_ID} --datarelease=${DATA_RELEASE} --housing=${HOUSING}" >> /var/log/deployment.log
		echo "" >> /var/log/deployment.log

                sudo /sbin/element-admin.sh --install --use-api-version=1 --repo-sw-url="${SW_REPO_URL_ADDR}" --nodeid="${NODE_ID}" --datarelease="${DATA_RELEASE}" --housing="${HOUSING}" &> /dev/null

		if [ "$?" != "0" ]
		then
			echo "Error while installing NE SW package!" >> /var/log/deployment.log

			echo "SW package installation failed ... aborting!" >> /var/log/deployment.log

			exit 1
		fi

		echo "NE SW package installation completed." >> /var/log/deployment.log

		touch $SW_INSTALL_COMPLETE

		# copy config.cfg to newly installed partition
		cp $CONFIG /upgrade_root/$CONFIG
		chown neadmin:users /upgrade_root/$CONFIG
		chmod 755 /upgrade_root/$CONFIG

		#cp /etc/init.d/ne_first_deploy.sh /upgrade_root/etc/init.d/
		#ln -s ../init.d/ne_first_deploy.sh /upgrade_root/etc/rc.d/rc3.d/S99ne_first_deploy

		#copy recovered shadow file to upgrade partition(installed package) - in case of VM recovery
#		if [ -f /etc/shadow_rec ]
#		then
#			echo "Copied recovered shadow file to upgrade partition!"
#			cp /etc/shadow_rec /upgrade_root/etc/shadow
#		fi

		# copy ssh client config to upgrade_root
		# this should/will be handeld in installation scripts
	#	cp /etc/ssh/ssh_config /upgrade_root/etc/ssh/ssh_config

	fi #first deploy or my rebuild

	# Execute OpenMN methods only from primary node (unit 1 and element 1).
	unitID=$(/sbin/cfg-getparams.sh mmUnitNumber)
	elementID=$(/sbin/cfg-getparams.sh mmNodeNumber)
	sysType=$(/sbin/cfg-getparams.sh systemType)
	thisNE=$(/sbin/cfg-getparams.sh mmMnHostname11)
	hsbNE=$(/sbin/cfg-getparams.sh mmMnHostname12)

	# only if first deploy - my_rebuild" == "" 
	if [ "${unitID}" == "1" ] && [ "${elementID}" == "1" ] && [ "$my_rebuild" == "" ]
	then
		if [ "${sysType}" != "standalone" ]
		then
			# wait for all elements to finish sw install
			echo "" >> /var/log/deployment.log
			echo -n "Wait for remote NE to finish SW install ..." >> /var/log/deployment.log

			while true
			do
					ne_12=`/sbin/ha-exec-cmd --cmd="ls -l $SW_INSTALL_COMPLETE" --host=$hsbNE --username=root`
					if [ "$ne_12" != "" ]
					then
						break
					else
						echo -n "." >> /var/log/deployment.log
						sleep 5
					fi
			done

			echo " OK" >> /var/log/deployment.log
		fi

		# Set node in use
		echo "Setting node IN USE ... " >> /var/log/deployment.log
		if [ "${USE_HTTPS}" == "no" ]
		then
			curl -i -X PUT \
			--user ${OPENMNS_USER}:${OPENMNS_PASSWORD} \
			--data "{\"nodeid\": \"${NODE_ID}\"}" \
			http://${MN_FQDN_NAME}/mns/openmn/rest/nbsp/sysinstall/nodeDataStatus
		else
			curl -k -i -X PUT \
			--user ${OPENMNS_USER}:${OPENMNS_PASSWORD} \
			--data "{\"nodeid\": \"${NODE_ID}\"}" \
			https://${MN_FQDN_NAME}/mns/openmn/rest/nbsp/sysinstall/nodeDataStatus
		fi

		sleep 1
		echo "OK" >> /var/log/deployment.log
 
		# Set DB sync to ON
#		echo "Activating DB synchronization ... "
#		if [ "${USE_HTTPS}" == "no" ]
#		then
#			curl -i -X PUT \
#			--user ${OPENMNS_USER}:${OPENMNS_PASSWORD} \
#			--data "{\"nodeid\": \"${NODE_ID}\"}" \
#			http://${MN_FQDN_NAME}/mns/openmn/rest/nbsp/sysinstall/dbSyncMode
#		else
#			curl -k -i -X PUT \
#			--user ${OPENMNS_USER}:${OPENMNS_PASSWORD} \
#			--data "{\"nodeid\": \"${NODE_ID}\"}" \
#			https://${MN_FQDN_NAME}/mns/openmn/rest/nbsp/sysinstall/dbSyncMode
#		fi
#		sleep 1
#		echo "OK"
#
#		# Get unsynced data
#		echo "Getting node's unsynchronized data ... "
#		if [ "${USE_HTTPS}" == "no" ]
#		then
#			curl -i -X PUT \
#			--user ${OPENMNS_USER}:${OPENMNS_PASSWORD} \
#			--data "{\"nodeid\": \"${NODE_ID}\"}" \
#			http://${MN_FQDN_NAME}/mns/openmn/rest/nbsp/sysinstall/refresh
#		else
#			curl -k -i -X PUT \
#			--user ${OPENMNS_USER}:${OPENMNS_PASSWORD} \
#			--data "{\"nodeid\": \"${NODE_ID}\"}" \
#			https://${MN_FQDN_NAME}/mns/openmn/rest/nbsp/sysinstall/refresh
#		fi
#
#		sleep 1
#		echo "OK"
	fi  # end if unit 1 element 1 myrebuild "" ; first deploy

	# if first deploy or my rebuild, set active release
	if [ "$my_rebuild" != "no" ]
	then
		if [ "${unitID}" == "1" ] && [ "${elementID}" == "1" ] && [ "$my_rebuild" == "" ]
		then
			# set active 
			echo "Set active release ... " >> /var/log/deployment.log
			if [ "${USE_HTTPS}" == "no" ]
			then
				curl -i -X PUT \
				--user ${OPENMNS_USER}:${OPENMNS_PASSWORD} \
				--data "{\"nodeid\": \"${NODE_ID}\" ,\"neRelease\": \"RESERVED: ${NE_RELEASE}\"}" \
				http://${MN_FQDN_NAME}/mns/openmn/rest/nbsp/sysinstall/activeRelease
			else
				curl -k -i -X PUT \
				--user ${OPENMNS_USER}:${OPENMNS_PASSWORD} \
				--data "{\"nodeid\": \"${NODE_ID}\" ,\"neRelease\": \"RESERVED: ${NE_RELEASE}\"}" \
				https://${MN_FQDN_NAME}/mns/openmn/rest/nbsp/sysinstall/activeRelease
			fi

			sleep 1
			echo "OK" >> /var/log/deployment.log
		else
			# only if my rebuild
			if [ "$my_rebuild" == "yes" ]
			then
				echo -n "Set active release ... " >> /var/log/deployment.log
				/sbin/element-admin.sh --set-active-release --product=RESERVED
				echo "OK" >> /var/log/deployment.log
			fi
		fi
	fi

	# if unit 1, element 1, and first deploy
	if [ "${unitID}" == "1" ] && [ "${elementID}" == "1" ] && [ "$my_rebuild" == "" ]
	then
		# stop solid on all remote NEs
		if [ "${sysType}" == "duplicated" ]
		then
			echo "" >> /var/log/deployment.log
			echo "Stopping solid on ${hsbNE} ... " >> /var/log/deployment.log
			/sbin/ha-exec-cmd --cmd="chroot /upgrade_root /etc/init.d/solidne stop" --host=${hsbNE} --username=root
			echo "OK" >> /var/log/deployment.log
		fi

		# stop solid on this NE
		echo "Stopping solid on ${thisNE} ..." >> /var/log/deployment.log
		chroot /upgrade_root /etc/init.d/solidne stop
		echo "OK" >> /var/log/deployment.log

		# set OP first deploy flag file
		touch $FIRST_DEPLOY

		echo "" >> /var/log/deployment.log
	fi   # end if unit 1 element 1 my_rebuild ""

	# if my rebuild, stop solid and reboot
	if [ "$my_rebuild" == "yes" ]
	then
		thisNE=$(/sbin/cfg-getparams.sh localHostname)

		# stop solid on this NE
		echo "Stopping solid on ${thisNE} ..." >> /var/log/deployment.log
		chroot /upgrade_root /etc/init.d/solidne stop
		echo "OK" >> /var/log/deployment.log

		echo "Rebooting ${thisNE} in 5 sec!" >> /var/log/deployment.log
		#sleep 5
		nohup sh -c 'sleep 5; /sbin/reboot' < /dev/null &> /dev/null &
	else
		if ([ "${unitID}" == "1" ] && [ "${elementID}" == "1" ])
		then
			if [ "$my_rebuild" == "" ]
			then
				if [ "${sysType}" == "duplicated" ]
				then
					echo "Rebooting ${hsbNE} in 15 sec!" >> /var/log/deployment.log
					/sbin/ha-exec-cmd --cmd="nohup sh -c 'sleep 15; /sbin/reboot' < /dev/null &> /dev/null &" --host=${hsbNE} --username=root
				fi

				echo "Rebooting ${thisNE} in 5 sec!" >> /var/log/deployment.log
				nohup sh -c 'sleep 5; /sbin/reboot' < /dev/null &> /dev/null &
			fi
		fi
	fi
else
	echo "" >> /var/log/deployment.log
	echo "ERROR: config.cfg does not exist. Can not configure system. ABORTING!" >> /var/log/deployment.log
	echo "" >> /var/log/deployment.log

	exit 1
fi

echo "SW package installation and activation ... DONE" >> /var/log/deployment.log

exit 0

