#!/bin/bash

echo "`date` [$PPID:$$] $0 $@" >> /var/log/deployment.log
echo "Prepare CLISH basic configuration - startup-config ... START" >> /var/log/deployment.log

STARTUP_CONF=startup-config
STARTUP_CONF_DEF=/etc/startup-config.def
CONFIG=/opt/si2000/neroot/config.cfg
my_rebuild=""

# get my hostname from startup-config
my_hostname=`/sbin/cfg-getparams.sh localHostname`

function cidr2mask() {

#if [ "$1" -lt "1" ] || [ "$1" -gt "32" ]
if [ "$1" -gt "32" ]
then
        echo ""
        return 1
fi

if [ "$1" -eq "0" ]
then
	echo "0.0.0.0"
	return 0
fi

value=$(($1 / 8))
ostanek=$(($1 % 8))

#echo $value
#echo $ostanek

ostanek_long=$(( ( 255 << ( 8 - $ostanek ) ) & 255 ))

#echo $ostanek_long

if [ "$value" == "0" ]
then
        echo "$ostanek_long.0.0.0"
fi

if [ "$value" == "1" ]
then
        echo "255.$ostanek_long.0.0"
fi

if [ "$value" == "2" ]
then
        echo "255.255.$ostanek_long.0"
fi

if [ "$value" == "3" ]
then
        echo "255.255.255.$ostanek_long"
fi

if [ "$value" == "4" ]
then
        echo "255.255.255.255"
fi

}

# check if rebuild is present
if [ ! -z "$rebuild" ]
then
    # New way of handling rebuild flag - it contains comma separated values now
    # Backward compatible, it handles single value also
    #
    # NOTE: Only existance and comparison to own hostname is impemented in new way
    #       The logic needed in case of different combinations for rebuild is yet to be developed
    #
    my_rebuild="no"
    # split csv
    IFS=',' read -ra HOSTNAME_ARRAY <<< "$rebuild"
    for ONE_HOSTNAME in "${HOSTNAME_ARRAY[@]}"; do
        if [ "x${ONE_HOSTNAME}" == "x${my_hostname}" ]
        then
            my_rebuild="yes"
            break
        fi
    done
fi

# exit only if not my rebuild; if my rebuild is 'yes' or 'empty' (first deploy), then continue
if [ "$my_rebuild" == "no" ]
then
	echo "It looks like re-deploy is going on, but not mine - nothing to do!" >> /var/log/deployment.log
	echo "Prepare CLISH basic configuration - startup-config ... END" >> /var/log/deployment.log
	exit 0
fi

#echo -n "Handle SSL cert ... "
#use_https="no"
##handle MNS SSL cert if it exists and not empty
#if [ -s ${OB_SCRIPTS_DIR}/MNS_CERTIFICATE ]
#then
#        MN_NAME=`echo ${MN_FQDN_NAME} | cut -d '.' -f1`
#        mkdir -p /opt/si2000/mnroot/ssl
#        mkdir -p /opt/si2000/mnroot/ssl/certs
#
#        cp ${OB_SCRIPTS_DIR}/MNS_CERTIFICATE /opt/si2000/mnroot/ssl/certs/mns-${MN_NAME}.crt
#        #cp ${OB_SCRIPTS_DIR}/MNS_CERTIFICATE /etc/ssl/certs/mns-${MN_NAME}.crt
#
#        #make SSL cert trustable
#        crt_hash=`openssl x509 -noout -hash -in /opt/si2000/mnroot/ssl/certs/mns-${MN_NAME}.crt`
#        ln -s /opt/si2000/mnroot/ssl/certs/mns-${MN_NAME}.crt /etc/ssl/certs/${crt_hash}.0
#
#        use_https="yes"
#fi
#echo "OK"

if [ -f ${CONFIG} ]
then
	source ${CONFIG}
else
	echo "Missing config.cfg - aborting!" >> /var/log/deployment.log
	echo "Prepare CLISH basic configuration - startup-config ... END" >> /var/log/deployment.log
	exit 1
fi

if [ "$SYSTEM_TYPE" == "standalone" ]
then
	unit_id="1"
        element_id="1"
else
	if [ "$HOSTNAME_11" == "$my_hostname" ]
	then
		unit_id="1"
		element_id="1"
	else
	        unit_id="1"
	        element_id="2"
	fi
fi

#prepare startup-config
if [ "$SYSTEM_TYPE" == "standalone" ]
then
	# generate startup-config
	cat > $STARTUP_CONF <<EOF
!
hostname $HOSTNAME_11
EOF
	chass_type=`echo "$CHASSIS_TYPE" | cut -d '_' -f1`
	chass_size=`echo "$CHASSIS_TYPE" | cut -d '_' -f2`

	cat >> $STARTUP_CONF <<EOF
!
system name $SYSTEM_NAME
!
product $PRODUCT_TYPE
!
system type $SYSTEM_TYPE
!
system unit-id $unit_id node-id $element_id
!
chassis type $chass_type size $chass_size
!
domain-name $DOMAIN_NAME
EOF

	# check if default startup-config - CE only
	if [ -f $STARTUP_CONF_DEF ]
	then
		cat $STARTUP_CONF_DEF >> $STARTUP_CONF

		cat >> $STARTUP_CONF <<EOF
interface mgmt
 ip address $MGMT_IP_ADDR_11
EOF
	else	
		cat >> $STARTUP_CONF <<EOF
!
interface mgmt
 ip address $MGMT_IP_ADDR_11
EOF
	fi

	if [ "$MGMT_ROUTE_GW" != "" ]
	then
		# calculate net mask - long
		subnet=`echo $MGMT_ROUTE_IP | cut -d '/' -f1`
		bit_mask=`echo $MGMT_ROUTE_IP | cut -d '/' -f2`
		net_mask_long=`cidr2mask $bit_mask`

		if [ "$net_mask_long" != "" ]
		then
			cat >> $STARTUP_CONF <<EOF
!
ip route mgmt $subnet $net_mask_long $MGMT_ROUTE_GW
EOF
		fi
	fi

	if [ "$NTP_PRIMARY" != "" ]
        then
                cat >> $STARTUP_CONF <<EOF
!
ntp-server primary $NTP_PRIMARY
EOF
	fi

	if [ "$MN_FQDN_NAME" != "" ] && [ "$MN_NODE_IP_ADDR" != "" ]
        then
                cat >> $STARTUP_CONF <<EOF
!
MN-server $MN_FQDN_NAME $MN_NODE_IP_ADDR
EOF
	fi

	if [ "$TIME_ZONE" != "" ]
	then
		if [ -f /usr/share/zoneinfo/$TIME_ZONE ]
		then
			cat >> $STARTUP_CONF <<EOF
!
timezone $TIME_ZONE
EOF
		fi
        fi

	if [ "$DNS_PRIMARY" != "" ]
        then
                cat >> $STARTUP_CONF <<EOF
!
dns-server primary $DNS_PRIMARY
EOF
	fi
fi

if [ "$SYSTEM_TYPE" == "duplicated" ]
then
	if [ "$unit_id" == "1" ] && [ "$element_id" == "1" ]
	then
		# generate startup-config
		cat > $STARTUP_CONF <<EOF
!
hostname $HOSTNAME_11
EOF
        	chass_type=`echo "$CHASSIS_TYPE" | cut -d '_' -f1`
        	chass_size=`echo "$CHASSIS_TYPE" | cut -d '_' -f2`

        	cat >> $STARTUP_CONF <<EOF
!
system name $SYSTEM_NAME
!
product $PRODUCT_TYPE
!
system type $SYSTEM_TYPE
!
system unit-id $unit_id node-id $element_id
!
chassis type $chass_type size $chass_size
!
domain-name $DOMAIN_NAME
EOF

	        # check if default startup-config - CE only
        	if [ -f $STARTUP_CONF_DEF ]
        	then
                	cat $STARTUP_CONF_DEF >> $STARTUP_CONF

                	cat >> $STARTUP_CONF <<EOF
interface mgmt
 ip address $MGMT_IP_ADDR_11
EOF
        	else
                	cat >> $STARTUP_CONF <<EOF
!
interface mgmt
 ip address $MGMT_IP_ADDR_11
EOF
        	fi

		if [ "$MGMT_ROUTE_GW" != "" ]
		then
                        # calculate net mask - long
                        subnet=`echo $MGMT_ROUTE_IP | cut -d '/' -f1`
                        bit_mask=`echo $MGMT_ROUTE_IP | cut -d '/' -f2`
                        net_mask_long=`cidr2mask $bit_mask`

			cat >> $STARTUP_CONF <<EOF
!
ip route mgmt $subnet $net_mask_long $MGMT_ROUTE_GW
EOF
		fi

		cat >> $STARTUP_CONF <<EOF
!
hsb
 enable
 ip address mgmt float $MGMT_IP_ADDR_FLOAT
 hostname $HOSTNAME_12
  ip address mgmt $MGMT_IP_ADDR_12
EOF

		if [ "$NTP_PRIMARY" != "" ]
                then
                        cat >> $STARTUP_CONF <<EOF
!
ntp-server primary $NTP_PRIMARY
EOF
		fi

		if [ "$MN_FQDN_NAME" != "" ] && [ "$MN_NODE_IP_ADDR" != "" ]
                then
                        cat >> $STARTUP_CONF <<EOF
!
MN-server $MN_FQDN_NAME $MN_NODE_IP_ADDR
EOF
		fi

                if [ "$TIME_ZONE" != "" ]
                then
                        if [ -f /usr/share/zoneinfo/$TIME_ZONE ]
                        then
                        cat >> $STARTUP_CONF <<EOF
!
timezone $TIME_ZONE
EOF
                        fi
                fi

		if [ "$DNS_PRIMARY" != "" ]
                then
                        cat >> $STARTUP_CONF <<EOF
!
dns-server primary $DNS_PRIMARY
EOF
		fi
	fi

	if [ "$unit_id" == "1" ] && [ "$element_id" == "2" ]
	then
		# generate startup-config
		cat > $STARTUP_CONF <<EOF
!
hostname $HOSTNAME_12
EOF

        chass_type=`echo "$CHASSIS_TYPE" | cut -d '_' -f1`
        chass_size=`echo "$CHASSIS_TYPE" | cut -d '_' -f2`

        cat >> $STARTUP_CONF <<EOF
!
system name $SYSTEM_NAME
!
product $PRODUCT_TYPE
!
system type $SYSTEM_TYPE
!
system unit-id $unit_id node-id $element_id
!
chassis type $chass_type size $chass_size
!
domain-name $DOMAIN_NAME
EOF

                # check if default startup-config - CE only
                if [ -f $STARTUP_CONF_DEF ]
                then
                        cat $STARTUP_CONF_DEF >> $STARTUP_CONF

                        cat >> $STARTUP_CONF <<EOF
interface mgmt
 ip address $MGMT_IP_ADDR_12
EOF
                else
                        cat >> $STARTUP_CONF <<EOF
!
interface mgmt
 ip address $MGMT_IP_ADDR_12
EOF
                fi

		if [ "$MGMT_ROUTE_GW" != "" ]
		then
                        # calculate net mask - long
                        subnet=`echo $MGMT_ROUTE_IP | cut -d '/' -f1`
                        bit_mask=`echo $MGMT_ROUTE_IP | cut -d '/' -f2`
                        net_mask_long=`cidr2mask $bit_mask`

			cat >> $STARTUP_CONF <<EOF
!
ip route mgmt $subnet $net_mask_long $MGMT_ROUTE_GW
EOF
		fi

		cat >> $STARTUP_CONF <<EOF
!
hsb
 enable
 ip address mgmt float $MGMT_IP_ADDR_FLOAT
 hostname $HOSTNAME_11
  ip address mgmt $MGMT_IP_ADDR_11
EOF

		if [ "$NTP_PRIMARY" != "" ]
                then
                        cat >> $STARTUP_CONF <<EOF
!
ntp-server primary $NTP_PRIMARY
EOF
		fi

		if [ "$MN_FQDN_NAME" != "" ] && [ "$MN_NODE_IP_ADDR" != "" ]
                then
                        cat >> $STARTUP_CONF <<EOF
!
MN-server $MN_FQDN_NAME $MN_NODE_IP_ADDR
EOF
		fi

                if [ "$TIME_ZONE" != "" ]
                then
                        if [ -f /usr/share/zoneinfo/$TIME_ZONE ]
                        then
                        cat >> $STARTUP_CONF <<EOF
!
timezone $TIME_ZONE
EOF
                        fi
                fi

		if [ "$DNS_PRIMARY" != "" ]
                then
                        cat >> $STARTUP_CONF <<EOF
!
dns-server primary $DNS_PRIMARY
EOF
		fi

	fi
fi

# add internet conn and ntp srv location
cat >> $STARTUP_CONF <<EOF
!
internet-connection available
!
ntp-server-location remote
EOF

cat $STARTUP_CONF >> /var/log/deployment.log

echo "Prepare CLISH basic configuration - startup-config ... END" >> /var/log/deployment.log

exit 0
