#!/bin/bash
###########################################################################
#                                                                         #
#                                                                         #
#              Copyright (c) 2008 IskraTEL                                #
#                                                                         #
#                                                                         #
#                                                                         #
#   Name        : trapdest.sh                                             #
#                                                                         #
#   Description : Script for managing trap destinations                   #
#                                                                         #
#   Date        : Oct 2012                                                #
#                                                                         #
#   Author      : Janez Robic                                             #
#                                                                         #
#   Translation : * None                                                  #
#                                                                         #
#   Remarks     : * None                                                  #
#                                                                         #
#   Revisions   : * None                                                  #
#                                                                         #
###########################################################################

#commands
LOGGER="/usr/bin/logger -p user.alert -t traps.sh --"
NIESUBAG_DAEMON=/etc/init.d/niesubag 

#config files
NIESUBFILE=/opt/iskratel/bin/niesubag.ini
NIESUBFILE_1=/opt/iskratel/bin/niesubag.ini_1

#constants
DEFAULT_TRAP_PORT=162
DEFAULT_TRAP_COMM="SNMP_trap"

TMPMAN=/tmp/manv3.txt
#delete TMPMAN (v3) file on exit
trap "rm -f $TMPMAN" EXIT

write_niesub_file ()
{
   if [ -s $NIESUBFILE_1 ]; then
      mv $NIESUBFILE_1 $NIESUBFILE
   else
      echo "Unable to write $NIESUBFILE !"  | $LOGGER
   fi
}

count_manager_number ()
{
   MANNMBR=`grep "\[manager.*\]" $NIESUBFILE |grep -v '^[;#]' | wc -l` 
   test -z $MANNMBR && MANNMBR=0
}


recalculate_manager_number ()
{
   MANAMES=`grep "manager" $NIESUBFILE | awk -F "[" '{print $2}'`
   J=1
   for CHANGE in $MANAMES; do
      sed "s/$CHANGE/manager$J]/g" $NIESUBFILE >> $NIESUBFILE_1
      write_niesub_file
      J=$((J+1))
   done
}

generate_manager_entry()
{
   get_port 
   get_community
   #remove all commented lines, but leave '#Service hardening' comments alone... 
   sed '/#Service hardening/ n; /^[;#]/d' $NIESUBFILE > $NIESUBFILE_1
   write_niesub_file
   
   count_manager_number
   #insert blank line, if not there
   if ! tail -n 1 $NIESUBFILE|grep "^$" >/dev/null; then
      echo "" >> $NIESUBFILE
   fi
   echo "[manager$[$MANNMBR+1]]" >> $NIESUBFILE
   if [ "$V3" = "" ]; then 
      echo "ipaddr = $IP" >> $NIESUBFILE
      echo "protocol = udp" >> $NIESUBFILE
      echo "port = $PORT" >> $NIESUBFILE
      echo "community = $COMM" >> $NIESUBFILE
   else
      cat $TMPMAN >> $NIESUBFILE
   fi
   echo "" >> $NIESUBFILE
}

delete_manager_entry()
{
   START_LINE=`sed -n "/ipaddr = ${IP}$/=" $NIESUBFILE`
   #find start of this [managerX] section
   START_LINE=$(sed -n "1,$START_LINE p" $NIESUBFILE|cat -n|grep '\[manager'|tail -n1|awk '{print $1}')
   #find start of the next [managerX] section
   END_LINE=`sed -n "$((START_LINE+1)),/\[.*\]/=" $NIESUBFILE|tail -n 1`
   #check if END_LINE is [managerX]
   [ "$(sed -n "$END_LINE p" $NIESUBFILE|grep '\[.*\]')" != "" ] && END_LINE=$((END_LINE-1))
   #remove manager section and trailing blank line (if exists)
   sed -e "$START_LINE,$END_LINE d" -e '${/^$/d;}' $NIESUBFILE > $NIESUBFILE_1
   count_manager_number
   if [ $MANNMBR -eq 1 ]; then 
      #before deleteing last manager, write dummy port number & community name
      get_port
      get_community
      echo "#port = $PORT" >> $NIESUBFILE_1
      echo "#community = $COMM" >> $NIESUBFILE_1
   fi
   write_niesub_file
   recalculate_manager_number
}

get_port()
{
   PORT="`grep 'port = ' $NIESUBFILE|grep -v agentxsocketport|head -n 1|cut -d '=' -f 2|sed 's/ *//g'`"
   test -z "$PORT" && PORT=$DEFAULT_TRAP_PORT
}

get_community()
{
   COMM="`grep 'community = ' $NIESUBFILE|head -n 1|cut -d '=' -f 2|sed 's/ *//g'`"
   test -z "$COMM" && COMM=$DEFAULT_TRAP_COMM
}

get_notification_type()
{
   case $(sed -n '/\[snmp\]/,/\[.*\]/ {/^[ \t]*notification_type/ p}' $NIESUBFILE|awk -F= '{print $2}'|tr -d ' ') in 
      1) echo "trap";;
      2) echo "inform";; 
      *) ;;  #none
   esac
}

update_port_number()
{
  count_manager_number
  if [ $MANNMBR -eq 0 ]; then 
     if [ "`grep '#port = ' $NIESUBFILE`" = "" ]; then
        #insert dummy port entry
        echo "#port = $PORT" >> $NIESUBFILE
     else
        #update dummy port
        sed "s/#port = .*$/#port = $PORT/" $NIESUBFILE > $NIESUBFILE_1
        write_niesub_file
     fi
     #no need to restart niesubag
     exit 0
  else #managers already in file, rewrite their port (and remove dummy port)
     sed -e "s/^port = .*$/port = $PORT/" -e '/#port = /d' $NIESUBFILE > $NIESUBFILE_1
     write_niesub_file
  fi   
}

update_trap_community()
{
  count_manager_number
  if [ $MANNMBR -eq 0 ]; then 
     if [ "`grep '#community = ' $NIESUBFILE`" = "" ]; then
        #insert dummy community name
        echo "#community = $COMM" >> $NIESUBFILE
     else
        #update dummy community
        sed "s/#community = .*$/#community = $COMM/" $NIESUBFILE > $NIESUBFILE_1
        write_niesub_file
     fi
     #no need to restart niesubag
     exit 0
  else #managers already in file, rewrite their community (and remove dummy community)
     sed -e "s/^community = .*$/community = $COMM/" -e '/#community = /d' $NIESUBFILE > $NIESUBFILE_1
     write_niesub_file
  fi   
}

update_notif_type()
{
   case $NOTIF_TYPE in
      trap)   NOTIF_TYPE_NUM=1;;
      none|inform) NOTIF_TYPE_NUM=2;;  #none == default == inform
      delete) #delete notification_type from [snmp] section (not used, just for example how to delete entry)
         sed  '/\[snmp\]/,/\[.*\]/ {/notification_type/ d}' $NIESUBFILE > $NIESUBFILE_1
         if diff  $NIESUBFILE $NIESUBFILE_1 >/dev/null; then
            #no change, no need to reload 
            rm -f $NIESUBFILE_1
            exit
         else
            mv $NIESUBFILE_1 $NIESUBFILE 
            return
         fi
         ;;
   esac
   #check if notification_type exist in [snmp] section
   if [ "$(sed -n '/\[snmp\]/,/\[.*\]/ {/^[ \t]*notification_type/ p}' $NIESUBFILE)" = "" ]; then 
      #add notification_type (to [snmp] section)
      sed -i "/\[snmp\]/a notification_type = $NOTIF_TYPE_NUM" $NIESUBFILE
      return   #reload needed
   fi
   #else: notification_type already exist, correct it (in [snmp] section)
   sed  "/\[snmp\]/,/\[.*\]/ {s/^[ \t]*notification_type[ \t]*=[ \t]*[12].*/notification_type = $NOTIF_TYPE_NUM/}" $NIESUBFILE > $NIESUBFILE_1
   if diff  $NIESUBFILE $NIESUBFILE_1 >/dev/null; then
      #no change, no need to reload 
      rm -f $NIESUBFILE_1
      exit
   else
      mv $NIESUBFILE_1 $NIESUBFILE 
   fi
}

update_niesubag()
{
   case $ACTION in
      insert)
         [ -z $IP ] && usage "Empty trap destination not allowed" 
         if grep "ipaddr = $IP$" $NIESUBFILE >/dev/null; then
            echo "Trap destination $IP already exists" >&2
            exit 1
         fi
         generate_manager_entry;; 
      delete)
         [ -z $IP ] && usage "Empty trap destination not allowed" 
         if ! grep "ipaddr = $IP$" $NIESUBFILE >/dev/null; then
            echo "Trap destination $IP does not exists" >&2
            exit 1
         fi
         delete_manager_entry;;
      port)
         update_port_number;;
      trap_community)
         [ -z $COMM ] && usage "Empty community name not allowed" 
         update_trap_community;;
      type) 
         case $NOTIF_TYPE in 
            inform|trap|none|delete) ;; #pass (delete is un-documented option)
            *) usage "Wrong notification type ($NOTIF_TYPE)";;
         esac
         update_notif_type;;
      *)
         echo "Wrong action: $ACTION" >&2
         exit 2;;
   esac
   #reload is faster than restart - use it if possible
   OPERATION=reload
   [ "`$NIESUBAG_DAEMON|grep reload`" = "" ] && OPERATION=restart
   $NIESUBAG_DAEMON $OPERATION  
}

show_niesubag()
{
   get_port
   get_community
   echo "port=$PORT"
   echo "community=$COMM"
   echo "notification_type=$(get_notification_type)"
   #print manager entries
   i=1
   #grep "ipaddr = " $NIESUBFILE > /tmp/niesubagMans
   grep "ipaddr = " $NIESUBFILE|grep -v '^[;#]' > /tmp/niesubagMans
   while read m; do
      m="`echo $m|cut -d '=' -f 2|sed 's/ *//g'`"
      echo "manager$i=$m"
      i=$((i+1))
   done < /tmp/niesubagMans
   rm -f /tmp/niesubagMans
   echo "all_managers=$((i-1))"
}

usage()
{
   prog=`basename $0`
   [ "$1" != "" ] && echo $1 >&2 && echo >&2
   echo "Usage: $prog --insert|-i <IP>" >&2
   echo "       $prog --delete|-d <IP>" >&2
   echo "       $prog --exist|-e <IP>" >&2
   echo "       $prog --community|-c <trap_community>" >&2
   echo "       $prog --port|-p <port>" >&2
   echo "       $prog --type|-t <inform|trap|none>" >&2
   echo "       $prog --show|-s" >&2
   echo "       $prog --help|-h" >&2
   echo "v3 usage: $prog --v3|-3 --insert|-i <IP> <user> [-a MD5|SHA authPasswd] [-p DES|AES privPasswd] [-t trap|inform]" >&2
   exit 1
}

parseV3params()
{
   [ "$1" != "--insert" -a "$1" != "-i" ] && usage "Wrong action ($1)"
   ACTION="insert"
   IP=$2
   SEC_USER=$3
   shift 3

   echo "version = 3" > $TMPMAN
   echo "ipaddr = $IP" >> $TMPMAN
   echo "protocol = udp" >> $TMPMAN
   echo "secname = $SEC_USER" >> $TMPMAN
   AUTH_PROT=""; AUTH_PASSWD=""; AUTH_LEVEL="noauth"; AUTH_VALID=yes
   PRIV_PROT=""; PRIV_PASSWD="": PRIV_LEVEL="nopriv"; PRIV_VALID=yes
   NOTIF_TYPE=""; TYPE_VALID=yes
   while [ $# -gt 0 ]; do 
      case $1 in 
         -a)  #auth protocol+password
            shift
            case $1 in 
               MD5|md5) AUTH_PROT=md5;; 
               SHA|sha) AUTH_PROT=sha;; 
               none) AUTH_VALID=no;;
               *) usage "Wrong authentication protocol ($1)";;
            esac
            if [ "$AUTH_VALID" = "yes" ]; then 
               [ "$(echo $2|wc -c)" -le 8 ] && usage "Authentication password too short (must be at least 8 chars)"
               AUTH_PASSWD=$2
               echo "secauthproto = $AUTH_PROT" >> $TMPMAN
               echo "secauthpassword = $AUTH_PASSWD" >> $TMPMAN
               AUTH_LEVEL="auth"
            fi
            shift 2
            ;;
          -p) #privacy protocol+password  
            shift
            case $1 in 
               DES|des) PRIV_PROT=des;; 
               AES|aes) PRIV_PROT=aes;; 
               none) PRIV_VALID=no;;
               *) usage "Wrong privacy protocol ($1)";;
            esac
            if [ "$PRIV_VALID" = "yes" ]; then 
               [ "$(echo $2|wc -c)" -le 8 ] && usage "Privacy password too short (must be at least 8 chars)"
               PRIV_PASSWD=$2
               echo "secprivproto = $PRIV_PROT" >> $TMPMAN
               echo "secprivpassword = $PRIV_PASSWD" >> $TMPMAN
               PRIV_LEVEL="priv"
            fi
            shift 2
            ;;
         -t) #type (inform|trap)
            shift
            case $1 in 
               trap|TRAP) NOTIF_TYPE=1;;
               inform|INFORM) NOTIF_TYPE=2;;
               none) TYPE_VALID=no;;
               *) usage "Wrong notification type ($1)";;
            esac
            shift 
            [ "$TYPE_VALID" = "yes" ] && echo "notification_type = $NOTIF_TYPE" >> $TMPMAN
            ;;
         *) 
            usage "Wrong arg ($1)"
            ;;
      esac
   done 
   SEC_LEVEL=${AUTH_LEVEL}${PRIV_LEVEL}
   [ "$AUTH_LEVEL" = "noauth" -a "$PRIV_LEVEL" = "nopriv" ] && SEC_LEVEL="noauth"
   echo "seclevel = $SEC_LEVEL" >> $TMPMAN
}

#main script
ACTION=""; IP="" 
COMM=""; PORT=""; 
V3=""

#parse input parameters
if [ "$1" = "--v3" -o "$1" = "-3" ]; then 
   case $# in 
      4|6|7|9|10|12) : ;;  #pass
      *) usage "Wrong number of parameters ($#)";;
   esac
else
   [ $# -ne 1 -a $# -ne 2 ] && usage "Wrong number of parameters ($#)"
fi
case $1 in
   --insert|-i) 
      ACTION="insert"
      IP=$2;;
   --delete|-d) 
      ACTION="delete"
      IP=$2;;
   --exist|-e) 
      IP=$2
      [ "$IP" = "" ] && usage "Empty trap destination not allowed" 
      show_niesubag | grep -w "${IP//\./\\.}"
      exit $?;;
   --community|-c) 
      ACTION="trap_community"
      COMM=$2;;
   --port|-p) 
      ACTION="port"
      PORT=$2;;
   --type|-t) 
      ACTION="type"
      NOTIF_TYPE=$2;;
   --v3|-3) 
      V3=v3
      shift
      parseV3params $@;;
   --show|-s) 
      show_niesubag
      exit 0;;
   --help|-h) 
      usage;;
   *) usage "Wrong action - $1!";;
esac
update_niesubag 

exit 0

